Class: Seam::Resources::AccessCode::DormakabaOracodeMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessCode::DormakabaOracodeMetadata
- Defined in:
- lib/seam/resources/access_code.rb
Instance Attribute Summary collapse
-
#is_cancellable ⇒ Boolean?
Indicates whether the stay can be cancelled via the Dormakaba Oracode API.
-
#is_early_checkin_able ⇒ Boolean?
Indicates whether early check-in is available for this stay.
-
#is_extendable ⇒ Boolean?
Indicates whether the stay can be extended via the Dormakaba Oracode API.
-
#is_overridable ⇒ Boolean?
Indicates whether the access code can be overridden.
-
#site_name ⇒ String?
Dormakaba Oracode site name associated with this access code.
-
#stay_id ⇒ Float?
Dormakaba Oracode stay ID associated with this access code.
-
#user_level_id ⇒ String?
Dormakaba Oracode user level ID associated with this access code.
-
#user_level_name ⇒ String?
Dormakaba Oracode user level name associated with this access code.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#is_cancellable ⇒ Boolean?
Indicates whether the stay can be cancelled via the Dormakaba Oracode API.
18 19 20 |
# File 'lib/seam/resources/access_code.rb', line 18 def is_cancellable @is_cancellable end |
#is_early_checkin_able ⇒ Boolean?
Indicates whether early check-in is available for this stay.
21 22 23 |
# File 'lib/seam/resources/access_code.rb', line 21 def is_early_checkin_able @is_early_checkin_able end |
#is_extendable ⇒ Boolean?
Indicates whether the stay can be extended via the Dormakaba Oracode API.
24 25 26 |
# File 'lib/seam/resources/access_code.rb', line 24 def is_extendable @is_extendable end |
#is_overridable ⇒ Boolean?
Indicates whether the access code can be overridden. When false, the maximum number of overrides has been reached.
27 28 29 |
# File 'lib/seam/resources/access_code.rb', line 27 def is_overridable @is_overridable end |
#site_name ⇒ String?
Dormakaba Oracode site name associated with this access code.
30 31 32 |
# File 'lib/seam/resources/access_code.rb', line 30 def site_name @site_name end |
#stay_id ⇒ Float?
Dormakaba Oracode stay ID associated with this access code.
33 34 35 |
# File 'lib/seam/resources/access_code.rb', line 33 def stay_id @stay_id end |
#user_level_id ⇒ String?
Dormakaba Oracode user level ID associated with this access code.
36 37 38 |
# File 'lib/seam/resources/access_code.rb', line 36 def user_level_id @user_level_id end |
#user_level_name ⇒ String?
Dormakaba Oracode user level name associated with this access code.
39 40 41 |
# File 'lib/seam/resources/access_code.rb', line 39 def user_level_name @user_level_name end |