Class: Seam::Resources::AccessCode::Errors::AccessCodeInactive
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::AccessCodeInactive
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the access code is disabled or inactive on the device. The code exists but will not grant access until re-enabled.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
access_code_inactive
185 186 187 |
# File 'lib/seam/resources/access_code.rb', line 185 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
188 189 190 |
# File 'lib/seam/resources/access_code.rb', line 188 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
191 192 193 |
# File 'lib/seam/resources/access_code.rb', line 191 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
194 |
# File 'lib/seam/resources/access_code.rb', line 194 date_accessor :created_at |