Class: Seam::Resources::AccessCode::Errors::AccountDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::AccountDisconnected
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the account is disconnected.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
-
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
account_disconnected
203 204 205 |
# File 'lib/seam/resources/access_code.rb', line 203 def error_code @error_code end |
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
206 207 208 |
# File 'lib/seam/resources/access_code.rb', line 206 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
209 210 211 |
# File 'lib/seam/resources/access_code.rb', line 209 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
212 213 214 |
# File 'lib/seam/resources/access_code.rb', line 212 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
215 |
# File 'lib/seam/resources/access_code.rb', line 215 date_accessor :created_at |