Class: Seam::Resources::AccessCode::Errors::AugustLockNotAuthorized

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Indicates that the user is not authorized to use the August lock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • august_lock_not_authorized

Returns:

  • (String)


377
378
379
# File 'lib/seam/resources/access_code.rb', line 377

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


380
381
382
# File 'lib/seam/resources/access_code.rb', line 380

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


383
384
385
# File 'lib/seam/resources/access_code.rb', line 383

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


386
# File 'lib/seam/resources/access_code.rb', line 386

date_accessor :created_at