Class: Seam::Resources::AccessCode::Errors::AuxiliaryHeatRunning
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::AuxiliaryHeatRunning
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the auxiliary heat is running.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
auxiliary_heat_running
413 414 415 |
# File 'lib/seam/resources/access_code.rb', line 413 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
416 417 418 |
# File 'lib/seam/resources/access_code.rb', line 416 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
419 420 421 |
# File 'lib/seam/resources/access_code.rb', line 419 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
422 |
# File 'lib/seam/resources/access_code.rb', line 422 date_accessor :created_at |