Class: Seam::Resources::AccessCode::Errors::BridgeDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::BridgeDisconnected
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the Seam API cannot communicate with Seam Bridge, for example, if the Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
bridge_disconnected
449 450 451 |
# File 'lib/seam/resources/access_code.rb', line 449 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
452 453 454 |
# File 'lib/seam/resources/access_code.rb', line 452 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
455 456 457 |
# File 'lib/seam/resources/access_code.rb', line 455 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
458 459 460 |
# File 'lib/seam/resources/access_code.rb', line 458 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
461 |
# File 'lib/seam/resources/access_code.rb', line 461 date_accessor :created_at |