Class: Seam::Resources::AccessCode::Errors::CodeConstraintsViolated

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

The code cannot be set on the device because it violates the device's code constraints (for example, its length, digits, or a too-simple value). The code will not be retried until you change it. See the device's code_constraints and supported_code_lengths.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • code_constraints_violated

Returns:

  • (String)


203
204
205
# File 'lib/seam/resources/access_code.rb', line 203

def error_code
  @error_code
end

#is_access_code_errorTrueClass

Indicates that this is an access code error.

Returns:

  • (TrueClass)


206
207
208
# File 'lib/seam/resources/access_code.rb', line 206

def is_access_code_error
  @is_access_code_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


209
210
211
# File 'lib/seam/resources/access_code.rb', line 209

def message
  @message
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the error.

Returns:

  • (Time, nil)


212
# File 'lib/seam/resources/access_code.rb', line 212

date_accessor :created_at