Class: Seam::Resources::AccessCode::Errors::DeviceOffline
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::DeviceOffline
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the device is offline.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
device_offline
287 288 289 |
# File 'lib/seam/resources/access_code.rb', line 287 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
290 291 292 |
# File 'lib/seam/resources/access_code.rb', line 290 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
293 294 295 |
# File 'lib/seam/resources/access_code.rb', line 293 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
296 |
# File 'lib/seam/resources/access_code.rb', line 296 date_accessor :created_at |