Class: Seam::Resources::AccessCode::Errors::DeviceRemoved
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::DeviceRemoved
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the device has been removed.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
device_removed
305 306 307 |
# File 'lib/seam/resources/access_code.rb', line 305 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
308 309 310 |
# File 'lib/seam/resources/access_code.rb', line 308 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
311 312 313 |
# File 'lib/seam/resources/access_code.rb', line 311 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
314 |
# File 'lib/seam/resources/access_code.rb', line 314 date_accessor :created_at |