Class: Seam::Resources::AccessCode::Errors::DormakabaSitesDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Indicates that one or more dormakaba sites associated with the connected account could not be connected. Contact dormakaba support.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • dormakaba_sites_disconnected

Returns:

  • (String)


338
339
340
# File 'lib/seam/resources/access_code.rb', line 338

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


341
342
343
# File 'lib/seam/resources/access_code.rb', line 341

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


344
345
346
# File 'lib/seam/resources/access_code.rb', line 344

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


347
348
349
# File 'lib/seam/resources/access_code.rb', line 347

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


350
# File 'lib/seam/resources/access_code.rb', line 350

date_accessor :created_at