Class: Seam::Resources::AccessCode::Errors::EmptyBackupAccessCodePool

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Indicates that the backup access code pool is empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • empty_backup_access_code_pool

Returns:

  • (String)


359
360
361
# File 'lib/seam/resources/access_code.rb', line 359

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


362
363
364
# File 'lib/seam/resources/access_code.rb', line 362

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


365
366
367
# File 'lib/seam/resources/access_code.rb', line 365

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


368
# File 'lib/seam/resources/access_code.rb', line 368

date_accessor :created_at