Class: Seam::Resources::AccessCode::Errors::FailedToExpire

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

This access code is still active on the device even though its ends_at has passed, so the recipient may still be able to unlock the device after their access window ended. Seam is attempting to remove it, and this error clears automatically once the access code is no longer active.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • failed_to_expire

Returns:

  • (String)


257
258
259
# File 'lib/seam/resources/access_code.rb', line 257

def error_code
  @error_code
end

#is_access_code_errorTrueClass

Indicates that this is an access code error.

Returns:

  • (TrueClass)


260
261
262
# File 'lib/seam/resources/access_code.rb', line 260

def is_access_code_error
  @is_access_code_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


263
264
265
# File 'lib/seam/resources/access_code.rb', line 263

def message
  @message
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the error.

Returns:

  • (Time, nil)


266
# File 'lib/seam/resources/access_code.rb', line 266

date_accessor :created_at