Class: Seam::Resources::AccessCode::Errors::FailedToIssue

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Seam was unable to issue this access code before its start time, so the recipient may be unable to unlock the device. This usually points to a problem that needs attention, such as an offline or disconnected device. Seam keeps retrying, and this error clears automatically if the access code is eventually issued.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • failed_to_issue

Returns:

  • (String)


221
222
223
# File 'lib/seam/resources/access_code.rb', line 221

def error_code
  @error_code
end

#is_access_code_errorTrueClass

Indicates that this is an access code error.

Returns:

  • (TrueClass)


224
225
226
# File 'lib/seam/resources/access_code.rb', line 224

def is_access_code_error
  @is_access_code_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


227
228
229
# File 'lib/seam/resources/access_code.rb', line 227

def message
  @message
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the error.

Returns:

  • (Time, nil)


230
# File 'lib/seam/resources/access_code.rb', line 230

date_accessor :created_at