Class: Seam::Resources::AccessCode::Errors::FailedToUpdate
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::FailedToUpdate
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Seam was unable to apply this access code's requested update to the device, so the code on the device does not match its requested state. Seam keeps retrying, and this error clears automatically once the update is applied.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_update
239 240 241 |
# File 'lib/seam/resources/access_code.rb', line 239 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
242 243 244 |
# File 'lib/seam/resources/access_code.rb', line 242 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
245 246 247 |
# File 'lib/seam/resources/access_code.rb', line 245 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
248 |
# File 'lib/seam/resources/access_code.rb', line 248 date_accessor :created_at |