Class: Seam::Resources::AccessCode::Errors::MissingDeviceCredentials
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::MissingDeviceCredentials
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that device credentials are missing.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
missing_device_credentials
467 468 469 |
# File 'lib/seam/resources/access_code.rb', line 467 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
470 471 472 |
# File 'lib/seam/resources/access_code.rb', line 470 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
473 474 475 |
# File 'lib/seam/resources/access_code.rb', line 473 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
476 |
# File 'lib/seam/resources/access_code.rb', line 476 date_accessor :created_at |