Class: Seam::Resources::AccessCode::Errors::ProviderIssue
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::ProviderIssue
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates a provider-specific issue that prevents the access code from being set or managed. Check the error message for details.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
provider_issue
50 51 52 |
# File 'lib/seam/resources/access_code.rb', line 50 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
53 54 55 |
# File 'lib/seam/resources/access_code.rb', line 53 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
56 57 58 |
# File 'lib/seam/resources/access_code.rb', line 56 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
59 |
# File 'lib/seam/resources/access_code.rb', line 59 date_accessor :created_at |