Class: Seam::Resources::AccessCode::Errors::SubscriptionRequired
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::SubscriptionRequired
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that a subscription is required to connect.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
subscription_required
431 432 433 |
# File 'lib/seam/resources/access_code.rb', line 431 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
434 435 436 |
# File 'lib/seam/resources/access_code.rb', line 434 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
437 438 439 |
# File 'lib/seam/resources/access_code.rb', line 437 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
440 |
# File 'lib/seam/resources/access_code.rb', line 440 date_accessor :created_at |