Class: Seam::Resources::AccessCode::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessCode::PendingMutations
- Defined in:
- lib/seam/resources/access_code.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the mutation.
-
#mutation_code ⇒ String
Known values: -
creating.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the mutation was created.
- #from ⇒ From
-
#scheduled_at ⇒ Time
Date and time at which Seam will attempt to program this access code on the device.
- #to ⇒ To
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the mutation.
558 559 560 |
# File 'lib/seam/resources/access_code.rb', line 558 def @message end |
#mutation_code ⇒ String
Known values:
creating
562 563 564 |
# File 'lib/seam/resources/access_code.rb', line 562 def mutation_code @mutation_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the mutation was created.
565 |
# File 'lib/seam/resources/access_code.rb', line 565 date_accessor :created_at |
#scheduled_at ⇒ Time
Date and time at which Seam will attempt to program this access code on the device.
568 |
# File 'lib/seam/resources/access_code.rb', line 568 date_accessor :scheduled_at |