Class: Seam::Resources::AccessCode::Warnings

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/access_code.rb

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#change_typeString?

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.

Returns:

  • (String, nil)


154
155
156
# File 'lib/seam/resources/access_code.rb', line 154

def change_type
  @change_type
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


157
158
159
# File 'lib/seam/resources/access_code.rb', line 157

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


160
161
162
# File 'lib/seam/resources/access_code.rb', line 160

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


163
# File 'lib/seam/resources/access_code.rb', line 163

date_accessor :created_at

#modified_fieldsArray<ModifiedFields>

List of fields that were changed externally, with their previous and new values.

Returns:



151
# File 'lib/seam/resources/access_code.rb', line 151

resource_list_accessor :modified_fields, ModifiedFields