Class: Seam::Resources::AccessCode::Warnings::BeingDeleted

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Access code is being deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


733
734
735
# File 'lib/seam/resources/access_code.rb', line 733

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • being_deleted

Returns:

  • (String)


738
739
740
# File 'lib/seam/resources/access_code.rb', line 738

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


741
# File 'lib/seam/resources/access_code.rb', line 741

date_accessor :created_at