Class: Seam::Resources::AccessCode::Warnings::DelayInRemovingFromDevice
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessCode::Warnings::DelayInRemovingFromDevice
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Delay in removing code from device.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
658 659 660 |
# File 'lib/seam/resources/access_code.rb', line 658 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
delay_in_removing_from_device
663 664 665 |
# File 'lib/seam/resources/access_code.rb', line 663 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
666 |
# File 'lib/seam/resources/access_code.rb', line 666 date_accessor :created_at |