Class: Seam::Resources::AccessCode::Warnings::DelayInSettingOnDevice
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessCode::Warnings::DelayInSettingOnDevice
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Delay in setting code on device.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
643 644 645 |
# File 'lib/seam/resources/access_code.rb', line 643 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
delay_in_setting_on_device
648 649 650 |
# File 'lib/seam/resources/access_code.rb', line 648 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
651 |
# File 'lib/seam/resources/access_code.rb', line 651 date_accessor :created_at |