Class: Seam::Resources::AccessCode::Warnings::ExternalModificationInEffect::ModifiedFields
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessCode::Warnings::ExternalModificationInEffect::ModifiedFields
- Defined in:
- lib/seam/resources/access_code.rb
Instance Attribute Summary collapse
-
#field ⇒ String
The name of the field that was changed (e.g.
code,starts_at,ends_at). -
#from ⇒ String?
The previous value of the field.
-
#to ⇒ String?
The new value of the field.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#field ⇒ String
The name of the field that was changed (e.g. code, starts_at, ends_at).
608 609 610 |
# File 'lib/seam/resources/access_code.rb', line 608 def field @field end |
#from ⇒ String?
The previous value of the field.
611 612 613 |
# File 'lib/seam/resources/access_code.rb', line 611 def from @from end |
#to ⇒ String?
The new value of the field.
614 615 616 |
# File 'lib/seam/resources/access_code.rb', line 614 def to @to end |