Class: Seam::Resources::AccessCode::Warnings::ThirdPartyIntegrationDetected

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Third-party integration detected that may cause access codes to fail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


673
674
675
# File 'lib/seam/resources/access_code.rb', line 673

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • third_party_integration_detected

Returns:

  • (String)


678
679
680
# File 'lib/seam/resources/access_code.rb', line 678

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


681
# File 'lib/seam/resources/access_code.rb', line 681

date_accessor :created_at