Class: Seam::Resources::AccessCode::Warnings::TimeFrameAdjustedForUnknownTimeZone

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

The device's time zone is unknown and this code's time frame crosses a daylight-saving transition in at least one plausible time zone. A 1-hour safety buffer has been applied to the side of the time frame affected by the transition (ends_at for spring-forward, starts_at for fall-back) so the code stays active through the shift — the code may be usable up to 1 hour beyond your requested window. Set the device's time zone via /devices/report_provider_metadata to clear the buffer and guarantee exact handling.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


592
593
594
# File 'lib/seam/resources/access_code.rb', line 592

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • time_frame_adjusted_for_unknown_time_zone

Returns:

  • (String)


597
598
599
# File 'lib/seam/resources/access_code.rb', line 597

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


600
# File 'lib/seam/resources/access_code.rb', line 600

date_accessor :created_at