Class: Seam::Resources::AccessGrant::RequestedAccessMethods

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/access_grant.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#codeString?

Specific PIN code to use for this access method. Only applicable when mode is 'code'.

Returns:

  • (String, nil)


94
95
96
# File 'lib/seam/resources/access_grant.rb', line 94

def code
  @code
end

#created_access_method_idsArray<String>

IDs of the access methods created for the requested access method.

Returns:

  • (Array<String>)


97
98
99
# File 'lib/seam/resources/access_grant.rb', line 97

def created_access_method_ids
  @created_access_method_ids
end

#display_nameString

Display name of the access method.

Returns:

  • (String)


100
101
102
# File 'lib/seam/resources/access_grant.rb', line 100

def display_name
  @display_name
end

#instant_key_max_use_countInteger?

Maximum number of times the instant key can be used. Only applicable when mode is 'mobile_key'. Defaults to 1 if not specified.

Returns:

  • (Integer, nil)


103
104
105
# File 'lib/seam/resources/access_grant.rb', line 103

def instant_key_max_use_count
  @instant_key_max_use_count
end

#modeString

Access method mode. Supported values: code, card, mobile_key, cloud_key. Known values:

  • code
  • card
  • mobile_key
  • cloud_key

Returns:

  • (String)


111
112
113
# File 'lib/seam/resources/access_grant.rb', line 111

def mode
  @mode
end

Instance Method Details

#created_atTime

Date and time at which the requested access method was added to the Access Grant.

Returns:

  • (Time)


114
# File 'lib/seam/resources/access_grant.rb', line 114

date_accessor :created_at