Class: Seam::Resources::AccessGrant::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/access_grant.rb

Overview

Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.

Defined Under Namespace

Classes: BeingDeleted, DeviceDoesNotSupportAccessCodes, DeviceTimeConstraintsViolated, OverprovisionedAccess, RequestedCodeUnavailable, UnderprovisionedAccess, UpdatingAccessTimes

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


266
267
268
# File 'lib/seam/resources/access_grant.rb', line 266

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • being_deleted
  • underprovisioned_access
  • overprovisioned_access
  • updating_access_times
  • requested_code_unavailable
  • device_does_not_support_access_codes
  • device_time_constraints_violated

Returns:

  • (String)


277
278
279
# File 'lib/seam/resources/access_grant.rb', line 277

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


280
# File 'lib/seam/resources/access_grant.rb', line 280

date_accessor :created_at