Class: Seam::Resources::AccessGrant::Warnings::BeingDeleted
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessGrant::Warnings::BeingDeleted
- Defined in:
- lib/seam/resources/access_grant.rb
Overview
Indicates that the access grant is being deleted.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
123 124 125 |
# File 'lib/seam/resources/access_grant.rb', line 123 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
being_deleted
128 129 130 |
# File 'lib/seam/resources/access_grant.rb', line 128 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
131 |
# File 'lib/seam/resources/access_grant.rb', line 131 date_accessor :created_at |