Class: Seam::Resources::AccessGrant::Warnings::OverprovisionedAccess
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessGrant::Warnings::OverprovisionedAccess
- Defined in:
- lib/seam/resources/access_grant.rb
Overview
Indicates that the access grant has access to locations it should not have. Access methods are being removed from the extra locations.
Defined Under Namespace
Classes: FailedDevices
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
-
#failed_devices ⇒ Array<FailedDevices>
Devices whose access codes could not be revoked during reconciliation.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
168 169 170 |
# File 'lib/seam/resources/access_grant.rb', line 168 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
overprovisioned_access
173 174 175 |
# File 'lib/seam/resources/access_grant.rb', line 173 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
176 |
# File 'lib/seam/resources/access_grant.rb', line 176 date_accessor :created_at |
#failed_devices ⇒ Array<FailedDevices>
Devices whose access codes could not be revoked during reconciliation. Present when the provider does not support revoking an offline access code (e.g. Dormakaba oracode with exhausted override budget).
165 |
# File 'lib/seam/resources/access_grant.rb', line 165 resource_list_accessor :failed_devices, FailedDevices |