Class: Seam::Resources::AccessGrant::Warnings::RequestedCodeUnavailable

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_grant.rb

Overview

Indicates that the requested PIN code was already in use on a device, so a different code was assigned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#device_idString

ID of the device where the requested code was unavailable.

Returns:

  • (String)


201
202
203
# File 'lib/seam/resources/access_grant.rb', line 201

def device_id
  @device_id
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


204
205
206
# File 'lib/seam/resources/access_grant.rb', line 204

def message
  @message
end

#new_codeString

The new PIN code that was assigned instead.

Returns:

  • (String)


207
208
209
# File 'lib/seam/resources/access_grant.rb', line 207

def new_code
  @new_code
end

#original_codeString

The originally requested PIN code that was unavailable.

Returns:

  • (String)


210
211
212
# File 'lib/seam/resources/access_grant.rb', line 210

def original_code
  @original_code
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • requested_code_unavailable

Returns:

  • (String)


215
216
217
# File 'lib/seam/resources/access_grant.rb', line 215

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


218
# File 'lib/seam/resources/access_grant.rb', line 218

date_accessor :created_at