Class: Seam::Resources::AccessGrant::Warnings::UnderprovisionedAccess

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_grant.rb

Overview

Indicates that the access grant should have access to more locations than it currently does. Access methods are being created for the missing locations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


138
139
140
# File 'lib/seam/resources/access_grant.rb', line 138

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • underprovisioned_access

Returns:

  • (String)


143
144
145
# File 'lib/seam/resources/access_grant.rb', line 143

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


146
# File 'lib/seam/resources/access_grant.rb', line 146

date_accessor :created_at