Class: Seam::Resources::AccessGrant::Warnings::UpdatingAccessTimes

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_grant.rb

Overview

Indicates that the access times for this access grant are being updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_method_idsArray<String>

IDs of the access methods being updated.

Returns:

  • (Array<String>)


183
184
185
# File 'lib/seam/resources/access_grant.rb', line 183

def access_method_ids
  @access_method_ids
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


186
187
188
# File 'lib/seam/resources/access_grant.rb', line 186

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • updating_access_times

Returns:

  • (String)


191
192
193
# File 'lib/seam/resources/access_grant.rb', line 191

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


194
# File 'lib/seam/resources/access_grant.rb', line 194

date_accessor :created_at