Class: Seam::Resources::AccessMethod::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessMethod::Warnings
- Defined in:
- lib/seam/resources/access_method.rb
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
59 60 61 |
# File 'lib/seam/resources/access_method.rb', line 59 def @message end |
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
62 63 64 |
# File 'lib/seam/resources/access_method.rb', line 62 def original_access_method_id @original_access_method_id end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
65 66 67 |
# File 'lib/seam/resources/access_method.rb', line 65 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
68 |
# File 'lib/seam/resources/access_method.rb', line 68 date_accessor :created_at |