Class: Seam::Resources::AccessMethod::Warnings::BeingDeleted

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_method.rb

Overview

Indicates that the access method is being deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


86
87
88
# File 'lib/seam/resources/access_method.rb', line 86

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • being_deleted

Returns:

  • (String)


91
92
93
# File 'lib/seam/resources/access_method.rb', line 91

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


94
# File 'lib/seam/resources/access_method.rb', line 94

date_accessor :created_at