Class: Seam::Resources::AccessMethod::Warnings::UpdatingAccessTimes

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_method.rb

Overview

Indicates that the access times for this access method are being updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


101
102
103
# File 'lib/seam/resources/access_method.rb', line 101

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • updating_access_times

Returns:

  • (String)


106
107
108
# File 'lib/seam/resources/access_method.rb', line 106

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


109
# File 'lib/seam/resources/access_method.rb', line 109

date_accessor :created_at