Class: Seam::Resources::AcsAccessGroup::Errors::FailedToCreateOnAcsSystem

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_access_group.rb

Overview

Indicates that the access group was not created on the access system. This is likely due to an internal unexpected error. Contact Seam support.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • failed_to_create_on_acs_system

Returns:

  • (String)


28
29
30
# File 'lib/seam/resources/acs_access_group.rb', line 28

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


31
32
33
# File 'lib/seam/resources/acs_access_group.rb', line 31

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


34
# File 'lib/seam/resources/acs_access_group.rb', line 34

date_accessor :created_at