Class: Seam::Resources::AcsAccessGroup::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsAccessGroup::PendingMutations
- Defined in:
- lib/seam/resources/acs_access_group.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#acs_user_id ⇒ String
ID of the user involved in the scheduled change.
-
#message ⇒ String
Detailed description of the mutation.
-
#mutation_code ⇒ String
Known values: -
creating. -
#variant ⇒ String
Whether the user is scheduled to be added to or removed from this access group.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the mutation was created.
- #from ⇒ From
- #to ⇒ To
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_user_id ⇒ String
ID of the user involved in the scheduled change.
97 98 99 |
# File 'lib/seam/resources/acs_access_group.rb', line 97 def acs_user_id @acs_user_id end |
#message ⇒ String
Detailed description of the mutation.
100 101 102 |
# File 'lib/seam/resources/acs_access_group.rb', line 100 def @message end |
#mutation_code ⇒ String
Known values:
creating
104 105 106 |
# File 'lib/seam/resources/acs_access_group.rb', line 104 def mutation_code @mutation_code end |
#variant ⇒ String
Whether the user is scheduled to be added to or removed from this access group. Known values:
addingremoving
110 111 112 |
# File 'lib/seam/resources/acs_access_group.rb', line 110 def variant @variant end |