Class: Seam::Resources::AcsCredential

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Means by which an access control system user gains access at an entrance. The acs_credential object represents a credential that provides an ACS user access within an access control system.

An access control system generally uses digital means of access to authorize a user trying to get through a specific entrance. Examples of credentials include plastic key cards, mobile keys, biometric identifiers, and PIN codes. The electronic nature of these credentials, as well as the fact that access is centralized, enables both the rapid provisioning and rescinding of access and the ability to compile access audit logs.

For each acs_credential, you define the access method. You can also specify additional properties, such as a PIN code, depending on the credential type.

For granting a person access to a space, Access Grants are the default and recommended approach. Use the lower-level ACS credential API directly only when you specifically need to manage individual credentials.

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodString

Access method for the credential. Supported values: code, card, mobile_key, cloud_key. Known values:

  • code
  • card
  • mobile_key
  • cloud_key

Returns:

  • (String)


244
245
246
# File 'lib/seam/resources/acs_credential.rb', line 244

def access_method
  @access_method
end

#acs_credential_idString

ID of the credential.

Returns:

  • (String)


247
248
249
# File 'lib/seam/resources/acs_credential.rb', line 247

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idString?

ID of the credential pool to which the credential belongs.

Returns:

  • (String, nil)


250
251
252
# File 'lib/seam/resources/acs_credential.rb', line 250

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idString

ID of the access control system that contains the credential.

Returns:

  • (String)


253
254
255
# File 'lib/seam/resources/acs_credential.rb', line 253

def acs_system_id
  @acs_system_id
end

#acs_user_idString?

ID of the ACS user to whom the credential belongs.

Returns:

  • (String, nil)


256
257
258
# File 'lib/seam/resources/acs_credential.rb', line 256

def acs_user_id
  @acs_user_id
end

#card_numberString?

Number of the card associated with the credential.

Returns:

  • (String, nil)


259
260
261
# File 'lib/seam/resources/acs_credential.rb', line 259

def card_number
  @card_number
end

#codeString?

Access (PIN) code for the credential.

Returns:

  • (String, nil)


262
263
264
# File 'lib/seam/resources/acs_credential.rb', line 262

def code
  @code
end

#connected_account_idString

ID of the connected account to which the credential belongs.

Returns:

  • (String)


265
266
267
# File 'lib/seam/resources/acs_credential.rb', line 265

def 
  @connected_account_id
end

#display_nameString

Display name that corresponds to the credential type.

Returns:

  • (String)


268
269
270
# File 'lib/seam/resources/acs_credential.rb', line 268

def display_name
  @display_name
end

#ends_atString?

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.

Returns:

  • (String, nil)


271
272
273
# File 'lib/seam/resources/acs_credential.rb', line 271

def ends_at
  @ends_at
end

#external_typeString?

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card. Known values:

  • pti_card
  • brivo_credential
  • hid_credential
  • visionline_card
  • salto_ks_credential
  • assa_abloy_vostio_key
  • salto_space_key
  • latch_access
  • dormakaba_ambiance_credential
  • hotek_card
  • salto_ks_tag
  • avigilon_alta_credential
  • kisi_credential
  • akiles_credential

Returns:

  • (String, nil)


289
290
291
# File 'lib/seam/resources/acs_credential.rb', line 289

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the credential type.

Returns:

  • (String, nil)


292
293
294
# File 'lib/seam/resources/acs_credential.rb', line 292

def external_type_display_name
  @external_type_display_name
end

#is_issuedBoolean?

Indicates whether the credential has been encoded onto a card.

Returns:

  • (Boolean, nil)


295
296
297
# File 'lib/seam/resources/acs_credential.rb', line 295

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerBoolean?

Indicates whether the latest state of the credential has been synced from Seam to the provider.

Returns:

  • (Boolean, nil)


298
299
300
# File 'lib/seam/resources/acs_credential.rb', line 298

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedTrueClass

Indicates whether Seam manages the credential.

Returns:

  • (TrueClass)


301
302
303
# File 'lib/seam/resources/acs_credential.rb', line 301

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialBoolean?

Indicates whether the credential is a multi-phone sync credential.

Returns:

  • (Boolean, nil)


304
305
306
# File 'lib/seam/resources/acs_credential.rb', line 304

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useBoolean?

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean, nil)


307
308
309
# File 'lib/seam/resources/acs_credential.rb', line 307

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idString?

ID of the parent credential.

Returns:

  • (String, nil)


310
311
312
# File 'lib/seam/resources/acs_credential.rb', line 310

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atString?

Date and time at which the credential validity starts, in ISO 8601 format.

Returns:

  • (String, nil)


313
314
315
# File 'lib/seam/resources/acs_credential.rb', line 313

def starts_at
  @starts_at
end

#user_identity_idString?

ID of the user identity to whom the credential belongs.

Returns:

  • (String, nil)


316
317
318
# File 'lib/seam/resources/acs_credential.rb', line 316

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the workspace that contains the credential.

Returns:

  • (String)


319
320
321
# File 'lib/seam/resources/acs_credential.rb', line 319

def workspace_id
  @workspace_id
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata for the credential.

Returns:



224
# File 'lib/seam/resources/acs_credential.rb', line 224

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

Vostio-specific metadata for the credential.

Returns:



227
# File 'lib/seam/resources/acs_credential.rb', line 227

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#created_atTime

Date and time at which the credential was created.

Returns:

  • (Time)


323
# File 'lib/seam/resources/acs_credential.rb', line 323

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the credential.

Returns:



233
# File 'lib/seam/resources/acs_credential.rb', line 233

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the credential was encoded onto a card.

Returns:

  • (Time, nil)


327
# File 'lib/seam/resources/acs_credential.rb', line 327

date_accessor :issued_at

#latest_desired_state_synced_with_provider_atTime?

Date and time at which the state of the credential was most recently synced from Seam to the provider.

Returns:

  • (Time, nil)


331
# File 'lib/seam/resources/acs_credential.rb', line 331

date_accessor :latest_desired_state_synced_with_provider_at

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the credential.

Returns:



230
# File 'lib/seam/resources/acs_credential.rb', line 230

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the credential.

Returns:



236
# File 'lib/seam/resources/acs_credential.rb', line 236

resource_list_accessor :warnings, Warnings