Class: Seam::Resources::AcsCredential::AssaAbloyVostioMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinBoolean?

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.

Returns:

  • (Boolean, nil)


22
23
24
# File 'lib/seam/resources/acs_credential.rb', line 22

def auto_join
  @auto_join
end

#door_namesArray<String>

Names of the doors to which to grant access in the Vostio access system.

Returns:

  • (Array<String>)


25
26
27
# File 'lib/seam/resources/acs_credential.rb', line 25

def door_names
  @door_names
end

#endpoint_idString?

Endpoint ID in the Vostio access system.

Returns:

  • (String, nil)


28
29
30
# File 'lib/seam/resources/acs_credential.rb', line 28

def endpoint_id
  @endpoint_id
end

#key_idString?

Key ID in the Vostio access system.

Returns:

  • (String, nil)


31
32
33
# File 'lib/seam/resources/acs_credential.rb', line 31

def key_id
  @key_id
end

#key_issuing_request_idString?

Key issuing request ID in the Vostio access system.

Returns:

  • (String, nil)


34
35
36
# File 'lib/seam/resources/acs_credential.rb', line 34

def key_issuing_request_id
  @key_issuing_request_id
end

#override_guest_acs_entrance_idsArray<String>

IDs of the guest entrances to override in the Vostio access system.

Returns:

  • (Array<String>)


37
38
39
# File 'lib/seam/resources/acs_credential.rb', line 37

def override_guest_acs_entrance_ids
  @override_guest_acs_entrance_ids
end