Class: Seam::Resources::AcsCredential::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsCredential::VisionlineMetadata
- Defined in:
- lib/seam/resources/acs_credential.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ String?
Card function type in the Visionline access system.
-
#card_id ⇒ String?
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
53 54 55 |
# File 'lib/seam/resources/acs_credential.rb', line 53 def auto_join @auto_join end |
#card_function_type ⇒ String?
Card function type in the Visionline access system.
56 57 58 |
# File 'lib/seam/resources/acs_credential.rb', line 56 def card_function_type @card_function_type end |
#card_id ⇒ String?
ID of the card in the Visionline access system.
59 60 61 |
# File 'lib/seam/resources/acs_credential.rb', line 59 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
62 63 64 |
# File 'lib/seam/resources/acs_credential.rb', line 62 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
65 66 67 |
# File 'lib/seam/resources/acs_credential.rb', line 65 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
68 69 70 |
# File 'lib/seam/resources/acs_credential.rb', line 68 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
71 72 73 |
# File 'lib/seam/resources/acs_credential.rb', line 71 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
74 75 76 |
# File 'lib/seam/resources/acs_credential.rb', line 74 def joiner_acs_credential_ids @joiner_acs_credential_ids end |