Class: Seam::Resources::AcsCredential::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.

Defined Under Namespace

Classes: BeingDeleted, NeedsToBeReissued, RequestedCodeUnavailable, ScheduleExternallyModified, ScheduleModified, UnknownIssueWithAcsCredential, WaitingToBeIssued

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


195
196
197
# File 'lib/seam/resources/acs_credential.rb', line 195

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • waiting_to_be_issued
  • schedule_externally_modified
  • schedule_modified
  • being_deleted
  • unknown_issue_with_acs_credential
  • needs_to_be_reissued
  • requested_code_unavailable

Returns:

  • (String)


206
207
208
# File 'lib/seam/resources/acs_credential.rb', line 206

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


209
# File 'lib/seam/resources/acs_credential.rb', line 209

date_accessor :created_at