Class: Seam::Resources::AcsCredential::Warnings::NeedsToBeReissued

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Access permissions for the credential have changed. Reissue (re-encode) the credential. This issue may affect the proper functioning of the credential.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


161
162
163
# File 'lib/seam/resources/acs_credential.rb', line 161

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • needs_to_be_reissued

Returns:

  • (String)


166
167
168
# File 'lib/seam/resources/acs_credential.rb', line 166

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


169
# File 'lib/seam/resources/acs_credential.rb', line 169

date_accessor :created_at