Class: Seam::Resources::AcsCredential::Warnings::RequestedCodeUnavailable

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Indicates that the requested PIN code could not be used, so the access system assigned a different code. Give the guest the assigned code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


176
177
178
# File 'lib/seam/resources/acs_credential.rb', line 176

def message
  @message
end

#new_codeString

The PIN code that was assigned instead.

Returns:

  • (String)


179
180
181
# File 'lib/seam/resources/acs_credential.rb', line 179

def new_code
  @new_code
end

#original_codeString

The originally requested PIN code that could not be used.

Returns:

  • (String)


182
183
184
# File 'lib/seam/resources/acs_credential.rb', line 182

def original_code
  @original_code
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • requested_code_unavailable

Returns:

  • (String)


187
188
189
# File 'lib/seam/resources/acs_credential.rb', line 187

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


190
# File 'lib/seam/resources/acs_credential.rb', line 190

date_accessor :created_at