Class: Seam::Resources::AcsCredential::Warnings::ScheduleExternallyModified
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsCredential::Warnings::ScheduleExternallyModified
- Defined in:
- lib/seam/resources/acs_credential.rb
Overview
Indicates that the schedule of one of the credential's children was modified externally.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
101 102 103 |
# File 'lib/seam/resources/acs_credential.rb', line 101 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
schedule_externally_modified
106 107 108 |
# File 'lib/seam/resources/acs_credential.rb', line 106 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
109 |
# File 'lib/seam/resources/acs_credential.rb', line 109 date_accessor :created_at |