Class: Seam::Resources::AcsCredential::Warnings::UnknownIssueWithAcsCredential

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

An unknown issue occurred while syncing the state of the credential with the provider. This issue may affect the proper functioning of the credential.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


146
147
148
# File 'lib/seam/resources/acs_credential.rb', line 146

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • unknown_issue_with_acs_credential

Returns:

  • (String)


151
152
153
# File 'lib/seam/resources/acs_credential.rb', line 151

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


154
# File 'lib/seam/resources/acs_credential.rb', line 154

date_accessor :created_at