Class: Seam::Resources::AcsEncoder
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEncoder
- Defined in:
- lib/seam/resources/acs_encoder.rb
Overview
Represents a hardware device that encodes credential data onto physical cards within an access control system.
Some access control systems require credentials to be encoded onto plastic key cards using a card encoder. This process involves the following two key steps:
- Credential creation Configure the access parameters for the credential.
- Card encoding Write the credential data onto the card using a compatible card encoder.
Separately, the Seam API also supports card scanning, which enables you to scan and read the encoded data on a card. You can use this action to confirm consistency with access control system records or diagnose discrepancies if needed.
See Working with Card Encoders and Scanners.
To verify if your access control system requires a card encoder, see the corresponding system integration guide.
Defined Under Namespace
Classes: Errors
Instance Attribute Summary collapse
-
#acs_encoder_id ⇒ String
ID of the encoder.
-
#acs_system_id ⇒ String
ID of the access control system that contains the encoder.
-
#connected_account_id ⇒ String
ID of the connected account that contains the encoder.
-
#display_name ⇒ String
Display name for the encoder.
-
#workspace_id ⇒ String
ID of the workspace that contains the encoder.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the encoder was created.
-
#errors ⇒ Array<Errors>
Errors associated with the encoder.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_encoder_id ⇒ String
ID of the encoder.
37 38 39 |
# File 'lib/seam/resources/acs_encoder.rb', line 37 def acs_encoder_id @acs_encoder_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the encoder.
40 41 42 |
# File 'lib/seam/resources/acs_encoder.rb', line 40 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String
ID of the connected account that contains the encoder.
43 44 45 |
# File 'lib/seam/resources/acs_encoder.rb', line 43 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name for the encoder.
46 47 48 |
# File 'lib/seam/resources/acs_encoder.rb', line 46 def display_name @display_name end |
#workspace_id ⇒ String
ID of the workspace that contains the encoder.
49 50 51 |
# File 'lib/seam/resources/acs_encoder.rb', line 49 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the encoder was created.
53 |
# File 'lib/seam/resources/acs_encoder.rb', line 53 date_accessor :created_at |