Class: Seam::Resources::AcsEntrance

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Represents an entrance within an access control system.

In an access control system, an entrance is a secured door, gate, zone, or other method of entry. You can list details for all the acs_entrance resources in your workspace or get these details for a specific acs_entrance. You can also list all entrances associated with a specific credential, and you can list all credentials associated with a specific entrance.

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, AvigilonAltaMetadata, BrivoMetadata, DormakabaAmbianceMetadata, DormakabaCommunityMetadata, Errors, HotekMetadata, LatchMetadata, SaltoKsMetadata, SaltoSpaceMetadata, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_entrance_idString

ID of the entrance.

Returns:

  • (String)


365
366
367
# File 'lib/seam/resources/acs_entrance.rb', line 365

def acs_entrance_id
  @acs_entrance_id
end

#acs_system_idString

ID of the access control system that contains the entrance.

Returns:

  • (String)


368
369
370
# File 'lib/seam/resources/acs_entrance.rb', line 368

def acs_system_id
  @acs_system_id
end

#can_belong_to_reservationBoolean?

Indicates whether the ACS entrance can belong to a reservation via an access_grant.reservation_key.

Returns:

  • (Boolean, nil)


371
372
373
# File 'lib/seam/resources/acs_entrance.rb', line 371

def can_belong_to_reservation
  @can_belong_to_reservation
end

#can_unlock_with_cardBoolean?

Indicates whether the ACS entrance can be unlocked with card credentials.

Returns:

  • (Boolean, nil)


374
375
376
# File 'lib/seam/resources/acs_entrance.rb', line 374

def can_unlock_with_card
  @can_unlock_with_card
end

#can_unlock_with_cloud_keyBoolean?

Indicates whether the ACS entrance can be unlocked with cloud key credentials.

Returns:

  • (Boolean, nil)


377
378
379
# File 'lib/seam/resources/acs_entrance.rb', line 377

def can_unlock_with_cloud_key
  @can_unlock_with_cloud_key
end

#can_unlock_with_codeBoolean?

Indicates whether the ACS entrance can be unlocked with pin codes.

Returns:

  • (Boolean, nil)


380
381
382
# File 'lib/seam/resources/acs_entrance.rb', line 380

def can_unlock_with_code
  @can_unlock_with_code
end

#can_unlock_with_mobile_keyBoolean?

Indicates whether the ACS entrance can be unlocked with mobile key credentials.

Returns:

  • (Boolean, nil)


383
384
385
# File 'lib/seam/resources/acs_entrance.rb', line 383

def can_unlock_with_mobile_key
  @can_unlock_with_mobile_key
end

#connected_account_idString

ID of the connected account associated with the entrance.

Returns:

  • (String)


386
387
388
# File 'lib/seam/resources/acs_entrance.rb', line 386

def 
  @connected_account_id
end

#display_nameString

Display name for the entrance.

Returns:

  • (String)


389
390
391
# File 'lib/seam/resources/acs_entrance.rb', line 389

def display_name
  @display_name
end

#is_lockedBoolean?

Indicates whether the entrance is currently locked.

Returns:

  • (Boolean, nil)


392
393
394
# File 'lib/seam/resources/acs_entrance.rb', line 392

def is_locked
  @is_locked
end

#space_idsArray<String>

IDs of the spaces that the entrance is in.

Returns:

  • (Array<String>)


395
396
397
# File 'lib/seam/resources/acs_entrance.rb', line 395

def space_ids
  @space_ids
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata associated with the entrance.

Returns:



326
# File 'lib/seam/resources/acs_entrance.rb', line 326

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

ASSA ABLOY Vostio-specific metadata associated with the entrance.

Returns:



329
# File 'lib/seam/resources/acs_entrance.rb', line 329

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#avigilon_alta_metadataAvigilonAltaMetadata?

Avigilon Alta-specific metadata associated with the entrance.

Returns:



332
# File 'lib/seam/resources/acs_entrance.rb', line 332

resource_accessor :avigilon_alta_metadata, AvigilonAltaMetadata

#brivo_metadataBrivoMetadata?

Brivo-specific metadata associated with the entrance.

Returns:



335
# File 'lib/seam/resources/acs_entrance.rb', line 335

resource_accessor :brivo_metadata, BrivoMetadata

#created_atTime

Date and time at which the entrance was created.

Returns:

  • (Time)


399
# File 'lib/seam/resources/acs_entrance.rb', line 399

date_accessor :created_at

#dormakaba_ambiance_metadataDormakabaAmbianceMetadata?

dormakaba Ambiance-specific metadata associated with the entrance.

Returns:



338
# File 'lib/seam/resources/acs_entrance.rb', line 338

resource_accessor :dormakaba_ambiance_metadata, DormakabaAmbianceMetadata

#dormakaba_community_metadataDormakabaCommunityMetadata?

dormakaba Community-specific metadata associated with the entrance.

Returns:



341
# File 'lib/seam/resources/acs_entrance.rb', line 341

resource_accessor :dormakaba_community_metadata, DormakabaCommunityMetadata

#errorsArray<Errors>

Errors associated with the entrance.

Returns:



359
# File 'lib/seam/resources/acs_entrance.rb', line 359

resource_list_accessor :errors, Errors

#hotek_metadataHotekMetadata?

Hotek-specific metadata associated with the entrance.

Returns:



344
# File 'lib/seam/resources/acs_entrance.rb', line 344

resource_accessor :hotek_metadata, HotekMetadata

#latch_metadataLatchMetadata?

Latch-specific metadata associated with the entrance.

Returns:



347
# File 'lib/seam/resources/acs_entrance.rb', line 347

resource_accessor :latch_metadata, LatchMetadata

#salto_ks_metadataSaltoKsMetadata?

Salto KS-specific metadata associated with the entrance.

Returns:



350
# File 'lib/seam/resources/acs_entrance.rb', line 350

resource_accessor :salto_ks_metadata, SaltoKsMetadata

#salto_space_metadataSaltoSpaceMetadata?

Salto Space-specific metadata associated with the entrance.

Returns:



353
# File 'lib/seam/resources/acs_entrance.rb', line 353

resource_accessor :salto_space_metadata, SaltoSpaceMetadata

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata associated with the entrance.

Returns:



356
# File 'lib/seam/resources/acs_entrance.rb', line 356

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the entrance.

Returns:



362
# File 'lib/seam/resources/acs_entrance.rb', line 362

resource_list_accessor :warnings, Warnings