Class: Seam::Resources::AcsEntrance::AkilesMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Defined Under Namespace

Classes: Actions

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#gadget_idString?

ID of the Akiles gadget.

Returns:

  • (String, nil)


24
25
26
# File 'lib/seam/resources/acs_entrance.rb', line 24

def gadget_id
  @gadget_id
end

#site_idString?

ID of the Akiles site the gadget belongs to.

Returns:

  • (String, nil)


27
28
29
# File 'lib/seam/resources/acs_entrance.rb', line 27

def site_id
  @site_id
end

#site_nameString?

Name of the Akiles site the gadget belongs to.

Returns:

  • (String, nil)


30
31
32
# File 'lib/seam/resources/acs_entrance.rb', line 30

def site_name
  @site_name
end

Instance Method Details

#actionsArray<Actions>

Actions the gadget exposes (for example, open).

Returns:



21
# File 'lib/seam/resources/acs_entrance.rb', line 21

resource_list_accessor :actions, Actions