Class: Seam::Resources::AcsEntrance::AssaAbloyVostioMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::AssaAbloyVostioMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#door_name ⇒ String?
Name of the door in the Vostio access system.
-
#door_number ⇒ Float?
Number of the door in the Vostio access system.
-
#door_type ⇒ String?
Type of the door in the Vostio access system.
-
#pms_id ⇒ String?
PMS ID of the door in the Vostio access system.
-
#stand_open ⇒ Boolean?
Indicates whether keys are allowed to set the door in stand open mode in the Vostio access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#door_name ⇒ String?
Name of the door in the Vostio access system.
36 37 38 |
# File 'lib/seam/resources/acs_entrance.rb', line 36 def door_name @door_name end |
#door_number ⇒ Float?
Number of the door in the Vostio access system.
39 40 41 |
# File 'lib/seam/resources/acs_entrance.rb', line 39 def door_number @door_number end |
#door_type ⇒ String?
Type of the door in the Vostio access system. Known values:
CommonDoorEntranceDoorGuestDoorElevator
47 48 49 |
# File 'lib/seam/resources/acs_entrance.rb', line 47 def door_type @door_type end |
#pms_id ⇒ String?
PMS ID of the door in the Vostio access system.
50 51 52 |
# File 'lib/seam/resources/acs_entrance.rb', line 50 def pms_id @pms_id end |
#stand_open ⇒ Boolean?
Indicates whether keys are allowed to set the door in stand open mode in the Vostio access system.
53 54 55 |
# File 'lib/seam/resources/acs_entrance.rb', line 53 def stand_open @stand_open end |