Class: Seam::Resources::AcsEntrance::BrivoMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_point_idString?

ID of the access point in the Brivo access system.

Returns:

  • (String, nil)


83
84
85
# File 'lib/seam/resources/acs_entrance.rb', line 83

def access_point_id
  @access_point_id
end

#site_idFloat?

ID of the site that the access point belongs to.

Returns:

  • (Float, nil)


86
87
88
# File 'lib/seam/resources/acs_entrance.rb', line 86

def site_id
  @site_id
end

#site_nameString?

Name of the site that the access point belongs to.

Returns:

  • (String, nil)


89
90
91
# File 'lib/seam/resources/acs_entrance.rb', line 89

def site_name
  @site_name
end