Class: Seam::Resources::AcsEntrance::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::Errors
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
107 108 109 |
# File 'lib/seam/resources/acs_entrance.rb', line 107 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
110 111 112 |
# File 'lib/seam/resources/acs_entrance.rb', line 110 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
113 |
# File 'lib/seam/resources/acs_entrance.rb', line 113 date_accessor :created_at |