Class: Seam::Resources::AcsEntrance::SaltoKsMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#battery_levelString?

Battery level of the door access device.

Returns:

  • (String, nil)


146
147
148
# File 'lib/seam/resources/acs_entrance.rb', line 146

def battery_level
  @battery_level
end

#door_nameString?

Name of the door in the Salto KS access system.

Returns:

  • (String, nil)


149
150
151
# File 'lib/seam/resources/acs_entrance.rb', line 149

def door_name
  @door_name
end

#intrusion_alarmBoolean?

Indicates whether an intrusion alarm is active on the door.

Returns:

  • (Boolean, nil)


152
153
154
# File 'lib/seam/resources/acs_entrance.rb', line 152

def intrusion_alarm
  @intrusion_alarm
end

#left_open_alarmBoolean?

Indicates whether the door is left open.

Returns:

  • (Boolean, nil)


155
156
157
# File 'lib/seam/resources/acs_entrance.rb', line 155

def left_open_alarm
  @left_open_alarm
end

#lock_typeString?

Type of the lock in the Salto KS access system.

Returns:

  • (String, nil)


158
159
160
# File 'lib/seam/resources/acs_entrance.rb', line 158

def lock_type
  @lock_type
end

#locked_stateString?

Locked state of the door in the Salto KS access system.

Returns:

  • (String, nil)


161
162
163
# File 'lib/seam/resources/acs_entrance.rb', line 161

def locked_state
  @locked_state
end

#onlineBoolean?

Indicates whether the door access device is online.

Returns:

  • (Boolean, nil)


164
165
166
# File 'lib/seam/resources/acs_entrance.rb', line 164

def online
  @online
end

#privacy_modeBoolean?

Indicates whether privacy mode is enabled for the lock.

Returns:

  • (Boolean, nil)


167
168
169
# File 'lib/seam/resources/acs_entrance.rb', line 167

def privacy_mode
  @privacy_mode
end