Class: Seam::Resources::AcsEntrance::SaltoSpaceMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#audit_on_keysBoolean?

Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.

Returns:

  • (Boolean, nil)


173
174
175
# File 'lib/seam/resources/acs_entrance.rb', line 173

def audit_on_keys
  @audit_on_keys
end

#door_descriptionString?

Description of the door in the Salto Space access system.

Returns:

  • (String, nil)


176
177
178
# File 'lib/seam/resources/acs_entrance.rb', line 176

def door_description
  @door_description
end

#door_idString?

Door ID in the Salto Space access system.

Returns:

  • (String, nil)


179
180
181
# File 'lib/seam/resources/acs_entrance.rb', line 179

def door_id
  @door_id
end

#door_nameString?

Name of the door in the Salto Space access system.

Returns:

  • (String, nil)


182
183
184
# File 'lib/seam/resources/acs_entrance.rb', line 182

def door_name
  @door_name
end

#room_descriptionString?

Description of the room in the Salto Space access system.

Returns:

  • (String, nil)


185
186
187
# File 'lib/seam/resources/acs_entrance.rb', line 185

def room_description
  @room_description
end

#room_nameString?

Name of the room in the Salto Space access system.

Returns:

  • (String, nil)


188
189
190
# File 'lib/seam/resources/acs_entrance.rb', line 188

def room_name
  @room_name
end