Class: Seam::Resources::AcsEntrance::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::Warnings
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
210 211 212 |
# File 'lib/seam/resources/acs_entrance.rb', line 210 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
213 214 215 |
# File 'lib/seam/resources/acs_entrance.rb', line 213 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
216 |
# File 'lib/seam/resources/acs_entrance.rb', line 216 date_accessor :created_at |