Class: Seam::Resources::AcsEntrance::Warnings::EntranceSetupRequired

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Indicates that this entrance requires additional configuration in the access control system before Seam can fully manage it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


258
259
260
# File 'lib/seam/resources/acs_entrance.rb', line 258

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • entrance_setup_required

Returns:

  • (String)


263
264
265
# File 'lib/seam/resources/acs_entrance.rb', line 263

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


266
# File 'lib/seam/resources/acs_entrance.rb', line 266

date_accessor :created_at