Class: Seam::Resources::AcsEntrance::Warnings::EntranceSharesZone

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Indicates that this entrance shares a zone with other entrances in Avigilon Alta and cannot be added to an access group individually.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


243
244
245
# File 'lib/seam/resources/acs_entrance.rb', line 243

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • entrance_shares_zone

Returns:

  • (String)


248
249
250
# File 'lib/seam/resources/acs_entrance.rb', line 248

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


251
# File 'lib/seam/resources/acs_entrance.rb', line 251

date_accessor :created_at