Class: Seam::Resources::AcsEntrance::Warnings::PrivacyMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Indicates that this entrance is in privacy mode. When privacy mode is enabled, access codes, mobile keys, and remote unlocks will not work unless the user has admin access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


288
289
290
# File 'lib/seam/resources/acs_entrance.rb', line 288

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • privacy_mode

Returns:

  • (String)


293
294
295
# File 'lib/seam/resources/acs_entrance.rb', line 293

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


296
# File 'lib/seam/resources/acs_entrance.rb', line 296

date_accessor :created_at