Class: Seam::Resources::AcsEntrance::Warnings::SaltoKsEntranceAccessCodeSupportRemoved

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Indicates that a change in the reported device model has been detected for this Salto KS entrance, which may occur after an IQ hub reset. Access code support may be affected. See https://help.getseam.com/articles/5098842588-salto-ks-lock-loses-access-code-support for troubleshooting steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


228
229
230
# File 'lib/seam/resources/acs_entrance.rb', line 228

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_entrance_access_code_support_removed

Returns:

  • (String)


233
234
235
# File 'lib/seam/resources/acs_entrance.rb', line 233

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


236
# File 'lib/seam/resources/acs_entrance.rb', line 236

date_accessor :created_at