Class: Seam::Resources::AcsSystem

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Represents an access control system.

Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.

For details about the resources associated with an access control system, see the access control systems namespace.

Defined Under Namespace

Classes: Errors, Location, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_access_group_countFloat?

Number of access groups in the access control system.

Returns:

  • (Float, nil)


309
310
311
# File 'lib/seam/resources/acs_system.rb', line 309

def acs_access_group_count
  @acs_access_group_count
end

#acs_system_idString

Returns:

  • (String)


312
313
314
# File 'lib/seam/resources/acs_system.rb', line 312

def acs_system_id
  @acs_system_id
end

#acs_user_countFloat?

Number of users in the access control system.

Returns:

  • (Float, nil)


315
316
317
# File 'lib/seam/resources/acs_system.rb', line 315

def acs_user_count
  @acs_user_count
end

#connected_account_idString

ID of the connected account associated with the access control system.

Returns:

  • (String)


318
319
320
# File 'lib/seam/resources/acs_system.rb', line 318

def 
  @connected_account_id
end

#connected_account_idsArray<String>

Deprecated.

Use connected_account_id.

IDs of the connected accounts associated with the access control system.

Returns:

  • (Array<String>)


322
323
324
# File 'lib/seam/resources/acs_system.rb', line 322

def 
  @connected_account_ids
end

#default_credential_manager_acs_system_idString?

ID of the default credential manager acs_system for this access control system.

Returns:

  • (String, nil)


325
326
327
# File 'lib/seam/resources/acs_system.rb', line 325

def default_credential_manager_acs_system_id
  @default_credential_manager_acs_system_id
end

#external_typeString?

Brand-specific terminology for the access control system type. Known values:

  • pti_site
  • avigilon_alta_org
  • salto_ks_site
  • salto_space_system
  • brivo_account
  • hid_credential_manager_organization
  • visionline_system
  • assa_abloy_credential_service
  • latch_building
  • dormakaba_community_site
  • dormakaba_ambiance_site
  • legic_connect_credential_service
  • assa_abloy_vostio
  • assa_abloy_vostio_credential_service
  • hotek_site
  • kisi_organization
  • akiles_organization

Returns:

  • (String, nil)


346
347
348
# File 'lib/seam/resources/acs_system.rb', line 346

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the access control system type.

Returns:

  • (String, nil)


349
350
351
# File 'lib/seam/resources/acs_system.rb', line 349

def external_type_display_name
  @external_type_display_name
end

#image_alt_textString

Alternative text for the access control system image.

Returns:

  • (String)


352
353
354
# File 'lib/seam/resources/acs_system.rb', line 352

def image_alt_text
  @image_alt_text
end

#image_urlString

URL for the image that represents the access control system.

Returns:

  • (String)


355
356
357
# File 'lib/seam/resources/acs_system.rb', line 355

def image_url
  @image_url
end

#is_credential_managerBoolean

Indicates whether the acs_system is a credential manager.

Returns:

  • (Boolean)


358
359
360
# File 'lib/seam/resources/acs_system.rb', line 358

def is_credential_manager
  @is_credential_manager
end

#nameString

Name of the access control system.

Returns:

  • (String)


361
362
363
# File 'lib/seam/resources/acs_system.rb', line 361

def name
  @name
end

#system_typeString?

Deprecated.

Use external_type.

Known values:

  • pti_site
  • avigilon_alta_org
  • salto_ks_site
  • salto_space_system
  • brivo_account
  • hid_credential_manager_organization
  • visionline_system
  • assa_abloy_credential_service
  • latch_building
  • dormakaba_community_site
  • dormakaba_ambiance_site
  • legic_connect_credential_service
  • assa_abloy_vostio
  • assa_abloy_vostio_credential_service
  • hotek_site
  • kisi_organization
  • akiles_organization

Returns:

  • (String, nil)


382
383
384
# File 'lib/seam/resources/acs_system.rb', line 382

def system_type
  @system_type
end

#system_type_display_nameString?

Deprecated.

Use external_type_display_name.

Returns:

  • (String, nil)


385
386
387
# File 'lib/seam/resources/acs_system.rb', line 385

def system_type_display_name
  @system_type_display_name
end

#workspace_idString

ID of the workspace that contains the access control system.

Returns:

  • (String)


388
389
390
# File 'lib/seam/resources/acs_system.rb', line 388

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the access control system was created.

Returns:

  • (Time)


392
# File 'lib/seam/resources/acs_system.rb', line 392

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the access control system.

Returns:



303
# File 'lib/seam/resources/acs_system.rb', line 303

resource_list_accessor :errors, Errors

#locationLocation

Location information for the access control system.

Returns:



297
# File 'lib/seam/resources/acs_system.rb', line 297

resource_accessor :location, Location

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the access control system.

Returns:



300
# File 'lib/seam/resources/acs_system.rb', line 300

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the access control system.

Returns:



306
# File 'lib/seam/resources/acs_system.rb', line 306

resource_list_accessor :warnings, Warnings