Class: Seam::Resources::AcsSystem::Errors

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.

Defined Under Namespace

Classes: AccountDisconnected, AcsSystemDisconnected, BridgeDisconnected, InsufficientPermissions, ProviderServiceUnavailable, SaltoKsCertificationExpired, SaltoKsSubscriptionLimitExceeded, SeamBridgeDisconnected, VisionlineInstanceUnreachable

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • seam_bridge_disconnected
  • bridge_disconnected
  • visionline_instance_unreachable
  • salto_ks_subscription_limit_exceeded
  • insufficient_permissions
  • acs_system_disconnected
  • account_disconnected
  • salto_ks_certification_expired
  • provider_service_unavailable

Returns:

  • (String)


168
169
170
# File 'lib/seam/resources/acs_system.rb', line 168

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


171
172
173
# File 'lib/seam/resources/acs_system.rb', line 171

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


174
# File 'lib/seam/resources/acs_system.rb', line 174

date_accessor :created_at