Class: Seam::Resources::AcsSystem::Errors::AccountDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the login credentials are invalid. Reconnect the account using a Connect Webview to restore access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • account_disconnected

Returns:

  • (String)


117
118
119
# File 'lib/seam/resources/acs_system.rb', line 117

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


120
121
122
# File 'lib/seam/resources/acs_system.rb', line 120

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


123
# File 'lib/seam/resources/acs_system.rb', line 123

date_accessor :created_at