Class: Seam::Resources::AcsSystem::Errors::AcsSystemDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the access control system has been disconnected. See Troubleshooting Your Access Control System to resolve the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • acs_system_disconnected

Returns:

  • (String)


102
103
104
# File 'lib/seam/resources/acs_system.rb', line 102

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


105
106
107
# File 'lib/seam/resources/acs_system.rb', line 105

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


108
# File 'lib/seam/resources/acs_system.rb', line 108

date_accessor :created_at