Class: Seam::Resources::AcsSystem::Errors::BridgeDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the Seam API cannot communicate with Seam Bridge, for example, if Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • bridge_disconnected

Returns:

  • (String)


37
38
39
# File 'lib/seam/resources/acs_system.rb', line 37

def error_code
  @error_code
end

#is_bridge_errorBoolean?

Indicates whether the error is related to the Seam Bridge.

Returns:

  • (Boolean, nil)


40
41
42
# File 'lib/seam/resources/acs_system.rb', line 40

def is_bridge_error
  @is_bridge_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


43
44
45
# File 'lib/seam/resources/acs_system.rb', line 43

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


46
# File 'lib/seam/resources/acs_system.rb', line 46

date_accessor :created_at