Class: Seam::Resources::AcsSystem::Errors::InsufficientPermissions

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that Seam's integration user does not have sufficient permissions on the provider's system backing this access control system. Access cannot be managed until permissions are restored. See the error message for specifics, then either reauthorize the connected account in Seam or grant the integration user the required permissions in the provider's system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • insufficient_permissions

Returns:

  • (String)


87
88
89
# File 'lib/seam/resources/acs_system.rb', line 87

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


90
91
92
# File 'lib/seam/resources/acs_system.rb', line 90

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


93
# File 'lib/seam/resources/acs_system.rb', line 93

date_accessor :created_at