Class: Seam::Resources::AcsSystem::Errors::ProviderServiceUnavailable

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the access control system provider's service is temporarily unavailable. Seam will automatically retry and reconnect when the service becomes available again.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • provider_service_unavailable

Returns:

  • (String)


147
148
149
# File 'lib/seam/resources/acs_system.rb', line 147

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


150
151
152
# File 'lib/seam/resources/acs_system.rb', line 150

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


153
# File 'lib/seam/resources/acs_system.rb', line 153

date_accessor :created_at