Class: Seam::Resources::AcsSystem::Errors::SaltoKsCertificationExpired

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the access control system has lost its Salto KS certification. Contact support to regain access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_certification_expired

Returns:

  • (String)


132
133
134
# File 'lib/seam/resources/acs_system.rb', line 132

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


135
136
137
# File 'lib/seam/resources/acs_system.rb', line 135

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


138
# File 'lib/seam/resources/acs_system.rb', line 138

date_accessor :created_at