Class: Seam::Resources::AcsSystem::Errors::SaltoKsSubscriptionLimitExceeded

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the maximum number of users allowed for the site has been reached. This means that new access codes cannot be created. Contact Salto support to increase the user limit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_subscription_limit_exceeded

Returns:

  • (String)


72
73
74
# File 'lib/seam/resources/acs_system.rb', line 72

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


75
76
77
# File 'lib/seam/resources/acs_system.rb', line 75

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


78
# File 'lib/seam/resources/acs_system.rb', line 78

date_accessor :created_at