Class: Seam::Resources::AcsSystem::Errors::SeamBridgeDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the Seam API cannot communicate with Seam Bridge, for example, if Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. This error might also occur if Seam Bridge is connected to the wrong workspace. See also Troubleshooting Your Access Control System.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • seam_bridge_disconnected

Returns:

  • (String)


21
22
23
# File 'lib/seam/resources/acs_system.rb', line 21

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


24
25
26
# File 'lib/seam/resources/acs_system.rb', line 24

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


27
# File 'lib/seam/resources/acs_system.rb', line 27

date_accessor :created_at