Class: Seam::Resources::AcsSystem::Warnings::SaltoKsSubscriptionLimitAlmostReached

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates that the Salto KS site has exceeded 80% of the maximum number of allowed users. Increase your subscription limit or delete some users from your site to rectify the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


213
214
215
# File 'lib/seam/resources/acs_system.rb', line 213

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_subscription_limit_almost_reached

Returns:

  • (String)


218
219
220
# File 'lib/seam/resources/acs_system.rb', line 218

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


221
# File 'lib/seam/resources/acs_system.rb', line 221

date_accessor :created_at