Class: Seam::Resources::AcsSystem::Warnings::TimeZoneDoesNotMatchLocation

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Indicates the access control system time zone could not be determined because the reported physical location does not match the time zone configured on the physical ACS entrances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


228
229
230
# File 'lib/seam/resources/acs_system.rb', line 228

def message
  @message
end

#misconfigured_acs_entrance_idsArray<String>

Deprecated.

this field is deprecated.

Returns:

  • (Array<String>)


231
232
233
# File 'lib/seam/resources/acs_system.rb', line 231

def misconfigured_acs_entrance_ids
  @misconfigured_acs_entrance_ids
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • time_zone_does_not_match_location

Returns:

  • (String)


236
237
238
# File 'lib/seam/resources/acs_system.rb', line 236

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


239
# File 'lib/seam/resources/acs_system.rb', line 239

date_accessor :created_at