Class: Seam::Resources::AcsUser

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Represents a user in an access system.

An access system user typically refers to an individual who requires access, like an employee or resident. Each user can possess multiple credentials that serve as their keys or identifiers for access. The type of credential can vary widely. For example, in the Salto system, a user can have a PIN code, a mobile app account, and a fob. In other platforms, it is not uncommon for a user to have more than one of the same credential type, such as multiple key cards. Additionally, these credentials can have a schedule or validity period.

For details about how to configure users in your access system, see the corresponding system integration guide.

Defined Under Namespace

Classes: AccessSchedule, Errors, PendingMutations, SaltoKsMetadata, SaltoSpaceMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_system_idString

ID of the access system that contains the access system user.

Returns:

  • (String)


344
345
346
# File 'lib/seam/resources/acs_user.rb', line 344

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the access system user.

Returns:

  • (String)


347
348
349
# File 'lib/seam/resources/acs_user.rb', line 347

def acs_user_id
  @acs_user_id
end

#connected_account_idString

The ID of the connected account that is associated with the access system user.

Returns:

  • (String)


350
351
352
# File 'lib/seam/resources/acs_user.rb', line 350

def 
  @connected_account_id
end

#display_nameString

Display name for the access system user.

Returns:

  • (String)


353
354
355
# File 'lib/seam/resources/acs_user.rb', line 353

def display_name
  @display_name
end

#emailString?

Deprecated.

use email_address.

Returns:

  • (String, nil)


356
357
358
# File 'lib/seam/resources/acs_user.rb', line 356

def email
  @email
end

#email_addressString?

Email address of the access system user.

Returns:

  • (String, nil)


359
360
361
# File 'lib/seam/resources/acs_user.rb', line 359

def email_address
  @email_address
end

#external_typeString?

Brand-specific terminology for the access system user type. Known values:

  • pti_user
  • brivo_user
  • hid_credential_manager_user
  • salto_site_user
  • latch_user
  • dormakaba_community_user
  • salto_space_user
  • avigilon_alta_user
  • kisi_user

Returns:

  • (String, nil)


372
373
374
# File 'lib/seam/resources/acs_user.rb', line 372

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the access system user type.

Returns:

  • (String, nil)


375
376
377
# File 'lib/seam/resources/acs_user.rb', line 375

def external_type_display_name
  @external_type_display_name
end

#full_nameString?

Full name of the access system user.

Returns:

  • (String, nil)


378
379
380
# File 'lib/seam/resources/acs_user.rb', line 378

def full_name
  @full_name
end

#hid_acs_system_idString?

ID of the HID access control system associated with the user.

Returns:

  • (String, nil)


381
382
383
# File 'lib/seam/resources/acs_user.rb', line 381

def hid_acs_system_id
  @hid_acs_system_id
end

#is_managedTrueClass

Indicates whether Seam manages the access system user.

Returns:

  • (TrueClass)


384
385
386
# File 'lib/seam/resources/acs_user.rb', line 384

def is_managed
  @is_managed
end

#is_suspendedBoolean?

Indicates whether the access system user is currently suspended.

Returns:

  • (Boolean, nil)


387
388
389
# File 'lib/seam/resources/acs_user.rb', line 387

def is_suspended
  @is_suspended
end

#phone_numberString?

Phone number of the access system user in E.164 format (for example, +15555550100).

Returns:

  • (String, nil)


390
391
392
# File 'lib/seam/resources/acs_user.rb', line 390

def phone_number
  @phone_number
end

#user_identity_email_addressString?

Email address of the user identity associated with the access system user.

Returns:

  • (String, nil)


393
394
395
# File 'lib/seam/resources/acs_user.rb', line 393

def user_identity_email_address
  @user_identity_email_address
end

#user_identity_full_nameString?

Full name of the user identity associated with the access system user.

Returns:

  • (String, nil)


396
397
398
# File 'lib/seam/resources/acs_user.rb', line 396

def user_identity_full_name
  @user_identity_full_name
end

#user_identity_idString?

ID of the user identity associated with the access system user.

Returns:

  • (String, nil)


399
400
401
# File 'lib/seam/resources/acs_user.rb', line 399

def user_identity_id
  @user_identity_id
end

#user_identity_phone_numberString?

Phone number of the user identity associated with the access system user in E.164 format (for example, +15555550100).

Returns:

  • (String, nil)


402
403
404
# File 'lib/seam/resources/acs_user.rb', line 402

def user_identity_phone_number
  @user_identity_phone_number
end

#workspace_idString

ID of the workspace that contains the access system user.

Returns:

  • (String)


405
406
407
# File 'lib/seam/resources/acs_user.rb', line 405

def workspace_id
  @workspace_id
end

Instance Method Details

#access_scheduleAccessSchedule?

starts_at and ends_at timestamps for the access system user's access.

Returns:



326
# File 'lib/seam/resources/acs_user.rb', line 326

resource_accessor :access_schedule, AccessSchedule

#created_atTime

Date and time at which the access system user was created.

Returns:

  • (Time)


409
# File 'lib/seam/resources/acs_user.rb', line 409

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the access system user.

Returns:



335
# File 'lib/seam/resources/acs_user.rb', line 335

resource_list_accessor :errors, Errors

#pending_mutationsArray<PendingMutations>

Pending mutations associated with the access system user. Seam is in the process of pushing these mutations to the integrated access system.

Returns:



338
# File 'lib/seam/resources/acs_user.rb', line 338

resource_list_accessor :pending_mutations, PendingMutations

#salto_ks_metadataSaltoKsMetadata?

Salto KS-specific metadata associated with the access system user.

Returns:



329
# File 'lib/seam/resources/acs_user.rb', line 329

resource_accessor :salto_ks_metadata, SaltoKsMetadata

#salto_space_metadataSaltoSpaceMetadata?

Salto Space-specific metadata associated with the access system user.

Returns:



332
# File 'lib/seam/resources/acs_user.rb', line 332

resource_accessor :salto_space_metadata, SaltoSpaceMetadata

#warningsArray<Warnings>

Warnings associated with the access system user.

Returns:



341
# File 'lib/seam/resources/acs_user.rb', line 341

resource_list_accessor :warnings, Warnings