Class: Seam::Resources::AcsUser::Errors::DeletedExternally

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user was deleted from the access system outside of Seam.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Known values:

  • deleted_externally

Returns:

  • (String)


27
28
29
# File 'lib/seam/resources/acs_user.rb', line 27

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


30
31
32
# File 'lib/seam/resources/acs_user.rb', line 30

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


33
# File 'lib/seam/resources/acs_user.rb', line 33

date_accessor :created_at