Class: Seam::Resources::AcsUser::Errors::FailedToDeleteOnAcsSystem
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsUser::Errors::FailedToDeleteOnAcsSystem
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user was not deleted on the access system. This is likely due to an internal unexpected error. Contact Seam support.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Known values: -
failed_to_delete_on_acs_system. -
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Known values:
failed_to_delete_on_acs_system
83 84 85 |
# File 'lib/seam/resources/acs_user.rb', line 83 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
86 87 88 |
# File 'lib/seam/resources/acs_user.rb', line 86 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
89 |
# File 'lib/seam/resources/acs_user.rb', line 89 date_accessor :created_at |