Class: Seam::Resources::AcsUser::Errors::FailedToUpdateOnAcsSystem

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user was not updated on the access system. This is likely due to an internal unexpected error. Contact Seam support.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Known values:

  • failed_to_update_on_acs_system

Returns:

  • (String)


69
70
71
# File 'lib/seam/resources/acs_user.rb', line 69

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


72
73
74
# File 'lib/seam/resources/acs_user.rb', line 72

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


75
# File 'lib/seam/resources/acs_user.rb', line 75

date_accessor :created_at