Class: Seam::Resources::AcsUser::Errors::LatchConflictWithResidentUser

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user was created from the Seam API but also exists on Mission Control. This is unsupported. Contact Seam support.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Known values:

  • latch_conflict_with_resident_user

Returns:

  • (String)


97
98
99
# File 'lib/seam/resources/acs_user.rb', line 97

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


100
101
102
# File 'lib/seam/resources/acs_user.rb', line 100

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


103
# File 'lib/seam/resources/acs_user.rb', line 103

date_accessor :created_at