Class: Seam::Resources::AcsUser::Errors::SaltoKsSubscriptionLimitExceeded

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user could not be subscribed on Salto KS because the subscription limit has been exceeded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Known values:

  • salto_ks_subscription_limit_exceeded

Returns:

  • (String)


41
42
43
# File 'lib/seam/resources/acs_user.rb', line 41

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


44
45
46
# File 'lib/seam/resources/acs_user.rb', line 44

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


47
# File 'lib/seam/resources/acs_user.rb', line 47

date_accessor :created_at