Class: Seam::Resources::AcsUser::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser::PendingMutations
- Defined in:
- lib/seam/resources/acs_user.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#acs_access_group_id ⇒ String
ID of the access group involved in the scheduled change.
-
#message ⇒ String
Detailed description of the mutation.
- #mutation_code ⇒ String
-
#variant ⇒ String
Whether the user is scheduled to be added to or removed from the access group.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the mutation was created.
- #from ⇒ From
-
#scheduled_at ⇒ Time?
Optional: When the user creation is scheduled to occur.
- #to ⇒ To
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_access_group_id ⇒ String
ID of the access group involved in the scheduled change.
90 91 92 |
# File 'lib/seam/resources/acs_user.rb', line 90 def acs_access_group_id @acs_access_group_id end |
#message ⇒ String
Detailed description of the mutation.
93 94 95 |
# File 'lib/seam/resources/acs_user.rb', line 93 def @message end |
#mutation_code ⇒ String
95 96 97 |
# File 'lib/seam/resources/acs_user.rb', line 95 def mutation_code @mutation_code end |
#variant ⇒ String
Whether the user is scheduled to be added to or removed from the access group.
98 99 100 |
# File 'lib/seam/resources/acs_user.rb', line 98 def variant @variant end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the mutation was created.
101 |
# File 'lib/seam/resources/acs_user.rb', line 101 date_accessor :created_at |
#scheduled_at ⇒ Time?
Optional: When the user creation is scheduled to occur.
104 |
# File 'lib/seam/resources/acs_user.rb', line 104 date_accessor :scheduled_at |