Class: Seam::Resources::AcsUser::SaltoSpaceMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser::SaltoSpaceMetadata
- Defined in:
- lib/seam/resources/acs_user.rb
Instance Attribute Summary collapse
-
#audit_openings ⇒ Boolean?
Indicates whether AuditOpenings is enabled for the user in the Salto Space access system.
-
#user_id ⇒ String?
User ID in the Salto Space access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#audit_openings ⇒ Boolean?
Indicates whether AuditOpenings is enabled for the user in the Salto Space access system.
116 117 118 |
# File 'lib/seam/resources/acs_user.rb', line 116 def audit_openings @audit_openings end |
#user_id ⇒ String?
User ID in the Salto Space access system.
119 120 121 |
# File 'lib/seam/resources/acs_user.rb', line 119 def user_id @user_id end |