Class: Seam::Resources::AcsUser::Warnings

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.

Defined Under Namespace

Classes: AcsUserInactive, BeingDeleted, LatchResidentUser, SaltoKsUserNotSubscribed, UnknownIssueWithAcsUser

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


302
303
304
# File 'lib/seam/resources/acs_user.rb', line 302

def message
  @message
end

#warning_codeString

Known values:

  • being_deleted
  • salto_ks_user_not_subscribed
  • acs_user_inactive
  • unknown_issue_with_acs_user
  • latch_resident_user

Returns:

  • (String)


310
311
312
# File 'lib/seam/resources/acs_user.rb', line 310

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


313
# File 'lib/seam/resources/acs_user.rb', line 313

date_accessor :created_at