Class: Seam::Resources::AcsUser::Warnings::AcsUserInactive

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user exists but is not currently able to gain access—for example, because their access schedule has not started yet or has ended, the access system has reached its limit for active users, or they have been unsubscribed or deactivated. Refer to the warning message for the provider-specific reason. This is distinct from is_suspended, which indicates the user has been explicitly blocked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


262
263
264
# File 'lib/seam/resources/acs_user.rb', line 262

def message
  @message
end

#warning_codeString

Known values:

  • acs_user_inactive

Returns:

  • (String)


266
267
268
# File 'lib/seam/resources/acs_user.rb', line 266

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


269
# File 'lib/seam/resources/acs_user.rb', line 269

date_accessor :created_at