Class: Seam::Resources::AcsUser::Warnings::BeingDeleted
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsUser::Warnings::BeingDeleted
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user is being deleted from the access system. This is a temporary state, and the access system user will be deleted shortly.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Known values: -
being_deleted.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
234 235 236 |
# File 'lib/seam/resources/acs_user.rb', line 234 def @message end |
#warning_code ⇒ String
Known values:
being_deleted
238 239 240 |
# File 'lib/seam/resources/acs_user.rb', line 238 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
241 |
# File 'lib/seam/resources/acs_user.rb', line 241 date_accessor :created_at |