Class: Seam::Resources::AcsUser::Warnings::LatchResidentUser

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user was created on Latch Mission Control. Please use the Latch Mission Control to manage this user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


290
291
292
# File 'lib/seam/resources/acs_user.rb', line 290

def message
  @message
end

#warning_codeString

Known values:

  • latch_resident_user

Returns:

  • (String)


294
295
296
# File 'lib/seam/resources/acs_user.rb', line 294

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


297
# File 'lib/seam/resources/acs_user.rb', line 297

date_accessor :created_at