Class: Seam::Resources::AcsUser::Warnings::SaltoKsUserNotSubscribed

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Indicates that the access system user is not subscribed on Salto KS, so they cannot unlock doors or perform any actions. This occurs when the their access schedule hasn’t started yet, if their access schedule has ended, if the site has reached its limit for active users (subscription slots), or if they have been manually unsubscribed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


248
249
250
# File 'lib/seam/resources/acs_user.rb', line 248

def message
  @message
end

#warning_codeString

Known values:

  • salto_ks_user_not_subscribed

Returns:

  • (String)


252
253
254
# File 'lib/seam/resources/acs_user.rb', line 252

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


255
# File 'lib/seam/resources/acs_user.rb', line 255

date_accessor :created_at