Class: Seam::Resources::AcsUser::Warnings::UnknownIssueWithAcsUser

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

An unknown issue occurred while syncing the state of this access system user with the provider. This issue may affect the proper functioning of this user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


276
277
278
# File 'lib/seam/resources/acs_user.rb', line 276

def message
  @message
end

#warning_codeString

Known values:

  • unknown_issue_with_acs_user

Returns:

  • (String)


280
281
282
# File 'lib/seam/resources/acs_user.rb', line 280

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


283
# File 'lib/seam/resources/acs_user.rb', line 283

date_accessor :created_at