Class: Seam::Resources::ActionAttempt
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Locking a door is pending.
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ Object
ID of the action attempt.
-
#action_type ⇒ Object
Action attempt to track the status of locking a door.
-
#error ⇒ Object
Error associated with the action.
-
#result ⇒ Object
Result of the action.
-
#status ⇒ Object
Returns the value of attribute status.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#action_attempt_id ⇒ Object
ID of the action attempt.
8 9 10 |
# File 'lib/seam/resources/action_attempt.rb', line 8 def action_attempt_id @action_attempt_id end |
#action_type ⇒ Object
Action attempt to track the status of locking a door.
10 11 12 |
# File 'lib/seam/resources/action_attempt.rb', line 10 def action_type @action_type end |
#error ⇒ Object
Error associated with the action.
12 13 14 |
# File 'lib/seam/resources/action_attempt.rb', line 12 def error @error end |
#result ⇒ Object
Result of the action.
14 15 16 |
# File 'lib/seam/resources/action_attempt.rb', line 14 def result @result end |
#status ⇒ Object
Returns the value of attribute status.
15 16 17 |
# File 'lib/seam/resources/action_attempt.rb', line 15 def status @status end |