Class: Seam::Resources::ActionAttempt::AssignCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Assigning a credential to an access method is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


1091
1092
1093
# File 'lib/seam/resources/action_attempt.rb', line 1091

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of assigning a pre-registered card credential to an access method. Known values:

  • ASSIGN_CREDENTIAL

Returns:

  • (String)


1096
1097
1098
# File 'lib/seam/resources/action_attempt.rb', line 1096

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


1102
1103
1104
# File 'lib/seam/resources/action_attempt.rb', line 1102

def status
  @status
end

Instance Method Details

#errorError?

Only present when status is error; nil otherwise.

Returns:



1082
# File 'lib/seam/resources/action_attempt.rb', line 1082

resource_accessor :error, Error

#resultResult?

Result of assigning a credential. If successful, includes the updated access method with the assigned credential. Only present when status is success; nil otherwise.

Returns:



1087
# File 'lib/seam/resources/action_attempt.rb', line 1087

resource_accessor :result, Result