Class: Seam::Resources::ActionAttempt::AssignCredential::Error

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


911
912
913
# File 'lib/seam/resources/action_attempt.rb', line 911

def message
  @message
end

#typeString

Error type to indicate that no matching credential was found. Known values:

  • uncategorized_error
  • action_attempt_expired
  • credential_not_found

Returns:

  • (String)


918
919
920
# File 'lib/seam/resources/action_attempt.rb', line 918

def type
  @type
end