Class: Seam::Resources::ActionAttempt::AssignCredential::Result::PendingMutations

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the mutation.

Returns:

  • (String)


963
964
965
# File 'lib/seam/resources/action_attempt.rb', line 963

def message
  @message
end

#mutation_codeString

Mutation code to indicate that Seam is in the process of updating the access times for this access method. Known values:

  • provisioning_access
  • revoking_access
  • updating_access_times

Returns:

  • (String)


970
971
972
# File 'lib/seam/resources/action_attempt.rb', line 970

def mutation_code
  @mutation_code
end

Instance Method Details

#created_atTime

Date and time at which the mutation was created.

Returns:

  • (Time)


973
# File 'lib/seam/resources/action_attempt.rb', line 973

date_accessor :created_at

#fromFrom

Previous access time configuration.

Returns:



957
# File 'lib/seam/resources/action_attempt.rb', line 957

resource_accessor :from, From

#toTo

New access time configuration.

Returns:



960
# File 'lib/seam/resources/action_attempt.rb', line 960

resource_accessor :to, To