Class: Seam::Resources::ActionAttempt::ConfigureAutoLock
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::ConfigureAutoLock
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Configuring the auto-lock is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of configuring the auto-lock on a lock.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1411 1412 1413 |
# File 'lib/seam/resources/action_attempt.rb', line 1411 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of configuring the auto-lock on a lock. Known values:
CONFIGURE_AUTO_LOCK
1416 1417 1418 |
# File 'lib/seam/resources/action_attempt.rb', line 1416 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1422 1423 1424 |
# File 'lib/seam/resources/action_attempt.rb', line 1422 def status @status end |