Class: Seam::Resources::ActionAttempt::EncodeCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::EncodeCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Encoding credential data from the physical encoder onto a card is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of encoding credential data from the physical encoder onto a card.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Only present when
statusiserror;nilotherwise. -
#result ⇒ Result?
Result of an encoding attempt.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
669 670 671 |
# File 'lib/seam/resources/action_attempt.rb', line 669 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of encoding credential data from the physical encoder onto a card. Known values:
ENCODE_CREDENTIAL
674 675 676 |
# File 'lib/seam/resources/action_attempt.rb', line 674 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
680 681 682 |
# File 'lib/seam/resources/action_attempt.rb', line 680 def status @status end |