Class: Seam::Resources::ActionAttempt::LockDoor
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::LockDoor
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Locking a door is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of locking a door.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
41 42 43 |
# File 'lib/seam/resources/action_attempt.rb', line 41 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of locking a door. Known values:
LOCK_DOOR
46 47 48 |
# File 'lib/seam/resources/action_attempt.rb', line 46 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
52 53 54 |
# File 'lib/seam/resources/action_attempt.rb', line 52 def status @status end |