Class: Seam::Resources::ActionAttempt::PushThermostatPrograms
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::PushThermostatPrograms
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Pushing thermostat weekly programs is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of pushing thermostat programs.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1319 1320 1321 |
# File 'lib/seam/resources/action_attempt.rb', line 1319 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of pushing thermostat programs. Known values:
PUSH_THERMOSTAT_PROGRAMS
1324 1325 1326 |
# File 'lib/seam/resources/action_attempt.rb', line 1324 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1330 1331 1332 |
# File 'lib/seam/resources/action_attempt.rb', line 1330 def status @status end |