Class: Seam::Resources::ActionAttempt::ResetSandboxWorkspace
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::ResetSandboxWorkspace
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Resetting a sandbox workspace is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of resetting a sandbox workspace.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1103 1104 1105 |
# File 'lib/seam/resources/action_attempt.rb', line 1103 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of resetting a sandbox workspace. Known values:
RESET_SANDBOX_WORKSPACE
1108 1109 1110 |
# File 'lib/seam/resources/action_attempt.rb', line 1108 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1114 1115 1116 |
# File 'lib/seam/resources/action_attempt.rb', line 1114 def status @status end |