Class: Seam::Resources::ActionAttempt::Result

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: AcsCredentialOnEncoder, AcsCredentialOnSeam, AkilesMetadata, AssaAbloyVostioMetadata, Errors, PendingMutations, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_codeHash?

Returns:

  • (Hash, nil)


395
396
397
# File 'lib/seam/resources/action_attempt.rb', line 395

def access_code
  @access_code
end

#access_methodString

Access method for the credential. Supported values: code, card, mobile_key, cloud_key.

Returns:

  • (String)


398
399
400
# File 'lib/seam/resources/action_attempt.rb', line 398

def access_method
  @access_method
end

#access_method_idString

ID of the access method.

Returns:

  • (String)


401
402
403
# File 'lib/seam/resources/action_attempt.rb', line 401

def access_method_id
  @access_method_id
end

#acs_credential_idString

ID of the credential.

Returns:

  • (String)


404
405
406
# File 'lib/seam/resources/action_attempt.rb', line 404

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idString?

ID of the credential pool to which the credential belongs.

Returns:

  • (String, nil)


407
408
409
# File 'lib/seam/resources/action_attempt.rb', line 407

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idString

ID of the access control system that contains the credential.

Returns:

  • (String)


410
411
412
# File 'lib/seam/resources/action_attempt.rb', line 410

def acs_system_id
  @acs_system_id
end

#acs_user_idString?

ID of the ACS user to whom the credential belongs.

Returns:

  • (String, nil)


413
414
415
# File 'lib/seam/resources/action_attempt.rb', line 413

def acs_user_id
  @acs_user_id
end

#card_numberString?

Number of the card associated with the credential.

Returns:

  • (String, nil)


416
417
418
# File 'lib/seam/resources/action_attempt.rb', line 416

def card_number
  @card_number
end

#client_session_tokenString?

Token of the client session associated with the access method.

Returns:

  • (String, nil)


419
420
421
# File 'lib/seam/resources/action_attempt.rb', line 419

def client_session_token
  @client_session_token
end

#codeString?

Returns:

  • (String, nil)


421
422
423
# File 'lib/seam/resources/action_attempt.rb', line 421

def code
  @code
end

#connected_account_idString

ID of the connected account to which the credential belongs.

Returns:

  • (String)


424
425
426
# File 'lib/seam/resources/action_attempt.rb', line 424

def 
  @connected_account_id
end

#customization_profile_idString?

ID of the customization profile associated with the access method.

Returns:

  • (String, nil)


427
428
429
# File 'lib/seam/resources/action_attempt.rb', line 427

def customization_profile_id
  @customization_profile_id
end

#display_nameString

Returns:

  • (String)


429
430
431
# File 'lib/seam/resources/action_attempt.rb', line 429

def display_name
  @display_name
end

#ends_atString?

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.

Returns:

  • (String, nil)


432
433
434
# File 'lib/seam/resources/action_attempt.rb', line 432

def ends_at
  @ends_at
end

#external_typeString?

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.

Returns:

  • (String, nil)


435
436
437
# File 'lib/seam/resources/action_attempt.rb', line 435

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the credential type.

Returns:

  • (String, nil)


438
439
440
# File 'lib/seam/resources/action_attempt.rb', line 438

def external_type_display_name
  @external_type_display_name
end

#instant_key_urlString?

URL of the Instant Key for mobile key access methods.

Returns:

  • (String, nil)


441
442
443
# File 'lib/seam/resources/action_attempt.rb', line 441

def instant_key_url
  @instant_key_url
end

#is_assignment_requiredBoolean?

Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.

Returns:

  • (Boolean, nil)


444
445
446
# File 'lib/seam/resources/action_attempt.rb', line 444

def is_assignment_required
  @is_assignment_required
end

#is_encoding_requiredBoolean?

Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.

Returns:

  • (Boolean, nil)


447
448
449
# File 'lib/seam/resources/action_attempt.rb', line 447

def is_encoding_required
  @is_encoding_required
end

#is_issuedBoolean?

Returns:

  • (Boolean, nil)


449
450
451
# File 'lib/seam/resources/action_attempt.rb', line 449

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerBoolean?

Indicates whether the latest state of the credential has been synced from Seam to the provider.

Returns:

  • (Boolean, nil)


452
453
454
# File 'lib/seam/resources/action_attempt.rb', line 452

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedBoolean

Indicates whether Seam manages the credential.

Returns:

  • (Boolean)


455
456
457
# File 'lib/seam/resources/action_attempt.rb', line 455

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialBoolean?

Indicates whether the credential is a multi-phone sync credential.

Returns:

  • (Boolean, nil)


458
459
460
# File 'lib/seam/resources/action_attempt.rb', line 458

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useBoolean?

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean, nil)


461
462
463
# File 'lib/seam/resources/action_attempt.rb', line 461

def is_one_time_use
  @is_one_time_use
end

#is_ready_for_assignmentBoolean?

Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.

Returns:

  • (Boolean, nil)


464
465
466
# File 'lib/seam/resources/action_attempt.rb', line 464

def is_ready_for_assignment
  @is_ready_for_assignment
end

#is_ready_for_encodingBoolean?

Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.

Returns:

  • (Boolean, nil)


467
468
469
# File 'lib/seam/resources/action_attempt.rb', line 467

def is_ready_for_encoding
  @is_ready_for_encoding
end

#modeString

Access method mode. Supported values: code, card, mobile_key, cloud_key.

Returns:

  • (String)


470
471
472
# File 'lib/seam/resources/action_attempt.rb', line 470

def mode
  @mode
end

#noise_thresholdHash

Returns:

  • (Hash)


472
473
474
# File 'lib/seam/resources/action_attempt.rb', line 472

def noise_threshold
  @noise_threshold
end

#parent_acs_credential_idString?

ID of the parent credential.

Returns:

  • (String, nil)


475
476
477
# File 'lib/seam/resources/action_attempt.rb', line 475

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atString?

Date and time at which the credential validity starts, in ISO 8601 format.

Returns:

  • (String, nil)


478
479
480
# File 'lib/seam/resources/action_attempt.rb', line 478

def starts_at
  @starts_at
end

#user_identity_idString?

ID of the user identity to whom the credential belongs.

Returns:

  • (String, nil)


481
482
483
# File 'lib/seam/resources/action_attempt.rb', line 481

def user_identity_id
  @user_identity_id
end

#was_confirmed_by_deviceBoolean?

Returns:

  • (Boolean, nil)


483
484
485
# File 'lib/seam/resources/action_attempt.rb', line 483

def was_confirmed_by_device
  @was_confirmed_by_device
end

#workspace_idString

Returns:

  • (String)


485
486
487
# File 'lib/seam/resources/action_attempt.rb', line 485

def workspace_id
  @workspace_id
end

Instance Method Details

#acs_credential_on_encoderAcsCredentialOnEncoder?

Snapshot of credential data read from the physical encoder.

Returns:



374
# File 'lib/seam/resources/action_attempt.rb', line 374

resource_accessor :acs_credential_on_encoder, AcsCredentialOnEncoder

#acs_credential_on_seamAcsCredentialOnSeam?

Corresponding credential data as stored on Seam and the access system.

Returns:



377
# File 'lib/seam/resources/action_attempt.rb', line 377

resource_accessor :acs_credential_on_seam, AcsCredentialOnSeam

#akiles_metadataAkilesMetadata?

Akiles-specific metadata for the credential.

Returns:



380
# File 'lib/seam/resources/action_attempt.rb', line 380

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

Vostio-specific metadata for the credential.

Returns:



383
# File 'lib/seam/resources/action_attempt.rb', line 383

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#created_atTime

Returns:

  • (Time)


487
# File 'lib/seam/resources/action_attempt.rb', line 487

date_accessor :created_at

#errorsArray<Errors>

Returns:



388
# File 'lib/seam/resources/action_attempt.rb', line 388

resource_list_accessor :errors, Errors

#issued_atTime?

Returns:

  • (Time, nil)


489
# File 'lib/seam/resources/action_attempt.rb', line 489

date_accessor :issued_at

#latest_desired_state_synced_with_provider_atTime?

Date and time at which the state of the credential was most recently synced from Seam to the provider.

Returns:

  • (Time, nil)


492
# File 'lib/seam/resources/action_attempt.rb', line 492

date_accessor :latest_desired_state_synced_with_provider_at

#pending_mutationsArray<PendingMutations>

Pending mutations for the access method. Indicates operations that are in progress.

Returns:



391
# File 'lib/seam/resources/action_attempt.rb', line 391

resource_list_accessor :pending_mutations, PendingMutations

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the credential.

Returns:



386
# File 'lib/seam/resources/action_attempt.rb', line 386

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Returns:



393
# File 'lib/seam/resources/action_attempt.rb', line 393

resource_list_accessor :warnings, Warnings