Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: VisionlineMetadata
Instance Attribute Summary collapse
-
#card_number ⇒ String?
A number or string that physically identifies the card associated with the credential.
-
#is_issued ⇒ Boolean?
Indicates whether the credential has been issued (encoded onto a card).
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which the credential was created.
-
#ends_at ⇒ Time?
Date and time at which the credential will stop being usable.
-
#starts_at ⇒ Time?
Date and time at which the credential becomes usable.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#card_number ⇒ String?
A number or string that physically identifies the card associated with the credential.
61 62 63 |
# File 'lib/seam/resources/action_attempt.rb', line 61 def card_number @card_number end |
#is_issued ⇒ Boolean?
Indicates whether the credential has been issued (encoded onto a card).
64 65 66 |
# File 'lib/seam/resources/action_attempt.rb', line 64 def is_issued @is_issued end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which the credential was created.
67 |
# File 'lib/seam/resources/action_attempt.rb', line 67 date_accessor :created_at |
#ends_at ⇒ Time?
Date and time at which the credential will stop being usable.
70 |
# File 'lib/seam/resources/action_attempt.rb', line 70 date_accessor :ends_at |
#starts_at ⇒ Time?
Date and time at which the credential becomes usable.
73 |
# File 'lib/seam/resources/action_attempt.rb', line 73 date_accessor :starts_at |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
58 |
# File 'lib/seam/resources/action_attempt.rb', line 58 resource_accessor :visionline_metadata, VisionlineMetadata |