Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#cancelledBoolean?

Indicates whether the card associated with the credential is cancelled.

Returns:

  • (Boolean, nil)


20
21
22
# File 'lib/seam/resources/action_attempt.rb', line 20

def cancelled
  @cancelled
end

#card_formatString?

Format of the card associated with the credential.

Returns:

  • (String, nil)


23
24
25
# File 'lib/seam/resources/action_attempt.rb', line 23

def card_format
  @card_format
end

#card_holderString?

Holder of the card associated with the credential.

Returns:

  • (String, nil)


26
27
28
# File 'lib/seam/resources/action_attempt.rb', line 26

def card_holder
  @card_holder
end

#card_idString?

Card ID for the Visionline card associated with the credential.

Returns:

  • (String, nil)


29
30
31
# File 'lib/seam/resources/action_attempt.rb', line 29

def card_id
  @card_id
end

#common_acs_entrance_idsArray<String>

IDs of the common entrances for the credential.

Returns:

  • (Array<String>)


32
33
34
# File 'lib/seam/resources/action_attempt.rb', line 32

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#discardedBoolean?

Indicates whether the card associated with the credential is discarded.

Returns:

  • (Boolean, nil)


35
36
37
# File 'lib/seam/resources/action_attempt.rb', line 35

def discarded
  @discarded
end

#expiredBoolean?

Indicates whether the card associated with the credential is expired.

Returns:

  • (Boolean, nil)


38
39
40
# File 'lib/seam/resources/action_attempt.rb', line 38

def expired
  @expired
end

#guest_acs_entrance_idsArray<String>

IDs of the guest entrances for the credential.

Returns:

  • (Array<String>)


41
42
43
# File 'lib/seam/resources/action_attempt.rb', line 41

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#number_of_issued_cardsFloat?

Number of issued cards associated with the credential.

Returns:

  • (Float, nil)


44
45
46
# File 'lib/seam/resources/action_attempt.rb', line 44

def number_of_issued_cards
  @number_of_issued_cards
end

#overriddenBoolean?

Indicates whether the card associated with the credential is overridden.

Returns:

  • (Boolean, nil)


47
48
49
# File 'lib/seam/resources/action_attempt.rb', line 47

def overridden
  @overridden
end

#overwrittenBoolean?

Indicates whether the card associated with the credential is overwritten.

Returns:

  • (Boolean, nil)


50
51
52
# File 'lib/seam/resources/action_attempt.rb', line 50

def overwritten
  @overwritten
end

#pending_auto_updateBoolean?

Indicates whether the card associated with the credential is pending auto-update.

Returns:

  • (Boolean, nil)


53
54
55
# File 'lib/seam/resources/action_attempt.rb', line 53

def pending_auto_update
  @pending_auto_update
end