Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodString

Access method for the credential. Supported values: code, card, mobile_key, cloud_key.

Returns:

  • (String)


176
177
178
# File 'lib/seam/resources/action_attempt.rb', line 176

def access_method
  @access_method
end

#acs_credential_idString

ID of the credential.

Returns:

  • (String)


179
180
181
# File 'lib/seam/resources/action_attempt.rb', line 179

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idString?

ID of the credential pool to which the credential belongs.

Returns:

  • (String, nil)


182
183
184
# File 'lib/seam/resources/action_attempt.rb', line 182

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idString

ID of the access control system that contains the credential.

Returns:

  • (String)


185
186
187
# File 'lib/seam/resources/action_attempt.rb', line 185

def acs_system_id
  @acs_system_id
end

#acs_user_idString?

ID of the ACS user to whom the credential belongs.

Returns:

  • (String, nil)


188
189
190
# File 'lib/seam/resources/action_attempt.rb', line 188

def acs_user_id
  @acs_user_id
end

#card_numberString?

Number of the card associated with the credential.

Returns:

  • (String, nil)


191
192
193
# File 'lib/seam/resources/action_attempt.rb', line 191

def card_number
  @card_number
end

#codeString?

Access (PIN) code for the credential.

Returns:

  • (String, nil)


194
195
196
# File 'lib/seam/resources/action_attempt.rb', line 194

def code
  @code
end

#connected_account_idString

ID of the connected account to which the credential belongs.

Returns:

  • (String)


197
198
199
# File 'lib/seam/resources/action_attempt.rb', line 197

def 
  @connected_account_id
end

#display_nameString

Display name that corresponds to the credential type.

Returns:

  • (String)


200
201
202
# File 'lib/seam/resources/action_attempt.rb', line 200

def display_name
  @display_name
end

#ends_atString?

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.

Returns:

  • (String, nil)


203
204
205
# File 'lib/seam/resources/action_attempt.rb', line 203

def ends_at
  @ends_at
end

#external_typeString?

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.

Returns:

  • (String, nil)


206
207
208
# File 'lib/seam/resources/action_attempt.rb', line 206

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the credential type.

Returns:

  • (String, nil)


209
210
211
# File 'lib/seam/resources/action_attempt.rb', line 209

def external_type_display_name
  @external_type_display_name
end

#is_issuedBoolean?

Indicates whether the credential has been encoded onto a card.

Returns:

  • (Boolean, nil)


212
213
214
# File 'lib/seam/resources/action_attempt.rb', line 212

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerBoolean?

Indicates whether the latest state of the credential has been synced from Seam to the provider.

Returns:

  • (Boolean, nil)


215
216
217
# File 'lib/seam/resources/action_attempt.rb', line 215

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedBoolean

Returns:

  • (Boolean)


217
218
219
# File 'lib/seam/resources/action_attempt.rb', line 217

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialBoolean?

Indicates whether the credential is a multi-phone sync credential.

Returns:

  • (Boolean, nil)


220
221
222
# File 'lib/seam/resources/action_attempt.rb', line 220

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useBoolean?

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean, nil)


223
224
225
# File 'lib/seam/resources/action_attempt.rb', line 223

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idString?

ID of the parent credential.

Returns:

  • (String, nil)


226
227
228
# File 'lib/seam/resources/action_attempt.rb', line 226

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atString?

Date and time at which the credential validity starts, in ISO 8601 format.

Returns:

  • (String, nil)


229
230
231
# File 'lib/seam/resources/action_attempt.rb', line 229

def starts_at
  @starts_at
end

#user_identity_idString?

ID of the user identity to whom the credential belongs.

Returns:

  • (String, nil)


232
233
234
# File 'lib/seam/resources/action_attempt.rb', line 232

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the workspace that contains the credential.

Returns:

  • (String)


235
236
237
# File 'lib/seam/resources/action_attempt.rb', line 235

def workspace_id
  @workspace_id
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata for the credential.

Returns:



161
# File 'lib/seam/resources/action_attempt.rb', line 161

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

Vostio-specific metadata for the credential.

Returns:



164
# File 'lib/seam/resources/action_attempt.rb', line 164

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#created_atTime

Date and time at which the credential was created.

Returns:

  • (Time)


238
# File 'lib/seam/resources/action_attempt.rb', line 238

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the credential.

Returns:



170
# File 'lib/seam/resources/action_attempt.rb', line 170

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the credential was encoded onto a card.

Returns:

  • (Time, nil)


241
# File 'lib/seam/resources/action_attempt.rb', line 241

date_accessor :issued_at

#latest_desired_state_synced_with_provider_atTime?

Date and time at which the state of the credential was most recently synced from Seam to the provider.

Returns:

  • (Time, nil)


244
# File 'lib/seam/resources/action_attempt.rb', line 244

date_accessor :latest_desired_state_synced_with_provider_at

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the credential.

Returns:



167
# File 'lib/seam/resources/action_attempt.rb', line 167

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the credential.

Returns:



173
# File 'lib/seam/resources/action_attempt.rb', line 173

resource_list_accessor :warnings, Warnings