Class: Seam::Resources::ActionAttempt::Result::PendingMutations

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the mutation.

Returns:

  • (String)


313
314
315
# File 'lib/seam/resources/action_attempt.rb', line 313

def message
  @message
end

#mutation_codeString

Mutation code to indicate that Seam is in the process of updating the access times for this access method.

Returns:

  • (String)


316
317
318
# File 'lib/seam/resources/action_attempt.rb', line 316

def mutation_code
  @mutation_code
end

Instance Method Details

#created_atTime

Date and time at which the mutation was created.

Returns:

  • (Time)


319
# File 'lib/seam/resources/action_attempt.rb', line 319

date_accessor :created_at

#fromFrom

Previous access time configuration.

Returns:



307
# File 'lib/seam/resources/action_attempt.rb', line 307

resource_accessor :from, From

#toTo

New access time configuration.

Returns:



310
# File 'lib/seam/resources/action_attempt.rb', line 310

resource_accessor :to, To