Class: Seam::Resources::ActionAttempt::Result::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinBoolean?

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.

Returns:

  • (Boolean, nil)


325
326
327
# File 'lib/seam/resources/action_attempt.rb', line 325

def auto_join
  @auto_join
end

#card_function_typeString?

Card function type in the Visionline access system.

Returns:

  • (String, nil)


328
329
330
# File 'lib/seam/resources/action_attempt.rb', line 328

def card_function_type
  @card_function_type
end

#card_idString?

ID of the card in the Visionline access system.

Returns:

  • (String, nil)


331
332
333
# File 'lib/seam/resources/action_attempt.rb', line 331

def card_id
  @card_id
end

#common_acs_entrance_idsArray<String>

Common entrance IDs in the Visionline access system.

Returns:

  • (Array<String>)


334
335
336
# File 'lib/seam/resources/action_attempt.rb', line 334

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#credential_idString?

ID of the credential in the Visionline access system.

Returns:

  • (String, nil)


337
338
339
# File 'lib/seam/resources/action_attempt.rb', line 337

def credential_id
  @credential_id
end

#guest_acs_entrance_idsArray<String>

Guest entrance IDs in the Visionline access system.

Returns:

  • (Array<String>)


340
341
342
# File 'lib/seam/resources/action_attempt.rb', line 340

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#is_validBoolean?

Indicates whether the credential is valid.

Returns:

  • (Boolean, nil)


343
344
345
# File 'lib/seam/resources/action_attempt.rb', line 343

def is_valid
  @is_valid
end

#joiner_acs_credential_idsArray<String>

IDs of the credentials to which you want to join.

Returns:

  • (Array<String>)


346
347
348
# File 'lib/seam/resources/action_attempt.rb', line 346

def joiner_acs_credential_ids
  @joiner_acs_credential_ids
end