Class: Seam::Resources::ActionAttempt::Result::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


352
353
354
# File 'lib/seam/resources/action_attempt.rb', line 352

def message
  @message
end

#new_codeString?

The PIN code that was assigned instead.

Returns:

  • (String, nil)


355
356
357
# File 'lib/seam/resources/action_attempt.rb', line 355

def new_code
  @new_code
end

#original_access_method_idString?

ID of the original access method from which this backup access method was split, if applicable.

Returns:

  • (String, nil)


358
359
360
# File 'lib/seam/resources/action_attempt.rb', line 358

def original_access_method_id
  @original_access_method_id
end

#original_codeString?

The originally requested PIN code that could not be used.

Returns:

  • (String, nil)


361
362
363
# File 'lib/seam/resources/action_attempt.rb', line 361

def original_code
  @original_code
end

#warning_codeString

Returns:

  • (String)


363
364
365
# File 'lib/seam/resources/action_attempt.rb', line 363

def warning_code
  @warning_code
end

#warning_messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


366
367
368
# File 'lib/seam/resources/action_attempt.rb', line 366

def warning_message
  @warning_message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


369
# File 'lib/seam/resources/action_attempt.rb', line 369

date_accessor :created_at