Class: Seam::Resources::ActionAttempt::ScanCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Reading credential data from the physical encoder is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


420
421
422
# File 'lib/seam/resources/action_attempt.rb', line 420

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of scanning a credential. Known values:

  • SCAN_CREDENTIAL

Returns:

  • (String)


425
426
427
# File 'lib/seam/resources/action_attempt.rb', line 425

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


431
432
433
# File 'lib/seam/resources/action_attempt.rb', line 431

def status
  @status
end

Instance Method Details

#errorError?

Only present when status is error; nil otherwise.

Returns:



411
# File 'lib/seam/resources/action_attempt.rb', line 411

resource_accessor :error, Error

#resultResult?

Result of scanning a card. If the attempt was successful, includes a snapshot of credential data read from the physical encoder, the corresponding data stored on Seam and the access system, and any associated warnings. Only present when status is success; nil otherwise.

Returns:



416
# File 'lib/seam/resources/action_attempt.rb', line 416

resource_accessor :result, Result