Class: Seam::Resources::ActionAttempt::ScanCredential::Error

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


99
100
101
# File 'lib/seam/resources/action_attempt.rb', line 99

def message
  @message
end

#typeString

Error type to indicate that the Seam Bridge is disconnected or cannot reach the access control system. Known values:

  • uncategorized_error
  • action_attempt_expired
  • no_credential_on_encoder
  • encoder_not_online
  • encoder_communication_timeout
  • bridge_disconnected

Returns:

  • (String)


109
110
111
# File 'lib/seam/resources/action_attempt.rb', line 109

def type
  @type
end