Class: Seam::Resources::ActionAttempt::ScanCredential::Result

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: AcsCredentialOnEncoder, AcsCredentialOnSeam, Warnings

Instance Attribute Summary

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Method Details

#acs_credential_on_encoderAcsCredentialOnEncoder?

Snapshot of credential data read from the physical encoder.

Returns:



392
# File 'lib/seam/resources/action_attempt.rb', line 392

resource_accessor :acs_credential_on_encoder, AcsCredentialOnEncoder

#acs_credential_on_seamAcsCredentialOnSeam?

Corresponding credential data as stored on Seam and the access system.

Returns:



395
# File 'lib/seam/resources/action_attempt.rb', line 395

resource_accessor :acs_credential_on_seam, AcsCredentialOnSeam

#warningsArray<Warnings>

Warnings related to scanning the credential, such as mismatches between the credential data currently encoded on the card and the corresponding data stored on Seam and the access system.

Returns:



398
# File 'lib/seam/resources/action_attempt.rb', line 398

resource_list_accessor :warnings, Warnings