Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnEncoder::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#cancelledBoolean?

Indicates whether the card associated with the credential is cancelled.

Returns:

  • (Boolean, nil)


125
126
127
# File 'lib/seam/resources/action_attempt.rb', line 125

def cancelled
  @cancelled
end

#card_formatString?

Format of the card associated with the credential. Known values:

  • TLCode
  • rfid48

Returns:

  • (String, nil)


131
132
133
# File 'lib/seam/resources/action_attempt.rb', line 131

def card_format
  @card_format
end

#card_holderString?

Holder of the card associated with the credential.

Returns:

  • (String, nil)


134
135
136
# File 'lib/seam/resources/action_attempt.rb', line 134

def card_holder
  @card_holder
end

#card_idString?

Card ID for the Visionline card associated with the credential.

Returns:

  • (String, nil)


137
138
139
# File 'lib/seam/resources/action_attempt.rb', line 137

def card_id
  @card_id
end

#common_acs_entrance_idsArray<String>

IDs of the common entrances for the credential.

Returns:

  • (Array<String>)


140
141
142
# File 'lib/seam/resources/action_attempt.rb', line 140

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#discardedBoolean?

Indicates whether the card associated with the credential is discarded.

Returns:

  • (Boolean, nil)


143
144
145
# File 'lib/seam/resources/action_attempt.rb', line 143

def discarded
  @discarded
end

#expiredBoolean?

Indicates whether the card associated with the credential is expired.

Returns:

  • (Boolean, nil)


146
147
148
# File 'lib/seam/resources/action_attempt.rb', line 146

def expired
  @expired
end

#guest_acs_entrance_idsArray<String>

IDs of the guest entrances for the credential.

Returns:

  • (Array<String>)


149
150
151
# File 'lib/seam/resources/action_attempt.rb', line 149

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#number_of_issued_cardsFloat?

Number of issued cards associated with the credential.

Returns:

  • (Float, nil)


152
153
154
# File 'lib/seam/resources/action_attempt.rb', line 152

def number_of_issued_cards
  @number_of_issued_cards
end

#overriddenBoolean?

Indicates whether the card associated with the credential is overridden.

Returns:

  • (Boolean, nil)


155
156
157
# File 'lib/seam/resources/action_attempt.rb', line 155

def overridden
  @overridden
end

#overwrittenBoolean?

Indicates whether the card associated with the credential is overwritten.

Returns:

  • (Boolean, nil)


158
159
160
# File 'lib/seam/resources/action_attempt.rb', line 158

def overwritten
  @overwritten
end

#pending_auto_updateBoolean?

Indicates whether the card associated with the credential is pending auto-update.

Returns:

  • (Boolean, nil)


161
162
163
# File 'lib/seam/resources/action_attempt.rb', line 161

def pending_auto_update
  @pending_auto_update
end