Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ String
Access method for the credential.
-
#acs_credential_id ⇒ String
ID of the credential.
-
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ String?
Number of the card associated with the credential.
-
#code ⇒ String?
Access (PIN) code for the credential.
-
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
-
#display_name ⇒ String
Display name that corresponds to the credential type.
-
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ String?
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
-
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
-
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
- #is_managed ⇒ Boolean
-
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once.
-
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
-
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
-
#workspace_id ⇒ String
ID of the workspace that contains the credential.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
-
#created_at ⇒ Time
Date and time at which the credential was created.
-
#errors ⇒ Array<Errors>
Errors associated with the credential.
-
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
-
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ String
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
300 301 302 |
# File 'lib/seam/resources/action_attempt.rb', line 300 def access_method @access_method end |
#acs_credential_id ⇒ String
ID of the credential.
303 304 305 |
# File 'lib/seam/resources/action_attempt.rb', line 303 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
306 307 308 |
# File 'lib/seam/resources/action_attempt.rb', line 306 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
309 310 311 |
# File 'lib/seam/resources/action_attempt.rb', line 309 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
312 313 314 |
# File 'lib/seam/resources/action_attempt.rb', line 312 def acs_user_id @acs_user_id end |
#card_number ⇒ String?
Number of the card associated with the credential.
315 316 317 |
# File 'lib/seam/resources/action_attempt.rb', line 315 def card_number @card_number end |
#code ⇒ String?
Access (PIN) code for the credential.
318 319 320 |
# File 'lib/seam/resources/action_attempt.rb', line 318 def code @code end |
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
321 322 323 |
# File 'lib/seam/resources/action_attempt.rb', line 321 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name that corresponds to the credential type.
324 325 326 |
# File 'lib/seam/resources/action_attempt.rb', line 324 def display_name @display_name end |
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
327 328 329 |
# File 'lib/seam/resources/action_attempt.rb', line 327 def ends_at @ends_at end |
#external_type ⇒ String?
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
Known values:
pti_cardbrivo_credentialhid_credentialvisionline_cardsalto_ks_credentialassa_abloy_vostio_keysalto_space_keylatch_accessdormakaba_ambiance_credentialhotek_cardsalto_ks_tagavigilon_alta_credentialkisi_credentialakiles_credential
345 346 347 |
# File 'lib/seam/resources/action_attempt.rb', line 345 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
348 349 350 |
# File 'lib/seam/resources/action_attempt.rb', line 348 def external_type_display_name @external_type_display_name end |
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
351 352 353 |
# File 'lib/seam/resources/action_attempt.rb', line 351 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
354 355 356 |
# File 'lib/seam/resources/action_attempt.rb', line 354 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ Boolean
356 357 358 |
# File 'lib/seam/resources/action_attempt.rb', line 356 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
359 360 361 |
# File 'lib/seam/resources/action_attempt.rb', line 359 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
362 363 364 |
# File 'lib/seam/resources/action_attempt.rb', line 362 def is_one_time_use @is_one_time_use end |
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
365 366 367 |
# File 'lib/seam/resources/action_attempt.rb', line 365 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
368 369 370 |
# File 'lib/seam/resources/action_attempt.rb', line 368 def starts_at @starts_at end |
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
371 372 373 |
# File 'lib/seam/resources/action_attempt.rb', line 371 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the credential.
374 375 376 |
# File 'lib/seam/resources/action_attempt.rb', line 374 def workspace_id @workspace_id end |
Instance Method Details
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
280 |
# File 'lib/seam/resources/action_attempt.rb', line 280 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
283 |
# File 'lib/seam/resources/action_attempt.rb', line 283 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#created_at ⇒ Time
Date and time at which the credential was created.
377 |
# File 'lib/seam/resources/action_attempt.rb', line 377 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the credential.
289 |
# File 'lib/seam/resources/action_attempt.rb', line 289 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
380 |
# File 'lib/seam/resources/action_attempt.rb', line 380 date_accessor :issued_at |
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
383 |
# File 'lib/seam/resources/action_attempt.rb', line 383 date_accessor :latest_desired_state_synced_with_provider_at |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
286 |
# File 'lib/seam/resources/action_attempt.rb', line 286 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
292 |
# File 'lib/seam/resources/action_attempt.rb', line 292 resource_list_accessor :warnings, Warnings |