Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::AssaAbloyVostioMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinBoolean?

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.

Returns:

  • (Boolean, nil)


194
195
196
# File 'lib/seam/resources/action_attempt.rb', line 194

def auto_join
  @auto_join
end

#door_namesArray<String>

Names of the doors to which to grant access in the Vostio access system.

Returns:

  • (Array<String>)


197
198
199
# File 'lib/seam/resources/action_attempt.rb', line 197

def door_names
  @door_names
end

#endpoint_idString?

Endpoint ID in the Vostio access system.

Returns:

  • (String, nil)


200
201
202
# File 'lib/seam/resources/action_attempt.rb', line 200

def endpoint_id
  @endpoint_id
end

#key_idString?

Key ID in the Vostio access system.

Returns:

  • (String, nil)


203
204
205
# File 'lib/seam/resources/action_attempt.rb', line 203

def key_id
  @key_id
end

#key_issuing_request_idString?

Key issuing request ID in the Vostio access system.

Returns:

  • (String, nil)


206
207
208
# File 'lib/seam/resources/action_attempt.rb', line 206

def key_issuing_request_id
  @key_issuing_request_id
end

#override_guest_acs_entrance_idsArray<String>

IDs of the guest entrances to override in the Vostio access system.

Returns:

  • (Array<String>)


209
210
211
# File 'lib/seam/resources/action_attempt.rb', line 209

def override_guest_acs_entrance_ids
  @override_guest_acs_entrance_ids
end