Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::Errors
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
206 207 208 |
# File 'lib/seam/resources/action_attempt.rb', line 206 def error_code @error_code end |
#message ⇒ String
208 209 210 |
# File 'lib/seam/resources/action_attempt.rb', line 208 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
211 |
# File 'lib/seam/resources/action_attempt.rb', line 211 date_accessor :created_at |