Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


247
248
249
# File 'lib/seam/resources/action_attempt.rb', line 247

def message
  @message
end

#new_codeString?

The PIN code that was assigned instead.

Returns:

  • (String, nil)


261
262
263
# File 'lib/seam/resources/action_attempt.rb', line 261

def new_code
  @new_code
end

#original_codeString?

The originally requested PIN code that could not be used.

Returns:

  • (String, nil)


264
265
266
# File 'lib/seam/resources/action_attempt.rb', line 264

def original_code
  @original_code
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • waiting_to_be_issued
  • schedule_externally_modified
  • schedule_modified
  • being_deleted
  • unknown_issue_with_acs_credential
  • needs_to_be_reissued
  • requested_code_unavailable

Returns:

  • (String)


258
259
260
# File 'lib/seam/resources/action_attempt.rb', line 258

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


267
# File 'lib/seam/resources/action_attempt.rb', line 267

date_accessor :created_at