Class: Seam::Resources::ActionAttempt::ScanToAssignCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Scanning a physical card and assigning the credential is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


912
913
914
# File 'lib/seam/resources/action_attempt.rb', line 912

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of scanning a physical card and assigning the credential to an ACS user. Known values:

  • SCAN_TO_ASSIGN_CREDENTIAL

Returns:

  • (String)


917
918
919
# File 'lib/seam/resources/action_attempt.rb', line 917

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


923
924
925
# File 'lib/seam/resources/action_attempt.rb', line 923

def status
  @status
end

Instance Method Details

#errorError?

Only present when status is error; nil otherwise.

Returns:



903
# File 'lib/seam/resources/action_attempt.rb', line 903

resource_accessor :error, Error

#resultResult?

Result of a scan to assign attempt. If the attempt was successful, includes the credential data that was scanned and assigned. Only present when status is success; nil otherwise.

Returns:



908
# File 'lib/seam/resources/action_attempt.rb', line 908

resource_accessor :result, Result