Class: Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::Errors
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
712 713 714 |
# File 'lib/seam/resources/action_attempt.rb', line 712 def error_code @error_code end |
#message ⇒ String
714 715 716 |
# File 'lib/seam/resources/action_attempt.rb', line 714 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
717 |
# File 'lib/seam/resources/action_attempt.rb', line 717 date_accessor :created_at |