Class: Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinBoolean?

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.

Returns:

  • (Boolean, nil)


739
740
741
# File 'lib/seam/resources/action_attempt.rb', line 739

def auto_join
  @auto_join
end

#card_function_typeString?

Card function type in the Visionline access system. Known values:

  • guest
  • staff

Returns:

  • (String, nil)


745
746
747
# File 'lib/seam/resources/action_attempt.rb', line 745

def card_function_type
  @card_function_type
end

#card_idString?

ID of the card in the Visionline access system.

Returns:

  • (String, nil)


748
749
750
# File 'lib/seam/resources/action_attempt.rb', line 748

def card_id
  @card_id
end

#common_acs_entrance_idsArray<String>

Common entrance IDs in the Visionline access system.

Returns:

  • (Array<String>)


751
752
753
# File 'lib/seam/resources/action_attempt.rb', line 751

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#credential_idString?

ID of the credential in the Visionline access system.

Returns:

  • (String, nil)


754
755
756
# File 'lib/seam/resources/action_attempt.rb', line 754

def credential_id
  @credential_id
end

#guest_acs_entrance_idsArray<String>

Guest entrance IDs in the Visionline access system.

Returns:

  • (Array<String>)


757
758
759
# File 'lib/seam/resources/action_attempt.rb', line 757

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#is_validBoolean?

Indicates whether the credential is valid.

Returns:

  • (Boolean, nil)


760
761
762
# File 'lib/seam/resources/action_attempt.rb', line 760

def is_valid
  @is_valid
end

#joiner_acs_credential_idsArray<String>

IDs of the credentials to which you want to join.

Returns:

  • (Array<String>)


763
764
765
# File 'lib/seam/resources/action_attempt.rb', line 763

def joiner_acs_credential_ids
  @joiner_acs_credential_ids
end