Class: Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::Warnings
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#new_code ⇒ String?
The PIN code that was assigned instead.
-
#original_code ⇒ String?
The originally requested PIN code that could not be used.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
753 754 755 |
# File 'lib/seam/resources/action_attempt.rb', line 753 def @message end |
#new_code ⇒ String?
The PIN code that was assigned instead.
767 768 769 |
# File 'lib/seam/resources/action_attempt.rb', line 767 def new_code @new_code end |
#original_code ⇒ String?
The originally requested PIN code that could not be used.
770 771 772 |
# File 'lib/seam/resources/action_attempt.rb', line 770 def original_code @original_code end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
waiting_to_be_issuedschedule_externally_modifiedschedule_modifiedbeing_deletedunknown_issue_with_acs_credentialneeds_to_be_reissuedrequested_code_unavailable
764 765 766 |
# File 'lib/seam/resources/action_attempt.rb', line 764 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
773 |
# File 'lib/seam/resources/action_attempt.rb', line 773 date_accessor :created_at |