Class: Seam::Resources::ActionAttempt::SimulateKeypadCodeEntry
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::SimulateKeypadCodeEntry
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Simulating a keypad code entry is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of simulating a keypad code entry.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1244 1245 1246 |
# File 'lib/seam/resources/action_attempt.rb', line 1244 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of simulating a keypad code entry. Known values:
SIMULATE_KEYPAD_CODE_ENTRY
1249 1250 1251 |
# File 'lib/seam/resources/action_attempt.rb', line 1249 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1255 1256 1257 |
# File 'lib/seam/resources/action_attempt.rb', line 1255 def status @status end |