Class: Seam::Resources::ActionAttempt::SimulateManualLockViaKeypad

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Simulating a manual lock action using a keypad is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


1331
1332
1333
# File 'lib/seam/resources/action_attempt.rb', line 1331

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of simulating a manual lock action using a keypad. Known values:

  • SIMULATE_MANUAL_LOCK_VIA_KEYPAD

Returns:

  • (String)


1336
1337
1338
# File 'lib/seam/resources/action_attempt.rb', line 1336

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


1342
1343
1344
# File 'lib/seam/resources/action_attempt.rb', line 1342

def status
  @status
end

Instance Method Details

#errorError?

Error associated with the action. Only present when status is error; nil otherwise.

Returns:



1322
# File 'lib/seam/resources/action_attempt.rb', line 1322

resource_accessor :error, Error

#resultResult?

Result of the action. Only present when status is success; nil otherwise.

Returns:



1327
# File 'lib/seam/resources/action_attempt.rb', line 1327

resource_accessor :result, Result