Class: Seam::Resources::ActionAttempt::UnlockDoor
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::UnlockDoor
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Unlocking a door is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of unlocking a door.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
80 81 82 |
# File 'lib/seam/resources/action_attempt.rb', line 80 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of unlocking a door. Known values:
UNLOCK_DOOR
85 86 87 |
# File 'lib/seam/resources/action_attempt.rb', line 85 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
91 92 93 |
# File 'lib/seam/resources/action_attempt.rb', line 91 def status @status end |