Class: Seam::Resources::ActionAttempt::UnlockDoor::Result
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::UnlockDoor::Result
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#was_confirmed_by_device ⇒ Boolean?
Indicates whether the device confirmed that the unlock action occurred.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#was_confirmed_by_device ⇒ Boolean?
Indicates whether the device confirmed that the unlock action occurred.
69 70 71 |
# File 'lib/seam/resources/action_attempt.rb', line 69 def was_confirmed_by_device @was_confirmed_by_device end |