Class: Seam::Resources::ConnectedAccount

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Represents a connected account. A connected account is an external third-party account to which your user has authorized Seam to get access, for example, an August account with a list of door locks.

Defined Under Namespace

Classes: Errors, UserIdentifier, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accepted_capabilitiesArray<String>

List of capabilities that were accepted during the account connection process. Known values:

  • lock
  • thermostat
  • noise_sensor
  • access_control
  • camera

Returns:

  • (Array<String>)


358
359
360
# File 'lib/seam/resources/connected_account.rb', line 358

def accepted_capabilities
  @accepted_capabilities
end

#account_typeString?

Type of connected account.

Returns:

  • (String, nil)


361
362
363
# File 'lib/seam/resources/connected_account.rb', line 361

def 
  @account_type
end

#account_type_display_nameString

Display name for the connected account type.

Returns:

  • (String)


364
365
366
# File 'lib/seam/resources/connected_account.rb', line 364

def 
  @account_type_display_name
end

#automatically_manage_new_devicesBoolean

Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.

Returns:

  • (Boolean)


367
368
369
# File 'lib/seam/resources/connected_account.rb', line 367

def automatically_manage_new_devices
  @automatically_manage_new_devices
end

#connected_account_idString

ID of the connected account.

Returns:

  • (String)


370
371
372
# File 'lib/seam/resources/connected_account.rb', line 370

def 
  @connected_account_id
end

#custom_metadataHash{String => String, Boolean}

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application. Keys set to null or to an empty string are omitted.

Returns:

  • (Hash{String => String, Boolean})


373
374
375
# File 'lib/seam/resources/connected_account.rb', line 373

def 
  @custom_metadata
end

#customer_keyString?

Your unique key for the customer associated with this connected account.

Returns:

  • (String, nil)


376
377
378
# File 'lib/seam/resources/connected_account.rb', line 376

def customer_key
  @customer_key
end

#default_checkin_timeString?

Default reservation check-in time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration — set during the connect_webview for providers like Lodgify whose API does not expose check-in times.

Returns:

  • (String, nil)


379
380
381
# File 'lib/seam/resources/connected_account.rb', line 379

def default_checkin_time
  @default_checkin_time
end

#default_checkout_timeString?

Default reservation check-out time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration.

Returns:

  • (String, nil)


382
383
384
# File 'lib/seam/resources/connected_account.rb', line 382

def default_checkout_time
  @default_checkout_time
end

#display_nameString

Display name for the connected account.

Returns:

  • (String)


385
386
387
# File 'lib/seam/resources/connected_account.rb', line 385

def display_name
  @display_name
end

#ical_feed_originString?

For iCal connected accounts, the platform that produced the feed (for example, airbnb, vrbo, or booking), or unknown when it could not be determined. Intended for rendering the source platform's logo.

Returns:

  • (String, nil)


388
389
390
# File 'lib/seam/resources/connected_account.rb', line 388

def ical_feed_origin
  @ical_feed_origin
end

#ical_urlString?

For iCal connected accounts, the feed URL for the connection. Sourced from the connector configuration.

Returns:

  • (String, nil)


391
392
393
# File 'lib/seam/resources/connected_account.rb', line 391

def ical_url
  @ical_url
end

#image_urlString?

Logo URL for the connected account provider.

Returns:

  • (String, nil)


394
395
396
# File 'lib/seam/resources/connected_account.rb', line 394

def image_url
  @image_url
end

#time_zoneString?

IANA time zone (e.g. America/Los_Angeles) for this connected account. Sourced from the connector configuration.

Returns:

  • (String, nil)


397
398
399
# File 'lib/seam/resources/connected_account.rb', line 397

def time_zone
  @time_zone
end

Instance Method Details

#created_atTime?

Date and time at which the connected account was created.

Returns:

  • (Time, nil)


401
# File 'lib/seam/resources/connected_account.rb', line 401

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the connected account.

Returns:



346
# File 'lib/seam/resources/connected_account.rb', line 346

resource_list_accessor :errors, Errors

#user_identifierUserIdentifier?

User identifier associated with the connected account.

Returns:



343
# File 'lib/seam/resources/connected_account.rb', line 343

resource_accessor :user_identifier, UserIdentifier

#warningsArray<Warnings>

Warnings associated with the connected account.

Returns:



349
# File 'lib/seam/resources/connected_account.rb', line 349

resource_list_accessor :warnings, Warnings