Class: Seam::Resources::ConnectedAccount::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount::Errors
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.
Defined Under Namespace
Classes: AccountDisconnected, BridgeDisconnected, DormakabaSitesDisconnected, SaltoKsSubscriptionLimitExceeded
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
account_disconnectedbridge_disconnectedsalto_ks_subscription_limit_exceededdormakaba_sites_disconnected
124 125 126 |
# File 'lib/seam/resources/connected_account.rb', line 124 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
127 128 129 |
# File 'lib/seam/resources/connected_account.rb', line 127 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
130 131 132 |
# File 'lib/seam/resources/connected_account.rb', line 130 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
133 134 135 |
# File 'lib/seam/resources/connected_account.rb', line 133 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
136 |
# File 'lib/seam/resources/connected_account.rb', line 136 date_accessor :created_at |