Class: Seam::Resources::ConnectedAccount::Errors::AccountDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that the account is disconnected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • account_disconnected

Returns:

  • (String)


15
16
17
# File 'lib/seam/resources/connected_account.rb', line 15

def error_code
  @error_code
end

#is_bridge_errorBoolean?

Indicates whether the error is related to Seam Bridge.

Returns:

  • (Boolean, nil)


18
19
20
# File 'lib/seam/resources/connected_account.rb', line 18

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorBoolean?

Indicates whether the error is related specifically to the connected account.

Returns:

  • (Boolean, nil)


21
22
23
# File 'lib/seam/resources/connected_account.rb', line 21

def 
  @is_connected_account_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


24
25
26
# File 'lib/seam/resources/connected_account.rb', line 24

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


27
# File 'lib/seam/resources/connected_account.rb', line 27

date_accessor :created_at