Class: Seam::Resources::ConnectedAccount::Errors::BridgeDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that the Seam API cannot communicate with Seam Bridge, for example, if the Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • bridge_disconnected

Returns:

  • (String)


36
37
38
# File 'lib/seam/resources/connected_account.rb', line 36

def error_code
  @error_code
end

#is_bridge_errorBoolean?

Indicates whether the error is related to Seam Bridge.

Returns:

  • (Boolean, nil)


39
40
41
# File 'lib/seam/resources/connected_account.rb', line 39

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorBoolean?

Indicates whether the error is related specifically to the connected account.

Returns:

  • (Boolean, nil)


42
43
44
# File 'lib/seam/resources/connected_account.rb', line 42

def 
  @is_connected_account_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


45
46
47
# File 'lib/seam/resources/connected_account.rb', line 45

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


48
# File 'lib/seam/resources/connected_account.rb', line 48

date_accessor :created_at