Class: Seam::Resources::ConnectedAccount::UserIdentifier

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#api_urlString?

API URL for the user identifier associated with the connected account.

Returns:

  • (String, nil)


149
150
151
# File 'lib/seam/resources/connected_account.rb', line 149

def api_url
  @api_url
end

#emailString?

Email address of the user identifier associated with the connected account.

Returns:

  • (String, nil)


152
153
154
# File 'lib/seam/resources/connected_account.rb', line 152

def email
  @email
end

#exclusiveBoolean?

Indicates whether the user identifier associated with the connected account is exclusive.

Returns:

  • (Boolean, nil)


155
156
157
# File 'lib/seam/resources/connected_account.rb', line 155

def exclusive
  @exclusive
end

#phoneString?

Phone number of the user identifier associated with the connected account.

Returns:

  • (String, nil)


158
159
160
# File 'lib/seam/resources/connected_account.rb', line 158

def phone
  @phone
end

#usernameString?

Username of the user identifier associated with the connected account.

Returns:

  • (String, nil)


161
162
163
# File 'lib/seam/resources/connected_account.rb', line 161

def username
  @username
end