Class: Seam::Resources::ConnectedAccount::Warnings::AccountReauthorizationRequested

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that the Connected Account requires reauthorization using a new Connect Webview. The account is still connected, but cannot access new features. Delaying reauthorization too long will eventually cause the Connected Account to become disconnected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


239
240
241
# File 'lib/seam/resources/connected_account.rb', line 239

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • account_reauthorization_requested

Returns:

  • (String)


244
245
246
# File 'lib/seam/resources/connected_account.rb', line 244

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


247
# File 'lib/seam/resources/connected_account.rb', line 247

date_accessor :created_at