Class: Seam::Resources::ConnectedAccount::Warnings::BeingDeleted

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that the connected account is currently being deleted. All devices, access codes, and other resources associated with this account are in the process of being removed from Seam.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


254
255
256
# File 'lib/seam/resources/connected_account.rb', line 254

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • being_deleted

Returns:

  • (String)


259
260
261
# File 'lib/seam/resources/connected_account.rb', line 259

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


262
# File 'lib/seam/resources/connected_account.rb', line 262

date_accessor :created_at