Class: Seam::Resources::ConnectedAccount::Warnings::DormakabaSitesUnapproved

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that one or more dormakaba sites associated with the connected account are not approved. Contact support@getseam.com to finish setting up your account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


299
300
301
# File 'lib/seam/resources/connected_account.rb', line 299

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • dormakaba_sites_unapproved

Returns:

  • (String)


304
305
306
# File 'lib/seam/resources/connected_account.rb', line 304

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


307
# File 'lib/seam/resources/connected_account.rb', line 307

date_accessor :created_at