Class: Seam::Resources::ConnectedAccount::Warnings::ProviderServiceUnavailable

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that the connected account's provider service is temporarily unavailable. Seam will automatically retry and reconnect when the service becomes available again.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


269
270
271
# File 'lib/seam/resources/connected_account.rb', line 269

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • provider_service_unavailable

Returns:

  • (String)


274
275
276
# File 'lib/seam/resources/connected_account.rb', line 274

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


277
# File 'lib/seam/resources/connected_account.rb', line 277

date_accessor :created_at