Class: Seam::Resources::ConnectedAccount::Warnings::SaltoKsSubscriptionLimitAlmostReached

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that the Salto KS site has exceeded 80% of the maximum number of allowed users. Increase your subscription limit or delete some users from your site.

Defined Under Namespace

Classes: SaltoKsMetadata

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


224
225
226
# File 'lib/seam/resources/connected_account.rb', line 224

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_subscription_limit_almost_reached

Returns:

  • (String)


229
230
231
# File 'lib/seam/resources/connected_account.rb', line 229

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


232
# File 'lib/seam/resources/connected_account.rb', line 232

date_accessor :created_at

#salto_ks_metadataSaltoKsMetadata

Salto KS metadata associated with the connected account that has a warning.

Returns:



221
# File 'lib/seam/resources/connected_account.rb', line 221

resource_accessor :salto_ks_metadata, SaltoKsMetadata