Class: Seam::Resources::ConnectedAccount::Warnings::SaltoKsSubscriptionLimitAlmostReached::SaltoKsMetadata::Sites

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#site_idString?

ID of a Salto site associated with the connected account that has a warning.

Returns:

  • (String, nil)


202
203
204
# File 'lib/seam/resources/connected_account.rb', line 202

def site_id
  @site_id
end

#site_nameString?

Name of a Salto site associated with the connected account that has a warning.

Returns:

  • (String, nil)


205
206
207
# File 'lib/seam/resources/connected_account.rb', line 205

def site_name
  @site_name
end

#site_user_subscription_limitInteger?

Subscription limit of site users for a Salto site associated with the connected account that has a warning.

Returns:

  • (Integer, nil)


208
209
210
# File 'lib/seam/resources/connected_account.rb', line 208

def site_user_subscription_limit
  @site_user_subscription_limit
end

#subscribed_site_user_countInteger?

Count of subscribed site users for a Salto site associated with the connected account that has a warning.

Returns:

  • (Integer, nil)


211
212
213
# File 'lib/seam/resources/connected_account.rb', line 211

def subscribed_site_user_count
  @subscribed_site_user_count
end