Class: Seam::Resources::ConnectedAccount::Warnings::ScheduledMaintenanceWindow

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Indicates that scheduled downtime is planned for the connected account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


170
171
172
# File 'lib/seam/resources/connected_account.rb', line 170

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • scheduled_maintenance_window

Returns:

  • (String)


175
176
177
# File 'lib/seam/resources/connected_account.rb', line 175

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


178
# File 'lib/seam/resources/connected_account.rb', line 178

date_accessor :created_at