Class: Seam::Resources::CustomerPortal

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/customer_portal.rb

Overview

Represents a Customer Portal. Customer Portal is a hosted, customizable interface for managing device access. It enables you to embed secure, pre-authenticated access flows into your product—either by sharing a link with users or embedding a view in an iframe.

With Customer Portal, you no longer need to build out frontend experiences for physical access, thermostats, and sensors. Instead, you can ship enterprise-grade access control experiences in a fraction of the time, while maintaining your product's branding and user experience.

Seam hosts these flows, handling everything from account connection and device mapping to full-featured device control.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#customer_keyString

Customer key for the customer portal.

Returns:

  • (String)


13
14
15
# File 'lib/seam/resources/customer_portal.rb', line 13

def customer_key
  @customer_key
end

#urlString

URL for the customer portal.

Returns:

  • (String)


16
17
18
# File 'lib/seam/resources/customer_portal.rb', line 16

def url
  @url
end

#workspace_idString

ID of the workspace associated with the customer portal.

Returns:

  • (String)


19
20
21
# File 'lib/seam/resources/customer_portal.rb', line 19

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the customer portal link was created.

Returns:

  • (Time)


23
# File 'lib/seam/resources/customer_portal.rb', line 23

date_accessor :created_at

#expires_atTime

Date and time at which the customer portal link expires.

Returns:

  • (Time)


27
# File 'lib/seam/resources/customer_portal.rb', line 27

date_accessor :expires_at