Class: Seam::Resources::Device::DeviceManufacturer

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#display_nameString

Display name for the manufacturer, such as August, Yale, Salto, and so on.

Returns:

  • (String)


10
11
12
# File 'lib/seam/resources/device.rb', line 10

def display_name
  @display_name
end

#image_urlString?

Image URL for the manufacturer logo.

Returns:

  • (String, nil)


13
14
15
# File 'lib/seam/resources/device.rb', line 13

def image_url
  @image_url
end

#manufacturerString

Manufacturer identifier, such as august, yale, salto, and so on.

Returns:

  • (String)


16
17
18
# File 'lib/seam/resources/device.rb', line 16

def manufacturer
  @manufacturer
end