Class: Seam::Resources::Device::DeviceProvider

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_provider_nameString

Device provider name. Corresponds to the integration type, such as august, schlage, yale_access, and so on.

Returns:

  • (String)


22
23
24
# File 'lib/seam/resources/device.rb', line 22

def device_provider_name
  @device_provider_name
end

#display_nameString

Display name for the device provider type.

Returns:

  • (String)


25
26
27
# File 'lib/seam/resources/device.rb', line 25

def display_name
  @display_name
end

#image_urlString?

Image URL for the device provider.

Returns:

  • (String, nil)


28
29
30
# File 'lib/seam/resources/device.rb', line 28

def image_url
  @image_url
end

#provider_categoryString

Provider category. Indicates the third-party provider type, such as stable, for stable integrations, or internal, for internal integrations.

Returns:

  • (String)


31
32
33
# File 'lib/seam/resources/device.rb', line 31

def provider_category
  @provider_category
end