Class: Seam::Resources::Device::Errors::AccountDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the account is disconnected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • account_disconnected

Returns:

  • (String)


42
43
44
# File 'lib/seam/resources/device.rb', line 42

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


45
46
47
# File 'lib/seam/resources/device.rb', line 45

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


48
49
50
# File 'lib/seam/resources/device.rb', line 48

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


51
52
53
# File 'lib/seam/resources/device.rb', line 51

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


54
# File 'lib/seam/resources/device.rb', line 54

date_accessor :created_at