Class: Seam::Resources::Device::Errors::AugustLockNotAuthorized

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the user is not authorized to use the August lock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • august_lock_not_authorized

Returns:

  • (String)


216
217
218
# File 'lib/seam/resources/device.rb', line 216

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


219
220
221
# File 'lib/seam/resources/device.rb', line 219

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


222
223
224
# File 'lib/seam/resources/device.rb', line 222

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


225
# File 'lib/seam/resources/device.rb', line 225

date_accessor :created_at