Class: Seam::Resources::Device::Errors::AuxiliaryHeatRunning

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the auxiliary heat is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • auxiliary_heat_running

Returns:

  • (String)


252
253
254
# File 'lib/seam/resources/device.rb', line 252

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


255
256
257
# File 'lib/seam/resources/device.rb', line 255

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


258
259
260
# File 'lib/seam/resources/device.rb', line 258

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


261
# File 'lib/seam/resources/device.rb', line 261

date_accessor :created_at