Class: Seam::Resources::Device::Errors::DeviceDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the device is disconnected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • device_disconnected

Returns:

  • (String)


180
181
182
# File 'lib/seam/resources/device.rb', line 180

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


183
184
185
# File 'lib/seam/resources/device.rb', line 183

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


186
187
188
# File 'lib/seam/resources/device.rb', line 186

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


189
# File 'lib/seam/resources/device.rb', line 189

date_accessor :created_at