Class: Seam::Resources::Device::Errors::DormakabaSitesDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that one or more dormakaba sites associated with the connected account could not be connected. Contact dormakaba support.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • dormakaba_sites_disconnected

Returns:

  • (String)


105
106
107
# File 'lib/seam/resources/device.rb', line 105

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


108
109
110
# File 'lib/seam/resources/device.rb', line 108

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


111
112
113
# File 'lib/seam/resources/device.rb', line 111

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


114
115
116
# File 'lib/seam/resources/device.rb', line 114

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


117
# File 'lib/seam/resources/device.rb', line 117

date_accessor :created_at