Class: Seam::Resources::Device::Errors::EmptyBackupAccessCodePool

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the backup access code pool is empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • empty_backup_access_code_pool

Returns:

  • (String)


198
199
200
# File 'lib/seam/resources/device.rb', line 198

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


201
202
203
# File 'lib/seam/resources/device.rb', line 201

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


204
205
206
# File 'lib/seam/resources/device.rb', line 204

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


207
# File 'lib/seam/resources/device.rb', line 207

date_accessor :created_at