Class: Seam::Resources::Device::Errors::HubDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the hub is disconnected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • hub_disconnected

Returns:

  • (String)


162
163
164
# File 'lib/seam/resources/device.rb', line 162

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


165
166
167
# File 'lib/seam/resources/device.rb', line 165

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


168
169
170
# File 'lib/seam/resources/device.rb', line 168

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


171
# File 'lib/seam/resources/device.rb', line 171

date_accessor :created_at