Class: Seam::Resources::Device::Errors::InsufficientPermissions

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that Seam's integration user does not have sufficient permissions on the provider's system to which this device belongs, so Seam cannot manage access codes or unlock the device. See the error message for specifics, then either reauthorize the connected account in Seam or grant the integration user the required permissions in the provider's system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • insufficient_permissions

Returns:

  • (String)


84
85
86
# File 'lib/seam/resources/device.rb', line 84

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


87
88
89
# File 'lib/seam/resources/device.rb', line 87

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


90
91
92
# File 'lib/seam/resources/device.rb', line 90

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


93
94
95
# File 'lib/seam/resources/device.rb', line 93

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


96
# File 'lib/seam/resources/device.rb', line 96

date_accessor :created_at