Class: Seam::Resources::Device::Errors::MissingDeviceCredentials

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that device credentials are missing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • missing_device_credentials

Returns:

  • (String)


234
235
236
# File 'lib/seam/resources/device.rb', line 234

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


237
238
239
# File 'lib/seam/resources/device.rb', line 237

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


240
241
242
# File 'lib/seam/resources/device.rb', line 240

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


243
# File 'lib/seam/resources/device.rb', line 243

date_accessor :created_at