Class: Seam::Resources::Device::Errors::SaltoKsSubscriptionLimitExceeded

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the Salto site user limit has been reached.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_subscription_limit_exceeded

Returns:

  • (String)


63
64
65
# File 'lib/seam/resources/device.rb', line 63

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


66
67
68
# File 'lib/seam/resources/device.rb', line 66

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


69
70
71
# File 'lib/seam/resources/device.rb', line 69

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


72
73
74
# File 'lib/seam/resources/device.rb', line 72

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


75
# File 'lib/seam/resources/device.rb', line 75

date_accessor :created_at