Class: Seam::Resources::Device::Errors::SubscriptionRequired

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that a subscription is required to connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • subscription_required

Returns:

  • (String)


270
271
272
# File 'lib/seam/resources/device.rb', line 270

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


273
274
275
# File 'lib/seam/resources/device.rb', line 273

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


276
277
278
# File 'lib/seam/resources/device.rb', line 276

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


279
# File 'lib/seam/resources/device.rb', line 279

date_accessor :created_at