Class: Seam::Resources::Device::Location
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Location
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#location_name ⇒ String?
Name of the device location.
-
#room_name ⇒ String?
Name of the room within the device location, when the provider reports one.
-
#time_zone ⇒ String?
Time zone of the device location.
-
#timezone ⇒ String?
deprecated
Deprecated.
Use
time_zoneinstead.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#location_name ⇒ String?
Name of the device location.
56 57 58 |
# File 'lib/seam/resources/device.rb', line 56 def location_name @location_name end |
#room_name ⇒ String?
Name of the room within the device location, when the provider reports one.
59 60 61 |
# File 'lib/seam/resources/device.rb', line 59 def room_name @room_name end |
#time_zone ⇒ String?
Time zone of the device location.
62 63 64 |
# File 'lib/seam/resources/device.rb', line 62 def time_zone @time_zone end |
#timezone ⇒ String?
Deprecated.
Use time_zone instead.
Time zone of the device location.
66 67 68 |
# File 'lib/seam/resources/device.rb', line 66 def timezone @timezone end |