Class: Seam::Resources::Device::Properties
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: AccessoryKeypad, ActiveThermostatSchedule, AkilesMetadata, Appearance, AqaraMetadata, AssaAbloyCredentialServiceMetadata, AssaAbloyVostioMetadata, AugustMetadata, AvailableClimatePresets, AvigilonAltaMetadata, Battery, BrivoMetadata, CodeConstraints, ControlbywebMetadata, CurrentClimateSetting, DefaultClimateSetting, DormakabaOracodeMetadata, EcobeeMetadata, FourSuitesMetadata, GenieMetadata, HoneywellResideoMetadata, IglooMetadata, IgloohomeMetadata, KeynestMetadata, KeypadBattery, KisiMetadata, KorelockMetadata, KwiksetMetadata, LocklyMetadata, MinutMetadata, Model, NestMetadata, NoiseawareMetadata, NukiMetadata, OfflineTimeFrameOptions, OmnitecMetadata, OnlineTimeFrameOptions, RingMetadata, SaltoKsMetadata, SaltoMetadata, SaltoSpaceCredentialServiceMetadata, SchlageMetadata, SeamBridgeMetadata, SensiMetadata, SmartthingsMetadata, TadoMetadata, TedeeMetadata, TemperatureThreshold, ThermostatDailyPrograms, ThermostatWeeklyProgram, TtlockMetadata, TwoNMetadata, UltraloqMetadata, VisionlineMetadata, WyzeMetadata, YacanMetadata
Instance Attribute Summary collapse
-
#active_thermostat_schedule_id ⇒ String?
ID of the active thermostat schedule.
-
#auto_lock_delay_seconds ⇒ Float?
The delay in seconds before the lock automatically locks after being unlocked.
-
#auto_lock_enabled ⇒ Boolean?
Indicates whether automatic locking is enabled.
-
#available_climate_preset_modes ⇒ Array<String>
Climate preset modes that the thermostat supports, such as "home", "away", "wake", "sleep", "occupied", and "unoccupied".
-
#available_fan_mode_settings ⇒ Array<String>
Fan mode settings that the thermostat supports.
-
#available_hvac_mode_settings ⇒ Array<String>
HVAC mode settings that the thermostat supports.
-
#backup_access_code_pool_enabled ⇒ Boolean?
Indicates whether the backup access code pool is currently enabled for the device.
-
#battery_level ⇒ Float?
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
-
#currently_triggering_noise_threshold_ids ⇒ Array<String>
Array of noise threshold IDs that are currently triggering.
-
#door_open ⇒ Boolean?
Indicates whether the door is open.
-
#fallback_climate_preset_key ⇒ String?
Key of the fallback climate preset for the thermostat.
-
#fan_mode_setting ⇒ String?
deprecated
Deprecated.
Use
current_climate_setting.fan_mode_settinginstead. -
#has_direct_power ⇒ Boolean?
Indicates whether the device has direct power.
-
#has_native_entry_events ⇒ Boolean?
Indicates whether the device supports native entry events.
-
#image_alt_text ⇒ String?
Alt text for the device image.
-
#image_url ⇒ String?
Image URL for the device.
-
#is_cooling ⇒ Boolean?
Indicates whether the connected HVAC system is currently cooling, as reported by the thermostat.
-
#is_fan_running ⇒ Boolean?
Indicates whether the fan in the connected HVAC system is currently running, as reported by the thermostat.
-
#is_heating ⇒ Boolean?
Indicates whether the connected HVAC system is currently heating, as reported by the thermostat.
-
#is_temporary_manual_override_active ⇒ Boolean?
Indicates whether the current thermostat settings differ from the most recent active program or schedule that Seam activated.
-
#locked ⇒ Boolean?
Indicates whether the lock is locked.
-
#manufacturer ⇒ String?
Manufacturer of the device.
-
#max_active_codes_supported ⇒ Float?
Maximum number of active access codes that the device supports.
-
#max_cooling_set_point_celsius ⇒ Float?
Maximum cooling set point in °C.
-
#max_cooling_set_point_fahrenheit ⇒ Float?
Maximum cooling set point in °F.
-
#max_heating_set_point_celsius ⇒ Float?
Maximum heating set point in °C.
-
#max_heating_set_point_fahrenheit ⇒ Float?
Maximum heating set point in °F.
-
#max_thermostat_daily_program_periods_per_day ⇒ Float?
Maximum number of periods that the thermostat can support per day.
-
#max_unique_climate_presets_per_thermostat_weekly_program ⇒ Float?
Maximum number of climate presets that the thermostat can support for weekly programming.
-
#min_cooling_set_point_celsius ⇒ Float?
Minimum cooling set point in °C.
-
#min_cooling_set_point_fahrenheit ⇒ Float?
Minimum cooling set point in °F.
-
#min_heating_cooling_delta_celsius ⇒ Float?
Minimum temperature difference in °C between the cooling and heating set points when in heat-cool (auto) mode.
-
#min_heating_cooling_delta_fahrenheit ⇒ Float?
Minimum temperature difference in °F between the cooling and heating set points when in heat-cool (auto) mode.
-
#min_heating_set_point_celsius ⇒ Float?
Minimum heating set point in °C.
-
#min_heating_set_point_fahrenheit ⇒ Float?
Minimum heating set point in °F.
-
#name ⇒ String
deprecated
Deprecated.
use device.display_name instead
-
#noise_level_decibels ⇒ Float?
Indicates current noise level in decibels, if the device supports noise detection.
-
#offline_access_codes_enabled ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_offline_access_codes
-
#online ⇒ Boolean
Indicates whether the device is online.
-
#online_access_codes_enabled ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_online_access_codes
-
#relative_humidity ⇒ Float?
Reported relative humidity, as a value between 0 and 1, inclusive.
-
#serial_number ⇒ String?
Serial number of the device.
-
#supported_code_lengths ⇒ Array<Float>
Supported code lengths for access codes.
-
#supports_accessory_keypad ⇒ Boolean?
deprecated
Deprecated.
use device.properties.model.can_connect_accessory_keypad
-
#supports_backup_access_code_pool ⇒ Boolean?
Indicates whether the device supports a backup access code pool.
-
#supports_offline_access_codes ⇒ Boolean?
deprecated
Deprecated.
use offline_access_codes_enabled
-
#temperature_celsius ⇒ Float?
Reported temperature in °C.
-
#temperature_fahrenheit ⇒ Float?
Reported temperature in °F.
-
#thermostat_daily_program_period_precision_minutes ⇒ Float?
Precision of the thermostat's period in minutes.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#accessory_keypad ⇒ AccessoryKeypad?
Accessory keypad properties and state.
-
#active_thermostat_schedule ⇒ ActiveThermostatSchedule?
Active thermostat schedule.
-
#akiles_metadata ⇒ AkilesMetadata?
Metadata for an Akiles device.
-
#appearance ⇒ Appearance
Appearance-related properties, as reported by the device.
-
#aqara_metadata ⇒ AqaraMetadata?
Metadata for an Aqara device.
-
#assa_abloy_credential_service_metadata ⇒ AssaAbloyCredentialServiceMetadata?
ASSA ABLOY Credential Service metadata for the phone.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Metadata for an ASSA ABLOY Vostio system.
-
#august_metadata ⇒ AugustMetadata?
Metadata for an August device.
-
#available_climate_presets ⇒ Array<AvailableClimatePresets>
Available climate presets for the thermostat.
-
#avigilon_alta_metadata ⇒ AvigilonAltaMetadata?
Metadata for an Avigilon Alta system.
-
#battery ⇒ Battery?
Represents the current status of the battery charge level.
-
#brivo_metadata ⇒ BrivoMetadata?
Metadata for a Brivo device.
-
#code_constraints ⇒ Array<CodeConstraints>
Constraints on access codes for the device.
-
#controlbyweb_metadata ⇒ ControlbywebMetadata?
Metadata for a ControlByWeb device.
-
#current_climate_setting ⇒ CurrentClimateSetting?
Current climate setting.
- #default_climate_setting ⇒ DefaultClimateSetting?
-
#dormakaba_oracode_metadata ⇒ DormakabaOracodeMetadata?
Metadata for a dormakaba Oracode device.
-
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata for an ecobee device.
-
#four_suites_metadata ⇒ FourSuitesMetadata?
Metadata for a 4SUITES device.
-
#genie_metadata ⇒ GenieMetadata?
Metadata for a Genie device.
-
#honeywell_resideo_metadata ⇒ HoneywellResideoMetadata?
Metadata for a Honeywell Resideo device.
-
#igloo_metadata ⇒ IglooMetadata?
Metadata for an igloo device.
-
#igloohome_metadata ⇒ IgloohomeMetadata?
Metadata for an igloohome device.
-
#keynest_metadata ⇒ KeynestMetadata?
Metadata for a KeyNest device.
-
#keypad_battery ⇒ KeypadBattery?
Keypad battery status.
-
#kisi_metadata ⇒ KisiMetadata?
Metadata for a Kisi device.
-
#korelock_metadata ⇒ KorelockMetadata?
Metadata for a Korelock device.
-
#kwikset_metadata ⇒ KwiksetMetadata?
Metadata for a Kwikset device.
-
#lockly_metadata ⇒ LocklyMetadata?
Metadata for a Lockly device.
-
#minut_metadata ⇒ MinutMetadata?
Metadata for a Minut device.
-
#model ⇒ Model
Device model-related properties.
-
#nest_metadata ⇒ NestMetadata?
Metadata for a Google Nest device.
-
#noiseaware_metadata ⇒ NoiseawareMetadata?
Metadata for a NoiseAware device.
-
#nuki_metadata ⇒ NukiMetadata?
Metadata for a Nuki device.
-
#offline_time_frame_options ⇒ Array<OfflineTimeFrameOptions>
Time frames that may be requested when creating an offline access code, expressed as a list of options.
-
#omnitec_metadata ⇒ OmnitecMetadata?
Metadata for an Omnitec device.
-
#online_time_frame_options ⇒ Array<OnlineTimeFrameOptions>
Time frames that may be requested when creating an online access code, expressed as a list of options.
-
#ring_metadata ⇒ RingMetadata?
Metadata for a Ring device.
-
#salto_ks_metadata ⇒ SaltoKsMetadata?
Metadata for a Salto KS device.
-
#salto_metadata ⇒ SaltoMetadata?
Metada for a Salto device.
-
#salto_space_credential_service_metadata ⇒ SaltoSpaceCredentialServiceMetadata?
Salto Space credential service metadata for the phone.
-
#schlage_metadata ⇒ SchlageMetadata?
Metadata for a Schlage device.
-
#seam_bridge_metadata ⇒ SeamBridgeMetadata?
Metadata for Seam Bridge.
-
#sensi_metadata ⇒ SensiMetadata?
Metadata for a Sensi device.
-
#smartthings_metadata ⇒ SmartthingsMetadata?
Metadata for a SmartThings device.
-
#tado_metadata ⇒ TadoMetadata?
Metadata for a tado° device.
-
#tedee_metadata ⇒ TedeeMetadata?
Metadata for a Tedee device.
-
#temperature_threshold ⇒ TemperatureThreshold?
Current temperature threshold set for the thermostat.
-
#thermostat_daily_programs ⇒ Array<ThermostatDailyPrograms>
Configured daily programs for the thermostat.
-
#thermostat_weekly_program ⇒ ThermostatWeeklyProgram?
Current weekly program for the thermostat.
-
#ttlock_metadata ⇒ TtlockMetadata?
Metadata for a TTLock device.
-
#two_n_metadata ⇒ TwoNMetadata?
Metadata for a 2N device.
-
#ultraloq_metadata ⇒ UltraloqMetadata?
Metadata for an Ultraloq device.
-
#visionline_metadata ⇒ VisionlineMetadata?
Metadata for an ASSA ABLOY Visionline system.
-
#wyze_metadata ⇒ WyzeMetadata?
Metadata for a Wyze device.
-
#yacan_metadata ⇒ YacanMetadata?
Metadata for a Yacan device.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#active_thermostat_schedule_id ⇒ String?
ID of the active thermostat schedule.
1982 1983 1984 |
# File 'lib/seam/resources/device.rb', line 1982 def active_thermostat_schedule_id @active_thermostat_schedule_id end |
#auto_lock_delay_seconds ⇒ Float?
The delay in seconds before the lock automatically locks after being unlocked.
1955 1956 1957 |
# File 'lib/seam/resources/device.rb', line 1955 def auto_lock_delay_seconds @auto_lock_delay_seconds end |
#auto_lock_enabled ⇒ Boolean?
Indicates whether automatic locking is enabled.
1958 1959 1960 |
# File 'lib/seam/resources/device.rb', line 1958 def auto_lock_enabled @auto_lock_enabled end |
#available_climate_preset_modes ⇒ Array<String>
Climate preset modes that the thermostat supports, such as "home", "away", "wake", "sleep", "occupied", and "unoccupied". Known values:
homeawaywakesleepoccupiedunoccupied
1992 1993 1994 |
# File 'lib/seam/resources/device.rb', line 1992 def available_climate_preset_modes @available_climate_preset_modes end |
#available_fan_mode_settings ⇒ Array<String>
Fan mode settings that the thermostat supports. Known values:
autooncirculate
1999 2000 2001 |
# File 'lib/seam/resources/device.rb', line 1999 def available_fan_mode_settings @available_fan_mode_settings end |
#available_hvac_mode_settings ⇒ Array<String>
HVAC mode settings that the thermostat supports. Known values:
offheatcoolheat_cooleco
2008 2009 2010 |
# File 'lib/seam/resources/device.rb', line 2008 def available_hvac_mode_settings @available_hvac_mode_settings end |
#backup_access_code_pool_enabled ⇒ Boolean?
Indicates whether the backup access code pool is currently enabled for the device. To disable it, set this to false using /devices/update.
1961 1962 1963 |
# File 'lib/seam/resources/device.rb', line 1961 def backup_access_code_pool_enabled @backup_access_code_pool_enabled end |
#battery_level ⇒ Float?
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
1910 1911 1912 |
# File 'lib/seam/resources/device.rb', line 1910 def battery_level @battery_level end |
#currently_triggering_noise_threshold_ids ⇒ Array<String>
Array of noise threshold IDs that are currently triggering.
1913 1914 1915 |
# File 'lib/seam/resources/device.rb', line 1913 def currently_triggering_noise_threshold_ids @currently_triggering_noise_threshold_ids end |
#door_open ⇒ Boolean?
Indicates whether the door is open.
1964 1965 1966 |
# File 'lib/seam/resources/device.rb', line 1964 def door_open @door_open end |
#fallback_climate_preset_key ⇒ String?
Key of the fallback climate preset for the thermostat.
2011 2012 2013 |
# File 'lib/seam/resources/device.rb', line 2011 def fallback_climate_preset_key @fallback_climate_preset_key end |
#fan_mode_setting ⇒ String?
Use current_climate_setting.fan_mode_setting instead.
Known values:
autooncirculate
2018 2019 2020 |
# File 'lib/seam/resources/device.rb', line 2018 def fan_mode_setting @fan_mode_setting end |
#has_direct_power ⇒ Boolean?
Indicates whether the device has direct power.
1916 1917 1918 |
# File 'lib/seam/resources/device.rb', line 1916 def has_direct_power @has_direct_power end |
#has_native_entry_events ⇒ Boolean?
Indicates whether the device supports native entry events.
1967 1968 1969 |
# File 'lib/seam/resources/device.rb', line 1967 def has_native_entry_events @has_native_entry_events end |
#image_alt_text ⇒ String?
Alt text for the device image.
1919 1920 1921 |
# File 'lib/seam/resources/device.rb', line 1919 def image_alt_text @image_alt_text end |
#image_url ⇒ String?
Image URL for the device.
1922 1923 1924 |
# File 'lib/seam/resources/device.rb', line 1922 def image_url @image_url end |
#is_cooling ⇒ Boolean?
Indicates whether the connected HVAC system is currently cooling, as reported by the thermostat.
2021 2022 2023 |
# File 'lib/seam/resources/device.rb', line 2021 def is_cooling @is_cooling end |
#is_fan_running ⇒ Boolean?
Indicates whether the fan in the connected HVAC system is currently running, as reported by the thermostat.
2024 2025 2026 |
# File 'lib/seam/resources/device.rb', line 2024 def is_fan_running @is_fan_running end |
#is_heating ⇒ Boolean?
Indicates whether the connected HVAC system is currently heating, as reported by the thermostat.
2027 2028 2029 |
# File 'lib/seam/resources/device.rb', line 2027 def is_heating @is_heating end |
#is_temporary_manual_override_active ⇒ Boolean?
Indicates whether the current thermostat settings differ from the most recent active program or schedule that Seam activated. For this condition to occur, current_climate_setting.manual_override_allowed must also be true.
2030 2031 2032 |
# File 'lib/seam/resources/device.rb', line 2030 def is_temporary_manual_override_active @is_temporary_manual_override_active end |
#locked ⇒ Boolean?
Indicates whether the lock is locked.
1970 1971 1972 |
# File 'lib/seam/resources/device.rb', line 1970 def locked @locked end |
#manufacturer ⇒ String?
Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.
1925 1926 1927 |
# File 'lib/seam/resources/device.rb', line 1925 def manufacturer @manufacturer end |
#max_active_codes_supported ⇒ Float?
Maximum number of active access codes that the device supports.
1973 1974 1975 |
# File 'lib/seam/resources/device.rb', line 1973 def max_active_codes_supported @max_active_codes_supported end |
#max_cooling_set_point_celsius ⇒ Float?
Maximum cooling set point in °C.
2033 2034 2035 |
# File 'lib/seam/resources/device.rb', line 2033 def max_cooling_set_point_celsius @max_cooling_set_point_celsius end |
#max_cooling_set_point_fahrenheit ⇒ Float?
Maximum cooling set point in °F.
2036 2037 2038 |
# File 'lib/seam/resources/device.rb', line 2036 def max_cooling_set_point_fahrenheit @max_cooling_set_point_fahrenheit end |
#max_heating_set_point_celsius ⇒ Float?
Maximum heating set point in °C.
2039 2040 2041 |
# File 'lib/seam/resources/device.rb', line 2039 def max_heating_set_point_celsius @max_heating_set_point_celsius end |
#max_heating_set_point_fahrenheit ⇒ Float?
Maximum heating set point in °F.
2042 2043 2044 |
# File 'lib/seam/resources/device.rb', line 2042 def max_heating_set_point_fahrenheit @max_heating_set_point_fahrenheit end |
#max_thermostat_daily_program_periods_per_day ⇒ Float?
Maximum number of periods that the thermostat can support per day. For example, if the thermostat supports 4 periods per day, this value is 4.
2045 2046 2047 |
# File 'lib/seam/resources/device.rb', line 2045 def max_thermostat_daily_program_periods_per_day @max_thermostat_daily_program_periods_per_day end |
#max_unique_climate_presets_per_thermostat_weekly_program ⇒ Float?
Maximum number of climate presets that the thermostat can support for weekly programming.
2048 2049 2050 |
# File 'lib/seam/resources/device.rb', line 2048 def max_unique_climate_presets_per_thermostat_weekly_program @max_unique_climate_presets_per_thermostat_weekly_program end |
#min_cooling_set_point_celsius ⇒ Float?
Minimum cooling set point in °C.
2051 2052 2053 |
# File 'lib/seam/resources/device.rb', line 2051 def min_cooling_set_point_celsius @min_cooling_set_point_celsius end |
#min_cooling_set_point_fahrenheit ⇒ Float?
Minimum cooling set point in °F.
2054 2055 2056 |
# File 'lib/seam/resources/device.rb', line 2054 def min_cooling_set_point_fahrenheit @min_cooling_set_point_fahrenheit end |
#min_heating_cooling_delta_celsius ⇒ Float?
Minimum temperature difference in °C between the cooling and heating set points when in heat-cool (auto) mode.
2057 2058 2059 |
# File 'lib/seam/resources/device.rb', line 2057 def min_heating_cooling_delta_celsius @min_heating_cooling_delta_celsius end |
#min_heating_cooling_delta_fahrenheit ⇒ Float?
Minimum temperature difference in °F between the cooling and heating set points when in heat-cool (auto) mode.
2060 2061 2062 |
# File 'lib/seam/resources/device.rb', line 2060 def min_heating_cooling_delta_fahrenheit @min_heating_cooling_delta_fahrenheit end |
#min_heating_set_point_celsius ⇒ Float?
Minimum heating set point in °C.
2063 2064 2065 |
# File 'lib/seam/resources/device.rb', line 2063 def min_heating_set_point_celsius @min_heating_set_point_celsius end |
#min_heating_set_point_fahrenheit ⇒ Float?
Minimum heating set point in °F.
2066 2067 2068 |
# File 'lib/seam/resources/device.rb', line 2066 def min_heating_set_point_fahrenheit @min_heating_set_point_fahrenheit end |
#name ⇒ String
use device.display_name instead
Name of the device.
1929 1930 1931 |
# File 'lib/seam/resources/device.rb', line 1929 def name @name end |
#noise_level_decibels ⇒ Float?
Indicates current noise level in decibels, if the device supports noise detection.
1932 1933 1934 |
# File 'lib/seam/resources/device.rb', line 1932 def noise_level_decibels @noise_level_decibels end |
#offline_access_codes_enabled ⇒ Boolean?
use device.can_program_offline_access_codes
Indicates whether it is currently possible to use offline access codes for the device.
1936 1937 1938 |
# File 'lib/seam/resources/device.rb', line 1936 def offline_access_codes_enabled @offline_access_codes_enabled end |
#online ⇒ Boolean
Indicates whether the device is online.
1939 1940 1941 |
# File 'lib/seam/resources/device.rb', line 1939 def online @online end |
#online_access_codes_enabled ⇒ Boolean?
use device.can_program_online_access_codes
Indicates whether it is currently possible to use online access codes for the device.
1943 1944 1945 |
# File 'lib/seam/resources/device.rb', line 1943 def online_access_codes_enabled @online_access_codes_enabled end |
#relative_humidity ⇒ Float?
Reported relative humidity, as a value between 0 and 1, inclusive.
2069 2070 2071 |
# File 'lib/seam/resources/device.rb', line 2069 def relative_humidity @relative_humidity end |
#serial_number ⇒ String?
Serial number of the device.
1946 1947 1948 |
# File 'lib/seam/resources/device.rb', line 1946 def serial_number @serial_number end |
#supported_code_lengths ⇒ Array<Float>
Supported code lengths for access codes.
1976 1977 1978 |
# File 'lib/seam/resources/device.rb', line 1976 def supported_code_lengths @supported_code_lengths end |
#supports_accessory_keypad ⇒ Boolean?
use device.properties.model.can_connect_accessory_keypad
1949 1950 1951 |
# File 'lib/seam/resources/device.rb', line 1949 def supports_accessory_keypad @supports_accessory_keypad end |
#supports_backup_access_code_pool ⇒ Boolean?
Indicates whether the device supports a backup access code pool.
1979 1980 1981 |
# File 'lib/seam/resources/device.rb', line 1979 def supports_backup_access_code_pool @supports_backup_access_code_pool end |
#supports_offline_access_codes ⇒ Boolean?
use offline_access_codes_enabled
1952 1953 1954 |
# File 'lib/seam/resources/device.rb', line 1952 def supports_offline_access_codes @supports_offline_access_codes end |
#temperature_celsius ⇒ Float?
Reported temperature in °C.
2072 2073 2074 |
# File 'lib/seam/resources/device.rb', line 2072 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float?
Reported temperature in °F.
2075 2076 2077 |
# File 'lib/seam/resources/device.rb', line 2075 def temperature_fahrenheit @temperature_fahrenheit end |
#thermostat_daily_program_period_precision_minutes ⇒ Float?
Precision of the thermostat's period in minutes. For example, if the thermostat supports 15-minute periods, this value is 15. All values are relative to the top of the hour, so for 15 minutes, the periods would be 0, 15, 30, and 45 minutes past the hour.
2078 2079 2080 |
# File 'lib/seam/resources/device.rb', line 2078 def thermostat_daily_program_period_precision_minutes @thermostat_daily_program_period_precision_minutes end |
Instance Method Details
#accessory_keypad ⇒ AccessoryKeypad?
Accessory keypad properties and state.
1743 |
# File 'lib/seam/resources/device.rb', line 1743 resource_accessor :accessory_keypad, AccessoryKeypad |
#active_thermostat_schedule ⇒ ActiveThermostatSchedule?
Active thermostat schedule.
1881 |
# File 'lib/seam/resources/device.rb', line 1881 resource_accessor :active_thermostat_schedule, ActiveThermostatSchedule |
#akiles_metadata ⇒ AkilesMetadata?
Metadata for an Akiles device.
1761 |
# File 'lib/seam/resources/device.rb', line 1761 resource_accessor :akiles_metadata, AkilesMetadata |
#appearance ⇒ Appearance
Appearance-related properties, as reported by the device.
1746 |
# File 'lib/seam/resources/device.rb', line 1746 resource_accessor :appearance, Appearance |
#aqara_metadata ⇒ AqaraMetadata?
Metadata for an Aqara device.
1764 |
# File 'lib/seam/resources/device.rb', line 1764 resource_accessor :aqara_metadata, AqaraMetadata |
#assa_abloy_credential_service_metadata ⇒ AssaAbloyCredentialServiceMetadata?
ASSA ABLOY Credential Service metadata for the phone.
1755 |
# File 'lib/seam/resources/device.rb', line 1755 resource_accessor :assa_abloy_credential_service_metadata, AssaAbloyCredentialServiceMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Metadata for an ASSA ABLOY Vostio system.
1767 |
# File 'lib/seam/resources/device.rb', line 1767 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#august_metadata ⇒ AugustMetadata?
Metadata for an August device.
1770 |
# File 'lib/seam/resources/device.rb', line 1770 resource_accessor :august_metadata, AugustMetadata |
#available_climate_presets ⇒ Array<AvailableClimatePresets>
Available climate presets for the thermostat.
1904 |
# File 'lib/seam/resources/device.rb', line 1904 resource_list_accessor :available_climate_presets, AvailableClimatePresets |
#avigilon_alta_metadata ⇒ AvigilonAltaMetadata?
Metadata for an Avigilon Alta system.
1773 |
# File 'lib/seam/resources/device.rb', line 1773 resource_accessor :avigilon_alta_metadata, AvigilonAltaMetadata |
#battery ⇒ Battery?
Represents the current status of the battery charge level.
1749 |
# File 'lib/seam/resources/device.rb', line 1749 resource_accessor :battery, Battery |
#brivo_metadata ⇒ BrivoMetadata?
Metadata for a Brivo device.
1776 |
# File 'lib/seam/resources/device.rb', line 1776 resource_accessor :brivo_metadata, BrivoMetadata |
#code_constraints ⇒ Array<CodeConstraints>
Constraints on access codes for the device. Seam represents each constraint as an object with a constraint_type property. Depending on the constraint type, there may also be additional properties. Note that some constraints are manufacturer- or device-specific.
1895 |
# File 'lib/seam/resources/device.rb', line 1895 resource_list_accessor :code_constraints, CodeConstraints |
#controlbyweb_metadata ⇒ ControlbywebMetadata?
Metadata for a ControlByWeb device.
1779 |
# File 'lib/seam/resources/device.rb', line 1779 resource_accessor :controlbyweb_metadata, ControlbywebMetadata |
#current_climate_setting ⇒ CurrentClimateSetting?
Current climate setting.
1884 |
# File 'lib/seam/resources/device.rb', line 1884 resource_accessor :current_climate_setting, CurrentClimateSetting |
#default_climate_setting ⇒ DefaultClimateSetting?
1886 |
# File 'lib/seam/resources/device.rb', line 1886 resource_accessor :default_climate_setting, DefaultClimateSetting |
#dormakaba_oracode_metadata ⇒ DormakabaOracodeMetadata?
Metadata for a dormakaba Oracode device.
1782 |
# File 'lib/seam/resources/device.rb', line 1782 resource_accessor :dormakaba_oracode_metadata, DormakabaOracodeMetadata |
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata for an ecobee device.
1785 |
# File 'lib/seam/resources/device.rb', line 1785 resource_accessor :ecobee_metadata, EcobeeMetadata |
#four_suites_metadata ⇒ FourSuitesMetadata?
Metadata for a 4SUITES device.
1788 |
# File 'lib/seam/resources/device.rb', line 1788 resource_accessor :four_suites_metadata, FourSuitesMetadata |
#genie_metadata ⇒ GenieMetadata?
Metadata for a Genie device.
1791 |
# File 'lib/seam/resources/device.rb', line 1791 resource_accessor :genie_metadata, GenieMetadata |
#honeywell_resideo_metadata ⇒ HoneywellResideoMetadata?
Metadata for a Honeywell Resideo device.
1794 |
# File 'lib/seam/resources/device.rb', line 1794 resource_accessor :honeywell_resideo_metadata, HoneywellResideoMetadata |
#igloo_metadata ⇒ IglooMetadata?
Metadata for an igloo device.
1797 |
# File 'lib/seam/resources/device.rb', line 1797 resource_accessor :igloo_metadata, IglooMetadata |
#igloohome_metadata ⇒ IgloohomeMetadata?
Metadata for an igloohome device.
1800 |
# File 'lib/seam/resources/device.rb', line 1800 resource_accessor :igloohome_metadata, IgloohomeMetadata |
#keynest_metadata ⇒ KeynestMetadata?
Metadata for a KeyNest device.
1803 |
# File 'lib/seam/resources/device.rb', line 1803 resource_accessor :keynest_metadata, KeynestMetadata |
#keypad_battery ⇒ KeypadBattery?
Keypad battery status.
1878 |
# File 'lib/seam/resources/device.rb', line 1878 resource_accessor :keypad_battery, KeypadBattery |
#kisi_metadata ⇒ KisiMetadata?
Metadata for a Kisi device.
1806 |
# File 'lib/seam/resources/device.rb', line 1806 resource_accessor :kisi_metadata, KisiMetadata |
#korelock_metadata ⇒ KorelockMetadata?
Metadata for a Korelock device.
1809 |
# File 'lib/seam/resources/device.rb', line 1809 resource_accessor :korelock_metadata, KorelockMetadata |
#kwikset_metadata ⇒ KwiksetMetadata?
Metadata for a Kwikset device.
1812 |
# File 'lib/seam/resources/device.rb', line 1812 resource_accessor :kwikset_metadata, KwiksetMetadata |
#lockly_metadata ⇒ LocklyMetadata?
Metadata for a Lockly device.
1815 |
# File 'lib/seam/resources/device.rb', line 1815 resource_accessor :lockly_metadata, LocklyMetadata |
#minut_metadata ⇒ MinutMetadata?
Metadata for a Minut device.
1818 |
# File 'lib/seam/resources/device.rb', line 1818 resource_accessor :minut_metadata, MinutMetadata |
#model ⇒ Model
Device model-related properties.
1752 |
# File 'lib/seam/resources/device.rb', line 1752 resource_accessor :model, Model |
#nest_metadata ⇒ NestMetadata?
Metadata for a Google Nest device.
1821 |
# File 'lib/seam/resources/device.rb', line 1821 resource_accessor :nest_metadata, NestMetadata |
#noiseaware_metadata ⇒ NoiseawareMetadata?
Metadata for a NoiseAware device.
1824 |
# File 'lib/seam/resources/device.rb', line 1824 resource_accessor :noiseaware_metadata, NoiseawareMetadata |
#nuki_metadata ⇒ NukiMetadata?
Metadata for a Nuki device.
1827 |
# File 'lib/seam/resources/device.rb', line 1827 resource_accessor :nuki_metadata, NukiMetadata |
#offline_time_frame_options ⇒ Array<OfflineTimeFrameOptions>
Time frames that may be requested when creating an offline access code, expressed as a list of options. The caller picks one option (by matching the requested duration when the options' duration ranges do not overlap, or by display_name when they do) and satisfies that one option's rules. When undefined, any time frame works.
1898 |
# File 'lib/seam/resources/device.rb', line 1898 resource_list_accessor :offline_time_frame_options, OfflineTimeFrameOptions |
#omnitec_metadata ⇒ OmnitecMetadata?
Metadata for an Omnitec device.
1830 |
# File 'lib/seam/resources/device.rb', line 1830 resource_accessor :omnitec_metadata, OmnitecMetadata |
#online_time_frame_options ⇒ Array<OnlineTimeFrameOptions>
Time frames that may be requested when creating an online access code, expressed as a list of options. The caller picks one option (by matching the requested duration when the options' duration ranges do not overlap, or by display_name when they do) and satisfies that one option's rules. When undefined, any time frame works.
1901 |
# File 'lib/seam/resources/device.rb', line 1901 resource_list_accessor :online_time_frame_options, OnlineTimeFrameOptions |
#ring_metadata ⇒ RingMetadata?
Metadata for a Ring device.
1833 |
# File 'lib/seam/resources/device.rb', line 1833 resource_accessor :ring_metadata, RingMetadata |
#salto_ks_metadata ⇒ SaltoKsMetadata?
Metadata for a Salto KS device.
1836 |
# File 'lib/seam/resources/device.rb', line 1836 resource_accessor :salto_ks_metadata, SaltoKsMetadata |
#salto_metadata ⇒ SaltoMetadata?
Metada for a Salto device.
1839 |
# File 'lib/seam/resources/device.rb', line 1839 resource_accessor :salto_metadata, SaltoMetadata |
#salto_space_credential_service_metadata ⇒ SaltoSpaceCredentialServiceMetadata?
Salto Space credential service metadata for the phone.
1758 |
# File 'lib/seam/resources/device.rb', line 1758 resource_accessor :salto_space_credential_service_metadata, SaltoSpaceCredentialServiceMetadata |
#schlage_metadata ⇒ SchlageMetadata?
Metadata for a Schlage device.
1842 |
# File 'lib/seam/resources/device.rb', line 1842 resource_accessor :schlage_metadata, SchlageMetadata |
#seam_bridge_metadata ⇒ SeamBridgeMetadata?
Metadata for Seam Bridge.
1845 |
# File 'lib/seam/resources/device.rb', line 1845 resource_accessor :seam_bridge_metadata, SeamBridgeMetadata |
#sensi_metadata ⇒ SensiMetadata?
Metadata for a Sensi device.
1848 |
# File 'lib/seam/resources/device.rb', line 1848 resource_accessor :sensi_metadata, SensiMetadata |
#smartthings_metadata ⇒ SmartthingsMetadata?
Metadata for a SmartThings device.
1851 |
# File 'lib/seam/resources/device.rb', line 1851 resource_accessor :smartthings_metadata, SmartthingsMetadata |
#tado_metadata ⇒ TadoMetadata?
Metadata for a tado° device.
1854 |
# File 'lib/seam/resources/device.rb', line 1854 resource_accessor :tado_metadata, TadoMetadata |
#tedee_metadata ⇒ TedeeMetadata?
Metadata for a Tedee device.
1857 |
# File 'lib/seam/resources/device.rb', line 1857 resource_accessor :tedee_metadata, TedeeMetadata |
#temperature_threshold ⇒ TemperatureThreshold?
Current temperature threshold set for the thermostat.
1889 |
# File 'lib/seam/resources/device.rb', line 1889 resource_accessor :temperature_threshold, TemperatureThreshold |
#thermostat_daily_programs ⇒ Array<ThermostatDailyPrograms>
Configured daily programs for the thermostat.
1907 |
# File 'lib/seam/resources/device.rb', line 1907 resource_list_accessor :thermostat_daily_programs, ThermostatDailyPrograms |
#thermostat_weekly_program ⇒ ThermostatWeeklyProgram?
Current weekly program for the thermostat.
1892 |
# File 'lib/seam/resources/device.rb', line 1892 resource_accessor :thermostat_weekly_program, ThermostatWeeklyProgram |
#ttlock_metadata ⇒ TtlockMetadata?
Metadata for a TTLock device.
1860 |
# File 'lib/seam/resources/device.rb', line 1860 resource_accessor :ttlock_metadata, TtlockMetadata |
#two_n_metadata ⇒ TwoNMetadata?
Metadata for a 2N device.
1863 |
# File 'lib/seam/resources/device.rb', line 1863 resource_accessor :two_n_metadata, TwoNMetadata |
#ultraloq_metadata ⇒ UltraloqMetadata?
Metadata for an Ultraloq device.
1866 |
# File 'lib/seam/resources/device.rb', line 1866 resource_accessor :ultraloq_metadata, UltraloqMetadata |
#visionline_metadata ⇒ VisionlineMetadata?
Metadata for an ASSA ABLOY Visionline system.
1869 |
# File 'lib/seam/resources/device.rb', line 1869 resource_accessor :visionline_metadata, VisionlineMetadata |
#wyze_metadata ⇒ WyzeMetadata?
Metadata for a Wyze device.
1872 |
# File 'lib/seam/resources/device.rb', line 1872 resource_accessor :wyze_metadata, WyzeMetadata |
#yacan_metadata ⇒ YacanMetadata?
Metadata for a Yacan device.
1875 |
# File 'lib/seam/resources/device.rb', line 1875 resource_accessor :yacan_metadata, YacanMetadata |