Class: Seam::Resources::Device::Properties::ActiveThermostatSchedule

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: Errors

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_preset_keyString

Key of the climate preset to use for the thermostat schedule.

Returns:

  • (String)


1399
1400
1401
# File 'lib/seam/resources/device.rb', line 1399

def climate_preset_key
  @climate_preset_key
end

#device_idString

ID of the desired thermostat device.

Returns:

  • (String)


1402
1403
1404
# File 'lib/seam/resources/device.rb', line 1402

def device_id
  @device_id
end

#is_override_allowedBoolean?

Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.

Returns:

  • (Boolean, nil)


1405
1406
1407
# File 'lib/seam/resources/device.rb', line 1405

def is_override_allowed
  @is_override_allowed
end

#max_override_period_minutesInteger?

Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.

Returns:

  • (Integer, nil)


1408
1409
1410
# File 'lib/seam/resources/device.rb', line 1408

def max_override_period_minutes
  @max_override_period_minutes
end

#nameString?

User-friendly name to identify the thermostat schedule.

Returns:

  • (String, nil)


1411
1412
1413
# File 'lib/seam/resources/device.rb', line 1411

def name
  @name
end

#thermostat_schedule_idString

ID of the thermostat schedule.

Returns:

  • (String)


1414
1415
1416
# File 'lib/seam/resources/device.rb', line 1414

def thermostat_schedule_id
  @thermostat_schedule_id
end

#workspace_idString

ID of the workspace that contains the thermostat schedule.

Returns:

  • (String)


1417
1418
1419
# File 'lib/seam/resources/device.rb', line 1417

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the thermostat schedule was created.

Returns:

  • (Time)


1420
# File 'lib/seam/resources/device.rb', line 1420

date_accessor :created_at

#ends_atTime

Date and time at which the thermostat schedule ends, in ISO 8601 format.

Returns:

  • (Time)


1423
# File 'lib/seam/resources/device.rb', line 1423

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the thermostat schedule.

Returns:



1396
# File 'lib/seam/resources/device.rb', line 1396

resource_list_accessor :errors, Errors

#starts_atTime

Date and time at which the thermostat schedule starts, in ISO 8601 format.

Returns:

  • (Time)


1426
# File 'lib/seam/resources/device.rb', line 1426

date_accessor :starts_at