Class: Seam::Resources::Device::Properties::AvailableClimatePresets::EcobeeMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_refString?

Reference to the Ecobee climate, if applicable.

Returns:

  • (String, nil)


1433
1434
1435
# File 'lib/seam/resources/device.rb', line 1433

def climate_ref
  @climate_ref
end

#is_optimizedBoolean?

Indicates if the climate preset is optimized by Ecobee.

Returns:

  • (Boolean, nil)


1436
1437
1438
# File 'lib/seam/resources/device.rb', line 1436

def is_optimized
  @is_optimized
end

#ownerString?

Indicates whether the climate preset is owned by the user or the system. Known values:

  • user
  • system

Returns:

  • (String, nil)


1442
1443
1444
# File 'lib/seam/resources/device.rb', line 1442

def owner
  @owner
end