Class: Seam::Resources::Device::Properties::CurrentClimateSetting

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: EcobeeMetadata

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_deleteBoolean?

Indicates whether the climate preset key can be deleted.

Returns:

  • (Boolean, nil)


1531
1532
1533
# File 'lib/seam/resources/device.rb', line 1531

def can_delete
  @can_delete
end

#can_editBoolean?

Indicates whether the climate preset key can be edited.

Returns:

  • (Boolean, nil)


1534
1535
1536
# File 'lib/seam/resources/device.rb', line 1534

def can_edit
  @can_edit
end

#can_use_with_thermostat_daily_programsBoolean?

Indicates whether the climate preset key can be programmed in a thermostat daily program.

Returns:

  • (Boolean, nil)


1537
1538
1539
# File 'lib/seam/resources/device.rb', line 1537

def can_use_with_thermostat_daily_programs
  @can_use_with_thermostat_daily_programs
end

#climate_preset_keyString?

Unique key to identify the climate preset.

Returns:

  • (String, nil)


1540
1541
1542
# File 'lib/seam/resources/device.rb', line 1540

def climate_preset_key
  @climate_preset_key
end

#climate_preset_modeString?

The climate preset mode for the thermostat, based on the available climate preset modes reported by the device. Known values:

  • home
  • away
  • wake
  • sleep
  • occupied
  • unoccupied

Returns:

  • (String, nil)


1550
1551
1552
# File 'lib/seam/resources/device.rb', line 1550

def climate_preset_mode
  @climate_preset_mode
end

#cooling_set_point_celsiusFloat?

Temperature to which the thermostat should cool (in °C). See also Set Points.

Returns:

  • (Float, nil)


1553
1554
1555
# File 'lib/seam/resources/device.rb', line 1553

def cooling_set_point_celsius
  @cooling_set_point_celsius
end

#cooling_set_point_fahrenheitFloat?

Temperature to which the thermostat should cool (in °F). See also Set Points.

Returns:

  • (Float, nil)


1556
1557
1558
# File 'lib/seam/resources/device.rb', line 1556

def cooling_set_point_fahrenheit
  @cooling_set_point_fahrenheit
end

#display_nameString?

Display name for the climate preset.

Returns:

  • (String, nil)


1559
1560
1561
# File 'lib/seam/resources/device.rb', line 1559

def display_name
  @display_name
end

#fan_mode_settingString?

Desired fan mode setting, such as on, auto, or circulate. Known values:

  • auto
  • on
  • circulate

Returns:

  • (String, nil)


1566
1567
1568
# File 'lib/seam/resources/device.rb', line 1566

def fan_mode_setting
  @fan_mode_setting
end

#heating_set_point_celsiusFloat?

Temperature to which the thermostat should heat (in °C). See also Set Points.

Returns:

  • (Float, nil)


1569
1570
1571
# File 'lib/seam/resources/device.rb', line 1569

def heating_set_point_celsius
  @heating_set_point_celsius
end

#heating_set_point_fahrenheitFloat?

Temperature to which the thermostat should heat (in °F). See also Set Points.

Returns:

  • (Float, nil)


1572
1573
1574
# File 'lib/seam/resources/device.rb', line 1572

def heating_set_point_fahrenheit
  @heating_set_point_fahrenheit
end

#hvac_mode_settingString?

Desired HVAC mode setting, such as heat, cool, heat_cool, or off. Known values:

  • off
  • heat
  • cool
  • heat_cool
  • eco

Returns:

  • (String, nil)


1581
1582
1583
# File 'lib/seam/resources/device.rb', line 1581

def hvac_mode_setting
  @hvac_mode_setting
end

#manual_override_allowedBoolean?

Deprecated.

Use 'thermostat_schedule.is_override_allowed'

Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.

Returns:

  • (Boolean, nil)


1585
1586
1587
# File 'lib/seam/resources/device.rb', line 1585

def manual_override_allowed
  @manual_override_allowed
end

#nameString?

User-friendly name to identify the climate preset.

Returns:

  • (String, nil)


1588
1589
1590
# File 'lib/seam/resources/device.rb', line 1588

def name
  @name
end

Instance Method Details

#ecobee_metadataEcobeeMetadata?

Metadata specific to the Ecobee climate, if applicable.

Returns:



1528
# File 'lib/seam/resources/device.rb', line 1528

resource_accessor :ecobee_metadata, EcobeeMetadata