Class: Seam::Resources::Device::Properties::DefaultClimateSetting

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: EcobeeMetadata

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_deleteBoolean?

Indicates whether the climate preset key can be deleted.

Returns:

  • (Boolean, nil)


1612
1613
1614
# File 'lib/seam/resources/device.rb', line 1612

def can_delete
  @can_delete
end

#can_editBoolean?

Indicates whether the climate preset key can be edited.

Returns:

  • (Boolean, nil)


1615
1616
1617
# File 'lib/seam/resources/device.rb', line 1615

def can_edit
  @can_edit
end

#can_use_with_thermostat_daily_programsBoolean?

Indicates whether the climate preset key can be programmed in a thermostat daily program.

Returns:

  • (Boolean, nil)


1618
1619
1620
# File 'lib/seam/resources/device.rb', line 1618

def can_use_with_thermostat_daily_programs
  @can_use_with_thermostat_daily_programs
end

#climate_preset_keyString?

Unique key to identify the climate preset.

Returns:

  • (String, nil)


1621
1622
1623
# File 'lib/seam/resources/device.rb', line 1621

def climate_preset_key
  @climate_preset_key
end

#climate_preset_modeString?

The climate preset mode for the thermostat, based on the available climate preset modes reported by the device. Known values:

  • home
  • away
  • wake
  • sleep
  • occupied
  • unoccupied

Returns:

  • (String, nil)


1631
1632
1633
# File 'lib/seam/resources/device.rb', line 1631

def climate_preset_mode
  @climate_preset_mode
end

#cooling_set_point_celsiusFloat?

Temperature to which the thermostat should cool (in °C). See also Set Points.

Returns:

  • (Float, nil)


1634
1635
1636
# File 'lib/seam/resources/device.rb', line 1634

def cooling_set_point_celsius
  @cooling_set_point_celsius
end

#cooling_set_point_fahrenheitFloat?

Temperature to which the thermostat should cool (in °F). See also Set Points.

Returns:

  • (Float, nil)


1637
1638
1639
# File 'lib/seam/resources/device.rb', line 1637

def cooling_set_point_fahrenheit
  @cooling_set_point_fahrenheit
end

#display_nameString?

Display name for the climate preset.

Returns:

  • (String, nil)


1640
1641
1642
# File 'lib/seam/resources/device.rb', line 1640

def display_name
  @display_name
end

#fan_mode_settingString?

Desired fan mode setting, such as on, auto, or circulate. Known values:

  • auto
  • on
  • circulate

Returns:

  • (String, nil)


1647
1648
1649
# File 'lib/seam/resources/device.rb', line 1647

def fan_mode_setting
  @fan_mode_setting
end

#heating_set_point_celsiusFloat?

Temperature to which the thermostat should heat (in °C). See also Set Points.

Returns:

  • (Float, nil)


1650
1651
1652
# File 'lib/seam/resources/device.rb', line 1650

def heating_set_point_celsius
  @heating_set_point_celsius
end

#heating_set_point_fahrenheitFloat?

Temperature to which the thermostat should heat (in °F). See also Set Points.

Returns:

  • (Float, nil)


1653
1654
1655
# File 'lib/seam/resources/device.rb', line 1653

def heating_set_point_fahrenheit
  @heating_set_point_fahrenheit
end

#hvac_mode_settingString?

Desired HVAC mode setting, such as heat, cool, heat_cool, or off. Known values:

  • off
  • heat
  • cool
  • heat_cool
  • eco

Returns:

  • (String, nil)


1662
1663
1664
# File 'lib/seam/resources/device.rb', line 1662

def hvac_mode_setting
  @hvac_mode_setting
end

#manual_override_allowedBoolean?

Deprecated.

Use 'thermostat_schedule.is_override_allowed'

Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.

Returns:

  • (Boolean, nil)


1666
1667
1668
# File 'lib/seam/resources/device.rb', line 1666

def manual_override_allowed
  @manual_override_allowed
end

#nameString?

User-friendly name to identify the climate preset.

Returns:

  • (String, nil)


1669
1670
1671
# File 'lib/seam/resources/device.rb', line 1669

def name
  @name
end

Instance Method Details

#ecobee_metadataEcobeeMetadata?

Metadata specific to the Ecobee climate, if applicable.

Returns:



1609
# File 'lib/seam/resources/device.rb', line 1609

resource_accessor :ecobee_metadata, EcobeeMetadata