Class: Seam::Resources::Device::Properties::DormakabaOracodeMetadata::PredefinedTimeSlots

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#check_in_timeString?

Check in time for a time slot for a dormakaba Oracode device.

Returns:

  • (String, nil)


268
269
270
# File 'lib/seam/resources/device.rb', line 268

def check_in_time
  @check_in_time
end

#check_out_timeString?

Checkout time for a time slot for a dormakaba Oracode device.

Returns:

  • (String, nil)


271
272
273
# File 'lib/seam/resources/device.rb', line 271

def check_out_time
  @check_out_time
end

#dormakaba_oracode_user_level_idString?

ID of a user level for a dormakaba Oracode device.

Returns:

  • (String, nil)


274
275
276
# File 'lib/seam/resources/device.rb', line 274

def dormakaba_oracode_user_level_id
  @dormakaba_oracode_user_level_id
end

#dormakaba_oracode_user_level_prefixFloat?

Prefix for a user level for a dormakaba Oracode device.

Returns:

  • (Float, nil)


277
278
279
# File 'lib/seam/resources/device.rb', line 277

def dormakaba_oracode_user_level_prefix
  @dormakaba_oracode_user_level_prefix
end

#is_24_hourBoolean?

Indicates whether a time slot for a dormakaba Oracode device is a 24-hour time slot.

Returns:

  • (Boolean, nil)


280
281
282
# File 'lib/seam/resources/device.rb', line 280

def is_24_hour
  @is_24_hour
end

#is_biweekly_modeBoolean?

Indicates whether a time slot for a dormakaba Oracode device is in biweekly mode.

Returns:

  • (Boolean, nil)


283
284
285
# File 'lib/seam/resources/device.rb', line 283

def is_biweekly_mode
  @is_biweekly_mode
end

#is_masterBoolean?

Indicates whether a time slot for a dormakaba Oracode device is a master time slot.

Returns:

  • (Boolean, nil)


286
287
288
# File 'lib/seam/resources/device.rb', line 286

def is_master
  @is_master
end

#is_one_shotBoolean?

Indicates whether a time slot for a dormakaba Oracode device is a one-shot time slot.

Returns:

  • (Boolean, nil)


289
290
291
# File 'lib/seam/resources/device.rb', line 289

def is_one_shot
  @is_one_shot
end

#nameString?

Name of a time slot for a dormakaba Oracode device.

Returns:

  • (String, nil)


292
293
294
# File 'lib/seam/resources/device.rb', line 292

def name
  @name
end

#prefixFloat?

Prefix for a time slot for a dormakaba Oracode device.

Returns:

  • (Float, nil)


295
296
297
# File 'lib/seam/resources/device.rb', line 295

def prefix
  @prefix
end