Class: Seam::Resources::Device::Properties::IgloohomeMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::IgloohomeMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#bridge_id ⇒ String?
Bridge ID for an igloohome device.
-
#bridge_name ⇒ String?
Bridge name for an igloohome device.
-
#device_id ⇒ String?
Device ID for an igloohome device.
-
#device_name ⇒ String?
Device name for an igloohome device.
-
#is_accessory_keypad_linked_to_bridge ⇒ Boolean?
Indicates whether a keypad is linked to a bridge for an igloohome device.
-
#keypad_id ⇒ String?
Keypad ID for an igloohome device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#bridge_id ⇒ String?
Bridge ID for an igloohome device.
379 380 381 |
# File 'lib/seam/resources/device.rb', line 379 def bridge_id @bridge_id end |
#bridge_name ⇒ String?
Bridge name for an igloohome device.
382 383 384 |
# File 'lib/seam/resources/device.rb', line 382 def bridge_name @bridge_name end |
#device_id ⇒ String?
Device ID for an igloohome device.
385 386 387 |
# File 'lib/seam/resources/device.rb', line 385 def device_id @device_id end |
#device_name ⇒ String?
Device name for an igloohome device.
388 389 390 |
# File 'lib/seam/resources/device.rb', line 388 def device_name @device_name end |
#is_accessory_keypad_linked_to_bridge ⇒ Boolean?
Indicates whether a keypad is linked to a bridge for an igloohome device.
391 392 393 |
# File 'lib/seam/resources/device.rb', line 391 def is_accessory_keypad_linked_to_bridge @is_accessory_keypad_linked_to_bridge end |
#keypad_id ⇒ String?
Keypad ID for an igloohome device.
394 395 396 |
# File 'lib/seam/resources/device.rb', line 394 def keypad_id @keypad_id end |