Class: Seam::Resources::Device::Properties::KeynestMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::KeynestMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Address for a KeyNest device.
-
#current_or_last_store_id ⇒ Float?
Current or last store ID for a KeyNest device.
-
#current_status ⇒ String?
Current status for a KeyNest device.
-
#current_user_company ⇒ String?
Current user company for a KeyNest device.
-
#current_user_email ⇒ String?
Current user email for a KeyNest device.
-
#current_user_name ⇒ String?
Current user name for a KeyNest device.
-
#current_user_phone_number ⇒ String?
Current user phone number for a KeyNest device.
-
#default_office_id ⇒ Float?
Default office ID for a KeyNest device.
-
#device_name ⇒ String?
Device name for a KeyNest device.
-
#fob_id ⇒ Float?
Fob ID for a KeyNest device.
-
#handover_method ⇒ String?
Handover method for a KeyNest device.
-
#has_photo ⇒ Boolean?
Whether the KeyNest device has a photo.
-
#is_quadient_locker ⇒ Boolean?
Whether the key is in a locker that does not support the access codes API.
-
#key_id ⇒ String?
Key ID for a KeyNest device.
-
#key_notes ⇒ String?
Key notes for a KeyNest device.
-
#keynest_app_user ⇒ String?
KeyNest app user for a KeyNest device.
-
#last_movement ⇒ String?
Last movement timestamp for a KeyNest device.
-
#property_id ⇒ String?
Property ID for a KeyNest device.
-
#property_postcode ⇒ String?
Property postcode for a KeyNest device.
-
#status_type ⇒ String?
Status type for a KeyNest device.
-
#subscription_plan ⇒ String?
Subscription plan for a KeyNest device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#address ⇒ String?
Address for a KeyNest device.
698 699 700 |
# File 'lib/seam/resources/device.rb', line 698 def address @address end |
#current_or_last_store_id ⇒ Float?
Current or last store ID for a KeyNest device.
701 702 703 |
# File 'lib/seam/resources/device.rb', line 701 def current_or_last_store_id @current_or_last_store_id end |
#current_status ⇒ String?
Current status for a KeyNest device.
704 705 706 |
# File 'lib/seam/resources/device.rb', line 704 def current_status @current_status end |
#current_user_company ⇒ String?
Current user company for a KeyNest device.
707 708 709 |
# File 'lib/seam/resources/device.rb', line 707 def current_user_company @current_user_company end |
#current_user_email ⇒ String?
Current user email for a KeyNest device.
710 711 712 |
# File 'lib/seam/resources/device.rb', line 710 def current_user_email @current_user_email end |
#current_user_name ⇒ String?
Current user name for a KeyNest device.
713 714 715 |
# File 'lib/seam/resources/device.rb', line 713 def current_user_name @current_user_name end |
#current_user_phone_number ⇒ String?
Current user phone number for a KeyNest device.
716 717 718 |
# File 'lib/seam/resources/device.rb', line 716 def current_user_phone_number @current_user_phone_number end |
#default_office_id ⇒ Float?
Default office ID for a KeyNest device.
719 720 721 |
# File 'lib/seam/resources/device.rb', line 719 def default_office_id @default_office_id end |
#device_name ⇒ String?
Device name for a KeyNest device.
722 723 724 |
# File 'lib/seam/resources/device.rb', line 722 def device_name @device_name end |
#fob_id ⇒ Float?
Fob ID for a KeyNest device.
725 726 727 |
# File 'lib/seam/resources/device.rb', line 725 def fob_id @fob_id end |
#handover_method ⇒ String?
Handover method for a KeyNest device.
728 729 730 |
# File 'lib/seam/resources/device.rb', line 728 def handover_method @handover_method end |
#has_photo ⇒ Boolean?
Whether the KeyNest device has a photo.
731 732 733 |
# File 'lib/seam/resources/device.rb', line 731 def has_photo @has_photo end |
#is_quadient_locker ⇒ Boolean?
Whether the key is in a locker that does not support the access codes API.
734 735 736 |
# File 'lib/seam/resources/device.rb', line 734 def is_quadient_locker @is_quadient_locker end |
#key_id ⇒ String?
Key ID for a KeyNest device.
737 738 739 |
# File 'lib/seam/resources/device.rb', line 737 def key_id @key_id end |
#key_notes ⇒ String?
Key notes for a KeyNest device.
740 741 742 |
# File 'lib/seam/resources/device.rb', line 740 def key_notes @key_notes end |
#keynest_app_user ⇒ String?
KeyNest app user for a KeyNest device.
743 744 745 |
# File 'lib/seam/resources/device.rb', line 743 def keynest_app_user @keynest_app_user end |
#last_movement ⇒ String?
Last movement timestamp for a KeyNest device.
746 747 748 |
# File 'lib/seam/resources/device.rb', line 746 def last_movement @last_movement end |
#property_id ⇒ String?
Property ID for a KeyNest device.
749 750 751 |
# File 'lib/seam/resources/device.rb', line 749 def property_id @property_id end |
#property_postcode ⇒ String?
Property postcode for a KeyNest device.
752 753 754 |
# File 'lib/seam/resources/device.rb', line 752 def property_postcode @property_postcode end |
#status_type ⇒ String?
Status type for a KeyNest device.
755 756 757 |
# File 'lib/seam/resources/device.rb', line 755 def status_type @status_type end |
#subscription_plan ⇒ String?
Subscription plan for a KeyNest device.
758 759 760 |
# File 'lib/seam/resources/device.rb', line 758 def subscription_plan @subscription_plan end |