Class: Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Humidity

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#timeString?

Time of latest humidity reading for a Minut device.

Returns:

  • (String, nil)


540
541
542
# File 'lib/seam/resources/device.rb', line 540

def time
  @time
end

#valueFloat?

Value of latest humidity reading for a Minut device.

Returns:

  • (Float, nil)


543
544
545
# File 'lib/seam/resources/device.rb', line 543

def value
  @value
end