Class: Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Pressure
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Pressure
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#time ⇒ String?
Time of latest pressure reading for a Minut device.
-
#value ⇒ Float?
Value of latest pressure reading for a Minut device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#time ⇒ String?
Time of latest pressure reading for a Minut device.
549 550 551 |
# File 'lib/seam/resources/device.rb', line 549 def time @time end |
#value ⇒ Float?
Value of latest pressure reading for a Minut device.
552 553 554 |
# File 'lib/seam/resources/device.rb', line 552 def value @value end |