Class: Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Temperature

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#timeString?

Time of latest temperature reading for a Minut device.

Returns:

  • (String, nil)


567
568
569
# File 'lib/seam/resources/device.rb', line 567

def time
  @time
end

#valueFloat?

Value of latest temperature reading for a Minut device.

Returns:

  • (Float, nil)


570
571
572
# File 'lib/seam/resources/device.rb', line 570

def value
  @value
end