Class: Seam::Resources::Device::Properties::Model

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accessory_keypad_supportedBoolean?

Deprecated.

use device.properties.model.can_connect_accessory_keypad

Returns:

  • (Boolean, nil)


400
401
402
# File 'lib/seam/resources/device.rb', line 400

def accessory_keypad_supported
  @accessory_keypad_supported
end

#can_connect_accessory_keypadBoolean?

Indicates whether the device can connect a accessory keypad.

Returns:

  • (Boolean, nil)


403
404
405
# File 'lib/seam/resources/device.rb', line 403

def can_connect_accessory_keypad
  @can_connect_accessory_keypad
end

#display_nameString

Display name of the device model.

Returns:

  • (String)


406
407
408
# File 'lib/seam/resources/device.rb', line 406

def display_name
  @display_name
end

#has_built_in_keypadBoolean?

Indicates whether the device has a built in accessory keypad.

Returns:

  • (Boolean, nil)


409
410
411
# File 'lib/seam/resources/device.rb', line 409

def has_built_in_keypad
  @has_built_in_keypad
end

#manufacturer_display_nameString

Display name that corresponds to the manufacturer-specific terminology for the device.

Returns:

  • (String)


412
413
414
# File 'lib/seam/resources/device.rb', line 412

def manufacturer_display_name
  @manufacturer_display_name
end

#offline_access_codes_supportedBoolean?

Deprecated.

use device.can_program_offline_access_codes.

Returns:

  • (Boolean, nil)


415
416
417
# File 'lib/seam/resources/device.rb', line 415

def offline_access_codes_supported
  @offline_access_codes_supported
end

#online_access_codes_supportedBoolean?

Deprecated.

use device.can_program_online_access_codes.

Returns:

  • (Boolean, nil)


418
419
420
# File 'lib/seam/resources/device.rb', line 418

def online_access_codes_supported
  @online_access_codes_supported
end