Class: Seam::Resources::Device::Properties::NukiMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idString?

Device ID for a Nuki device.

Returns:

  • (String, nil)


944
945
946
# File 'lib/seam/resources/device.rb', line 944

def device_id
  @device_id
end

#device_nameString?

Device name for a Nuki device.

Returns:

  • (String, nil)


947
948
949
# File 'lib/seam/resources/device.rb', line 947

def device_name
  @device_name
end

#keypad_2_pairedBoolean?

Indicates whether keypad 2 is paired for a Nuki device.

Returns:

  • (Boolean, nil)


950
951
952
# File 'lib/seam/resources/device.rb', line 950

def keypad_2_paired
  @keypad_2_paired
end

#keypad_battery_criticalBoolean?

Indicates whether the keypad battery is in a critical state for a Nuki device.

Returns:

  • (Boolean, nil)


953
954
955
# File 'lib/seam/resources/device.rb', line 953

def keypad_battery_critical
  @keypad_battery_critical
end

#keypad_pairedBoolean?

Indicates whether the keypad is paired for a Nuki device.

Returns:

  • (Boolean, nil)


956
957
958
# File 'lib/seam/resources/device.rb', line 956

def keypad_paired
  @keypad_paired
end