Class: Seam::Resources::Device::Properties::TemperatureThreshold

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#lower_limit_celsiusFloat?

Lower limit in °C within the current temperature threshold set for the thermostat.

Returns:

  • (Float, nil)


1672
1673
1674
# File 'lib/seam/resources/device.rb', line 1672

def lower_limit_celsius
  @lower_limit_celsius
end

#lower_limit_fahrenheitFloat?

Lower limit in °F within the current temperature threshold set for the thermostat.

Returns:

  • (Float, nil)


1675
1676
1677
# File 'lib/seam/resources/device.rb', line 1675

def lower_limit_fahrenheit
  @lower_limit_fahrenheit
end

#upper_limit_celsiusFloat?

Upper limit in °C within the current temperature threshold set for the thermostat.

Returns:

  • (Float, nil)


1678
1679
1680
# File 'lib/seam/resources/device.rb', line 1678

def upper_limit_celsius
  @upper_limit_celsius
end

#upper_limit_fahrenheitFloat?

Upper limit in °F within the current temperature threshold set for the thermostat.

Returns:

  • (Float, nil)


1681
1682
1683
# File 'lib/seam/resources/device.rb', line 1681

def upper_limit_fahrenheit
  @upper_limit_fahrenheit
end