Class: Seam::Resources::Device::Properties::ThermostatDailyPrograms
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::ThermostatDailyPrograms
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: Periods
Instance Attribute Summary collapse
-
#device_id ⇒ String
ID of the thermostat device on which the thermostat daily program is configured.
-
#name ⇒ String?
User-friendly name to identify the thermostat daily program.
-
#thermostat_daily_program_id ⇒ String
ID of the thermostat daily program.
-
#workspace_id ⇒ String
ID of the workspace that contains the thermostat daily program.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the thermostat daily program was created.
-
#periods ⇒ Array<Periods>
Array of thermostat daily program periods.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ String
ID of the thermostat device on which the thermostat daily program is configured.
1702 1703 1704 |
# File 'lib/seam/resources/device.rb', line 1702 def device_id @device_id end |
#name ⇒ String?
User-friendly name to identify the thermostat daily program.
1705 1706 1707 |
# File 'lib/seam/resources/device.rb', line 1705 def name @name end |
#thermostat_daily_program_id ⇒ String
ID of the thermostat daily program.
1708 1709 1710 |
# File 'lib/seam/resources/device.rb', line 1708 def thermostat_daily_program_id @thermostat_daily_program_id end |
#workspace_id ⇒ String
ID of the workspace that contains the thermostat daily program.
1711 1712 1713 |
# File 'lib/seam/resources/device.rb', line 1711 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the thermostat daily program was created.
1714 |
# File 'lib/seam/resources/device.rb', line 1714 date_accessor :created_at |