Class: Seam::Resources::Device::Properties::ThermostatDailyPrograms::Periods
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::ThermostatDailyPrograms::Periods
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#climate_preset_key ⇒ Object
Key of the climate preset to activate at the
starts_at_time. -
#starts_at_time ⇒ Object
Time at which the thermostat daily program period starts, in ISO 8601 format.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#climate_preset_key ⇒ Object
Key of the climate preset to activate at the starts_at_time.
919 920 921 |
# File 'lib/seam/resources/device.rb', line 919 def climate_preset_key @climate_preset_key end |
#starts_at_time ⇒ Object
Time at which the thermostat daily program period starts, in ISO 8601 format.
921 922 923 |
# File 'lib/seam/resources/device.rb', line 921 def starts_at_time @starts_at_time end |