Class: Seam::Resources::Device::Properties::ThermostatWeeklyProgram
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::ThermostatWeeklyProgram
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#friday_program_id ⇒ String?
ID of the thermostat daily program to run on Fridays.
-
#monday_program_id ⇒ String?
ID of the thermostat daily program to run on Mondays.
-
#saturday_program_id ⇒ String?
ID of the thermostat daily program to run on Saturdays.
-
#sunday_program_id ⇒ String?
ID of the thermostat daily program to run on Sundays.
-
#thursday_program_id ⇒ String?
ID of the thermostat daily program to run on Thursdays.
-
#tuesday_program_id ⇒ String?
ID of the thermostat daily program to run on Tuesdays.
-
#wednesday_program_id ⇒ String?
ID of the thermostat daily program to run on Wednesdays.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the thermostat weekly program was created.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#friday_program_id ⇒ String?
ID of the thermostat daily program to run on Fridays.
1720 1721 1722 |
# File 'lib/seam/resources/device.rb', line 1720 def friday_program_id @friday_program_id end |
#monday_program_id ⇒ String?
ID of the thermostat daily program to run on Mondays.
1723 1724 1725 |
# File 'lib/seam/resources/device.rb', line 1723 def monday_program_id @monday_program_id end |
#saturday_program_id ⇒ String?
ID of the thermostat daily program to run on Saturdays.
1726 1727 1728 |
# File 'lib/seam/resources/device.rb', line 1726 def saturday_program_id @saturday_program_id end |
#sunday_program_id ⇒ String?
ID of the thermostat daily program to run on Sundays.
1729 1730 1731 |
# File 'lib/seam/resources/device.rb', line 1729 def sunday_program_id @sunday_program_id end |
#thursday_program_id ⇒ String?
ID of the thermostat daily program to run on Thursdays.
1732 1733 1734 |
# File 'lib/seam/resources/device.rb', line 1732 def thursday_program_id @thursday_program_id end |
#tuesday_program_id ⇒ String?
ID of the thermostat daily program to run on Tuesdays.
1735 1736 1737 |
# File 'lib/seam/resources/device.rb', line 1735 def tuesday_program_id @tuesday_program_id end |
#wednesday_program_id ⇒ String?
ID of the thermostat daily program to run on Wednesdays.
1738 1739 1740 |
# File 'lib/seam/resources/device.rb', line 1738 def wednesday_program_id @wednesday_program_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the thermostat weekly program was created.
1741 |
# File 'lib/seam/resources/device.rb', line 1741 date_accessor :created_at |