Class: Seam::Resources::Device::Warnings

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/device.rb

Overview

Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.

Defined Under Namespace

Classes: AccessoryKeypadSetupRequired, DeviceCommunicationDegraded, DeviceHasFlakyConnection, HubRequiredForAdditionalCapabilities, KeynestUnsupportedLocker, LocklyTimeZoneNotConfigured, ManyActiveBackupCodes, MaxAccessCodesReached, PartialBackupAccessCodePool, PowerSavingMode, PrivacyMode, ProviderIssue, SaltoKsLockAccessCodeSupportRemoved, SaltoKsOfficeMode, SaltoKsPrivacyMode, SaltoKsSubscriptionLimitAlmostReached, ScheduledMaintenanceWindow, TemperatureThresholdExceeded, ThirdPartyIntegrationDetected, TimeZoneMismatch, TimeZoneUnknown, TtlockLockGatewayUnlockingNotEnabled, TtlockWeakGatewaySignal, TwoNDeviceMissingTimezone, UltraloqTimeZoneUnknown, UnknownIssueWithPhone, UnreliableOnlineStatus

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2499
2500
2501
# File 'lib/seam/resources/device.rb', line 2499

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • partial_backup_access_code_pool
  • many_active_backup_codes
  • third_party_integration_detected
  • ttlock_lock_gateway_unlocking_not_enabled
  • ttlock_weak_gateway_signal
  • power_saving_mode
  • temperature_threshold_exceeded
  • device_communication_degraded
  • scheduled_maintenance_window
  • device_has_flaky_connection
  • salto_ks_office_mode
  • salto_ks_privacy_mode
  • privacy_mode
  • salto_ks_subscription_limit_almost_reached
  • salto_ks_lock_access_code_support_removed
  • unknown_issue_with_phone
  • lockly_time_zone_not_configured
  • ultraloq_time_zone_unknown
  • time_zone_unknown
  • time_zone_mismatch
  • two_n_device_missing_timezone
  • hub_required_for_additional_capabilities
  • provider_issue
  • keynest_unsupported_locker
  • accessory_keypad_setup_required
  • unreliable_online_status
  • max_access_codes_reached

Returns:

  • (String)


2530
2531
2532
# File 'lib/seam/resources/device.rb', line 2530

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2533
# File 'lib/seam/resources/device.rb', line 2533

date_accessor :created_at