Class: Seam::Resources::Device::Warnings::AccessoryKeypadSetupRequired

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the accessory keypad exists, but is not linked to the Igloohome Bridge. Online access code programming will fail until the keypad is linked to the Igloohome Bridge in the Igloohome app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2447
2448
2449
# File 'lib/seam/resources/device.rb', line 2447

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • accessory_keypad_setup_required

Returns:

  • (String)


2452
2453
2454
# File 'lib/seam/resources/device.rb', line 2452

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2455
# File 'lib/seam/resources/device.rb', line 2455

date_accessor :created_at