Class: Seam::Resources::Device::Warnings::DeviceCommunicationDegraded
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::DeviceCommunicationDegraded
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the device appears to be unresponsive.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2192 2193 2194 |
# File 'lib/seam/resources/device.rb', line 2192 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
device_communication_degraded
2197 2198 2199 |
# File 'lib/seam/resources/device.rb', line 2197 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2200 |
# File 'lib/seam/resources/device.rb', line 2200 date_accessor :created_at |