Class: Seam::Resources::Device::Warnings::HubRequiredForAdditionalCapabilities

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that a hub or relay must be connected to unlock additional capabilities such as remote unlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2405
2406
2407
# File 'lib/seam/resources/device.rb', line 2405

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • hub_required_for_additional_capabilities

Returns:

  • (String)


2410
2411
2412
# File 'lib/seam/resources/device.rb', line 2410

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2413
# File 'lib/seam/resources/device.rb', line 2413

date_accessor :created_at