Class: Seam::Resources::Device::Warnings::KeynestUnsupportedLocker
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::KeynestUnsupportedLocker
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the key is in a locker that does not support the access codes API.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2435 2436 2437 |
# File 'lib/seam/resources/device.rb', line 2435 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
keynest_unsupported_locker
2440 2441 2442 |
# File 'lib/seam/resources/device.rb', line 2440 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2443 |
# File 'lib/seam/resources/device.rb', line 2443 date_accessor :created_at |