Class: Seam::Resources::Device::Warnings::LocklyTimeZoneNotConfigured

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that Seam detected that the Lockly device does not have a time zone configured. Time-bound codes may not work as expected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2327
2328
2329
# File 'lib/seam/resources/device.rb', line 2327

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • lockly_time_zone_not_configured

Returns:

  • (String)


2332
2333
2334
# File 'lib/seam/resources/device.rb', line 2332

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2335
# File 'lib/seam/resources/device.rb', line 2335

date_accessor :created_at