Class: Seam::Resources::Device::Warnings::ManyActiveBackupCodes

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that there are too many backup codes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2105
2106
2107
# File 'lib/seam/resources/device.rb', line 2105

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • many_active_backup_codes

Returns:

  • (String)


2110
2111
2112
# File 'lib/seam/resources/device.rb', line 2110

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2113
# File 'lib/seam/resources/device.rb', line 2113

date_accessor :created_at