Class: Seam::Resources::Device::Warnings::PowerSavingMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the device is in power saving mode and may have limited functionality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2165
2166
2167
# File 'lib/seam/resources/device.rb', line 2165

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • power_saving_mode

Returns:

  • (String)


2170
2171
2172
# File 'lib/seam/resources/device.rb', line 2170

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2173
# File 'lib/seam/resources/device.rb', line 2173

date_accessor :created_at