Class: Seam::Resources::Device::Warnings::PrivacyMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the lock is in Privacy Mode. Access codes and remote unlock are blocked until Privacy Mode is disabled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2267
2268
2269
# File 'lib/seam/resources/device.rb', line 2267

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • privacy_mode

Returns:

  • (String)


2272
2273
2274
# File 'lib/seam/resources/device.rb', line 2272

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2275
# File 'lib/seam/resources/device.rb', line 2275

date_accessor :created_at