Class: Seam::Resources::Device::Warnings::ProviderIssue
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::ProviderIssue
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates a provider-specific issue that may affect device functionality.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2417 2418 2419 |
# File 'lib/seam/resources/device.rb', line 2417 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
provider_issue
2422 2423 2424 |
# File 'lib/seam/resources/device.rb', line 2422 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2425 |
# File 'lib/seam/resources/device.rb', line 2425 date_accessor :created_at |