Class: Seam::Resources::Device::Warnings::SaltoKsOfficeMode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::SaltoKsOfficeMode
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the Salto KS lock is in Office Mode. Access Codes will not unlock doors.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2240 2241 2242 |
# File 'lib/seam/resources/device.rb', line 2240 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
salto_ks_office_mode
2245 2246 2247 |
# File 'lib/seam/resources/device.rb', line 2245 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2248 |
# File 'lib/seam/resources/device.rb', line 2248 date_accessor :created_at |