Class: Seam::Resources::Device::Warnings::SaltoKsPrivacyMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the Salto KS lock is in Privacy Mode. Access Codes will not unlock doors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2255
2256
2257
# File 'lib/seam/resources/device.rb', line 2255

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_privacy_mode

Returns:

  • (String)


2260
2261
2262
# File 'lib/seam/resources/device.rb', line 2260

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2263
# File 'lib/seam/resources/device.rb', line 2263

date_accessor :created_at