Class: Seam::Resources::Device::Warnings::SaltoKsSubscriptionLimitAlmostReached

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the Salto KS site has exceeded 80% of the maximum number of allowed users. Increase your subscription limit or delete some users from your site.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2285
2286
2287
# File 'lib/seam/resources/device.rb', line 2285

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_subscription_limit_almost_reached

Returns:

  • (String)


2290
2291
2292
# File 'lib/seam/resources/device.rb', line 2290

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2293
# File 'lib/seam/resources/device.rb', line 2293

date_accessor :created_at