Class: Seam::Resources::Device::Warnings::TemperatureThresholdExceeded
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::TemperatureThresholdExceeded
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the temperature threshold has been exceeded.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2177 2178 2179 |
# File 'lib/seam/resources/device.rb', line 2177 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
temperature_threshold_exceeded
2182 2183 2184 |
# File 'lib/seam/resources/device.rb', line 2182 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2185 |
# File 'lib/seam/resources/device.rb', line 2185 date_accessor :created_at |