Class: Seam::Resources::Device::Warnings::ThirdPartyIntegrationDetected
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::ThirdPartyIntegrationDetected
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that a third-party integration has been detected.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2120 2121 2122 |
# File 'lib/seam/resources/device.rb', line 2120 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
third_party_integration_detected
2125 2126 2127 |
# File 'lib/seam/resources/device.rb', line 2125 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2128 |
# File 'lib/seam/resources/device.rb', line 2128 date_accessor :created_at |