Class: Seam::Resources::Device::Warnings::TimeZoneUnknown
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::TimeZoneUnknown
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that Seam does not know the device's time zone. Set a time zone to enable time-bound access codes.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2360 2361 2362 |
# File 'lib/seam/resources/device.rb', line 2360 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
time_zone_unknown
2365 2366 2367 |
# File 'lib/seam/resources/device.rb', line 2365 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2368 |
# File 'lib/seam/resources/device.rb', line 2368 date_accessor :created_at |