Class: Seam::Resources::Device::Warnings::TtlockLockGatewayUnlockingNotEnabled

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the Remote Unlock feature is not enabled in the settings."

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2135
2136
2137
# File 'lib/seam/resources/device.rb', line 2135

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • ttlock_lock_gateway_unlocking_not_enabled

Returns:

  • (String)


2140
2141
2142
# File 'lib/seam/resources/device.rb', line 2140

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2143
# File 'lib/seam/resources/device.rb', line 2143

date_accessor :created_at