Class: Seam::Resources::Device::Warnings::TtlockWeakGatewaySignal

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the gateway signal is weak.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2150
2151
2152
# File 'lib/seam/resources/device.rb', line 2150

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • ttlock_weak_gateway_signal

Returns:

  • (String)


2155
2156
2157
# File 'lib/seam/resources/device.rb', line 2155

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2158
# File 'lib/seam/resources/device.rb', line 2158

date_accessor :created_at