Class: Seam::Resources::Device::Warnings::UltraloqTimeZoneUnknown

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that Seam does not know the time zone of the Ultraloq device. Set a time zone to enable time-bound access codes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2345
2346
2347
# File 'lib/seam/resources/device.rb', line 2345

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • ultraloq_time_zone_unknown

Returns:

  • (String)


2350
2351
2352
# File 'lib/seam/resources/device.rb', line 2350

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2353
# File 'lib/seam/resources/device.rb', line 2353

date_accessor :created_at