Class: Seam::Resources::Device::Warnings::UnreliableOnlineStatus

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the device may optimistically be reported as online because the provider does not reliably report its online status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2477
2478
2479
# File 'lib/seam/resources/device.rb', line 2477

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • unreliable_online_status

Returns:

  • (String)


2482
2483
2484
# File 'lib/seam/resources/device.rb', line 2482

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2485
# File 'lib/seam/resources/device.rb', line 2485

date_accessor :created_at