Class: Seam::Resources::NoiseThreshold

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/noise_threshold.rb

Overview

Represents a noise threshold for a noise sensor. Thresholds represent the limits of noise tolerated at a property, which can be customized for each hour of the day. Each device has its own default thresholds, but you can use the Seam API to modify them.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idString

Unique identifier for the device that contains the noise threshold.

Returns:

  • (String)


9
10
11
# File 'lib/seam/resources/noise_threshold.rb', line 9

def device_id
  @device_id
end

#ends_daily_atString

Time at which the noise threshold should become inactive daily.

Returns:

  • (String)


12
13
14
# File 'lib/seam/resources/noise_threshold.rb', line 12

def ends_daily_at
  @ends_daily_at
end

#nameString

Name of the noise threshold.

Returns:

  • (String)


15
16
17
# File 'lib/seam/resources/noise_threshold.rb', line 15

def name
  @name
end

#noise_threshold_decibelsFloat

Noise level in decibels for the noise threshold.

Returns:

  • (Float)


18
19
20
# File 'lib/seam/resources/noise_threshold.rb', line 18

def noise_threshold_decibels
  @noise_threshold_decibels
end

#noise_threshold_idString

Unique identifier for the noise threshold.

Returns:

  • (String)


21
22
23
# File 'lib/seam/resources/noise_threshold.rb', line 21

def noise_threshold_id
  @noise_threshold_id
end

#noise_threshold_nrsFloat?

Noise level in Noiseaware Noise Risk Score (NRS) for the noise threshold. This parameter is only relevant for Noiseaware sensors.

Returns:

  • (Float, nil)


24
25
26
# File 'lib/seam/resources/noise_threshold.rb', line 24

def noise_threshold_nrs
  @noise_threshold_nrs
end

#starts_daily_atString

Time at which the noise threshold should become active daily.

Returns:

  • (String)


27
28
29
# File 'lib/seam/resources/noise_threshold.rb', line 27

def starts_daily_at
  @starts_daily_at
end