Class: Seam::Resources::Pagination

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/pagination.rb

Overview

Information about the current page of results.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#has_next_pageBoolean

Indicates whether there is another page of results after this one.

Returns:

  • (Boolean)


9
10
11
# File 'lib/seam/resources/pagination.rb', line 9

def has_next_page
  @has_next_page
end

#next_page_cursorString?

Opaque value that can be used to select the next page of results via the page_cursor parameter.

Returns:

  • (String, nil)


12
13
14
# File 'lib/seam/resources/pagination.rb', line 12

def next_page_cursor
  @next_page_cursor
end

#next_page_urlString?

URL to get the next page of results.

Returns:

  • (String, nil)


15
16
17
# File 'lib/seam/resources/pagination.rb', line 15

def next_page_url
  @next_page_url
end