Class: Seam::Resources::Phone

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/phone.rb

Overview

Represents an app user's mobile phone.

Defined Under Namespace

Classes: Errors, Properties, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#custom_metadataHash

Optional custom metadata for the phone.

Returns:

  • (Hash)


75
76
77
# File 'lib/seam/resources/phone.rb', line 75

def 
  @custom_metadata
end

#device_idString

ID of the phone.

Returns:

  • (String)


78
79
80
# File 'lib/seam/resources/phone.rb', line 78

def device_id
  @device_id
end

#device_typeString

Type of the phone device, such as ios_phone or android_phone.

Returns:

  • (String)


81
82
83
# File 'lib/seam/resources/phone.rb', line 81

def device_type
  @device_type
end

#display_nameString

Display name of the phone. Defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the phone easily, especially when there are numerous phones.

Returns:

  • (String)


84
85
86
# File 'lib/seam/resources/phone.rb', line 84

def display_name
  @display_name
end

#nicknameString?

Optional nickname to describe the phone, settable through Seam.

Returns:

  • (String, nil)


87
88
89
# File 'lib/seam/resources/phone.rb', line 87

def nickname
  @nickname
end

#workspace_idString

ID of the workspace that contains the phone.

Returns:

  • (String)


90
91
92
# File 'lib/seam/resources/phone.rb', line 90

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the phone was created.

Returns:

  • (Time)


94
# File 'lib/seam/resources/phone.rb', line 94

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the phone.

Returns:



69
# File 'lib/seam/resources/phone.rb', line 69

resource_list_accessor :errors, Errors

#propertiesProperties

Properties of the phone.

Returns:



66
# File 'lib/seam/resources/phone.rb', line 66

resource_accessor :properties, Properties

#warningsArray<Warnings>

Warnings associated with the phone.

Returns:



72
# File 'lib/seam/resources/phone.rb', line 72

resource_list_accessor :warnings, Warnings