Class: Seam::Resources::Phone::Properties::AssaAbloyCredentialServiceMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Phone::Properties::AssaAbloyCredentialServiceMetadata
- Defined in:
- lib/seam/resources/phone.rb
Defined Under Namespace
Classes: Endpoints
Instance Attribute Summary collapse
-
#has_active_endpoint ⇒ Boolean?
Indicates whether the credential service has active endpoints associated with the phone.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#endpoints ⇒ Array<Endpoints>
Endpoints associated with the phone.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#has_active_endpoint ⇒ Boolean?
Indicates whether the credential service has active endpoints associated with the phone.
35 36 37 |
# File 'lib/seam/resources/phone.rb', line 35 def has_active_endpoint @has_active_endpoint end |