Class: Seam::Resources::SeamEvent

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/event.rb

Defined Under Namespace

Classes: AccessCodeErrors, AccessCodeWarnings, AcsSystemErrors, AcsSystemWarnings, ChangedProperties, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings, From, Reason, RequestedMutations, To

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_code_idString?

Returns:

  • (String, nil)


203
204
205
# File 'lib/seam/resources/event.rb', line 203

def access_code_id
  @access_code_id
end

#access_code_is_managedBoolean?

Whether the access code is managed by Seam (true) or unmanaged (false). Only present when access_code_id is set.

Returns:

  • (Boolean, nil)


206
207
208
# File 'lib/seam/resources/event.rb', line 206

def access_code_is_managed
  @access_code_is_managed
end

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


209
210
211
# File 'lib/seam/resources/event.rb', line 209

def access_grant_id
  @access_grant_id
end

#access_grant_idsArray<String>

IDs of the access grants associated with this access method.

Returns:

  • (Array<String>)


212
213
214
# File 'lib/seam/resources/event.rb', line 212

def access_grant_ids
  @access_grant_ids
end

#access_grant_keyString?

Key of the affected Access Grant (if present).

Returns:

  • (String, nil)


215
216
217
# File 'lib/seam/resources/event.rb', line 215

def access_grant_key
  @access_grant_key
end

#access_grant_keysArray<String>

Keys of the access grants associated with this access method (if present).

Returns:

  • (Array<String>)


218
219
220
# File 'lib/seam/resources/event.rb', line 218

def access_grant_keys
  @access_grant_keys
end

#access_method_idString

ID of the affected access method.

Returns:

  • (String)


221
222
223
# File 'lib/seam/resources/event.rb', line 221

def access_method_id
  @access_method_id
end

#acs_access_group_idString

ID of the affected access group.

Returns:

  • (String)


224
225
226
# File 'lib/seam/resources/event.rb', line 224

def acs_access_group_id
  @acs_access_group_id
end

#acs_credential_idString

ID of the affected credential.

Returns:

  • (String)


227
228
229
# File 'lib/seam/resources/event.rb', line 227

def acs_credential_id
  @acs_credential_id
end

#acs_encoder_idString

ID of the affected encoder.

Returns:

  • (String)


230
231
232
# File 'lib/seam/resources/event.rb', line 230

def acs_encoder_id
  @acs_encoder_id
end

#acs_entrance_idString

Returns:

  • (String)


232
233
234
# File 'lib/seam/resources/event.rb', line 232

def acs_entrance_id
  @acs_entrance_id
end

#acs_entrance_idsArray<String>

Returns:

  • (Array<String>)


234
235
236
# File 'lib/seam/resources/event.rb', line 234

def acs_entrance_ids
  @acs_entrance_ids
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


237
238
239
# File 'lib/seam/resources/event.rb', line 237

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the affected access system user.

Returns:

  • (String)


240
241
242
# File 'lib/seam/resources/event.rb', line 240

def acs_user_id
  @acs_user_id
end

#action_attempt_idString?

Returns:

  • (String, nil)


242
243
244
# File 'lib/seam/resources/event.rb', line 242

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


245
246
247
# File 'lib/seam/resources/event.rb', line 245

def action_type
  @action_type
end

#activation_reasonString

The reason the camera was activated.

Returns:

  • (String)


248
249
250
# File 'lib/seam/resources/event.rb', line 248

def activation_reason
  @activation_reason
end

#backup_access_code_idString

ID of the backup access code that was pulled from the pool.

Returns:

  • (String)


251
252
253
# File 'lib/seam/resources/event.rb', line 251

def backup_access_code_id
  @backup_access_code_id
end

#battery_levelFloat

Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.

Returns:

  • (Float)


254
255
256
# File 'lib/seam/resources/event.rb', line 254

def battery_level
  @battery_level
end

#battery_statusString

Battery status of the affected device, calculated from the numeric battery_level value.

Returns:

  • (String)


257
258
259
# File 'lib/seam/resources/event.rb', line 257

def battery_status
  @battery_status
end

#change_reasonString?

Human-readable reason for the change (e.g. ongoing code auto-renewed).

Returns:

  • (String, nil)


260
261
262
# File 'lib/seam/resources/event.rb', line 260

def change_reason
  @change_reason
end

#client_session_idString

ID of the affected client session.

Returns:

  • (String)


263
264
265
# File 'lib/seam/resources/event.rb', line 263

def client_session_id
  @client_session_id
end

#climate_preset_keyString

Key of the climate preset that was activated.

Returns:

  • (String)


266
267
268
# File 'lib/seam/resources/event.rb', line 266

def climate_preset_key
  @climate_preset_key
end

#codeString?

Returns:

  • (String, nil)


268
269
270
# File 'lib/seam/resources/event.rb', line 268

def code
  @code
end

#connect_webview_idString?

Returns:

  • (String, nil)


270
271
272
# File 'lib/seam/resources/event.rb', line 270

def connect_webview_id
  @connect_webview_id
end

#connected_account_custom_metadataHash?

Returns:

  • (Hash, nil)


272
273
274
# File 'lib/seam/resources/event.rb', line 272

def 
  @connected_account_custom_metadata
end

#connected_account_idString?

Returns:

  • (String, nil)


274
275
276
# File 'lib/seam/resources/event.rb', line 274

def 
  @connected_account_id
end

#cooling_set_point_celsiusFloat?

Temperature to which the thermostat should cool (in °C). See also Set Points.

Returns:

  • (Float, nil)


277
278
279
# File 'lib/seam/resources/event.rb', line 277

def cooling_set_point_celsius
  @cooling_set_point_celsius
end

#cooling_set_point_fahrenheitFloat?

Temperature to which the thermostat should cool (in °F). See also Set Points.

Returns:

  • (Float, nil)


280
281
282
# File 'lib/seam/resources/event.rb', line 280

def cooling_set_point_fahrenheit
  @cooling_set_point_fahrenheit
end

#customer_keyString?

Returns:

  • (String, nil)


282
283
284
# File 'lib/seam/resources/event.rb', line 282

def customer_key
  @customer_key
end

#descriptionString

Human-readable description of the change and its source.

Returns:

  • (String)


285
286
287
# File 'lib/seam/resources/event.rb', line 285

def description
  @description
end

#desired_temperature_celsiusFloat?

Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.

Returns:

  • (Float, nil)


288
289
290
# File 'lib/seam/resources/event.rb', line 288

def desired_temperature_celsius
  @desired_temperature_celsius
end

#desired_temperature_fahrenheitFloat?

Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.

Returns:

  • (Float, nil)


291
292
293
# File 'lib/seam/resources/event.rb', line 291

def desired_temperature_fahrenheit
  @desired_temperature_fahrenheit
end

#device_custom_metadataHash?

Returns:

  • (Hash, nil)


293
294
295
# File 'lib/seam/resources/event.rb', line 293

def 
  @device_custom_metadata
end

#device_idString?

Returns:

  • (String, nil)


295
296
297
# File 'lib/seam/resources/event.rb', line 295

def device_id
  @device_id
end

#device_idsArray<String>

Returns:

  • (Array<String>)


297
298
299
# File 'lib/seam/resources/event.rb', line 297

def device_ids
  @device_ids
end

#device_nameString?

Returns:

  • (String, nil)


299
300
301
# File 'lib/seam/resources/event.rb', line 299

def device_name
  @device_name
end

#ends_atString?

The new end time for the access grant.

Returns:

  • (String, nil)


302
303
304
# File 'lib/seam/resources/event.rb', line 302

def ends_at
  @ends_at
end

#error_codeString

Error code associated with the disconnection event, if any.

Returns:

  • (String)


305
306
307
# File 'lib/seam/resources/event.rb', line 305

def error_code
  @error_code
end

#error_messageString

Description of why the access methods could not be created.

Returns:

  • (String)


308
309
310
# File 'lib/seam/resources/event.rb', line 308

def error_message
  @error_message
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


311
312
313
# File 'lib/seam/resources/event.rb', line 311

def event_description
  @event_description
end

#event_idString?

ID of the event.

Returns:

  • (String, nil)


314
315
316
# File 'lib/seam/resources/event.rb', line 314

def event_id
  @event_id
end

#event_typeString?

Type of the event.

Returns:

  • (String, nil)


317
318
319
# File 'lib/seam/resources/event.rb', line 317

def event_type
  @event_type
end

#fan_mode_settingString?

Desired fan mode setting, such as on, auto, or circulate.

Returns:

  • (String, nil)


320
321
322
# File 'lib/seam/resources/event.rb', line 320

def fan_mode_setting
  @fan_mode_setting
end

#heating_set_point_celsiusFloat?

Temperature to which the thermostat should heat (in °C). See also Set Points.

Returns:

  • (Float, nil)


323
324
325
# File 'lib/seam/resources/event.rb', line 323

def heating_set_point_celsius
  @heating_set_point_celsius
end

#heating_set_point_fahrenheitFloat?

Temperature to which the thermostat should heat (in °F). See also Set Points.

Returns:

  • (Float, nil)


326
327
328
# File 'lib/seam/resources/event.rb', line 326

def heating_set_point_fahrenheit
  @heating_set_point_fahrenheit
end

#hvac_mode_settingString?

Desired HVAC mode setting, such as heat, cool, heat_cool, or off.

Returns:

  • (String, nil)


329
330
331
# File 'lib/seam/resources/event.rb', line 329

def hvac_mode_setting
  @hvac_mode_setting
end

#image_urlString?

Returns:

  • (String, nil)


331
332
333
# File 'lib/seam/resources/event.rb', line 331

def image_url
  @image_url
end

#is_backup_codeBoolean?

Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).

Returns:

  • (Boolean, nil)


334
335
336
# File 'lib/seam/resources/event.rb', line 334

def is_backup_code
  @is_backup_code
end

#is_fallback_climate_presetBoolean

Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.

Returns:

  • (Boolean)


337
338
339
# File 'lib/seam/resources/event.rb', line 337

def is_fallback_climate_preset
  @is_fallback_climate_preset
end

#is_via_bluetoothBoolean?

Returns:

  • (Boolean, nil)


339
340
341
# File 'lib/seam/resources/event.rb', line 339

def is_via_bluetooth
  @is_via_bluetooth
end

#is_via_nfcBoolean?

Returns:

  • (Boolean, nil)


341
342
343
# File 'lib/seam/resources/event.rb', line 341

def is_via_nfc
  @is_via_nfc
end

#lower_limit_celsiusFloat?

Lower temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


344
345
346
# File 'lib/seam/resources/event.rb', line 344

def lower_limit_celsius
  @lower_limit_celsius
end

#lower_limit_fahrenheitFloat?

Lower temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


347
348
349
# File 'lib/seam/resources/event.rb', line 347

def lower_limit_fahrenheit
  @lower_limit_fahrenheit
end

#methodString

Returns:

  • (String)


349
350
351
# File 'lib/seam/resources/event.rb', line 349

def method
  @method
end

#minut_metadataHash?

Metadata from Minut.

Returns:

  • (Hash, nil)


352
353
354
# File 'lib/seam/resources/event.rb', line 352

def 
  @minut_metadata
end

#missing_device_idsArray<String>

IDs of the devices that did not receive a requested access method. Use these to identify which specific devices failed without having to fetch the Access Grant.

Returns:

  • (Array<String>)


355
356
357
# File 'lib/seam/resources/event.rb', line 355

def missing_device_ids
  @missing_device_ids
end

#motion_sub_typeString?

Sub-type of motion detected, if available.

Returns:

  • (String, nil)


358
359
360
# File 'lib/seam/resources/event.rb', line 358

def motion_sub_type
  @motion_sub_type
end

#noise_level_decibelsFloat?

Detected noise level in decibels.

Returns:

  • (Float, nil)


361
362
363
# File 'lib/seam/resources/event.rb', line 361

def noise_level_decibels
  @noise_level_decibels
end

#noise_level_nrsFloat?

Detected noise level in Noiseaware Noise Risk Score (NRS).

Returns:

  • (Float, nil)


364
365
366
# File 'lib/seam/resources/event.rb', line 364

def noise_level_nrs
  @noise_level_nrs
end

#noise_threshold_idString?

ID of the noise threshold that was triggered.

Returns:

  • (String, nil)


367
368
369
# File 'lib/seam/resources/event.rb', line 367

def noise_threshold_id
  @noise_threshold_id
end

#noise_threshold_nameString?

Name of the noise threshold that was triggered.

Returns:

  • (String, nil)


370
371
372
# File 'lib/seam/resources/event.rb', line 370

def noise_threshold_name
  @noise_threshold_name
end

#noiseaware_metadataHash?

Metadata from Noiseaware.

Returns:

  • (Hash, nil)


373
374
375
# File 'lib/seam/resources/event.rb', line 373

def 
  @noiseaware_metadata
end

#space_idString

ID of the affected space.

Returns:

  • (String)


376
377
378
# File 'lib/seam/resources/event.rb', line 376

def space_id
  @space_id
end

#space_keyString?

Unique key for the space within the workspace.

Returns:

  • (String, nil)


379
380
381
# File 'lib/seam/resources/event.rb', line 379

def space_key
  @space_key
end

#starts_atString?

The new start time for the access grant.

Returns:

  • (String, nil)


382
383
384
# File 'lib/seam/resources/event.rb', line 382

def starts_at
  @starts_at
end

#statusString

Status of the action.

Returns:

  • (String)


385
386
387
# File 'lib/seam/resources/event.rb', line 385

def status
  @status
end

#temperature_celsiusFloat

Temperature, in °C, reported by the affected thermostat.

Returns:

  • (Float)


388
389
390
# File 'lib/seam/resources/event.rb', line 388

def temperature_celsius
  @temperature_celsius
end

#temperature_fahrenheitFloat

Temperature, in °F, reported by the affected thermostat.

Returns:

  • (Float)


391
392
393
# File 'lib/seam/resources/event.rb', line 391

def temperature_fahrenheit
  @temperature_fahrenheit
end

#thermostat_schedule_idString?

ID of the thermostat schedule that prompted the affected climate preset to be activated.

Returns:

  • (String, nil)


394
395
396
# File 'lib/seam/resources/event.rb', line 394

def thermostat_schedule_id
  @thermostat_schedule_id
end

#upper_limit_celsiusFloat?

Upper temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


397
398
399
# File 'lib/seam/resources/event.rb', line 397

def upper_limit_celsius
  @upper_limit_celsius
end

#upper_limit_fahrenheitFloat?

Upper temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


400
401
402
# File 'lib/seam/resources/event.rb', line 400

def upper_limit_fahrenheit
  @upper_limit_fahrenheit
end

#video_urlString?

Returns:

  • (String, nil)


402
403
404
# File 'lib/seam/resources/event.rb', line 402

def video_url
  @video_url
end

#workspace_idString?

ID of the workspace associated with the event.

Returns:

  • (String, nil)


405
406
407
# File 'lib/seam/resources/event.rb', line 405

def workspace_id
  @workspace_id
end

Instance Method Details

#access_code_errorsArray<AccessCodeErrors>

Errors associated with the access code.

Returns:



174
# File 'lib/seam/resources/event.rb', line 174

resource_list_accessor :access_code_errors, AccessCodeErrors

#access_code_warningsArray<AccessCodeWarnings>

Warnings associated with the access code.

Returns:



177
# File 'lib/seam/resources/event.rb', line 177

resource_list_accessor :access_code_warnings, AccessCodeWarnings

#acs_system_errorsArray<AcsSystemErrors>

Errors associated with the access control system.

Returns:



180
# File 'lib/seam/resources/event.rb', line 180

resource_list_accessor :acs_system_errors, AcsSystemErrors

#acs_system_warningsArray<AcsSystemWarnings>

Warnings associated with the access control system.

Returns:



183
# File 'lib/seam/resources/event.rb', line 183

resource_list_accessor :acs_system_warnings, AcsSystemWarnings

#changed_propertiesArray<ChangedProperties>

List of properties that changed on the access code.

Returns:



186
# File 'lib/seam/resources/event.rb', line 186

resource_list_accessor :changed_properties, ChangedProperties

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



189
# File 'lib/seam/resources/event.rb', line 189

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



192
# File 'lib/seam/resources/event.rb', line 192

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime?

Date and time at which the event was created.

Returns:

  • (Time, nil)


409
# File 'lib/seam/resources/event.rb', line 409

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



195
# File 'lib/seam/resources/event.rb', line 195

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



198
# File 'lib/seam/resources/event.rb', line 198

resource_list_accessor :device_warnings, DeviceWarnings

#fromFrom

Returns:



166
# File 'lib/seam/resources/event.rb', line 166

resource_accessor :from, From

#occurred_atTime?

Date and time at which the event occurred.

Returns:

  • (Time, nil)


413
# File 'lib/seam/resources/event.rb', line 413

date_accessor :occurred_at

#reasonReason?

Why access was denied, when the provider reports a determinable cause. Omitted when unknown.

Returns:



169
# File 'lib/seam/resources/event.rb', line 169

resource_accessor :reason, Reason

#requested_mutationsArray<RequestedMutations>

Array of mutations requested on the access code, each containing the mutation type and from/to values.

Returns:



201
# File 'lib/seam/resources/event.rb', line 201

resource_list_accessor :requested_mutations, RequestedMutations

#toTo

Returns:



171
# File 'lib/seam/resources/event.rb', line 171

resource_accessor :to, To