Class: Seam::Resources::SeamEvent::AccessCodeBackupAccessCodePulled

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A backup access code was pulled from the backup access code pool and set on a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


1097
1098
1099
# File 'lib/seam/resources/event.rb', line 1097

def access_code_id
  @access_code_id
end

#backup_access_code_idString

ID of the backup access code that was pulled from the pool.

Returns:

  • (String)


1100
1101
1102
# File 'lib/seam/resources/event.rb', line 1100

def backup_access_code_id
  @backup_access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1103
1104
1105
# File 'lib/seam/resources/event.rb', line 1103

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


1106
1107
1108
# File 'lib/seam/resources/event.rb', line 1106

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1109
1110
1111
# File 'lib/seam/resources/event.rb', line 1109

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


1112
1113
1114
# File 'lib/seam/resources/event.rb', line 1112

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1115
1116
1117
# File 'lib/seam/resources/event.rb', line 1115

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1118
1119
1120
# File 'lib/seam/resources/event.rb', line 1118

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.backup_access_code_pulled

Returns:

  • (String)


1122
1123
1124
# File 'lib/seam/resources/event.rb', line 1122

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1125
1126
1127
# File 'lib/seam/resources/event.rb', line 1125

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1128
# File 'lib/seam/resources/event.rb', line 1128

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1131
# File 'lib/seam/resources/event.rb', line 1131

date_accessor :occurred_at