Class: Seam::Resources::SeamEvent::AccessCodeChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
An access code was changed.
Defined Under Namespace
Classes: ChangedProperties
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#change_reason ⇒ String?
Human-readable reason for the change (e.g.
ongoing code auto-renewed). -
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.changed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#changed_properties ⇒ Array<ChangedProperties>
List of properties that changed on the access code.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
64 65 66 |
# File 'lib/seam/resources/event.rb', line 64 def access_code_id @access_code_id end |
#change_reason ⇒ String?
Human-readable reason for the change (e.g. ongoing code auto-renewed).
67 68 69 |
# File 'lib/seam/resources/event.rb', line 67 def change_reason @change_reason end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
70 71 72 |
# File 'lib/seam/resources/event.rb', line 70 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
73 74 75 |
# File 'lib/seam/resources/event.rb', line 73 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
76 77 78 |
# File 'lib/seam/resources/event.rb', line 76 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
79 80 81 |
# File 'lib/seam/resources/event.rb', line 79 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
82 83 84 |
# File 'lib/seam/resources/event.rb', line 82 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
85 86 87 |
# File 'lib/seam/resources/event.rb', line 85 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.changed
89 90 91 |
# File 'lib/seam/resources/event.rb', line 89 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
92 93 94 |
# File 'lib/seam/resources/event.rb', line 92 def workspace_id @workspace_id end |
Instance Method Details
#changed_properties ⇒ Array<ChangedProperties>
List of properties that changed on the access code.
61 |
# File 'lib/seam/resources/event.rb', line 61 resource_list_accessor :changed_properties, ChangedProperties |
#created_at ⇒ Time
Date and time at which the event was created.
95 |
# File 'lib/seam/resources/event.rb', line 95 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
98 |
# File 'lib/seam/resources/event.rb', line 98 date_accessor :occurred_at |