Class: Seam::Resources::SeamEvent::AccessCodeChanged::ChangedProperties

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#fromString?

Previous value of the property, or null if not set.

Returns:

  • (String, nil)


50
51
52
# File 'lib/seam/resources/event.rb', line 50

def from
  @from
end

#propertyString

Name of the property that changed (e.g. code).

Returns:

  • (String)


53
54
55
# File 'lib/seam/resources/event.rb', line 53

def property
  @property
end

#toString?

New value of the property, or null if cleared.

Returns:

  • (String, nil)


56
57
58
# File 'lib/seam/resources/event.rb', line 56

def to
  @to
end