Class: Seam::Resources::SeamEvent::AccessCodeCodeChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The pin code of an access code was changed on the device.

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


182
183
184
# File 'lib/seam/resources/event.rb', line 182

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


185
186
187
# File 'lib/seam/resources/event.rb', line 185

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


188
189
190
# File 'lib/seam/resources/event.rb', line 188

def 
  @connected_account_id
end

#descriptionString

Human-readable description of the change and its source.

Returns:

  • (String)


191
192
193
# File 'lib/seam/resources/event.rb', line 191

def description
  @description
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


194
195
196
# File 'lib/seam/resources/event.rb', line 194

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


197
198
199
# File 'lib/seam/resources/event.rb', line 197

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


200
201
202
# File 'lib/seam/resources/event.rb', line 200

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


203
204
205
# File 'lib/seam/resources/event.rb', line 203

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.code_changed

Returns:

  • (String)


207
208
209
# File 'lib/seam/resources/event.rb', line 207

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


210
211
212
# File 'lib/seam/resources/event.rb', line 210

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


213
# File 'lib/seam/resources/event.rb', line 213

date_accessor :created_at

#fromFrom

Previous pin code configuration.

Returns:



176
# File 'lib/seam/resources/event.rb', line 176

resource_accessor :from, From

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


216
# File 'lib/seam/resources/event.rb', line 216

date_accessor :occurred_at

#toTo

New pin code configuration.

Returns:



179
# File 'lib/seam/resources/event.rb', line 179

resource_accessor :to, To