Class: Seam::Resources::SeamEvent::AccessCodeCreated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


11
12
13
# File 'lib/seam/resources/event.rb', line 11

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


14
15
16
# File 'lib/seam/resources/event.rb', line 14

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


17
18
19
# File 'lib/seam/resources/event.rb', line 17

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


20
21
22
# File 'lib/seam/resources/event.rb', line 20

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


23
24
25
# File 'lib/seam/resources/event.rb', line 23

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


26
27
28
# File 'lib/seam/resources/event.rb', line 26

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


29
30
31
# File 'lib/seam/resources/event.rb', line 29

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.created

Returns:

  • (String)


33
34
35
# File 'lib/seam/resources/event.rb', line 33

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


36
37
38
# File 'lib/seam/resources/event.rb', line 36

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


39
# File 'lib/seam/resources/event.rb', line 39

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


42
# File 'lib/seam/resources/event.rb', line 42

date_accessor :occurred_at