Class: Seam::Resources::SeamEvent::AccessCodeDelayInRemovingFromDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

There was an unusually long delay in removing an access code from a device.

Defined Under Namespace

Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


855
856
857
# File 'lib/seam/resources/event.rb', line 855

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


858
859
860
# File 'lib/seam/resources/event.rb', line 858

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


861
862
863
# File 'lib/seam/resources/event.rb', line 861

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


864
865
866
# File 'lib/seam/resources/event.rb', line 864

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


867
868
869
# File 'lib/seam/resources/event.rb', line 867

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


870
871
872
# File 'lib/seam/resources/event.rb', line 870

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


873
874
875
# File 'lib/seam/resources/event.rb', line 873

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.delay_in_removing_from_device

Returns:

  • (String)


877
878
879
# File 'lib/seam/resources/event.rb', line 877

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


880
881
882
# File 'lib/seam/resources/event.rb', line 880

def workspace_id
  @workspace_id
end

Instance Method Details

#access_code_errorsArray<AccessCodeErrors>

Errors associated with the access code.

Returns:



837
# File 'lib/seam/resources/event.rb', line 837

resource_list_accessor :access_code_errors, AccessCodeErrors

#access_code_warningsArray<AccessCodeWarnings>

Warnings associated with the access code.

Returns:



840
# File 'lib/seam/resources/event.rb', line 840

resource_list_accessor :access_code_warnings, AccessCodeWarnings

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



843
# File 'lib/seam/resources/event.rb', line 843

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



846
# File 'lib/seam/resources/event.rb', line 846

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


883
# File 'lib/seam/resources/event.rb', line 883

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



849
# File 'lib/seam/resources/event.rb', line 849

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



852
# File 'lib/seam/resources/event.rb', line 852

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


886
# File 'lib/seam/resources/event.rb', line 886

date_accessor :occurred_at