Class: Seam::Resources::SeamEvent::AccessCodeDelayInSettingOnDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

There was an unusually long delay in setting an access code on a device.

Defined Under Namespace

Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


558
559
560
# File 'lib/seam/resources/event.rb', line 558

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


561
562
563
# File 'lib/seam/resources/event.rb', line 561

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


564
565
566
# File 'lib/seam/resources/event.rb', line 564

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


567
568
569
# File 'lib/seam/resources/event.rb', line 567

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


570
571
572
# File 'lib/seam/resources/event.rb', line 570

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


573
574
575
# File 'lib/seam/resources/event.rb', line 573

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


576
577
578
# File 'lib/seam/resources/event.rb', line 576

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.delay_in_setting_on_device

Returns:

  • (String)


580
581
582
# File 'lib/seam/resources/event.rb', line 580

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


583
584
585
# File 'lib/seam/resources/event.rb', line 583

def workspace_id
  @workspace_id
end

Instance Method Details

#access_code_errorsArray<AccessCodeErrors>

Errors associated with the access code.

Returns:



540
# File 'lib/seam/resources/event.rb', line 540

resource_list_accessor :access_code_errors, AccessCodeErrors

#access_code_warningsArray<AccessCodeWarnings>

Warnings associated with the access code.

Returns:



543
# File 'lib/seam/resources/event.rb', line 543

resource_list_accessor :access_code_warnings, AccessCodeWarnings

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



546
# File 'lib/seam/resources/event.rb', line 546

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



549
# File 'lib/seam/resources/event.rb', line 549

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


586
# File 'lib/seam/resources/event.rb', line 586

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



552
# File 'lib/seam/resources/event.rb', line 552

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



555
# File 'lib/seam/resources/event.rb', line 555

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


589
# File 'lib/seam/resources/event.rb', line 589

date_accessor :occurred_at