Class: Seam::Resources::SeamEvent::AccessCodeDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


724
725
726
# File 'lib/seam/resources/event.rb', line 724

def access_code_id
  @access_code_id
end

#codeString?

Code for the affected access code.

Returns:

  • (String, nil)


727
728
729
# File 'lib/seam/resources/event.rb', line 727

def code
  @code
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


730
731
732
# File 'lib/seam/resources/event.rb', line 730

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


733
734
735
# File 'lib/seam/resources/event.rb', line 733

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


736
737
738
# File 'lib/seam/resources/event.rb', line 736

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


739
740
741
# File 'lib/seam/resources/event.rb', line 739

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


742
743
744
# File 'lib/seam/resources/event.rb', line 742

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


745
746
747
# File 'lib/seam/resources/event.rb', line 745

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.deleted

Returns:

  • (String)


749
750
751
# File 'lib/seam/resources/event.rb', line 749

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


752
753
754
# File 'lib/seam/resources/event.rb', line 752

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


755
# File 'lib/seam/resources/event.rb', line 755

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


758
# File 'lib/seam/resources/event.rb', line 758

date_accessor :occurred_at