Class: Seam::Resources::SeamEvent::AccessCodeDeletedExternalToSeam

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was deleted outside of Seam.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


1059
1060
1061
# File 'lib/seam/resources/event.rb', line 1059

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1062
1063
1064
# File 'lib/seam/resources/event.rb', line 1062

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


1065
1066
1067
# File 'lib/seam/resources/event.rb', line 1065

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1068
1069
1070
# File 'lib/seam/resources/event.rb', line 1068

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


1071
1072
1073
# File 'lib/seam/resources/event.rb', line 1071

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1074
1075
1076
# File 'lib/seam/resources/event.rb', line 1074

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1077
1078
1079
# File 'lib/seam/resources/event.rb', line 1077

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.deleted_external_to_seam

Returns:

  • (String)


1081
1082
1083
# File 'lib/seam/resources/event.rb', line 1081

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1084
1085
1086
# File 'lib/seam/resources/event.rb', line 1084

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1087
# File 'lib/seam/resources/event.rb', line 1087

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1090
# File 'lib/seam/resources/event.rb', line 1090

date_accessor :occurred_at