Class: Seam::Resources::SeamEvent::AccessCodeFailedToRemoveFromDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code failed to be removed from a device.

Defined Under Namespace

Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


983
984
985
# File 'lib/seam/resources/event.rb', line 983

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


986
987
988
# File 'lib/seam/resources/event.rb', line 986

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


989
990
991
# File 'lib/seam/resources/event.rb', line 989

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


992
993
994
# File 'lib/seam/resources/event.rb', line 992

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


995
996
997
# File 'lib/seam/resources/event.rb', line 995

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


998
999
1000
# File 'lib/seam/resources/event.rb', line 998

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1001
1002
1003
# File 'lib/seam/resources/event.rb', line 1001

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.failed_to_remove_from_device

Returns:

  • (String)


1005
1006
1007
# File 'lib/seam/resources/event.rb', line 1005

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1008
1009
1010
# File 'lib/seam/resources/event.rb', line 1008

def workspace_id
  @workspace_id
end

Instance Method Details

#access_code_errorsArray<AccessCodeErrors>

Errors associated with the access code.

Returns:



965
# File 'lib/seam/resources/event.rb', line 965

resource_list_accessor :access_code_errors, AccessCodeErrors

#access_code_warningsArray<AccessCodeWarnings>

Warnings associated with the access code.

Returns:



968
# File 'lib/seam/resources/event.rb', line 968

resource_list_accessor :access_code_warnings, AccessCodeWarnings

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



971
# File 'lib/seam/resources/event.rb', line 971

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



974
# File 'lib/seam/resources/event.rb', line 974

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1011
# File 'lib/seam/resources/event.rb', line 1011

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



977
# File 'lib/seam/resources/event.rb', line 977

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



980
# File 'lib/seam/resources/event.rb', line 980

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1014
# File 'lib/seam/resources/event.rb', line 1014

date_accessor :occurred_at