Class: Seam::Resources::SeamEvent::AccessCodeFailedToSetOnDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code failed to be set on a device.

Defined Under Namespace

Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


686
687
688
# File 'lib/seam/resources/event.rb', line 686

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


689
690
691
# File 'lib/seam/resources/event.rb', line 689

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


692
693
694
# File 'lib/seam/resources/event.rb', line 692

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


695
696
697
# File 'lib/seam/resources/event.rb', line 695

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


698
699
700
# File 'lib/seam/resources/event.rb', line 698

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


701
702
703
# File 'lib/seam/resources/event.rb', line 701

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


704
705
706
# File 'lib/seam/resources/event.rb', line 704

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.failed_to_set_on_device

Returns:

  • (String)


708
709
710
# File 'lib/seam/resources/event.rb', line 708

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


711
712
713
# File 'lib/seam/resources/event.rb', line 711

def workspace_id
  @workspace_id
end

Instance Method Details

#access_code_errorsArray<AccessCodeErrors>

Errors associated with the access code.

Returns:



668
# File 'lib/seam/resources/event.rb', line 668

resource_list_accessor :access_code_errors, AccessCodeErrors

#access_code_warningsArray<AccessCodeWarnings>

Warnings associated with the access code.

Returns:



671
# File 'lib/seam/resources/event.rb', line 671

resource_list_accessor :access_code_warnings, AccessCodeWarnings

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



674
# File 'lib/seam/resources/event.rb', line 674

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



677
# File 'lib/seam/resources/event.rb', line 677

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


714
# File 'lib/seam/resources/event.rb', line 714

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



680
# File 'lib/seam/resources/event.rb', line 680

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



683
# File 'lib/seam/resources/event.rb', line 683

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


717
# File 'lib/seam/resources/event.rb', line 717

date_accessor :occurred_at