Class: Seam::Resources::SeamEvent::AccessCodeModifiedExternalToSeam

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was modified outside of Seam.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


1021
1022
1023
# File 'lib/seam/resources/event.rb', line 1021

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1024
1025
1026
# File 'lib/seam/resources/event.rb', line 1024

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


1027
1028
1029
# File 'lib/seam/resources/event.rb', line 1027

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1030
1031
1032
# File 'lib/seam/resources/event.rb', line 1030

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


1033
1034
1035
# File 'lib/seam/resources/event.rb', line 1033

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1036
1037
1038
# File 'lib/seam/resources/event.rb', line 1036

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1039
1040
1041
# File 'lib/seam/resources/event.rb', line 1039

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.modified_external_to_seam

Returns:

  • (String)


1043
1044
1045
# File 'lib/seam/resources/event.rb', line 1043

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1046
1047
1048
# File 'lib/seam/resources/event.rb', line 1046

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1049
# File 'lib/seam/resources/event.rb', line 1049

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1052
# File 'lib/seam/resources/event.rb', line 1052

date_accessor :occurred_at