Class: Seam::Resources::SeamEvent::AccessCodeMutationsRequested

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

Mutations were requested on an access code. This event fires at request time, before the change is confirmed on the device.

Defined Under Namespace

Classes: RequestedMutations

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


310
311
312
# File 'lib/seam/resources/event.rb', line 310

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


313
314
315
# File 'lib/seam/resources/event.rb', line 313

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


316
317
318
# File 'lib/seam/resources/event.rb', line 316

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


319
320
321
# File 'lib/seam/resources/event.rb', line 319

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


322
323
324
# File 'lib/seam/resources/event.rb', line 322

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


325
326
327
# File 'lib/seam/resources/event.rb', line 325

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


328
329
330
# File 'lib/seam/resources/event.rb', line 328

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.mutations_requested

Returns:

  • (String)


332
333
334
# File 'lib/seam/resources/event.rb', line 332

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


335
336
337
# File 'lib/seam/resources/event.rb', line 335

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


338
# File 'lib/seam/resources/event.rb', line 338

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


341
# File 'lib/seam/resources/event.rb', line 341

date_accessor :occurred_at

#requested_mutationsArray<RequestedMutations>

Array of mutations requested on the access code, each containing the mutation type and from/to values.

Returns:



307
# File 'lib/seam/resources/event.rb', line 307

resource_list_accessor :requested_mutations, RequestedMutations