Class: Seam::Resources::SeamEvent::AccessCodeMutationsRequested::RequestedMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::SeamEvent::AccessCodeMutationsRequested::RequestedMutations
- Defined in:
- lib/seam/resources/event.rb
Instance Attribute Summary collapse
-
#from ⇒ Hash?
Previous property values before the requested change.
-
#mutation_code ⇒ String
Code identifying the type of mutation requested, such as
updating_name,updating_code,updating_time_frame, ordeleting. -
#to ⇒ Hash?
New property values after the requested change.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#from ⇒ Hash?
Previous property values before the requested change. Keys depend on the mutation type. Absent for non-property mutations like deleting.
289 290 291 |
# File 'lib/seam/resources/event.rb', line 289 def from @from end |
#mutation_code ⇒ String
Code identifying the type of mutation requested, such as updating_name, updating_code, updating_time_frame, or deleting.
Known values:
updating_nameupdating_codeupdating_time_framedeletingcreatingdeferring_creation
299 300 301 |
# File 'lib/seam/resources/event.rb', line 299 def mutation_code @mutation_code end |
#to ⇒ Hash?
New property values after the requested change. Keys depend on the mutation type. Absent for non-property mutations like deleting.
302 303 304 |
# File 'lib/seam/resources/event.rb', line 302 def to @to end |