Class: Seam::Resources::SeamEvent::AccessCodeNameChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The name of an access code was changed on the device.

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


123
124
125
# File 'lib/seam/resources/event.rb', line 123

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


126
127
128
# File 'lib/seam/resources/event.rb', line 126

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


129
130
131
# File 'lib/seam/resources/event.rb', line 129

def 
  @connected_account_id
end

#descriptionString

Human-readable description of the change and its source.

Returns:

  • (String)


132
133
134
# File 'lib/seam/resources/event.rb', line 132

def description
  @description
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


135
136
137
# File 'lib/seam/resources/event.rb', line 135

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


138
139
140
# File 'lib/seam/resources/event.rb', line 138

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


141
142
143
# File 'lib/seam/resources/event.rb', line 141

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


144
145
146
# File 'lib/seam/resources/event.rb', line 144

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.name_changed

Returns:

  • (String)


148
149
150
# File 'lib/seam/resources/event.rb', line 148

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


151
152
153
# File 'lib/seam/resources/event.rb', line 151

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


154
# File 'lib/seam/resources/event.rb', line 154

date_accessor :created_at

#fromFrom

Previous access code name configuration.

Returns:



117
# File 'lib/seam/resources/event.rb', line 117

resource_accessor :from, From

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


157
# File 'lib/seam/resources/event.rb', line 157

date_accessor :occurred_at

#toTo

New access code name configuration.

Returns:



120
# File 'lib/seam/resources/event.rb', line 120

resource_accessor :to, To