Class: Seam::Resources::SeamEvent::AccessCodeRemovedFromDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was removed from a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


430
431
432
# File 'lib/seam/resources/event.rb', line 430

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


433
434
435
# File 'lib/seam/resources/event.rb', line 433

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


436
437
438
# File 'lib/seam/resources/event.rb', line 436

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


439
440
441
# File 'lib/seam/resources/event.rb', line 439

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


442
443
444
# File 'lib/seam/resources/event.rb', line 442

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


445
446
447
# File 'lib/seam/resources/event.rb', line 445

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


448
449
450
# File 'lib/seam/resources/event.rb', line 448

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.removed_from_device

Returns:

  • (String)


452
453
454
# File 'lib/seam/resources/event.rb', line 452

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


455
456
457
# File 'lib/seam/resources/event.rb', line 455

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


458
# File 'lib/seam/resources/event.rb', line 458

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


461
# File 'lib/seam/resources/event.rb', line 461

date_accessor :occurred_at