Class: Seam::Resources::SeamEvent::AccessCodeScheduledOnDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was scheduled natively on a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


348
349
350
# File 'lib/seam/resources/event.rb', line 348

def access_code_id
  @access_code_id
end

#codeString

Code for the affected access code.

Returns:

  • (String)


351
352
353
# File 'lib/seam/resources/event.rb', line 351

def code
  @code
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


354
355
356
# File 'lib/seam/resources/event.rb', line 354

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


357
358
359
# File 'lib/seam/resources/event.rb', line 357

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


360
361
362
# File 'lib/seam/resources/event.rb', line 360

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


363
364
365
# File 'lib/seam/resources/event.rb', line 363

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


366
367
368
# File 'lib/seam/resources/event.rb', line 366

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


369
370
371
# File 'lib/seam/resources/event.rb', line 369

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.scheduled_on_device

Returns:

  • (String)


373
374
375
# File 'lib/seam/resources/event.rb', line 373

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


376
377
378
# File 'lib/seam/resources/event.rb', line 376

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


379
# File 'lib/seam/resources/event.rb', line 379

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


382
# File 'lib/seam/resources/event.rb', line 382

date_accessor :occurred_at