Class: Seam::Resources::SeamEvent::AccessCodeSetOnDevice

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was set on a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


389
390
391
# File 'lib/seam/resources/event.rb', line 389

def access_code_id
  @access_code_id
end

#codeString

Code for the affected access code.

Returns:

  • (String)


392
393
394
# File 'lib/seam/resources/event.rb', line 392

def code
  @code
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


395
396
397
# File 'lib/seam/resources/event.rb', line 395

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


398
399
400
# File 'lib/seam/resources/event.rb', line 398

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


401
402
403
# File 'lib/seam/resources/event.rb', line 401

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


404
405
406
# File 'lib/seam/resources/event.rb', line 404

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


407
408
409
# File 'lib/seam/resources/event.rb', line 407

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


410
411
412
# File 'lib/seam/resources/event.rb', line 410

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.set_on_device

Returns:

  • (String)


414
415
416
# File 'lib/seam/resources/event.rb', line 414

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


417
418
419
# File 'lib/seam/resources/event.rb', line 417

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


420
# File 'lib/seam/resources/event.rb', line 420

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


423
# File 'lib/seam/resources/event.rb', line 423

date_accessor :occurred_at