Class: Seam::Resources::SeamEvent::AccessCodeTimeFrameChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The time frame of an access code was changed on the device.

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


247
248
249
# File 'lib/seam/resources/event.rb', line 247

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


250
251
252
# File 'lib/seam/resources/event.rb', line 250

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


253
254
255
# File 'lib/seam/resources/event.rb', line 253

def 
  @connected_account_id
end

#descriptionString

Human-readable description of the change and its source.

Returns:

  • (String)


256
257
258
# File 'lib/seam/resources/event.rb', line 256

def description
  @description
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


259
260
261
# File 'lib/seam/resources/event.rb', line 259

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


262
263
264
# File 'lib/seam/resources/event.rb', line 262

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


265
266
267
# File 'lib/seam/resources/event.rb', line 265

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


268
269
270
# File 'lib/seam/resources/event.rb', line 268

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.time_frame_changed

Returns:

  • (String)


272
273
274
# File 'lib/seam/resources/event.rb', line 272

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


275
276
277
# File 'lib/seam/resources/event.rb', line 275

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


278
# File 'lib/seam/resources/event.rb', line 278

date_accessor :created_at

#fromFrom

Previous time frame configuration.

Returns:



241
# File 'lib/seam/resources/event.rb', line 241

resource_accessor :from, From

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


281
# File 'lib/seam/resources/event.rb', line 281

date_accessor :occurred_at

#toTo

New time frame configuration.

Returns:



244
# File 'lib/seam/resources/event.rb', line 244

resource_accessor :to, To