Class: Seam::Resources::SeamEvent::AccessCodeUnmanagedConvertedToManaged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An unmanaged access code was converted successfully to a managed access code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


1138
1139
1140
# File 'lib/seam/resources/event.rb', line 1138

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1141
1142
1143
# File 'lib/seam/resources/event.rb', line 1141

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


1144
1145
1146
# File 'lib/seam/resources/event.rb', line 1144

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1147
1148
1149
# File 'lib/seam/resources/event.rb', line 1147

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


1150
1151
1152
# File 'lib/seam/resources/event.rb', line 1150

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1153
1154
1155
# File 'lib/seam/resources/event.rb', line 1153

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1156
1157
1158
# File 'lib/seam/resources/event.rb', line 1156

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.unmanaged.converted_to_managed

Returns:

  • (String)


1160
1161
1162
# File 'lib/seam/resources/event.rb', line 1160

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1163
1164
1165
# File 'lib/seam/resources/event.rb', line 1163

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1166
# File 'lib/seam/resources/event.rb', line 1166

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1169
# File 'lib/seam/resources/event.rb', line 1169

date_accessor :occurred_at