Class: Seam::Resources::SeamEvent::AccessCodeUnmanagedCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeUnmanagedCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
An unmanaged access code was created on a device.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.unmanaged.created. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
1304 1305 1306 |
# File 'lib/seam/resources/event.rb', line 1304 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
1307 1308 1309 |
# File 'lib/seam/resources/event.rb', line 1307 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
1310 1311 1312 |
# File 'lib/seam/resources/event.rb', line 1310 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
1313 1314 1315 |
# File 'lib/seam/resources/event.rb', line 1313 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
1316 1317 1318 |
# File 'lib/seam/resources/event.rb', line 1316 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1319 1320 1321 |
# File 'lib/seam/resources/event.rb', line 1319 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1322 1323 1324 |
# File 'lib/seam/resources/event.rb', line 1322 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.unmanaged.created
1326 1327 1328 |
# File 'lib/seam/resources/event.rb', line 1326 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1329 1330 1331 |
# File 'lib/seam/resources/event.rb', line 1329 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1332 |
# File 'lib/seam/resources/event.rb', line 1332 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1335 |
# File 'lib/seam/resources/event.rb', line 1335 date_accessor :occurred_at |