Class: Seam::Resources::SeamEvent::AccessCodeUnmanagedFailedToConvertToManaged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An unmanaged access code failed to be converted to a managed access code.

Defined Under Namespace

Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


1266
1267
1268
# File 'lib/seam/resources/event.rb', line 1266

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1269
1270
1271
# File 'lib/seam/resources/event.rb', line 1269

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


1272
1273
1274
# File 'lib/seam/resources/event.rb', line 1272

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1275
1276
1277
# File 'lib/seam/resources/event.rb', line 1275

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


1278
1279
1280
# File 'lib/seam/resources/event.rb', line 1278

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1281
1282
1283
# File 'lib/seam/resources/event.rb', line 1281

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1284
1285
1286
# File 'lib/seam/resources/event.rb', line 1284

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.unmanaged.failed_to_convert_to_managed

Returns:

  • (String)


1288
1289
1290
# File 'lib/seam/resources/event.rb', line 1288

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1291
1292
1293
# File 'lib/seam/resources/event.rb', line 1291

def workspace_id
  @workspace_id
end

Instance Method Details

#access_code_errorsArray<AccessCodeErrors>

Errors associated with the access code.

Returns:



1248
# File 'lib/seam/resources/event.rb', line 1248

resource_list_accessor :access_code_errors, AccessCodeErrors

#access_code_warningsArray<AccessCodeWarnings>

Warnings associated with the access code.

Returns:



1251
# File 'lib/seam/resources/event.rb', line 1251

resource_list_accessor :access_code_warnings, AccessCodeWarnings

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



1254
# File 'lib/seam/resources/event.rb', line 1254

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



1257
# File 'lib/seam/resources/event.rb', line 1257

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1294
# File 'lib/seam/resources/event.rb', line 1294

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



1260
# File 'lib/seam/resources/event.rb', line 1260

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



1263
# File 'lib/seam/resources/event.rb', line 1263

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1297
# File 'lib/seam/resources/event.rb', line 1297

date_accessor :occurred_at