Class: Seam::Resources::SeamEvent::AccessCodeUnmanagedRemoved

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An unmanaged access code was removed from a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


1342
1343
1344
# File 'lib/seam/resources/event.rb', line 1342

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1345
1346
1347
# File 'lib/seam/resources/event.rb', line 1345

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


1348
1349
1350
# File 'lib/seam/resources/event.rb', line 1348

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


1351
1352
1353
# File 'lib/seam/resources/event.rb', line 1351

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


1354
1355
1356
# File 'lib/seam/resources/event.rb', line 1354

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1357
1358
1359
# File 'lib/seam/resources/event.rb', line 1357

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1360
1361
1362
# File 'lib/seam/resources/event.rb', line 1360

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.unmanaged.removed

Returns:

  • (String)


1364
1365
1366
# File 'lib/seam/resources/event.rb', line 1364

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1367
1368
1369
# File 'lib/seam/resources/event.rb', line 1367

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1370
# File 'lib/seam/resources/event.rb', line 1370

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1373
# File 'lib/seam/resources/event.rb', line 1373

date_accessor :occurred_at