Class: Seam::Resources::SeamEvent::AccessGrantAccessGrantedToAllDoors
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessGrantAccessGrantedToAllDoors
- Defined in:
- lib/seam/resources/event.rb
Overview
All access requested for an Access Grant was successfully granted.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_grant.access_granted_to_all_doors. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_id ⇒ String
ID of the affected Access Grant.
1432 1433 1434 |
# File 'lib/seam/resources/event.rb', line 1432 def access_grant_id @access_grant_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1435 1436 1437 |
# File 'lib/seam/resources/event.rb', line 1435 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1438 1439 1440 |
# File 'lib/seam/resources/event.rb', line 1438 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_grant.access_granted_to_all_doors
1442 1443 1444 |
# File 'lib/seam/resources/event.rb', line 1442 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1445 1446 1447 |
# File 'lib/seam/resources/event.rb', line 1445 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1448 |
# File 'lib/seam/resources/event.rb', line 1448 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1451 |
# File 'lib/seam/resources/event.rb', line 1451 date_accessor :occurred_at |