Class: Seam::Resources::SeamEvent::AccessGrantAccessGrantedToDoor

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

Access requested as part of an Access Grant to a particular door was successfully granted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


1458
1459
1460
# File 'lib/seam/resources/event.rb', line 1458

def access_grant_id
  @access_grant_id
end

#acs_entrance_idString

ID of the affected entrance.

Returns:

  • (String)


1461
1462
1463
# File 'lib/seam/resources/event.rb', line 1461

def acs_entrance_id
  @acs_entrance_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1464
1465
1466
# File 'lib/seam/resources/event.rb', line 1464

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1467
1468
1469
# File 'lib/seam/resources/event.rb', line 1467

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_grant.access_granted_to_door

Returns:

  • (String)


1471
1472
1473
# File 'lib/seam/resources/event.rb', line 1471

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1474
1475
1476
# File 'lib/seam/resources/event.rb', line 1474

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1477
# File 'lib/seam/resources/event.rb', line 1477

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1480
# File 'lib/seam/resources/event.rb', line 1480

date_accessor :occurred_at