Class: Seam::Resources::SeamEvent::AccessGrantAccessTimesChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An Access Grant's start or end time was changed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


1516
1517
1518
# File 'lib/seam/resources/event.rb', line 1516

def access_grant_id
  @access_grant_id
end

#access_grant_keyString?

Key of the affected Access Grant (if present).

Returns:

  • (String, nil)


1519
1520
1521
# File 'lib/seam/resources/event.rb', line 1519

def access_grant_key
  @access_grant_key
end

#ends_atString?

The new end time for the access grant.

Returns:

  • (String, nil)


1522
1523
1524
# File 'lib/seam/resources/event.rb', line 1522

def ends_at
  @ends_at
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1525
1526
1527
# File 'lib/seam/resources/event.rb', line 1525

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1528
1529
1530
# File 'lib/seam/resources/event.rb', line 1528

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_grant.access_times_changed

Returns:

  • (String)


1532
1533
1534
# File 'lib/seam/resources/event.rb', line 1532

def event_type
  @event_type
end

#starts_atString?

The new start time for the access grant.

Returns:

  • (String, nil)


1535
1536
1537
# File 'lib/seam/resources/event.rb', line 1535

def starts_at
  @starts_at
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1538
1539
1540
# File 'lib/seam/resources/event.rb', line 1538

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1541
# File 'lib/seam/resources/event.rb', line 1541

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1544
# File 'lib/seam/resources/event.rb', line 1544

date_accessor :occurred_at