Class: Seam::Resources::SeamEvent::AccessGrantAccessToDoorLost

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

Access to a particular door that was requested as part of an Access Grant was lost.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


1487
1488
1489
# File 'lib/seam/resources/event.rb', line 1487

def access_grant_id
  @access_grant_id
end

#acs_entrance_idString

ID of the affected entrance.

Returns:

  • (String)


1490
1491
1492
# File 'lib/seam/resources/event.rb', line 1490

def acs_entrance_id
  @acs_entrance_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1493
1494
1495
# File 'lib/seam/resources/event.rb', line 1493

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1496
1497
1498
# File 'lib/seam/resources/event.rb', line 1496

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_grant.access_to_door_lost

Returns:

  • (String)


1500
1501
1502
# File 'lib/seam/resources/event.rb', line 1500

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1503
1504
1505
# File 'lib/seam/resources/event.rb', line 1503

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1506
# File 'lib/seam/resources/event.rb', line 1506

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1509
# File 'lib/seam/resources/event.rb', line 1509

date_accessor :occurred_at