Class: Seam::Resources::SeamEvent::AccessGrantCouldNotCreateRequestedAccessMethods

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

One or more requested access methods could not be created for an Access Grant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


1551
1552
1553
# File 'lib/seam/resources/event.rb', line 1551

def access_grant_id
  @access_grant_id
end

#error_messageString

Description of why the access methods could not be created.

Returns:

  • (String)


1554
1555
1556
# File 'lib/seam/resources/event.rb', line 1554

def error_message
  @error_message
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1557
1558
1559
# File 'lib/seam/resources/event.rb', line 1557

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1560
1561
1562
# File 'lib/seam/resources/event.rb', line 1560

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_grant.could_not_create_requested_access_methods

Returns:

  • (String)


1564
1565
1566
# File 'lib/seam/resources/event.rb', line 1564

def event_type
  @event_type
end

#missing_device_idsArray<String>

IDs of the devices that did not receive a requested access method. Use these to identify which specific devices failed without having to fetch the Access Grant.

Returns:

  • (Array<String>)


1567
1568
1569
# File 'lib/seam/resources/event.rb', line 1567

def missing_device_ids
  @missing_device_ids
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1570
1571
1572
# File 'lib/seam/resources/event.rb', line 1570

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1573
# File 'lib/seam/resources/event.rb', line 1573

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1576
# File 'lib/seam/resources/event.rb', line 1576

date_accessor :occurred_at