Class: Seam::Resources::SeamEvent::AccessGrantCreated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An Access Grant was created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


1380
1381
1382
# File 'lib/seam/resources/event.rb', line 1380

def access_grant_id
  @access_grant_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1383
1384
1385
# File 'lib/seam/resources/event.rb', line 1383

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1386
1387
1388
# File 'lib/seam/resources/event.rb', line 1386

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_grant.created

Returns:

  • (String)


1390
1391
1392
# File 'lib/seam/resources/event.rb', line 1390

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1393
1394
1395
# File 'lib/seam/resources/event.rb', line 1393

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1396
# File 'lib/seam/resources/event.rb', line 1396

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1399
# File 'lib/seam/resources/event.rb', line 1399

date_accessor :occurred_at