Class: Seam::Resources::SeamEvent::AccessGrantDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An Access Grant was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idString

ID of the affected Access Grant.

Returns:

  • (String)


1406
1407
1408
# File 'lib/seam/resources/event.rb', line 1406

def access_grant_id
  @access_grant_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1409
1410
1411
# File 'lib/seam/resources/event.rb', line 1409

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1412
1413
1414
# File 'lib/seam/resources/event.rb', line 1412

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_grant.deleted

Returns:

  • (String)


1416
1417
1418
# File 'lib/seam/resources/event.rb', line 1416

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1419
1420
1421
# File 'lib/seam/resources/event.rb', line 1419

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1422
# File 'lib/seam/resources/event.rb', line 1422

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1425
# File 'lib/seam/resources/event.rb', line 1425

date_accessor :occurred_at