Class: Seam::Resources::SeamEvent::AccessMethodCardEncodingRequired

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access method representing a physical card requires encoding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idsArray<String>

IDs of the access grants associated with this access method.

Returns:

  • (Array<String>)


1653
1654
1655
# File 'lib/seam/resources/event.rb', line 1653

def access_grant_ids
  @access_grant_ids
end

#access_grant_keysArray<String>

Keys of the access grants associated with this access method (if present).

Returns:

  • (Array<String>)


1656
1657
1658
# File 'lib/seam/resources/event.rb', line 1656

def access_grant_keys
  @access_grant_keys
end

#access_method_idString

ID of the affected access method.

Returns:

  • (String)


1659
1660
1661
# File 'lib/seam/resources/event.rb', line 1659

def access_method_id
  @access_method_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1662
1663
1664
# File 'lib/seam/resources/event.rb', line 1662

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1665
1666
1667
# File 'lib/seam/resources/event.rb', line 1665

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_method.card_encoding_required

Returns:

  • (String)


1669
1670
1671
# File 'lib/seam/resources/event.rb', line 1669

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1672
1673
1674
# File 'lib/seam/resources/event.rb', line 1672

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1675
# File 'lib/seam/resources/event.rb', line 1675

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1678
# File 'lib/seam/resources/event.rb', line 1678

date_accessor :occurred_at