Class: Seam::Resources::SeamEvent::AccessMethodCreated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access method was created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idsArray<String>

IDs of the access grants associated with this access method.

Returns:

  • (Array<String>)


1755
1756
1757
# File 'lib/seam/resources/event.rb', line 1755

def access_grant_ids
  @access_grant_ids
end

#access_grant_keysArray<String>

Keys of the access grants associated with this access method (if present).

Returns:

  • (Array<String>)


1758
1759
1760
# File 'lib/seam/resources/event.rb', line 1758

def access_grant_keys
  @access_grant_keys
end

#access_method_idString

ID of the affected access method.

Returns:

  • (String)


1761
1762
1763
# File 'lib/seam/resources/event.rb', line 1761

def access_method_id
  @access_method_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1764
1765
1766
# File 'lib/seam/resources/event.rb', line 1764

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1767
1768
1769
# File 'lib/seam/resources/event.rb', line 1767

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_method.created

Returns:

  • (String)


1771
1772
1773
# File 'lib/seam/resources/event.rb', line 1771

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1774
1775
1776
# File 'lib/seam/resources/event.rb', line 1774

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1777
# File 'lib/seam/resources/event.rb', line 1777

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1780
# File 'lib/seam/resources/event.rb', line 1780

date_accessor :occurred_at