Class: Seam::Resources::SeamEvent::AccessMethodDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessMethodDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
An access method was deleted.
Instance Attribute Summary collapse
-
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
-
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ String
ID of the affected access method.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_method.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
1685 1686 1687 |
# File 'lib/seam/resources/event.rb', line 1685 def access_grant_ids @access_grant_ids end |
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
1688 1689 1690 |
# File 'lib/seam/resources/event.rb', line 1688 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ String
ID of the affected access method.
1691 1692 1693 |
# File 'lib/seam/resources/event.rb', line 1691 def access_method_id @access_method_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1694 1695 1696 |
# File 'lib/seam/resources/event.rb', line 1694 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1697 1698 1699 |
# File 'lib/seam/resources/event.rb', line 1697 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_method.deleted
1701 1702 1703 |
# File 'lib/seam/resources/event.rb', line 1701 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1704 1705 1706 |
# File 'lib/seam/resources/event.rb', line 1704 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1707 |
# File 'lib/seam/resources/event.rb', line 1707 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1710 |
# File 'lib/seam/resources/event.rb', line 1710 date_accessor :occurred_at |