Class: Seam::Resources::SeamEvent::AccessMethodIssued

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access method was issued.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idsArray<String>

IDs of the access grants associated with this access method.

Returns:

  • (Array<String>)


1583
1584
1585
# File 'lib/seam/resources/event.rb', line 1583

def access_grant_ids
  @access_grant_ids
end

#access_grant_keysArray<String>

Keys of the access grants associated with this access method (if present).

Returns:

  • (Array<String>)


1586
1587
1588
# File 'lib/seam/resources/event.rb', line 1586

def access_grant_keys
  @access_grant_keys
end

#access_method_idString

ID of the affected access method.

Returns:

  • (String)


1589
1590
1591
# File 'lib/seam/resources/event.rb', line 1589

def access_method_id
  @access_method_id
end

#codeString?

The actual PIN code for code access methods (only present when mode is 'code').

Returns:

  • (String, nil)


1592
1593
1594
# File 'lib/seam/resources/event.rb', line 1592

def code
  @code
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1595
1596
1597
# File 'lib/seam/resources/event.rb', line 1595

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1598
1599
1600
# File 'lib/seam/resources/event.rb', line 1598

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_method.issued

Returns:

  • (String)


1602
1603
1604
# File 'lib/seam/resources/event.rb', line 1602

def event_type
  @event_type
end

#is_backup_codeBoolean?

Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).

Returns:

  • (Boolean, nil)


1605
1606
1607
# File 'lib/seam/resources/event.rb', line 1605

def is_backup_code
  @is_backup_code
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1608
1609
1610
# File 'lib/seam/resources/event.rb', line 1608

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1611
# File 'lib/seam/resources/event.rb', line 1611

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1614
# File 'lib/seam/resources/event.rb', line 1614

date_accessor :occurred_at