Class: Seam::Resources::SeamEvent::AccessMethodReissued

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access method was reissued.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idsArray<String>

IDs of the access grants associated with this access method.

Returns:

  • (Array<String>)


1717
1718
1719
# File 'lib/seam/resources/event.rb', line 1717

def access_grant_ids
  @access_grant_ids
end

#access_grant_keysArray<String>

Keys of the access grants associated with this access method (if present).

Returns:

  • (Array<String>)


1720
1721
1722
# File 'lib/seam/resources/event.rb', line 1720

def access_grant_keys
  @access_grant_keys
end

#access_method_idString

ID of the affected access method.

Returns:

  • (String)


1723
1724
1725
# File 'lib/seam/resources/event.rb', line 1723

def access_method_id
  @access_method_id
end

#codeString?

The actual PIN code for code access methods (only present when mode is 'code').

Returns:

  • (String, nil)


1726
1727
1728
# File 'lib/seam/resources/event.rb', line 1726

def code
  @code
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1729
1730
1731
# File 'lib/seam/resources/event.rb', line 1729

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1732
1733
1734
# File 'lib/seam/resources/event.rb', line 1732

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_method.reissued

Returns:

  • (String)


1736
1737
1738
# File 'lib/seam/resources/event.rb', line 1736

def event_type
  @event_type
end

#is_backup_codeBoolean?

Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).

Returns:

  • (Boolean, nil)


1739
1740
1741
# File 'lib/seam/resources/event.rb', line 1739

def is_backup_code
  @is_backup_code
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1742
1743
1744
# File 'lib/seam/resources/event.rb', line 1742

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1745
# File 'lib/seam/resources/event.rb', line 1745

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1748
# File 'lib/seam/resources/event.rb', line 1748

date_accessor :occurred_at