Class: Seam::Resources::SeamEvent::AccessMethodRevoked

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access method was revoked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_grant_idsArray<String>

IDs of the access grants associated with this access method.

Returns:

  • (Array<String>)


1621
1622
1623
# File 'lib/seam/resources/event.rb', line 1621

def access_grant_ids
  @access_grant_ids
end

#access_grant_keysArray<String>

Keys of the access grants associated with this access method (if present).

Returns:

  • (Array<String>)


1624
1625
1626
# File 'lib/seam/resources/event.rb', line 1624

def access_grant_keys
  @access_grant_keys
end

#access_method_idString

ID of the affected access method.

Returns:

  • (String)


1627
1628
1629
# File 'lib/seam/resources/event.rb', line 1627

def access_method_id
  @access_method_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1630
1631
1632
# File 'lib/seam/resources/event.rb', line 1630

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1633
1634
1635
# File 'lib/seam/resources/event.rb', line 1633

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_method.revoked

Returns:

  • (String)


1637
1638
1639
# File 'lib/seam/resources/event.rb', line 1637

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1640
1641
1642
# File 'lib/seam/resources/event.rb', line 1640

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1643
# File 'lib/seam/resources/event.rb', line 1643

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1646
# File 'lib/seam/resources/event.rb', line 1646

date_accessor :occurred_at