Class: Seam::Resources::SeamEvent::AcsAccessGroupDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An ACS access group was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_access_group_idString

ID of the affected access group.

Returns:

  • (String)


2254
2255
2256
# File 'lib/seam/resources/event.rb', line 2254

def acs_access_group_id
  @acs_access_group_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2257
2258
2259
# File 'lib/seam/resources/event.rb', line 2257

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2260
2261
2262
# File 'lib/seam/resources/event.rb', line 2260

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2263
2264
2265
# File 'lib/seam/resources/event.rb', line 2263

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2266
2267
2268
# File 'lib/seam/resources/event.rb', line 2266

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_access_group.deleted

Returns:

  • (String)


2270
2271
2272
# File 'lib/seam/resources/event.rb', line 2270

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2273
2274
2275
# File 'lib/seam/resources/event.rb', line 2273

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2276
# File 'lib/seam/resources/event.rb', line 2276

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2279
# File 'lib/seam/resources/event.rb', line 2279

date_accessor :occurred_at