Class: Seam::Resources::SeamEvent::AcsCredentialDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system credential was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_credential_idString

ID of the affected credential.

Returns:

  • (String)


1998
1999
2000
# File 'lib/seam/resources/event.rb', line 1998

def acs_credential_id
  @acs_credential_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2001
2002
2003
# File 'lib/seam/resources/event.rb', line 2001

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2004
2005
2006
# File 'lib/seam/resources/event.rb', line 2004

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2007
2008
2009
# File 'lib/seam/resources/event.rb', line 2007

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2010
2011
2012
# File 'lib/seam/resources/event.rb', line 2010

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_credential.deleted

Returns:

  • (String)


2014
2015
2016
# File 'lib/seam/resources/event.rb', line 2014

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2017
2018
2019
# File 'lib/seam/resources/event.rb', line 2017

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2020
# File 'lib/seam/resources/event.rb', line 2020

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2023
# File 'lib/seam/resources/event.rb', line 2023

date_accessor :occurred_at