Class: Seam::Resources::SeamEvent::AcsCredentialInvalidated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsCredentialInvalidated
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system credential was invalidated. That is, the credential cannot be used anymore.
Instance Attribute Summary collapse
-
#acs_credential_id ⇒ String
ID of the affected credential.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_credential.invalidated. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_credential_id ⇒ String
ID of the affected credential.
2094 2095 2096 |
# File 'lib/seam/resources/event.rb', line 2094 def acs_credential_id @acs_credential_id end |
#acs_system_id ⇒ String
ID of the access system.
2097 2098 2099 |
# File 'lib/seam/resources/event.rb', line 2097 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2100 2101 2102 |
# File 'lib/seam/resources/event.rb', line 2100 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2103 2104 2105 |
# File 'lib/seam/resources/event.rb', line 2103 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2106 2107 2108 |
# File 'lib/seam/resources/event.rb', line 2106 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_credential.invalidated
2110 2111 2112 |
# File 'lib/seam/resources/event.rb', line 2110 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2113 2114 2115 |
# File 'lib/seam/resources/event.rb', line 2113 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2116 |
# File 'lib/seam/resources/event.rb', line 2116 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2119 |
# File 'lib/seam/resources/event.rb', line 2119 date_accessor :occurred_at |