Class: Seam::Resources::SeamEvent::AcsCredentialIssued
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsCredentialIssued
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system credential was issued.
Instance Attribute Summary collapse
-
#acs_credential_id ⇒ String
ID of the affected credential.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_credential.issued. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_credential_id ⇒ String
ID of the affected credential.
2030 2031 2032 |
# File 'lib/seam/resources/event.rb', line 2030 def acs_credential_id @acs_credential_id end |
#acs_system_id ⇒ String
ID of the access system.
2033 2034 2035 |
# File 'lib/seam/resources/event.rb', line 2033 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2036 2037 2038 |
# File 'lib/seam/resources/event.rb', line 2036 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2039 2040 2041 |
# File 'lib/seam/resources/event.rb', line 2039 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2042 2043 2044 |
# File 'lib/seam/resources/event.rb', line 2042 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_credential.issued
2046 2047 2048 |
# File 'lib/seam/resources/event.rb', line 2046 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2049 2050 2051 |
# File 'lib/seam/resources/event.rb', line 2049 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2052 |
# File 'lib/seam/resources/event.rb', line 2052 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2055 |
# File 'lib/seam/resources/event.rb', line 2055 date_accessor :occurred_at |