Class: Seam::Resources::SeamEvent::AcsCredentialReissued

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system credential was reissued.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_credential_idString

ID of the affected credential.

Returns:

  • (String)


2062
2063
2064
# File 'lib/seam/resources/event.rb', line 2062

def acs_credential_id
  @acs_credential_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2065
2066
2067
# File 'lib/seam/resources/event.rb', line 2065

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2068
2069
2070
# File 'lib/seam/resources/event.rb', line 2068

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2071
2072
2073
# File 'lib/seam/resources/event.rb', line 2071

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2074
2075
2076
# File 'lib/seam/resources/event.rb', line 2074

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_credential.reissued

Returns:

  • (String)


2078
2079
2080
# File 'lib/seam/resources/event.rb', line 2078

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2081
2082
2083
# File 'lib/seam/resources/event.rb', line 2081

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2084
# File 'lib/seam/resources/event.rb', line 2084

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2087
# File 'lib/seam/resources/event.rb', line 2087

date_accessor :occurred_at