Class: Seam::Resources::SeamEvent::AcsEncoderAdded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system encoder was added.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_encoder_idString

ID of the affected encoder.

Returns:

  • (String)


2190
2191
2192
# File 'lib/seam/resources/event.rb', line 2190

def acs_encoder_id
  @acs_encoder_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2193
2194
2195
# File 'lib/seam/resources/event.rb', line 2193

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2196
2197
2198
# File 'lib/seam/resources/event.rb', line 2196

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2199
2200
2201
# File 'lib/seam/resources/event.rb', line 2199

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2202
2203
2204
# File 'lib/seam/resources/event.rb', line 2202

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_encoder.added

Returns:

  • (String)


2206
2207
2208
# File 'lib/seam/resources/event.rb', line 2206

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2209
2210
2211
# File 'lib/seam/resources/event.rb', line 2209

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2212
# File 'lib/seam/resources/event.rb', line 2212

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2215
# File 'lib/seam/resources/event.rb', line 2215

date_accessor :occurred_at