Class: Seam::Resources::SeamEvent::AcsEncoderRemoved

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system encoder was removed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_encoder_idString

ID of the affected encoder.

Returns:

  • (String)


2222
2223
2224
# File 'lib/seam/resources/event.rb', line 2222

def acs_encoder_id
  @acs_encoder_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2225
2226
2227
# File 'lib/seam/resources/event.rb', line 2225

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2228
2229
2230
# File 'lib/seam/resources/event.rb', line 2228

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2231
2232
2233
# File 'lib/seam/resources/event.rb', line 2231

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2234
2235
2236
# File 'lib/seam/resources/event.rb', line 2234

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_encoder.removed

Returns:

  • (String)


2238
2239
2240
# File 'lib/seam/resources/event.rb', line 2238

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2241
2242
2243
# File 'lib/seam/resources/event.rb', line 2241

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2244
# File 'lib/seam/resources/event.rb', line 2244

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2247
# File 'lib/seam/resources/event.rb', line 2247

date_accessor :occurred_at