Class: Seam::Resources::SeamEvent::AcsEntranceAdded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system entrance was added.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_entrance_idString

ID of the affected entrance.

Returns:

  • (String)


2286
2287
2288
# File 'lib/seam/resources/event.rb', line 2286

def acs_entrance_id
  @acs_entrance_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2289
2290
2291
# File 'lib/seam/resources/event.rb', line 2289

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2292
2293
2294
# File 'lib/seam/resources/event.rb', line 2292

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2295
2296
2297
# File 'lib/seam/resources/event.rb', line 2295

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2298
2299
2300
# File 'lib/seam/resources/event.rb', line 2298

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_entrance.added

Returns:

  • (String)


2302
2303
2304
# File 'lib/seam/resources/event.rb', line 2302

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2305
2306
2307
# File 'lib/seam/resources/event.rb', line 2305

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2308
# File 'lib/seam/resources/event.rb', line 2308

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2311
# File 'lib/seam/resources/event.rb', line 2311

date_accessor :occurred_at