Class: Seam::Resources::SeamEvent::AcsEntranceRemoved

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system entrance was removed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_entrance_idString

ID of the affected entrance.

Returns:

  • (String)


2318
2319
2320
# File 'lib/seam/resources/event.rb', line 2318

def acs_entrance_id
  @acs_entrance_id
end

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2321
2322
2323
# File 'lib/seam/resources/event.rb', line 2321

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2324
2325
2326
# File 'lib/seam/resources/event.rb', line 2324

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2327
2328
2329
# File 'lib/seam/resources/event.rb', line 2327

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2330
2331
2332
# File 'lib/seam/resources/event.rb', line 2330

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_entrance.removed

Returns:

  • (String)


2334
2335
2336
# File 'lib/seam/resources/event.rb', line 2334

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2337
2338
2339
# File 'lib/seam/resources/event.rb', line 2337

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2340
# File 'lib/seam/resources/event.rb', line 2340

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2343
# File 'lib/seam/resources/event.rb', line 2343

date_accessor :occurred_at