Class: Seam::Resources::SeamEvent::AcsSystemAdded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsSystemAdded
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system was added.
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_system.added. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system.
1880 1881 1882 |
# File 'lib/seam/resources/event.rb', line 1880 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
1883 1884 1885 |
# File 'lib/seam/resources/event.rb', line 1883 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1886 1887 1888 |
# File 'lib/seam/resources/event.rb', line 1886 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1889 1890 1891 |
# File 'lib/seam/resources/event.rb', line 1889 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_system.added
1893 1894 1895 |
# File 'lib/seam/resources/event.rb', line 1893 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1896 1897 1898 |
# File 'lib/seam/resources/event.rb', line 1896 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1899 |
# File 'lib/seam/resources/event.rb', line 1899 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1902 |
# File 'lib/seam/resources/event.rb', line 1902 date_accessor :occurred_at |