Class: Seam::Resources::SeamEvent::AcsSystemConnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system was connected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_system_idString

ID of the access system.

Returns:

  • (String)


1851
1852
1853
# File 'lib/seam/resources/event.rb', line 1851

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


1854
1855
1856
# File 'lib/seam/resources/event.rb', line 1854

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1857
1858
1859
# File 'lib/seam/resources/event.rb', line 1857

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1860
1861
1862
# File 'lib/seam/resources/event.rb', line 1860

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_system.connected

Returns:

  • (String)


1864
1865
1866
# File 'lib/seam/resources/event.rb', line 1864

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1867
1868
1869
# File 'lib/seam/resources/event.rb', line 1867

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1870
# File 'lib/seam/resources/event.rb', line 1870

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1873
# File 'lib/seam/resources/event.rb', line 1873

date_accessor :occurred_at