Class: Seam::Resources::SeamEvent::AcsSystemDisconnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system was disconnected.

Defined Under Namespace

Classes: AcsSystemErrors, AcsSystemWarnings, ConnectedAccountErrors, ConnectedAccountWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_system_idString

ID of the access system.

Returns:

  • (String)


1969
1970
1971
# File 'lib/seam/resources/event.rb', line 1969

def acs_system_id
  @acs_system_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


1972
1973
1974
# File 'lib/seam/resources/event.rb', line 1972

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


1975
1976
1977
# File 'lib/seam/resources/event.rb', line 1975

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


1978
1979
1980
# File 'lib/seam/resources/event.rb', line 1978

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_system.disconnected

Returns:

  • (String)


1982
1983
1984
# File 'lib/seam/resources/event.rb', line 1982

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


1985
1986
1987
# File 'lib/seam/resources/event.rb', line 1985

def workspace_id
  @workspace_id
end

Instance Method Details

#acs_system_errorsArray<AcsSystemErrors>

Errors associated with the access control system.

Returns:



1957
# File 'lib/seam/resources/event.rb', line 1957

resource_list_accessor :acs_system_errors, AcsSystemErrors

#acs_system_warningsArray<AcsSystemWarnings>

Warnings associated with the access control system.

Returns:



1960
# File 'lib/seam/resources/event.rb', line 1960

resource_list_accessor :acs_system_warnings, AcsSystemWarnings

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



1963
# File 'lib/seam/resources/event.rb', line 1963

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



1966
# File 'lib/seam/resources/event.rb', line 1966

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


1988
# File 'lib/seam/resources/event.rb', line 1988

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


1991
# File 'lib/seam/resources/event.rb', line 1991

date_accessor :occurred_at