Class: Seam::Resources::SeamEvent::AcsUserCreated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access system user was created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_system_idString

ID of the access system.

Returns:

  • (String)


2126
2127
2128
# File 'lib/seam/resources/event.rb', line 2126

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the affected access system user.

Returns:

  • (String)


2129
2130
2131
# File 'lib/seam/resources/event.rb', line 2129

def acs_user_id
  @acs_user_id
end

#connected_account_idString?

ID of the connected account.

Returns:

  • (String, nil)


2132
2133
2134
# File 'lib/seam/resources/event.rb', line 2132

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2135
2136
2137
# File 'lib/seam/resources/event.rb', line 2135

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2138
2139
2140
# File 'lib/seam/resources/event.rb', line 2138

def event_id
  @event_id
end

#event_typeString

Known values:

  • acs_user.created

Returns:

  • (String)


2142
2143
2144
# File 'lib/seam/resources/event.rb', line 2142

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2145
2146
2147
# File 'lib/seam/resources/event.rb', line 2145

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2148
# File 'lib/seam/resources/event.rb', line 2148

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2151
# File 'lib/seam/resources/event.rb', line 2151

date_accessor :occurred_at