Class: Seam::Resources::SeamEvent::ActionAttemptLockDoorFailed

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A lock door action attempt failed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the affected action attempt.

Returns:

  • (String)


2721
2722
2723
# File 'lib/seam/resources/event.rb', line 2721

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


2724
2725
2726
# File 'lib/seam/resources/event.rb', line 2724

def action_type
  @action_type
end

#connected_account_idString?

ID of the connected account associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2727
2728
2729
# File 'lib/seam/resources/event.rb', line 2727

def 
  @connected_account_id
end

#device_idString?

ID of the device associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2730
2731
2732
# File 'lib/seam/resources/event.rb', line 2730

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2733
2734
2735
# File 'lib/seam/resources/event.rb', line 2733

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2736
2737
2738
# File 'lib/seam/resources/event.rb', line 2736

def event_id
  @event_id
end

#event_typeString

Known values:

  • action_attempt.lock_door.failed

Returns:

  • (String)


2740
2741
2742
# File 'lib/seam/resources/event.rb', line 2740

def event_type
  @event_type
end

#statusString

Status of the action.

Returns:

  • (String)


2743
2744
2745
# File 'lib/seam/resources/event.rb', line 2743

def status
  @status
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2746
2747
2748
# File 'lib/seam/resources/event.rb', line 2746

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2749
# File 'lib/seam/resources/event.rb', line 2749

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2752
# File 'lib/seam/resources/event.rb', line 2752

date_accessor :occurred_at