Class: Seam::Resources::SeamEvent::ActionAttemptLockDoorSucceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A lock door action attempt succeeded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the affected action attempt.

Returns:

  • (String)


2683
2684
2685
# File 'lib/seam/resources/event.rb', line 2683

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


2686
2687
2688
# File 'lib/seam/resources/event.rb', line 2686

def action_type
  @action_type
end

#connected_account_idString?

ID of the connected account associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2689
2690
2691
# File 'lib/seam/resources/event.rb', line 2689

def 
  @connected_account_id
end

#device_idString?

ID of the device associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2692
2693
2694
# File 'lib/seam/resources/event.rb', line 2692

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2695
2696
2697
# File 'lib/seam/resources/event.rb', line 2695

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2698
2699
2700
# File 'lib/seam/resources/event.rb', line 2698

def event_id
  @event_id
end

#event_typeString

Known values:

  • action_attempt.lock_door.succeeded

Returns:

  • (String)


2702
2703
2704
# File 'lib/seam/resources/event.rb', line 2702

def event_type
  @event_type
end

#statusString

Status of the action.

Returns:

  • (String)


2705
2706
2707
# File 'lib/seam/resources/event.rb', line 2705

def status
  @status
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2708
2709
2710
# File 'lib/seam/resources/event.rb', line 2708

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2711
# File 'lib/seam/resources/event.rb', line 2711

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2714
# File 'lib/seam/resources/event.rb', line 2714

date_accessor :occurred_at