Class: Seam::Resources::SeamEvent::ActionAttemptSimulateKeypadCodeEntryFailed

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A simulate keypad code entry action attempt failed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the affected action attempt.

Returns:

  • (String)


2873
2874
2875
# File 'lib/seam/resources/event.rb', line 2873

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


2876
2877
2878
# File 'lib/seam/resources/event.rb', line 2876

def action_type
  @action_type
end

#connected_account_idString?

ID of the connected account associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2879
2880
2881
# File 'lib/seam/resources/event.rb', line 2879

def 
  @connected_account_id
end

#device_idString?

ID of the device associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2882
2883
2884
# File 'lib/seam/resources/event.rb', line 2882

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2885
2886
2887
# File 'lib/seam/resources/event.rb', line 2885

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2888
2889
2890
# File 'lib/seam/resources/event.rb', line 2888

def event_id
  @event_id
end

#event_typeString

Known values:

  • action_attempt.simulate_keypad_code_entry.failed

Returns:

  • (String)


2892
2893
2894
# File 'lib/seam/resources/event.rb', line 2892

def event_type
  @event_type
end

#statusString

Status of the action.

Returns:

  • (String)


2895
2896
2897
# File 'lib/seam/resources/event.rb', line 2895

def status
  @status
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2898
2899
2900
# File 'lib/seam/resources/event.rb', line 2898

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2901
# File 'lib/seam/resources/event.rb', line 2901

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2904
# File 'lib/seam/resources/event.rb', line 2904

date_accessor :occurred_at