Class: Seam::Resources::SeamEvent::ActionAttemptSimulateKeypadCodeEntrySucceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A simulate keypad code entry action attempt succeeded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the affected action attempt.

Returns:

  • (String)


2835
2836
2837
# File 'lib/seam/resources/event.rb', line 2835

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


2838
2839
2840
# File 'lib/seam/resources/event.rb', line 2838

def action_type
  @action_type
end

#connected_account_idString?

ID of the connected account associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2841
2842
2843
# File 'lib/seam/resources/event.rb', line 2841

def 
  @connected_account_id
end

#device_idString?

ID of the device associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2844
2845
2846
# File 'lib/seam/resources/event.rb', line 2844

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2847
2848
2849
# File 'lib/seam/resources/event.rb', line 2847

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2850
2851
2852
# File 'lib/seam/resources/event.rb', line 2850

def event_id
  @event_id
end

#event_typeString

Known values:

  • action_attempt.simulate_keypad_code_entry.succeeded

Returns:

  • (String)


2854
2855
2856
# File 'lib/seam/resources/event.rb', line 2854

def event_type
  @event_type
end

#statusString

Status of the action.

Returns:

  • (String)


2857
2858
2859
# File 'lib/seam/resources/event.rb', line 2857

def status
  @status
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2860
2861
2862
# File 'lib/seam/resources/event.rb', line 2860

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2863
# File 'lib/seam/resources/event.rb', line 2863

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2866
# File 'lib/seam/resources/event.rb', line 2866

date_accessor :occurred_at