Class: Seam::Resources::SeamEvent::ActionAttemptSimulateManualLockViaKeypadFailed
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ActionAttemptSimulateManualLockViaKeypadFailed
- Defined in:
- lib/seam/resources/event.rb
Overview
A simulate manual lock via keypad action attempt failed.
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the affected action attempt.
-
#action_type ⇒ String
Type of the action.
-
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
-
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
action_attempt.simulate_manual_lock_via_keypad.failed. -
#status ⇒ String
Status of the action.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the affected action attempt.
2949 2950 2951 |
# File 'lib/seam/resources/event.rb', line 2949 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Type of the action.
2952 2953 2954 |
# File 'lib/seam/resources/event.rb', line 2952 def action_type @action_type end |
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
2955 2956 2957 |
# File 'lib/seam/resources/event.rb', line 2955 def connected_account_id @connected_account_id end |
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
2958 2959 2960 |
# File 'lib/seam/resources/event.rb', line 2958 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2961 2962 2963 |
# File 'lib/seam/resources/event.rb', line 2961 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2964 2965 2966 |
# File 'lib/seam/resources/event.rb', line 2964 def event_id @event_id end |
#event_type ⇒ String
Known values:
action_attempt.simulate_manual_lock_via_keypad.failed
2968 2969 2970 |
# File 'lib/seam/resources/event.rb', line 2968 def event_type @event_type end |
#status ⇒ String
Status of the action.
2971 2972 2973 |
# File 'lib/seam/resources/event.rb', line 2971 def status @status end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2974 2975 2976 |
# File 'lib/seam/resources/event.rb', line 2974 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2977 |
# File 'lib/seam/resources/event.rb', line 2977 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2980 |
# File 'lib/seam/resources/event.rb', line 2980 date_accessor :occurred_at |