Class: Seam::Resources::SeamEvent::ActionAttemptSimulateManualLockViaKeypadSucceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A simulate manual lock via keypad action attempt succeeded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the affected action attempt.

Returns:

  • (String)


2911
2912
2913
# File 'lib/seam/resources/event.rb', line 2911

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


2914
2915
2916
# File 'lib/seam/resources/event.rb', line 2914

def action_type
  @action_type
end

#connected_account_idString?

ID of the connected account associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2917
2918
2919
# File 'lib/seam/resources/event.rb', line 2917

def 
  @connected_account_id
end

#device_idString?

ID of the device associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2920
2921
2922
# File 'lib/seam/resources/event.rb', line 2920

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2923
2924
2925
# File 'lib/seam/resources/event.rb', line 2923

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2926
2927
2928
# File 'lib/seam/resources/event.rb', line 2926

def event_id
  @event_id
end

#event_typeString

Known values:

  • action_attempt.simulate_manual_lock_via_keypad.succeeded

Returns:

  • (String)


2930
2931
2932
# File 'lib/seam/resources/event.rb', line 2930

def event_type
  @event_type
end

#statusString

Status of the action.

Returns:

  • (String)


2933
2934
2935
# File 'lib/seam/resources/event.rb', line 2933

def status
  @status
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2936
2937
2938
# File 'lib/seam/resources/event.rb', line 2936

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2939
# File 'lib/seam/resources/event.rb', line 2939

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2942
# File 'lib/seam/resources/event.rb', line 2942

date_accessor :occurred_at