Class: Seam::Resources::SeamEvent::ActionAttemptUnlockDoorSucceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An unlock door action attempt succeeded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the affected action attempt.

Returns:

  • (String)


2759
2760
2761
# File 'lib/seam/resources/event.rb', line 2759

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Type of the action.

Returns:

  • (String)


2762
2763
2764
# File 'lib/seam/resources/event.rb', line 2762

def action_type
  @action_type
end

#connected_account_idString?

ID of the connected account associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2765
2766
2767
# File 'lib/seam/resources/event.rb', line 2765

def 
  @connected_account_id
end

#device_idString?

ID of the device associated with the action attempt, if applicable.

Returns:

  • (String, nil)


2768
2769
2770
# File 'lib/seam/resources/event.rb', line 2768

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2771
2772
2773
# File 'lib/seam/resources/event.rb', line 2771

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2774
2775
2776
# File 'lib/seam/resources/event.rb', line 2774

def event_id
  @event_id
end

#event_typeString

Known values:

  • action_attempt.unlock_door.succeeded

Returns:

  • (String)


2778
2779
2780
# File 'lib/seam/resources/event.rb', line 2778

def event_type
  @event_type
end

#statusString

Status of the action.

Returns:

  • (String)


2781
2782
2783
# File 'lib/seam/resources/event.rb', line 2781

def status
  @status
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2784
2785
2786
# File 'lib/seam/resources/event.rb', line 2784

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2787
# File 'lib/seam/resources/event.rb', line 2787

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2790
# File 'lib/seam/resources/event.rb', line 2790

date_accessor :occurred_at