Class: Seam::Resources::SeamEvent::ClientSessionDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A client session was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#client_session_idString

ID of the affected client session.

Returns:

  • (String)


2350
2351
2352
# File 'lib/seam/resources/event.rb', line 2350

def client_session_id
  @client_session_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2353
2354
2355
# File 'lib/seam/resources/event.rb', line 2353

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2356
2357
2358
# File 'lib/seam/resources/event.rb', line 2356

def event_id
  @event_id
end

#event_typeString

Known values:

  • client_session.deleted

Returns:

  • (String)


2360
2361
2362
# File 'lib/seam/resources/event.rb', line 2360

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2363
2364
2365
# File 'lib/seam/resources/event.rb', line 2363

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2366
# File 'lib/seam/resources/event.rb', line 2366

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2369
# File 'lib/seam/resources/event.rb', line 2369

date_accessor :occurred_at