Class: Seam::Resources::SeamEvent::ConnectedAccountCompletedFirstSync

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A connected account completed the first sync with Seam, and the corresponding devices or systems are now available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


2534
2535
2536
# File 'lib/seam/resources/event.rb', line 2534

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the affected connected account.

Returns:

  • (String)


2537
2538
2539
# File 'lib/seam/resources/event.rb', line 2537

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2540
2541
2542
# File 'lib/seam/resources/event.rb', line 2540

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2543
2544
2545
# File 'lib/seam/resources/event.rb', line 2543

def event_id
  @event_id
end

#event_typeString

Known values:

  • connected_account.completed_first_sync

Returns:

  • (String)


2547
2548
2549
# File 'lib/seam/resources/event.rb', line 2547

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2550
2551
2552
# File 'lib/seam/resources/event.rb', line 2550

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2553
# File 'lib/seam/resources/event.rb', line 2553

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2556
# File 'lib/seam/resources/event.rb', line 2556

date_accessor :occurred_at