Class: Seam::Resources::SeamEvent::ConnectedAccountCompletedFirstSyncAfterReconnection

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A connected account completed the first sync after reconnection with Seam, and the corresponding devices or systems are now available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


2595
2596
2597
# File 'lib/seam/resources/event.rb', line 2595

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the affected connected account.

Returns:

  • (String)


2598
2599
2600
# File 'lib/seam/resources/event.rb', line 2598

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2601
2602
2603
# File 'lib/seam/resources/event.rb', line 2601

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2604
2605
2606
# File 'lib/seam/resources/event.rb', line 2604

def event_id
  @event_id
end

#event_typeString

Known values:

  • connected_account.completed_first_sync_after_reconnection

Returns:

  • (String)


2608
2609
2610
# File 'lib/seam/resources/event.rb', line 2608

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2611
2612
2613
# File 'lib/seam/resources/event.rb', line 2611

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2614
# File 'lib/seam/resources/event.rb', line 2614

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2617
# File 'lib/seam/resources/event.rb', line 2617

date_accessor :occurred_at