Class: Seam::Resources::SeamEvent::ConnectedAccountConnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A connected account was connected for the first time or was reconnected after being disconnected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connect_webview_idString?

ID of the Connect Webview associated with the event.

Returns:

  • (String, nil)


2376
2377
2378
# File 'lib/seam/resources/event.rb', line 2376

def connect_webview_id
  @connect_webview_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


2379
2380
2381
# File 'lib/seam/resources/event.rb', line 2379

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the affected connected account.

Returns:

  • (String)


2382
2383
2384
# File 'lib/seam/resources/event.rb', line 2382

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with this connected account, if any.

Returns:

  • (String, nil)


2385
2386
2387
# File 'lib/seam/resources/event.rb', line 2385

def customer_key
  @customer_key
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2388
2389
2390
# File 'lib/seam/resources/event.rb', line 2388

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2391
2392
2393
# File 'lib/seam/resources/event.rb', line 2391

def event_id
  @event_id
end

#event_typeString

Known values:

  • connected_account.connected

Returns:

  • (String)


2395
2396
2397
# File 'lib/seam/resources/event.rb', line 2395

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2398
2399
2400
# File 'lib/seam/resources/event.rb', line 2398

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2401
# File 'lib/seam/resources/event.rb', line 2401

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2404
# File 'lib/seam/resources/event.rb', line 2404

date_accessor :occurred_at