Class: Seam::Resources::SeamEvent::ConnectedAccountDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A connected account was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


2563
2564
2565
# File 'lib/seam/resources/event.rb', line 2563

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the affected connected account.

Returns:

  • (String)


2566
2567
2568
# File 'lib/seam/resources/event.rb', line 2566

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with this connected account, if any.

Returns:

  • (String, nil)


2569
2570
2571
# File 'lib/seam/resources/event.rb', line 2569

def customer_key
  @customer_key
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2572
2573
2574
# File 'lib/seam/resources/event.rb', line 2572

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2575
2576
2577
# File 'lib/seam/resources/event.rb', line 2575

def event_id
  @event_id
end

#event_typeString

Known values:

  • connected_account.deleted

Returns:

  • (String)


2579
2580
2581
# File 'lib/seam/resources/event.rb', line 2579

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2582
2583
2584
# File 'lib/seam/resources/event.rb', line 2582

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2585
# File 'lib/seam/resources/event.rb', line 2585

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2588
# File 'lib/seam/resources/event.rb', line 2588

date_accessor :occurred_at