Class: Seam::Resources::SeamEvent::ConnectedAccountDisconnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A connected account was disconnected.

Defined Under Namespace

Classes: ConnectedAccountErrors, ConnectedAccountWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


2505
2506
2507
# File 'lib/seam/resources/event.rb', line 2505

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the affected connected account.

Returns:

  • (String)


2508
2509
2510
# File 'lib/seam/resources/event.rb', line 2508

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2511
2512
2513
# File 'lib/seam/resources/event.rb', line 2511

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2514
2515
2516
# File 'lib/seam/resources/event.rb', line 2514

def event_id
  @event_id
end

#event_typeString

Known values:

  • connected_account.disconnected

Returns:

  • (String)


2518
2519
2520
# File 'lib/seam/resources/event.rb', line 2518

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2521
2522
2523
# File 'lib/seam/resources/event.rb', line 2521

def workspace_id
  @workspace_id
end

Instance Method Details

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



2499
# File 'lib/seam/resources/event.rb', line 2499

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



2502
# File 'lib/seam/resources/event.rb', line 2502

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2524
# File 'lib/seam/resources/event.rb', line 2524

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2527
# File 'lib/seam/resources/event.rb', line 2527

date_accessor :occurred_at