Class: Seam::Resources::SeamEvent::ConnectedAccountReauthorizationRequested

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A connected account requires reauthorization using a new Connect Webview. The account is still connected, but cannot access new features. Delaying reauthorization too long will eventually cause the Connected Account to become disconnected.

Defined Under Namespace

Classes: ConnectedAccountErrors, ConnectedAccountWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


2654
2655
2656
# File 'lib/seam/resources/event.rb', line 2654

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the affected connected account.

Returns:

  • (String)


2657
2658
2659
# File 'lib/seam/resources/event.rb', line 2657

def 
  @connected_account_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


2660
2661
2662
# File 'lib/seam/resources/event.rb', line 2660

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


2663
2664
2665
# File 'lib/seam/resources/event.rb', line 2663

def event_id
  @event_id
end

#event_typeString

Known values:

  • connected_account.reauthorization_requested

Returns:

  • (String)


2667
2668
2669
# File 'lib/seam/resources/event.rb', line 2667

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


2670
2671
2672
# File 'lib/seam/resources/event.rb', line 2670

def workspace_id
  @workspace_id
end

Instance Method Details

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



2648
# File 'lib/seam/resources/event.rb', line 2648

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



2651
# File 'lib/seam/resources/event.rb', line 2651

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


2673
# File 'lib/seam/resources/event.rb', line 2673

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


2676
# File 'lib/seam/resources/event.rb', line 2676

date_accessor :occurred_at