Class: Seam::Resources::SeamEvent::ConnectedAccountReauthorizationRequested::ConnectedAccountErrors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


2625
2626
2627
# File 'lib/seam/resources/event.rb', line 2625

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2628
2629
2630
# File 'lib/seam/resources/event.rb', line 2628

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


2631
# File 'lib/seam/resources/event.rb', line 2631

date_accessor :created_at