Class: Seam::Resources::SeamEvent::DeviceAccessoryKeypadConnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An accessory keypad was connected to a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4086
4087
4088
# File 'lib/seam/resources/event.rb', line 4086

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4089
4090
4091
# File 'lib/seam/resources/event.rb', line 4089

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4092
4093
4094
# File 'lib/seam/resources/event.rb', line 4092

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4095
4096
4097
# File 'lib/seam/resources/event.rb', line 4095

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4098
4099
4100
# File 'lib/seam/resources/event.rb', line 4098

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4101
4102
4103
# File 'lib/seam/resources/event.rb', line 4101

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4104
4105
4106
# File 'lib/seam/resources/event.rb', line 4104

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.accessory_keypad_connected

Returns:

  • (String)


4108
4109
4110
# File 'lib/seam/resources/event.rb', line 4108

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4111
4112
4113
# File 'lib/seam/resources/event.rb', line 4111

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4114
# File 'lib/seam/resources/event.rb', line 4114

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4117
# File 'lib/seam/resources/event.rb', line 4117

date_accessor :occurred_at