Class: Seam::Resources::SeamEvent::DeviceAccessoryKeypadDisconnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An accessory keypad was disconnected from a device.

Defined Under Namespace

Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4184
4185
4186
# File 'lib/seam/resources/event.rb', line 4184

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4187
4188
4189
# File 'lib/seam/resources/event.rb', line 4187

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4190
4191
4192
# File 'lib/seam/resources/event.rb', line 4190

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4193
4194
4195
# File 'lib/seam/resources/event.rb', line 4193

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4196
4197
4198
# File 'lib/seam/resources/event.rb', line 4196

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4199
4200
4201
# File 'lib/seam/resources/event.rb', line 4199

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4202
4203
4204
# File 'lib/seam/resources/event.rb', line 4202

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.accessory_keypad_disconnected

Returns:

  • (String)


4206
4207
4208
# File 'lib/seam/resources/event.rb', line 4206

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4209
4210
4211
# File 'lib/seam/resources/event.rb', line 4209

def workspace_id
  @workspace_id
end

Instance Method Details

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



4172
# File 'lib/seam/resources/event.rb', line 4172

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



4175
# File 'lib/seam/resources/event.rb', line 4175

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4212
# File 'lib/seam/resources/event.rb', line 4212

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



4178
# File 'lib/seam/resources/event.rb', line 4178

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



4181
# File 'lib/seam/resources/event.rb', line 4181

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4215
# File 'lib/seam/resources/event.rb', line 4215

date_accessor :occurred_at