Class: Seam::Resources::SeamEvent::DeviceAdded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceAdded
- Defined in:
- lib/seam/resources/event.rb
Overview
A device was added to Seam or was re-added to Seam after having been removed.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.added. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3086 3087 3088 |
# File 'lib/seam/resources/event.rb', line 3086 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3089 3090 3091 |
# File 'lib/seam/resources/event.rb', line 3089 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3092 3093 3094 |
# File 'lib/seam/resources/event.rb', line 3092 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3095 3096 3097 |
# File 'lib/seam/resources/event.rb', line 3095 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3098 3099 3100 |
# File 'lib/seam/resources/event.rb', line 3098 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3101 3102 3103 |
# File 'lib/seam/resources/event.rb', line 3101 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3104 3105 3106 |
# File 'lib/seam/resources/event.rb', line 3104 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.added
3108 3109 3110 |
# File 'lib/seam/resources/event.rb', line 3108 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3111 3112 3113 |
# File 'lib/seam/resources/event.rb', line 3111 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3114 |
# File 'lib/seam/resources/event.rb', line 3114 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3117 |
# File 'lib/seam/resources/event.rb', line 3117 date_accessor :occurred_at |