Class: Seam::Resources::SeamEvent::DeviceConnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The status of a device changed from offline to online. That is, the device.properties.online property changed from false to true. Note that some devices operate entirely in offline mode, so Seam never emits a device.connected event for these devices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3048
3049
3050
# File 'lib/seam/resources/event.rb', line 3048

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3051
3052
3053
# File 'lib/seam/resources/event.rb', line 3051

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3054
3055
3056
# File 'lib/seam/resources/event.rb', line 3054

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3057
3058
3059
# File 'lib/seam/resources/event.rb', line 3057

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3060
3061
3062
# File 'lib/seam/resources/event.rb', line 3060

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3063
3064
3065
# File 'lib/seam/resources/event.rb', line 3063

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3066
3067
3068
# File 'lib/seam/resources/event.rb', line 3066

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.connected

Returns:

  • (String)


3070
3071
3072
# File 'lib/seam/resources/event.rb', line 3070

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3073
3074
3075
# File 'lib/seam/resources/event.rb', line 3073

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3076
# File 'lib/seam/resources/event.rb', line 3076

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3079
# File 'lib/seam/resources/event.rb', line 3079

date_accessor :occurred_at