Class: Seam::Resources::SeamEvent::DeviceConvertedToUnmanaged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A managed device was successfully converted to an unmanaged device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3124
3125
3126
# File 'lib/seam/resources/event.rb', line 3124

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3127
3128
3129
# File 'lib/seam/resources/event.rb', line 3127

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3130
3131
3132
# File 'lib/seam/resources/event.rb', line 3130

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3133
3134
3135
# File 'lib/seam/resources/event.rb', line 3133

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3136
3137
3138
# File 'lib/seam/resources/event.rb', line 3136

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3139
3140
3141
# File 'lib/seam/resources/event.rb', line 3139

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3142
3143
3144
# File 'lib/seam/resources/event.rb', line 3142

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.converted_to_unmanaged

Returns:

  • (String)


3146
3147
3148
# File 'lib/seam/resources/event.rb', line 3146

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3149
3150
3151
# File 'lib/seam/resources/event.rb', line 3149

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3152
# File 'lib/seam/resources/event.rb', line 3152

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3155
# File 'lib/seam/resources/event.rb', line 3155

date_accessor :occurred_at