Class: Seam::Resources::SeamEvent::DeviceDisconnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The status of a device changed from online to offline. That is, the device.properties.online property changed from true to false.

Defined Under Namespace

Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3298
3299
3300
# File 'lib/seam/resources/event.rb', line 3298

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3301
3302
3303
# File 'lib/seam/resources/event.rb', line 3301

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3304
3305
3306
# File 'lib/seam/resources/event.rb', line 3304

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3307
3308
3309
# File 'lib/seam/resources/event.rb', line 3307

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3310
3311
3312
# File 'lib/seam/resources/event.rb', line 3310

def device_id
  @device_id
end

#error_codeString

Error code associated with the disconnection event, if any. Known values:

  • account_disconnected
  • hub_disconnected
  • device_disconnected

Returns:

  • (String)


3317
3318
3319
# File 'lib/seam/resources/event.rb', line 3317

def error_code
  @error_code
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3320
3321
3322
# File 'lib/seam/resources/event.rb', line 3320

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3323
3324
3325
# File 'lib/seam/resources/event.rb', line 3323

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.disconnected

Returns:

  • (String)


3327
3328
3329
# File 'lib/seam/resources/event.rb', line 3327

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3330
3331
3332
# File 'lib/seam/resources/event.rb', line 3330

def workspace_id
  @workspace_id
end

Instance Method Details

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



3286
# File 'lib/seam/resources/event.rb', line 3286

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



3289
# File 'lib/seam/resources/event.rb', line 3289

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3333
# File 'lib/seam/resources/event.rb', line 3333

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



3292
# File 'lib/seam/resources/event.rb', line 3292

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



3295
# File 'lib/seam/resources/event.rb', line 3295

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3336
# File 'lib/seam/resources/event.rb', line 3336

date_accessor :occurred_at