Class: Seam::Resources::SeamEvent::DeviceDoorbellRang

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A doorbell button was pressed on a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4893
4894
4895
# File 'lib/seam/resources/event.rb', line 4893

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4896
4897
4898
# File 'lib/seam/resources/event.rb', line 4896

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4899
4900
4901
# File 'lib/seam/resources/event.rb', line 4899

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4902
4903
4904
# File 'lib/seam/resources/event.rb', line 4902

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4905
4906
4907
# File 'lib/seam/resources/event.rb', line 4905

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4908
4909
4910
# File 'lib/seam/resources/event.rb', line 4908

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4911
4912
4913
# File 'lib/seam/resources/event.rb', line 4911

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.doorbell_rang

Returns:

  • (String)


4915
4916
4917
# File 'lib/seam/resources/event.rb', line 4915

def event_type
  @event_type
end

#image_urlString?

URL to a thumbnail image captured at the time the doorbell was pressed.

Returns:

  • (String, nil)


4918
4919
4920
# File 'lib/seam/resources/event.rb', line 4918

def image_url
  @image_url
end

#video_urlString?

URL to a short video clip captured at the time the doorbell was pressed.

Returns:

  • (String, nil)


4921
4922
4923
# File 'lib/seam/resources/event.rb', line 4921

def video_url
  @video_url
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4924
4925
4926
# File 'lib/seam/resources/event.rb', line 4924

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4927
# File 'lib/seam/resources/event.rb', line 4927

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4930
# File 'lib/seam/resources/event.rb', line 4930

date_accessor :occurred_at