Class: Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequired

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A third-party subscription is required to use all device features.

Defined Under Namespace

Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4010
4011
4012
# File 'lib/seam/resources/event.rb', line 4010

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4013
4014
4015
# File 'lib/seam/resources/event.rb', line 4013

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4016
4017
4018
# File 'lib/seam/resources/event.rb', line 4016

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4019
4020
4021
# File 'lib/seam/resources/event.rb', line 4019

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4022
4023
4024
# File 'lib/seam/resources/event.rb', line 4022

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4025
4026
4027
# File 'lib/seam/resources/event.rb', line 4025

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4028
4029
4030
# File 'lib/seam/resources/event.rb', line 4028

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.error.subscription_required

Returns:

  • (String)


4032
4033
4034
# File 'lib/seam/resources/event.rb', line 4032

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4035
4036
4037
# File 'lib/seam/resources/event.rb', line 4035

def workspace_id
  @workspace_id
end

Instance Method Details

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



3998
# File 'lib/seam/resources/event.rb', line 3998

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



4001
# File 'lib/seam/resources/event.rb', line 4001

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4038
# File 'lib/seam/resources/event.rb', line 4038

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



4004
# File 'lib/seam/resources/event.rb', line 4004

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



4007
# File 'lib/seam/resources/event.rb', line 4007

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4041
# File 'lib/seam/resources/event.rb', line 4041

date_accessor :occurred_at