Class: Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequiredResolved

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A third-party subscription is active or no longer required to use all device features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4048
4049
4050
# File 'lib/seam/resources/event.rb', line 4048

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4051
4052
4053
# File 'lib/seam/resources/event.rb', line 4051

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4054
4055
4056
# File 'lib/seam/resources/event.rb', line 4054

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4057
4058
4059
# File 'lib/seam/resources/event.rb', line 4057

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4060
4061
4062
# File 'lib/seam/resources/event.rb', line 4060

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4063
4064
4065
# File 'lib/seam/resources/event.rb', line 4063

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4066
4067
4068
# File 'lib/seam/resources/event.rb', line 4066

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.error.subscription_required.resolved

Returns:

  • (String)


4070
4071
4072
# File 'lib/seam/resources/event.rb', line 4070

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4073
4074
4075
# File 'lib/seam/resources/event.rb', line 4073

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4076
# File 'lib/seam/resources/event.rb', line 4076

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4079
# File 'lib/seam/resources/event.rb', line 4079

date_accessor :occurred_at