Class: Seam::Resources::SeamEvent::DeviceNameChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The name of a device was changed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4795
4796
4797
# File 'lib/seam/resources/event.rb', line 4795

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4798
4799
4800
# File 'lib/seam/resources/event.rb', line 4798

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4801
4802
4803
# File 'lib/seam/resources/event.rb', line 4801

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4804
4805
4806
# File 'lib/seam/resources/event.rb', line 4804

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4807
4808
4809
# File 'lib/seam/resources/event.rb', line 4807

def device_id
  @device_id
end

#device_nameString

The new name of the affected device.

Returns:

  • (String)


4810
4811
4812
# File 'lib/seam/resources/event.rb', line 4810

def device_name
  @device_name
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4813
4814
4815
# File 'lib/seam/resources/event.rb', line 4813

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4816
4817
4818
# File 'lib/seam/resources/event.rb', line 4816

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.name_changed

Returns:

  • (String)


4820
4821
4822
# File 'lib/seam/resources/event.rb', line 4820

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4823
4824
4825
# File 'lib/seam/resources/event.rb', line 4823

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4826
# File 'lib/seam/resources/event.rb', line 4826

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4829
# File 'lib/seam/resources/event.rb', line 4829

date_accessor :occurred_at