Class: Seam::Resources::SeamEvent::DeviceRemoved
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceRemoved
- Defined in:
- lib/seam/resources/event.rb
Overview
A device was removed externally from the connected account.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.removed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3583 3584 3585 |
# File 'lib/seam/resources/event.rb', line 3583 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3586 3587 3588 |
# File 'lib/seam/resources/event.rb', line 3586 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3589 3590 3591 |
# File 'lib/seam/resources/event.rb', line 3589 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3592 3593 3594 |
# File 'lib/seam/resources/event.rb', line 3592 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3595 3596 3597 |
# File 'lib/seam/resources/event.rb', line 3595 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3598 3599 3600 |
# File 'lib/seam/resources/event.rb', line 3598 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3601 3602 3603 |
# File 'lib/seam/resources/event.rb', line 3601 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.removed
3605 3606 3607 |
# File 'lib/seam/resources/event.rb', line 3605 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3608 3609 3610 |
# File 'lib/seam/resources/event.rb', line 3608 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3611 |
# File 'lib/seam/resources/event.rb', line 3611 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3614 |
# File 'lib/seam/resources/event.rb', line 3614 date_accessor :occurred_at |