Class: Seam::Resources::SeamEvent::DeviceSaltoPrivacyModeActivated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A Salto device activated privacy mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3738
3739
3740
# File 'lib/seam/resources/event.rb', line 3738

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3741
3742
3743
# File 'lib/seam/resources/event.rb', line 3741

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3744
3745
3746
# File 'lib/seam/resources/event.rb', line 3744

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3747
3748
3749
# File 'lib/seam/resources/event.rb', line 3747

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3750
3751
3752
# File 'lib/seam/resources/event.rb', line 3750

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3753
3754
3755
# File 'lib/seam/resources/event.rb', line 3753

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3756
3757
3758
# File 'lib/seam/resources/event.rb', line 3756

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.salto.privacy_mode_activated

Returns:

  • (String)


3760
3761
3762
# File 'lib/seam/resources/event.rb', line 3760

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3763
3764
3765
# File 'lib/seam/resources/event.rb', line 3763

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3766
# File 'lib/seam/resources/event.rb', line 3766

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3769
# File 'lib/seam/resources/event.rb', line 3769

date_accessor :occurred_at