Class: Seam::Resources::SeamEvent::DeviceSaltoPrivacyModeDeactivated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A Salto device deactivated privacy mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3776
3777
3778
# File 'lib/seam/resources/event.rb', line 3776

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3779
3780
3781
# File 'lib/seam/resources/event.rb', line 3779

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3782
3783
3784
# File 'lib/seam/resources/event.rb', line 3782

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3785
3786
3787
# File 'lib/seam/resources/event.rb', line 3785

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3788
3789
3790
# File 'lib/seam/resources/event.rb', line 3788

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3791
3792
3793
# File 'lib/seam/resources/event.rb', line 3791

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3794
3795
3796
# File 'lib/seam/resources/event.rb', line 3794

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.salto.privacy_mode_deactivated

Returns:

  • (String)


3798
3799
3800
# File 'lib/seam/resources/event.rb', line 3798

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3801
3802
3803
# File 'lib/seam/resources/event.rb', line 3801

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3804
# File 'lib/seam/resources/event.rb', line 3804

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3807
# File 'lib/seam/resources/event.rb', line 3807

date_accessor :occurred_at