Class: Seam::Resources::SeamEvent::DeviceTampered

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A device detected that it was tampered with, for example, opened or moved.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3448
3449
3450
# File 'lib/seam/resources/event.rb', line 3448

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3451
3452
3453
# File 'lib/seam/resources/event.rb', line 3451

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3454
3455
3456
# File 'lib/seam/resources/event.rb', line 3454

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3457
3458
3459
# File 'lib/seam/resources/event.rb', line 3457

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3460
3461
3462
# File 'lib/seam/resources/event.rb', line 3460

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3463
3464
3465
# File 'lib/seam/resources/event.rb', line 3463

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3466
3467
3468
# File 'lib/seam/resources/event.rb', line 3466

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.tampered

Returns:

  • (String)


3470
3471
3472
# File 'lib/seam/resources/event.rb', line 3470

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3473
3474
3475
# File 'lib/seam/resources/event.rb', line 3473

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3476
# File 'lib/seam/resources/event.rb', line 3476

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3479
# File 'lib/seam/resources/event.rb', line 3479

date_accessor :occurred_at