Class: Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationDetected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationDetected
- Defined in:
- lib/seam/resources/event.rb
Overview
Seam detected that a device is using a third-party integration that will interfere with Seam device management.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.third_party_integration_detected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3662 3663 3664 |
# File 'lib/seam/resources/event.rb', line 3662 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3665 3666 3667 |
# File 'lib/seam/resources/event.rb', line 3665 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3668 3669 3670 |
# File 'lib/seam/resources/event.rb', line 3668 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3671 3672 3673 |
# File 'lib/seam/resources/event.rb', line 3671 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3674 3675 3676 |
# File 'lib/seam/resources/event.rb', line 3674 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3677 3678 3679 |
# File 'lib/seam/resources/event.rb', line 3677 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3680 3681 3682 |
# File 'lib/seam/resources/event.rb', line 3680 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.third_party_integration_detected
3684 3685 3686 |
# File 'lib/seam/resources/event.rb', line 3684 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3687 3688 3689 |
# File 'lib/seam/resources/event.rb', line 3687 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3690 |
# File 'lib/seam/resources/event.rb', line 3690 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3693 |
# File 'lib/seam/resources/event.rb', line 3693 date_accessor :occurred_at |