Class: Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationNoLongerDetected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationNoLongerDetected
- Defined in:
- lib/seam/resources/event.rb
Overview
Seam detected that a device is no longer using a third-party integration that was interfering with Seam device management.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.third_party_integration_no_longer_detected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3700 3701 3702 |
# File 'lib/seam/resources/event.rb', line 3700 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3703 3704 3705 |
# File 'lib/seam/resources/event.rb', line 3703 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3706 3707 3708 |
# File 'lib/seam/resources/event.rb', line 3706 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3709 3710 3711 |
# File 'lib/seam/resources/event.rb', line 3709 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3712 3713 3714 |
# File 'lib/seam/resources/event.rb', line 3712 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3715 3716 3717 |
# File 'lib/seam/resources/event.rb', line 3715 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3718 3719 3720 |
# File 'lib/seam/resources/event.rb', line 3718 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.third_party_integration_no_longer_detected
3722 3723 3724 |
# File 'lib/seam/resources/event.rb', line 3722 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3725 3726 3727 |
# File 'lib/seam/resources/event.rb', line 3725 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3728 |
# File 'lib/seam/resources/event.rb', line 3728 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3731 |
# File 'lib/seam/resources/event.rb', line 3731 date_accessor :occurred_at |