Class: Seam::Resources::SeamEvent::DeviceUnmanagedConnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The status of an unmanaged device changed from offline to online. That is, the device.properties.online property changed from false to true.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3200
3201
3202
# File 'lib/seam/resources/event.rb', line 3200

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3203
3204
3205
# File 'lib/seam/resources/event.rb', line 3203

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3206
3207
3208
# File 'lib/seam/resources/event.rb', line 3206

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3209
3210
3211
# File 'lib/seam/resources/event.rb', line 3209

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3212
3213
3214
# File 'lib/seam/resources/event.rb', line 3212

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3215
3216
3217
# File 'lib/seam/resources/event.rb', line 3215

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3218
3219
3220
# File 'lib/seam/resources/event.rb', line 3218

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.unmanaged.connected

Returns:

  • (String)


3222
3223
3224
# File 'lib/seam/resources/event.rb', line 3222

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3225
3226
3227
# File 'lib/seam/resources/event.rb', line 3225

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3228
# File 'lib/seam/resources/event.rb', line 3228

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3231
# File 'lib/seam/resources/event.rb', line 3231

date_accessor :occurred_at