Class: Seam::Resources::SeamEvent::DeviceUnmanagedConvertedToManaged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An unmanaged device was successfully converted to a managed device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3162
3163
3164
# File 'lib/seam/resources/event.rb', line 3162

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3165
3166
3167
# File 'lib/seam/resources/event.rb', line 3165

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3168
3169
3170
# File 'lib/seam/resources/event.rb', line 3168

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3171
3172
3173
# File 'lib/seam/resources/event.rb', line 3171

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3174
3175
3176
# File 'lib/seam/resources/event.rb', line 3174

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3177
3178
3179
# File 'lib/seam/resources/event.rb', line 3177

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3180
3181
3182
# File 'lib/seam/resources/event.rb', line 3180

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.unmanaged.converted_to_managed

Returns:

  • (String)


3184
3185
3186
# File 'lib/seam/resources/event.rb', line 3184

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3187
3188
3189
# File 'lib/seam/resources/event.rb', line 3187

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3190
# File 'lib/seam/resources/event.rb', line 3190

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3193
# File 'lib/seam/resources/event.rb', line 3193

date_accessor :occurred_at