Class: Seam::Resources::SeamEvent::DeviceUnmanagedDisconnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The status of an unmanaged device changed from online to offline. That is, the device.properties.online property changed from true to false.

Defined Under Namespace

Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3403
3404
3405
# File 'lib/seam/resources/event.rb', line 3403

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3406
3407
3408
# File 'lib/seam/resources/event.rb', line 3406

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3409
3410
3411
# File 'lib/seam/resources/event.rb', line 3409

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3412
3413
3414
# File 'lib/seam/resources/event.rb', line 3412

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3415
3416
3417
# File 'lib/seam/resources/event.rb', line 3415

def device_id
  @device_id
end

#error_codeString

Error code associated with the disconnection event, if any. Known values:

  • account_disconnected
  • hub_disconnected
  • device_disconnected

Returns:

  • (String)


3422
3423
3424
# File 'lib/seam/resources/event.rb', line 3422

def error_code
  @error_code
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3425
3426
3427
# File 'lib/seam/resources/event.rb', line 3425

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3428
3429
3430
# File 'lib/seam/resources/event.rb', line 3428

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.unmanaged.disconnected

Returns:

  • (String)


3432
3433
3434
# File 'lib/seam/resources/event.rb', line 3432

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3435
3436
3437
# File 'lib/seam/resources/event.rb', line 3435

def workspace_id
  @workspace_id
end

Instance Method Details

#connected_account_errorsArray<ConnectedAccountErrors>

Errors associated with the connected account.

Returns:



3391
# File 'lib/seam/resources/event.rb', line 3391

resource_list_accessor :connected_account_errors, ConnectedAccountErrors

#connected_account_warningsArray<ConnectedAccountWarnings>

Warnings associated with the connected account.

Returns:



3394
# File 'lib/seam/resources/event.rb', line 3394

resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3438
# File 'lib/seam/resources/event.rb', line 3438

date_accessor :created_at

#device_errorsArray<DeviceErrors>

Errors associated with the device.

Returns:



3397
# File 'lib/seam/resources/event.rb', line 3397

resource_list_accessor :device_errors, DeviceErrors

#device_warningsArray<DeviceWarnings>

Warnings associated with the device.

Returns:



3400
# File 'lib/seam/resources/event.rb', line 3400

resource_list_accessor :device_warnings, DeviceWarnings

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3441
# File 'lib/seam/resources/event.rb', line 3441

date_accessor :occurred_at