Class: Seam::Resources::SeamEvent::RequestedMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::SeamEvent::RequestedMutations
- Defined in:
- lib/seam/resources/event.rb
Instance Attribute Summary collapse
-
#from ⇒ Object
Previous property values before the requested change.
-
#mutation_code ⇒ Object
Code identifying the type of mutation requested, such as
updating_name,updating_code,updating_time_frame, ordeleting. -
#to ⇒ Object
New property values after the requested change.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#from ⇒ Object
Previous property values before the requested change. Keys depend on the mutation type. Absent for non-property mutations like deleting.
107 108 109 |
# File 'lib/seam/resources/event.rb', line 107 def from @from end |
#mutation_code ⇒ Object
Code identifying the type of mutation requested, such as updating_name, updating_code, updating_time_frame, or deleting.
109 110 111 |
# File 'lib/seam/resources/event.rb', line 109 def mutation_code @mutation_code end |
#to ⇒ Object
New property values after the requested change. Keys depend on the mutation type. Absent for non-property mutations like deleting.
111 112 113 |
# File 'lib/seam/resources/event.rb', line 111 def to @to end |