Class: Seam::Resources::SeamEvent::SpaceCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::SpaceCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
A space was created.
Instance Attribute Summary collapse
-
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances attached to the space when it was created.
-
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was created.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Type of the event.
-
#space_id ⇒ String
ID of the affected space.
-
#space_key ⇒ String?
Unique key for the space within the workspace.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances attached to the space when it was created.
5002 5003 5004 |
# File 'lib/seam/resources/event.rb', line 5002 def acs_entrance_ids @acs_entrance_ids end |
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was created.
5005 5006 5007 |
# File 'lib/seam/resources/event.rb', line 5005 def device_ids @device_ids end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
5008 5009 5010 |
# File 'lib/seam/resources/event.rb', line 5008 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
5011 5012 5013 |
# File 'lib/seam/resources/event.rb', line 5011 def event_id @event_id end |
#event_type ⇒ String
Type of the event. Known values:
space.created
5016 5017 5018 |
# File 'lib/seam/resources/event.rb', line 5016 def event_type @event_type end |
#space_id ⇒ String
ID of the affected space.
5019 5020 5021 |
# File 'lib/seam/resources/event.rb', line 5019 def space_id @space_id end |
#space_key ⇒ String?
Unique key for the space within the workspace.
5022 5023 5024 |
# File 'lib/seam/resources/event.rb', line 5022 def space_key @space_key end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
5025 5026 5027 |
# File 'lib/seam/resources/event.rb', line 5025 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
5028 |
# File 'lib/seam/resources/event.rb', line 5028 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
5031 |
# File 'lib/seam/resources/event.rb', line 5031 date_accessor :occurred_at |