Class: Seam::Resources::SeamEvent::SpaceDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::SpaceDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
A space was deleted.
Instance Attribute Summary collapse
-
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances currently attached to the space when it was deleted.
-
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was deleted.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Type of the event.
-
#space_id ⇒ String
ID of the affected space.
-
#space_key ⇒ String?
Unique key for the space within the workspace.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances currently attached to the space when it was deleted.
5038 5039 5040 |
# File 'lib/seam/resources/event.rb', line 5038 def acs_entrance_ids @acs_entrance_ids end |
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was deleted.
5041 5042 5043 |
# File 'lib/seam/resources/event.rb', line 5041 def device_ids @device_ids end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
5044 5045 5046 |
# File 'lib/seam/resources/event.rb', line 5044 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
5047 5048 5049 |
# File 'lib/seam/resources/event.rb', line 5047 def event_id @event_id end |
#event_type ⇒ String
Type of the event. Known values:
space.deleted
5052 5053 5054 |
# File 'lib/seam/resources/event.rb', line 5052 def event_type @event_type end |
#space_id ⇒ String
ID of the affected space.
5055 5056 5057 |
# File 'lib/seam/resources/event.rb', line 5055 def space_id @space_id end |
#space_key ⇒ String?
Unique key for the space within the workspace.
5058 5059 5060 |
# File 'lib/seam/resources/event.rb', line 5058 def space_key @space_key end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
5061 5062 5063 |
# File 'lib/seam/resources/event.rb', line 5061 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
5064 |
# File 'lib/seam/resources/event.rb', line 5064 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
5067 |
# File 'lib/seam/resources/event.rb', line 5067 date_accessor :occurred_at |