Class: Seam::Resources::SeamEvent::SpaceDeviceMembershipChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A device was added or removed from a space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_entrance_idsArray<String>

IDs of all ACS entrances currently attached to the space.

Returns:

  • (Array<String>)


4966
4967
4968
# File 'lib/seam/resources/event.rb', line 4966

def acs_entrance_ids
  @acs_entrance_ids
end

#device_idsArray<String>

IDs of all devices currently attached to the space.

Returns:

  • (Array<String>)


4969
4970
4971
# File 'lib/seam/resources/event.rb', line 4969

def device_ids
  @device_ids
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4972
4973
4974
# File 'lib/seam/resources/event.rb', line 4972

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4975
4976
4977
# File 'lib/seam/resources/event.rb', line 4975

def event_id
  @event_id
end

#event_typeString

Type of the event. Known values:

  • space.device_membership_changed

Returns:

  • (String)


4980
4981
4982
# File 'lib/seam/resources/event.rb', line 4980

def event_type
  @event_type
end

#space_idString

ID of the affected space.

Returns:

  • (String)


4983
4984
4985
# File 'lib/seam/resources/event.rb', line 4983

def space_id
  @space_id
end

#space_keyString?

Unique key for the space within the workspace.

Returns:

  • (String, nil)


4986
4987
4988
# File 'lib/seam/resources/event.rb', line 4986

def space_key
  @space_key
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4989
4990
4991
# File 'lib/seam/resources/event.rb', line 4989

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4992
# File 'lib/seam/resources/event.rb', line 4992

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4995
# File 'lib/seam/resources/event.rb', line 4995

date_accessor :occurred_at