Class: Seam::Resources::SeamEvent::ThermostatClimatePresetActivated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat climate preset was activated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#climate_preset_keyString

Key of the climate preset that was activated.

Returns:

  • (String)


4470
4471
4472
# File 'lib/seam/resources/event.rb', line 4470

def climate_preset_key
  @climate_preset_key
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4473
4474
4475
# File 'lib/seam/resources/event.rb', line 4473

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4476
4477
4478
# File 'lib/seam/resources/event.rb', line 4476

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4479
4480
4481
# File 'lib/seam/resources/event.rb', line 4479

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4482
4483
4484
# File 'lib/seam/resources/event.rb', line 4482

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4485
4486
4487
# File 'lib/seam/resources/event.rb', line 4485

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4488
4489
4490
# File 'lib/seam/resources/event.rb', line 4488

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4491
4492
4493
# File 'lib/seam/resources/event.rb', line 4491

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.climate_preset_activated

Returns:

  • (String)


4495
4496
4497
# File 'lib/seam/resources/event.rb', line 4495

def event_type
  @event_type
end

#is_fallback_climate_presetBoolean

Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.

Returns:

  • (Boolean)


4498
4499
4500
# File 'lib/seam/resources/event.rb', line 4498

def is_fallback_climate_preset
  @is_fallback_climate_preset
end

#thermostat_schedule_idString?

ID of the thermostat schedule that prompted the affected climate preset to be activated.

Returns:

  • (String, nil)


4501
4502
4503
# File 'lib/seam/resources/event.rb', line 4501

def thermostat_schedule_id
  @thermostat_schedule_id
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4504
4505
4506
# File 'lib/seam/resources/event.rb', line 4504

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4507
# File 'lib/seam/resources/event.rb', line 4507

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4510
# File 'lib/seam/resources/event.rb', line 4510

date_accessor :occurred_at