Class: Seam::Resources::SeamEvent::ThermostatManuallyAdjusted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat was adjusted manually.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4517
4518
4519
# File 'lib/seam/resources/event.rb', line 4517

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4520
4521
4522
# File 'lib/seam/resources/event.rb', line 4520

def 
  @connected_account_id
end

#cooling_set_point_celsiusFloat?

Temperature to which the thermostat should cool (in °C). See also Set Points.

Returns:

  • (Float, nil)


4523
4524
4525
# File 'lib/seam/resources/event.rb', line 4523

def cooling_set_point_celsius
  @cooling_set_point_celsius
end

#cooling_set_point_fahrenheitFloat?

Temperature to which the thermostat should cool (in °F). See also Set Points.

Returns:

  • (Float, nil)


4526
4527
4528
# File 'lib/seam/resources/event.rb', line 4526

def cooling_set_point_fahrenheit
  @cooling_set_point_fahrenheit
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4529
4530
4531
# File 'lib/seam/resources/event.rb', line 4529

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4532
4533
4534
# File 'lib/seam/resources/event.rb', line 4532

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4535
4536
4537
# File 'lib/seam/resources/event.rb', line 4535

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4538
4539
4540
# File 'lib/seam/resources/event.rb', line 4538

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4541
4542
4543
# File 'lib/seam/resources/event.rb', line 4541

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.manually_adjusted

Returns:

  • (String)


4545
4546
4547
# File 'lib/seam/resources/event.rb', line 4545

def event_type
  @event_type
end

#fan_mode_settingString?

Desired fan mode setting, such as on, auto, or circulate. Known values:

  • auto
  • on
  • circulate

Returns:

  • (String, nil)


4552
4553
4554
# File 'lib/seam/resources/event.rb', line 4552

def fan_mode_setting
  @fan_mode_setting
end

#heating_set_point_celsiusFloat?

Temperature to which the thermostat should heat (in °C). See also Set Points.

Returns:

  • (Float, nil)


4555
4556
4557
# File 'lib/seam/resources/event.rb', line 4555

def heating_set_point_celsius
  @heating_set_point_celsius
end

#heating_set_point_fahrenheitFloat?

Temperature to which the thermostat should heat (in °F). See also Set Points.

Returns:

  • (Float, nil)


4558
4559
4560
# File 'lib/seam/resources/event.rb', line 4558

def heating_set_point_fahrenheit
  @heating_set_point_fahrenheit
end

#hvac_mode_settingString?

Desired HVAC mode setting, such as heat, cool, heat_cool, or off. Known values:

  • off
  • heat
  • cool
  • heat_cool
  • eco

Returns:

  • (String, nil)


4567
4568
4569
# File 'lib/seam/resources/event.rb', line 4567

def hvac_mode_setting
  @hvac_mode_setting
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4576
4577
4578
# File 'lib/seam/resources/event.rb', line 4576

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4579
# File 'lib/seam/resources/event.rb', line 4579

date_accessor :created_at

#event_methodString

Method used to adjust the affected thermostat manually. seam indicates that the Seam API, Seam CLI, or Seam Console was used to adjust the thermostat. Known values:

  • seam
  • external

Returns:

  • (String)


4573
# File 'lib/seam/resources/event.rb', line 4573

aliased_accessor :event_method, from: :method

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4582
# File 'lib/seam/resources/event.rb', line 4582

date_accessor :occurred_at