Class: Seam::Resources::SeamEvent::ThermostatTemperatureChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat's reported temperature changed by at least 1 °C.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4751
4752
4753
# File 'lib/seam/resources/event.rb', line 4751

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4754
4755
4756
# File 'lib/seam/resources/event.rb', line 4754

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4757
4758
4759
# File 'lib/seam/resources/event.rb', line 4757

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4760
4761
4762
# File 'lib/seam/resources/event.rb', line 4760

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4763
4764
4765
# File 'lib/seam/resources/event.rb', line 4763

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4766
4767
4768
# File 'lib/seam/resources/event.rb', line 4766

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4769
4770
4771
# File 'lib/seam/resources/event.rb', line 4769

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.temperature_changed

Returns:

  • (String)


4773
4774
4775
# File 'lib/seam/resources/event.rb', line 4773

def event_type
  @event_type
end

#temperature_celsiusFloat

Temperature, in °C, reported by the affected thermostat.

Returns:

  • (Float)


4776
4777
4778
# File 'lib/seam/resources/event.rb', line 4776

def temperature_celsius
  @temperature_celsius
end

#temperature_fahrenheitFloat

Temperature, in °F, reported by the affected thermostat.

Returns:

  • (Float)


4779
4780
4781
# File 'lib/seam/resources/event.rb', line 4779

def temperature_fahrenheit
  @temperature_fahrenheit
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4782
4783
4784
# File 'lib/seam/resources/event.rb', line 4782

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4785
# File 'lib/seam/resources/event.rb', line 4785

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4788
# File 'lib/seam/resources/event.rb', line 4788

date_accessor :occurred_at