Class: Seam::Resources::SeamEvent::ThermostatTemperatureReachedSetPoint
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatTemperatureReachedSetPoint
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat's temperature reading is within 1 °C of the configured cooling or heating set point.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#desired_temperature_celsius ⇒ Float?
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
-
#desired_temperature_fahrenheit ⇒ Float?
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.temperature_reached_set_point. -
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4701 4702 4703 |
# File 'lib/seam/resources/event.rb', line 4701 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4704 4705 4706 |
# File 'lib/seam/resources/event.rb', line 4704 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4707 4708 4709 |
# File 'lib/seam/resources/event.rb', line 4707 def customer_key @customer_key end |
#desired_temperature_celsius ⇒ Float?
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
4710 4711 4712 |
# File 'lib/seam/resources/event.rb', line 4710 def desired_temperature_celsius @desired_temperature_celsius end |
#desired_temperature_fahrenheit ⇒ Float?
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
4713 4714 4715 |
# File 'lib/seam/resources/event.rb', line 4713 def desired_temperature_fahrenheit @desired_temperature_fahrenheit end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4716 4717 4718 |
# File 'lib/seam/resources/event.rb', line 4716 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4719 4720 4721 |
# File 'lib/seam/resources/event.rb', line 4719 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4722 4723 4724 |
# File 'lib/seam/resources/event.rb', line 4722 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4725 4726 4727 |
# File 'lib/seam/resources/event.rb', line 4725 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.temperature_reached_set_point
4729 4730 4731 |
# File 'lib/seam/resources/event.rb', line 4729 def event_type @event_type end |
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
4732 4733 4734 |
# File 'lib/seam/resources/event.rb', line 4732 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
4735 4736 4737 |
# File 'lib/seam/resources/event.rb', line 4735 def temperature_fahrenheit @temperature_fahrenheit end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4738 4739 4740 |
# File 'lib/seam/resources/event.rb', line 4738 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4741 |
# File 'lib/seam/resources/event.rb', line 4741 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4744 |
# File 'lib/seam/resources/event.rb', line 4744 date_accessor :occurred_at |