Class: Seam::Resources::SeamEvent::ThermostatTemperatureThresholdNoLongerExceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat's temperature reading no longer exceeds the set threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4645
4646
4647
# File 'lib/seam/resources/event.rb', line 4645

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4648
4649
4650
# File 'lib/seam/resources/event.rb', line 4648

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4651
4652
4653
# File 'lib/seam/resources/event.rb', line 4651

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4654
4655
4656
# File 'lib/seam/resources/event.rb', line 4654

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4657
4658
4659
# File 'lib/seam/resources/event.rb', line 4657

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4660
4661
4662
# File 'lib/seam/resources/event.rb', line 4660

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4663
4664
4665
# File 'lib/seam/resources/event.rb', line 4663

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.temperature_threshold_no_longer_exceeded

Returns:

  • (String)


4667
4668
4669
# File 'lib/seam/resources/event.rb', line 4667

def event_type
  @event_type
end

#lower_limit_celsiusFloat?

Lower temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


4670
4671
4672
# File 'lib/seam/resources/event.rb', line 4670

def lower_limit_celsius
  @lower_limit_celsius
end

#lower_limit_fahrenheitFloat?

Lower temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


4673
4674
4675
# File 'lib/seam/resources/event.rb', line 4673

def lower_limit_fahrenheit
  @lower_limit_fahrenheit
end

#temperature_celsiusFloat

Temperature, in °C, reported by the affected thermostat.

Returns:

  • (Float)


4676
4677
4678
# File 'lib/seam/resources/event.rb', line 4676

def temperature_celsius
  @temperature_celsius
end

#temperature_fahrenheitFloat

Temperature, in °F, reported by the affected thermostat.

Returns:

  • (Float)


4679
4680
4681
# File 'lib/seam/resources/event.rb', line 4679

def temperature_fahrenheit
  @temperature_fahrenheit
end

#upper_limit_celsiusFloat?

Upper temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


4682
4683
4684
# File 'lib/seam/resources/event.rb', line 4682

def upper_limit_celsius
  @upper_limit_celsius
end

#upper_limit_fahrenheitFloat?

Upper temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


4685
4686
4687
# File 'lib/seam/resources/event.rb', line 4685

def upper_limit_fahrenheit
  @upper_limit_fahrenheit
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4688
4689
4690
# File 'lib/seam/resources/event.rb', line 4688

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4691
# File 'lib/seam/resources/event.rb', line 4691

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4694
# File 'lib/seam/resources/event.rb', line 4694

date_accessor :occurred_at