Class: Seam::Resources::ThermostatDailyProgram::Periods

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/thermostat_daily_program.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_preset_keyObject

Key of the climate preset to activate at the starts_at_time.



9
10
11
# File 'lib/seam/resources/thermostat_daily_program.rb', line 9

def climate_preset_key
  @climate_preset_key
end

#starts_at_timeObject

Time at which the thermostat daily program period starts, in ISO 8601 format.



11
12
13
# File 'lib/seam/resources/thermostat_daily_program.rb', line 11

def starts_at_time
  @starts_at_time
end