Class: Seam::Resources::ThermostatSchedule

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/thermostat_schedule.rb

Overview

Represents a thermostat schedule that activates a configured climate preset on a thermostat at a specified starting time and deactivates the climate preset at a specified ending time.

Defined Under Namespace

Classes: Errors

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_preset_keyString

Key of the climate preset to use for the thermostat schedule.

Returns:

  • (String)


24
25
26
# File 'lib/seam/resources/thermostat_schedule.rb', line 24

def climate_preset_key
  @climate_preset_key
end

#device_idString

ID of the desired thermostat device.

Returns:

  • (String)


27
28
29
# File 'lib/seam/resources/thermostat_schedule.rb', line 27

def device_id
  @device_id
end

#is_override_allowedBoolean?

Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.

Returns:

  • (Boolean, nil)


30
31
32
# File 'lib/seam/resources/thermostat_schedule.rb', line 30

def is_override_allowed
  @is_override_allowed
end

#max_override_period_minutesInteger?

Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.

Returns:

  • (Integer, nil)


33
34
35
# File 'lib/seam/resources/thermostat_schedule.rb', line 33

def max_override_period_minutes
  @max_override_period_minutes
end

#nameString?

User-friendly name to identify the thermostat schedule.

Returns:

  • (String, nil)


36
37
38
# File 'lib/seam/resources/thermostat_schedule.rb', line 36

def name
  @name
end

#thermostat_schedule_idString

ID of the thermostat schedule.

Returns:

  • (String)


39
40
41
# File 'lib/seam/resources/thermostat_schedule.rb', line 39

def thermostat_schedule_id
  @thermostat_schedule_id
end

#workspace_idString

ID of the workspace that contains the thermostat schedule.

Returns:

  • (String)


42
43
44
# File 'lib/seam/resources/thermostat_schedule.rb', line 42

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the thermostat schedule was created.

Returns:

  • (Time)


46
# File 'lib/seam/resources/thermostat_schedule.rb', line 46

date_accessor :created_at

#ends_atTime

Date and time at which the thermostat schedule ends, in ISO 8601 format.

Returns:

  • (Time)


50
# File 'lib/seam/resources/thermostat_schedule.rb', line 50

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the thermostat schedule.

Returns:



21
# File 'lib/seam/resources/thermostat_schedule.rb', line 21

resource_list_accessor :errors, Errors

#starts_atTime

Date and time at which the thermostat schedule starts, in ISO 8601 format.

Returns:

  • (Time)


54
# File 'lib/seam/resources/thermostat_schedule.rb', line 54

date_accessor :starts_at