Class: Seam::Resources::UnmanagedAccessCode::DormakabaOracodeMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessCode::DormakabaOracodeMetadata
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Instance Attribute Summary collapse
-
#is_cancellable ⇒ Boolean?
Indicates whether the stay can be cancelled via the Dormakaba Oracode API.
-
#is_early_checkin_able ⇒ Boolean?
Indicates whether early check-in is available for this stay.
-
#is_extendable ⇒ Boolean?
Indicates whether the stay can be extended via the Dormakaba Oracode API.
-
#is_overridable ⇒ Boolean?
Indicates whether the access code can be overridden.
-
#site_name ⇒ String?
Dormakaba Oracode site name associated with this access code.
-
#stay_id ⇒ Float?
Dormakaba Oracode stay ID associated with this access code.
-
#user_level_id ⇒ String?
Dormakaba Oracode user level ID associated with this access code.
-
#user_level_name ⇒ String?
Dormakaba Oracode user level name associated with this access code.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#is_cancellable ⇒ Boolean?
Indicates whether the stay can be cancelled via the Dormakaba Oracode API.
20 21 22 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 20 def is_cancellable @is_cancellable end |
#is_early_checkin_able ⇒ Boolean?
Indicates whether early check-in is available for this stay.
23 24 25 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 23 def is_early_checkin_able @is_early_checkin_able end |
#is_extendable ⇒ Boolean?
Indicates whether the stay can be extended via the Dormakaba Oracode API.
26 27 28 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 26 def is_extendable @is_extendable end |
#is_overridable ⇒ Boolean?
Indicates whether the access code can be overridden. When false, the maximum number of overrides has been reached.
29 30 31 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 29 def is_overridable @is_overridable end |
#site_name ⇒ String?
Dormakaba Oracode site name associated with this access code.
32 33 34 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 32 def site_name @site_name end |
#stay_id ⇒ Float?
Dormakaba Oracode stay ID associated with this access code.
35 36 37 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 35 def stay_id @stay_id end |
#user_level_id ⇒ String?
Dormakaba Oracode user level ID associated with this access code.
38 39 40 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 38 def user_level_id @user_level_id end |
#user_level_name ⇒ String?
Dormakaba Oracode user level name associated with this access code.
41 42 43 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 41 def user_level_name @user_level_name end |