Class: Seam::Resources::UnmanagedAccessCode::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#change_typeString?

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.

Returns:

  • (String, nil)


62
63
64
# File 'lib/seam/resources/unmanaged_access_code.rb', line 62

def change_type
  @change_type
end

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


65
66
67
# File 'lib/seam/resources/unmanaged_access_code.rb', line 65

def error_code
  @error_code
end

#is_access_code_errorBoolean

Indicates that this is an access code error.

Returns:

  • (Boolean)


68
69
70
# File 'lib/seam/resources/unmanaged_access_code.rb', line 68

def is_access_code_error
  @is_access_code_error
end

#is_bridge_errorBoolean?

Indicates whether the error is related to Seam Bridge.

Returns:

  • (Boolean, nil)


71
72
73
# File 'lib/seam/resources/unmanaged_access_code.rb', line 71

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorBoolean?

Returns:

  • (Boolean, nil)


73
74
75
# File 'lib/seam/resources/unmanaged_access_code.rb', line 73

def 
  @is_connected_account_error
end

#is_device_errorBoolean

Returns:

  • (Boolean)


75
76
77
# File 'lib/seam/resources/unmanaged_access_code.rb', line 75

def is_device_error
  @is_device_error
end

#managed_access_code_idString?

ID of the managed access code that conflicts with this managed access code, when Seam can identify it.

Returns:

  • (String, nil)


78
79
80
# File 'lib/seam/resources/unmanaged_access_code.rb', line 78

def managed_access_code_id
  @managed_access_code_id
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


81
82
83
# File 'lib/seam/resources/unmanaged_access_code.rb', line 81

def message
  @message
end

#unmanaged_access_code_idString?

ID of the unmanaged access code that conflicts with this managed access code, when Seam can identify it.

Returns:

  • (String, nil)


84
85
86
# File 'lib/seam/resources/unmanaged_access_code.rb', line 84

def unmanaged_access_code_id
  @unmanaged_access_code_id
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the error.

Returns:

  • (Time, nil)


87
# File 'lib/seam/resources/unmanaged_access_code.rb', line 87

date_accessor :created_at

#modified_fieldsArray<ModifiedFields>

List of fields that were changed externally, with their previous and new values.

Returns:



59
# File 'lib/seam/resources/unmanaged_access_code.rb', line 59

resource_list_accessor :modified_fields, ModifiedFields