Class: Seam::Resources::UnmanagedAccessCode::Errors::AccessCodeInactive
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::AccessCodeInactive
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the access code is disabled or inactive on the device. The code exists but will not grant access until re-enabled.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
access_code_inactive
187 188 189 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 187 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
190 191 192 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 190 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
193 194 195 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 193 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
196 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 196 date_accessor :created_at |