Class: Seam::Resources::UnmanagedAccessCode::Errors::AuxiliaryHeatRunning

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Indicates that the auxiliary heat is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • auxiliary_heat_running

Returns:

  • (String)


415
416
417
# File 'lib/seam/resources/unmanaged_access_code.rb', line 415

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


418
419
420
# File 'lib/seam/resources/unmanaged_access_code.rb', line 418

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


421
422
423
# File 'lib/seam/resources/unmanaged_access_code.rb', line 421

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


424
# File 'lib/seam/resources/unmanaged_access_code.rb', line 424

date_accessor :created_at