Class: Seam::Resources::UnmanagedAccessCode::Errors::BridgeDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::BridgeDisconnected
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the Seam API cannot communicate with Seam Bridge, for example, if the Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
bridge_disconnected
523 524 525 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 523 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
526 527 528 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 526 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
529 530 531 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 529 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
532 533 534 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 532 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
535 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 535 date_accessor :created_at |