Class: Seam::Resources::UnmanagedAccessCode::Errors::ConflictingExternalModification

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Code was modified or removed externally after Seam successfully set it on the device. The external change conflicts with the state that Seam is trying to apply, so Seam will attempt to set the code on the device again.

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#change_typeString?

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device. Known values:

  • modified
  • removed

Returns:

  • (String, nil)


164
165
166
# File 'lib/seam/resources/unmanaged_access_code.rb', line 164

def change_type
  @change_type
end

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • conflicting_external_modification

Returns:

  • (String)


169
170
171
# File 'lib/seam/resources/unmanaged_access_code.rb', line 169

def error_code
  @error_code
end

#is_access_code_errorTrueClass

Indicates that this is an access code error.

Returns:

  • (TrueClass)


172
173
174
# File 'lib/seam/resources/unmanaged_access_code.rb', line 172

def is_access_code_error
  @is_access_code_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


175
176
177
# File 'lib/seam/resources/unmanaged_access_code.rb', line 175

def message
  @message
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the error.

Returns:

  • (Time, nil)


178
# File 'lib/seam/resources/unmanaged_access_code.rb', line 178

date_accessor :created_at

#modified_fieldsArray<ModifiedFields>

List of fields that were changed externally, with their previous and new values.

Returns:



158
# File 'lib/seam/resources/unmanaged_access_code.rb', line 158

resource_list_accessor :modified_fields, ModifiedFields