Class: Seam::Resources::UnmanagedAccessCode::Errors::DeviceRemoved
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::DeviceRemoved
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the device has been removed.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
device_removed
307 308 309 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 307 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
310 311 312 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 310 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
313 314 315 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 313 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
316 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 316 date_accessor :created_at |