Class: Seam::Resources::UnmanagedAccessCode::Errors::DuplicateCodeOnDevice
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::DuplicateCodeOnDevice
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Duplicate access code detected on device.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#managed_access_code_id ⇒ String?
ID of the managed access code that conflicts with this managed access code, when Seam can identify it.
-
#message ⇒ String
Detailed description of the error.
-
#unmanaged_access_code_id ⇒ String?
ID of the unmanaged access code that conflicts with this managed access code, when Seam can identify it.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
duplicate_code_on_device
106 107 108 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 106 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
109 110 111 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 109 def is_access_code_error @is_access_code_error end |
#managed_access_code_id ⇒ String?
ID of the managed access code that conflicts with this managed access code, when Seam can identify it.
112 113 114 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 112 def managed_access_code_id @managed_access_code_id end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
115 116 117 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 115 def @message end |
#unmanaged_access_code_id ⇒ String?
ID of the unmanaged access code that conflicts with this managed access code, when Seam can identify it.
118 119 120 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 118 def unmanaged_access_code_id @unmanaged_access_code_id end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
121 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 121 date_accessor :created_at |