Class: Seam::Resources::UnmanagedAccessCode::Errors::FailedToExpire
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::FailedToExpire
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
This access code is still active on the device even though its ends_at has passed, so the recipient may still be able to unlock the device after their access window ended. Seam is attempting to remove it, and this error clears automatically once the access code is no longer active.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_expire
259 260 261 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 259 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
262 263 264 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 262 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
265 266 267 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 265 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
268 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 268 date_accessor :created_at |