Class: Seam::Resources::UnmanagedAccessCode::Errors::FailedToIssue
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::FailedToIssue
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Seam was unable to issue this access code before its start time, so the recipient may be unable to unlock the device. This usually points to a problem that needs attention, such as an offline or disconnected device. Seam keeps retrying, and this error clears automatically if the access code is eventually issued.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_issue
223 224 225 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 223 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
226 227 228 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 226 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
229 230 231 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 229 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
232 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 232 date_accessor :created_at |