Class: Seam::Resources::UnmanagedAccessCode::Errors::HubDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::HubDisconnected
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the hub is disconnected.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
hub_disconnected
325 326 327 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 325 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
328 329 330 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 328 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
331 332 333 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 331 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
334 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 334 date_accessor :created_at |