Class: Seam::Resources::UnmanagedAccessCode::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.

Defined Under Namespace

Classes: BeingDeleted, CodeRotatesPeriodically, DelayInRemovingFromDevice, DelayInSettingOnDevice, ExternalModificationInEffect, IglooAlgopinMustBeUsedWithinN24Hours, ManagementTransferred, ThirdPartyIntegrationDetected, TimeFrameAdjustedForUnknownTimeZone, UnknownIssueWithAccessCode, UsingBackupAccessCode

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


713
714
715
# File 'lib/seam/resources/unmanaged_access_code.rb', line 713

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • code_rotates_periodically
  • time_frame_adjusted_for_unknown_time_zone
  • external_modification_in_effect
  • delay_in_setting_on_device
  • delay_in_removing_from_device
  • third_party_integration_detected
  • igloo_algopin_must_be_used_within_24_hours
  • management_transferred
  • using_backup_access_code
  • being_deleted
  • unknown_issue_with_access_code

Returns:

  • (String)


728
729
730
# File 'lib/seam/resources/unmanaged_access_code.rb', line 728

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


731
# File 'lib/seam/resources/unmanaged_access_code.rb', line 731

date_accessor :created_at