Class: Seam::Resources::UnmanagedAccessCode::Warnings::CodeRotatesPeriodically

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

The access code's PIN rotates periodically when the code is renewed. Retrieve the latest code before each use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


529
530
531
# File 'lib/seam/resources/unmanaged_access_code.rb', line 529

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • code_rotates_periodically

Returns:

  • (String)


534
535
536
# File 'lib/seam/resources/unmanaged_access_code.rb', line 534

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


537
# File 'lib/seam/resources/unmanaged_access_code.rb', line 537

date_accessor :created_at