Class: Seam::Resources::UnmanagedAccessCode::Warnings::DelayInRemovingFromDevice

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Delay in removing code from device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


610
611
612
# File 'lib/seam/resources/unmanaged_access_code.rb', line 610

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • delay_in_removing_from_device

Returns:

  • (String)


615
616
617
# File 'lib/seam/resources/unmanaged_access_code.rb', line 615

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


618
# File 'lib/seam/resources/unmanaged_access_code.rb', line 618

date_accessor :created_at