Class: Seam::Resources::UnmanagedAccessCode::Warnings::ExternalModificationInEffect

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Code was modified or removed externally after Seam successfully set it on the device. External modification is allowed for this code, so the externally modified state is being honored.

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#change_typeString?

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device. Known values:

  • modified
  • removed

Returns:

  • (String, nil)


657
658
659
# File 'lib/seam/resources/unmanaged_access_code.rb', line 657

def change_type
  @change_type
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


660
661
662
# File 'lib/seam/resources/unmanaged_access_code.rb', line 660

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • external_modification_in_effect

Returns:

  • (String)


665
666
667
# File 'lib/seam/resources/unmanaged_access_code.rb', line 665

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


668
# File 'lib/seam/resources/unmanaged_access_code.rb', line 668

date_accessor :created_at

#modified_fieldsArray<ModifiedFields>

List of fields that were changed externally, with their previous and new values.

Returns:



651
# File 'lib/seam/resources/unmanaged_access_code.rb', line 651

resource_list_accessor :modified_fields, ModifiedFields