Class: Seam::Resources::UnmanagedAccessCode::Warnings::ExternalModificationInEffect::ModifiedFields
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessCode::Warnings::ExternalModificationInEffect::ModifiedFields
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Instance Attribute Summary collapse
-
#field ⇒ String
The name of the field that was changed (e.g.
code,starts_at,ends_at). -
#from ⇒ String?
The previous value of the field.
-
#to ⇒ String?
The new value of the field.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#field ⇒ String
The name of the field that was changed (e.g. code, starts_at, ends_at).
560 561 562 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 560 def field @field end |
#from ⇒ String?
The previous value of the field.
563 564 565 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 563 def from @from end |
#to ⇒ String?
The new value of the field.
566 567 568 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 566 def to @to end |