Class: Seam::Resources::UnmanagedAccessCode::Warnings::IglooAlgopinMustBeUsedWithinN24Hours

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Algopins must be used within 24 hours.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


640
641
642
# File 'lib/seam/resources/unmanaged_access_code.rb', line 640

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • igloo_algopin_must_be_used_within_24_hours

Returns:

  • (String)


645
646
647
# File 'lib/seam/resources/unmanaged_access_code.rb', line 645

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


648
# File 'lib/seam/resources/unmanaged_access_code.rb', line 648

date_accessor :created_at