Class: Seam::Resources::UnmanagedAccessCode::Warnings::ManagementTransferred
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessCode::Warnings::ManagementTransferred
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Management was transferred to another workspace.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
750 751 752 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 750 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
management_transferred
755 756 757 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 755 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
758 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 758 date_accessor :created_at |