Class: Seam::Resources::UnmanagedAccessCode::Warnings::ModifiedFields
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessCode::Warnings::ModifiedFields
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Instance Attribute Summary collapse
-
#field ⇒ Object
The name of the field that was changed (e.g.
code,starts_at,ends_at). -
#from ⇒ Object
The previous value of the field.
-
#to ⇒ Object
The new value of the field.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#field ⇒ Object
The name of the field that was changed (e.g. code, starts_at, ends_at).
70 71 72 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 70 def field @field end |
#from ⇒ Object
The previous value of the field.
72 73 74 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 72 def from @from end |
#to ⇒ Object
The new value of the field.
74 75 76 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 74 def to @to end |