Class: Seam::Resources::UnmanagedAccessCode::Warnings::ThirdPartyIntegrationDetected
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessCode::Warnings::ThirdPartyIntegrationDetected
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Third-party integration detected that may cause access codes to fail.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
625 626 627 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 625 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
third_party_integration_detected
630 631 632 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 630 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
633 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 633 date_accessor :created_at |