Class: Seam::Resources::UnmanagedAccessCode::Warnings::UnknownIssueWithAccessCode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessCode::Warnings::UnknownIssueWithAccessCode
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
An unknown issue occurred with the access code.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
795 796 797 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 795 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
unknown_issue_with_access_code
800 801 802 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 800 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
803 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 803 date_accessor :created_at |