Class: Seam::Resources::UnmanagedAccessCode::Warnings::UsingBackupAccessCode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

A backup access code has been pulled and is being used in place of this access code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


670
671
672
# File 'lib/seam/resources/unmanaged_access_code.rb', line 670

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • using_backup_access_code

Returns:

  • (String)


675
676
677
# File 'lib/seam/resources/unmanaged_access_code.rb', line 675

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


678
# File 'lib/seam/resources/unmanaged_access_code.rb', line 678

date_accessor :created_at