Class: Seam::Resources::UnmanagedAccessGrant::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.

Defined Under Namespace

Classes: CannotCreateRequestedAccessMethods

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • cannot_create_requested_access_methods

Returns:

  • (String)


31
32
33
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 31

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


34
35
36
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 34

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


37
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 37

date_accessor :created_at