Class: Seam::Resources::UnmanagedAccessGrant::Warnings::DeviceDoesNotSupportAccessCodes

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Indicates that a device in the access grant does not support access codes and was excluded from code materialization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#device_idString

ID of the device that does not support access codes.

Returns:

  • (String)


225
226
227
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 225

def device_id
  @device_id
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


228
229
230
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 228

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • device_does_not_support_access_codes

Returns:

  • (String)


233
234
235
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 233

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


236
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 236

date_accessor :created_at