Class: Seam::Resources::UnmanagedAccessGrant::Warnings::DeviceTimeConstraintsViolated

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Indicates that a device in the access grant cannot program an access code for the grant's time range because of device-specific time constraints.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#device_idString

ID of the device whose time constraints the access grant violates.

Returns:

  • (String)


243
244
245
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 243

def device_id
  @device_id
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


246
247
248
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 246

def message
  @message
end

#reasonString

Specific reason why the grant's times are not programmable on the device. Known values:

  • duration_exceeds_max
  • times_do_not_match_slots
  • ongoing_not_supported

Returns:

  • (String)


253
254
255
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 253

def reason
  @reason
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • device_time_constraints_violated

Returns:

  • (String)


258
259
260
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 258

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


261
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 261

date_accessor :created_at