Class: Seam::Resources::UnmanagedAccessGrant::Warnings::FailedDevices
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessGrant::Warnings::FailedDevices
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Instance Attribute Summary collapse
-
#device_id ⇒ String
Device whose access code could not be revoked.
-
#error_code ⇒ String
Reason the access code could not be revoked (e.g.
offline_access_code_not_revocable). -
#message ⇒ String
Human-readable description of why revocation failed.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ String
Device whose access code could not be revoked.
92 93 94 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 92 def device_id @device_id end |
#error_code ⇒ String
Reason the access code could not be revoked (e.g. offline_access_code_not_revocable).
95 96 97 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 95 def error_code @error_code end |
#message ⇒ String
Human-readable description of why revocation failed.
98 99 100 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 98 def @message end |