Class: Seam::Resources::UnmanagedAccessGrant::Warnings::OverprovisionedAccess

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Indicates that the access grant has access to locations it should not have. Access methods are being removed from the extra locations.

Defined Under Namespace

Classes: FailedDevices

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


168
169
170
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 168

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • overprovisioned_access

Returns:

  • (String)


173
174
175
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 173

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


176
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 176

date_accessor :created_at

#failed_devicesArray<FailedDevices>

Devices whose access codes could not be revoked during reconciliation. Present when the provider does not support revoking an offline access code (e.g. Dormakaba oracode with exhausted override budget).

Returns:



165
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 165

resource_list_accessor :failed_devices, FailedDevices