Class: Seam::Resources::UnmanagedAccessGrant::Warnings::RequestedCodeUnavailable
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessGrant::Warnings::RequestedCodeUnavailable
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Overview
Indicates that the requested PIN code was already in use on a device, so a different code was assigned.
Instance Attribute Summary collapse
-
#device_id ⇒ String
ID of the device where the requested code was unavailable.
-
#message ⇒ String
Detailed description of the warning.
-
#new_code ⇒ String
The new PIN code that was assigned instead.
-
#original_code ⇒ String
The originally requested PIN code that was unavailable.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#device_id ⇒ String
ID of the device where the requested code was unavailable.
201 202 203 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 201 def device_id @device_id end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
204 205 206 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 204 def @message end |
#new_code ⇒ String
The new PIN code that was assigned instead.
207 208 209 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 207 def new_code @new_code end |
#original_code ⇒ String
The originally requested PIN code that was unavailable.
210 211 212 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 210 def original_code @original_code end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
requested_code_unavailable
215 216 217 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 215 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
218 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 218 date_accessor :created_at |