Class: Seam::Resources::UnmanagedAccessGrant::Warnings::UpdatingAccessTimes
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessGrant::Warnings::UpdatingAccessTimes
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Overview
Indicates that the access times for this access grant are being updated.
Instance Attribute Summary collapse
-
#access_method_ids ⇒ Array<String>
IDs of the access methods being updated.
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#access_method_ids ⇒ Array<String>
IDs of the access methods being updated.
183 184 185 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 183 def access_method_ids @access_method_ids end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
186 187 188 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 186 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
updating_access_times
191 192 193 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 191 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
194 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 194 date_accessor :created_at |