Class: Seam::Resources::UnmanagedAccessMethod

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_method.rb

Overview

Represents an unmanaged access method. Unmanaged access methods do not have client sessions, instant keys, customization profiles, or keys.

Defined Under Namespace

Classes: Errors, PendingMutations, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_method_idString

ID of the access method.

Returns:

  • (String)


179
180
181
# File 'lib/seam/resources/unmanaged_access_method.rb', line 179

def access_method_id
  @access_method_id
end

#codeString?

The actual PIN code for code access methods.

Returns:

  • (String, nil)


182
183
184
# File 'lib/seam/resources/unmanaged_access_method.rb', line 182

def code
  @code
end

#display_nameString

Display name of the access method.

Returns:

  • (String)


185
186
187
# File 'lib/seam/resources/unmanaged_access_method.rb', line 185

def display_name
  @display_name
end

#is_assignment_requiredBoolean?

Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.

Returns:

  • (Boolean, nil)


188
189
190
# File 'lib/seam/resources/unmanaged_access_method.rb', line 188

def is_assignment_required
  @is_assignment_required
end

#is_encoding_requiredBoolean?

Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.

Returns:

  • (Boolean, nil)


191
192
193
# File 'lib/seam/resources/unmanaged_access_method.rb', line 191

def is_encoding_required
  @is_encoding_required
end

#is_issuedBoolean

Indicates whether the access method has been issued.

Returns:

  • (Boolean)


194
195
196
# File 'lib/seam/resources/unmanaged_access_method.rb', line 194

def is_issued
  @is_issued
end

#is_ready_for_assignmentBoolean?

Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.

Returns:

  • (Boolean, nil)


197
198
199
# File 'lib/seam/resources/unmanaged_access_method.rb', line 197

def is_ready_for_assignment
  @is_ready_for_assignment
end

#is_ready_for_encodingBoolean?

Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.

Returns:

  • (Boolean, nil)


200
201
202
# File 'lib/seam/resources/unmanaged_access_method.rb', line 200

def is_ready_for_encoding
  @is_ready_for_encoding
end

#modeString

Access method mode. Supported values: code, card, mobile_key, cloud_key. Known values:

  • code
  • card
  • mobile_key
  • cloud_key

Returns:

  • (String)


208
209
210
# File 'lib/seam/resources/unmanaged_access_method.rb', line 208

def mode
  @mode
end

#workspace_idString

ID of the Seam workspace associated with the access method.

Returns:

  • (String)


211
212
213
# File 'lib/seam/resources/unmanaged_access_method.rb', line 211

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the access method was created.

Returns:

  • (Time)


215
# File 'lib/seam/resources/unmanaged_access_method.rb', line 215

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the access method.

Returns:



170
# File 'lib/seam/resources/unmanaged_access_method.rb', line 170

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the access method was issued.

Returns:

  • (Time, nil)


219
# File 'lib/seam/resources/unmanaged_access_method.rb', line 219

date_accessor :issued_at

#pending_mutationsArray<PendingMutations>

Pending mutations for the access method. Indicates operations that are in progress.

Returns:



173
# File 'lib/seam/resources/unmanaged_access_method.rb', line 173

resource_list_accessor :pending_mutations, PendingMutations

#warningsArray<Warnings>

Warnings associated with the access method.

Returns:



176
# File 'lib/seam/resources/unmanaged_access_method.rb', line 176

resource_list_accessor :warnings, Warnings