Class: Seam::Resources::UnmanagedAccessMethod::Warnings::UpdatingAccessTimes
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessMethod::Warnings::UpdatingAccessTimes
- Defined in:
- lib/seam/resources/unmanaged_access_method.rb
Overview
Indicates that the access times for this access method are being updated.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
101 102 103 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 101 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
updating_access_times
106 107 108 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 106 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
109 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 109 date_accessor :created_at |