Class: Seam::Resources::UnmanagedDevice

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Represents an unmanaged device. An unmanaged device has a limited set of visible properties and a subset of supported events. You cannot control an unmanaged device. Any access codes on an unmanaged device are unmanaged. To control an unmanaged device with Seam, convert it to a managed device.

Defined Under Namespace

Classes: Errors, Location, Properties, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_configure_auto_lockBoolean?

Indicates whether the lock supports configuring automatic locking.

Returns:

  • (Boolean, nil)


939
940
941
# File 'lib/seam/resources/unmanaged_device.rb', line 939

def can_configure_auto_lock
  @can_configure_auto_lock
end

#can_hvac_coolBoolean?

Indicates whether the thermostat supports cooling.

Returns:

  • (Boolean, nil)


942
943
944
# File 'lib/seam/resources/unmanaged_device.rb', line 942

def can_hvac_cool
  @can_hvac_cool
end

#can_hvac_heatBoolean?

Indicates whether the thermostat supports heating.

Returns:

  • (Boolean, nil)


945
946
947
# File 'lib/seam/resources/unmanaged_device.rb', line 945

def can_hvac_heat
  @can_hvac_heat
end

#can_hvac_heat_coolBoolean?

Indicates whether the thermostat supports simultaneous heating and cooling.

Returns:

  • (Boolean, nil)


948
949
950
# File 'lib/seam/resources/unmanaged_device.rb', line 948

def can_hvac_heat_cool
  @can_hvac_heat_cool
end

#can_program_offline_access_codesBoolean?

Indicates whether the device supports programming offline access codes.

Returns:

  • (Boolean, nil)


951
952
953
# File 'lib/seam/resources/unmanaged_device.rb', line 951

def can_program_offline_access_codes
  @can_program_offline_access_codes
end

#can_program_online_access_codesBoolean?

Indicates whether the device supports programming online access codes.

Returns:

  • (Boolean, nil)


954
955
956
# File 'lib/seam/resources/unmanaged_device.rb', line 954

def can_program_online_access_codes
  @can_program_online_access_codes
end

#can_program_thermostat_programs_as_different_each_dayBoolean?

Indicates whether the thermostat supports different climate programs for each day of the week.

Returns:

  • (Boolean, nil)


957
958
959
# File 'lib/seam/resources/unmanaged_device.rb', line 957

def can_program_thermostat_programs_as_different_each_day
  @can_program_thermostat_programs_as_different_each_day
end

#can_program_thermostat_programs_as_same_each_dayBoolean?

Indicates whether the thermostat supports a single climate program applied to every day.

Returns:

  • (Boolean, nil)


960
961
962
# File 'lib/seam/resources/unmanaged_device.rb', line 960

def can_program_thermostat_programs_as_same_each_day
  @can_program_thermostat_programs_as_same_each_day
end

#can_program_thermostat_programs_as_weekday_weekendBoolean?

Indicates whether the thermostat supports weekday/weekend climate programs.

Returns:

  • (Boolean, nil)


963
964
965
# File 'lib/seam/resources/unmanaged_device.rb', line 963

def can_program_thermostat_programs_as_weekday_weekend
  @can_program_thermostat_programs_as_weekday_weekend
end

#can_remotely_lockBoolean?

Indicates whether the device supports remote locking.

Returns:

  • (Boolean, nil)


966
967
968
# File 'lib/seam/resources/unmanaged_device.rb', line 966

def can_remotely_lock
  @can_remotely_lock
end

#can_remotely_unlockBoolean?

Indicates whether the device supports remote unlocking.

Returns:

  • (Boolean, nil)


969
970
971
# File 'lib/seam/resources/unmanaged_device.rb', line 969

def can_remotely_unlock
  @can_remotely_unlock
end

#can_run_thermostat_programsBoolean?

Indicates whether the thermostat supports running climate programs.

Returns:

  • (Boolean, nil)


972
973
974
# File 'lib/seam/resources/unmanaged_device.rb', line 972

def can_run_thermostat_programs
  @can_run_thermostat_programs
end

#can_simulate_connectionBoolean?

Indicates whether the device supports simulating connection in a sandbox.

Returns:

  • (Boolean, nil)


975
976
977
# File 'lib/seam/resources/unmanaged_device.rb', line 975

def can_simulate_connection
  @can_simulate_connection
end

#can_simulate_disconnectionBoolean?

Indicates whether the device supports simulating disconnection in a sandbox.

Returns:

  • (Boolean, nil)


978
979
980
# File 'lib/seam/resources/unmanaged_device.rb', line 978

def can_simulate_disconnection
  @can_simulate_disconnection
end

#can_simulate_hub_connectionBoolean?

Indicates whether the hub supports simulating connection in a sandbox.

Returns:

  • (Boolean, nil)


981
982
983
# File 'lib/seam/resources/unmanaged_device.rb', line 981

def can_simulate_hub_connection
  @can_simulate_hub_connection
end

#can_simulate_hub_disconnectionBoolean?

Indicates whether the hub supports simulating disconnection in a sandbox.

Returns:

  • (Boolean, nil)


984
985
986
# File 'lib/seam/resources/unmanaged_device.rb', line 984

def can_simulate_hub_disconnection
  @can_simulate_hub_disconnection
end

#can_simulate_paid_subscriptionBoolean?

Indicates whether the device supports simulating a paid subscription in a sandbox.

Returns:

  • (Boolean, nil)


987
988
989
# File 'lib/seam/resources/unmanaged_device.rb', line 987

def can_simulate_paid_subscription
  @can_simulate_paid_subscription
end

#can_simulate_removalBoolean?

Indicates whether the device supports simulating removal in a sandbox.

Returns:

  • (Boolean, nil)


990
991
992
# File 'lib/seam/resources/unmanaged_device.rb', line 990

def can_simulate_removal
  @can_simulate_removal
end

#can_turn_off_hvacBoolean?

Indicates whether the thermostat can be turned off.

Returns:

  • (Boolean, nil)


993
994
995
# File 'lib/seam/resources/unmanaged_device.rb', line 993

def can_turn_off_hvac
  @can_turn_off_hvac
end

#can_unlock_with_codeBoolean?

Indicates whether the lock supports unlocking with an access code.

Returns:

  • (Boolean, nil)


996
997
998
# File 'lib/seam/resources/unmanaged_device.rb', line 996

def can_unlock_with_code
  @can_unlock_with_code
end

#capabilities_supportedArray<String>

Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags. Known values:

  • access_code
  • lock
  • noise_detection
  • thermostat
  • battery
  • phone

Returns:

  • (Array<String>)


1006
1007
1008
# File 'lib/seam/resources/unmanaged_device.rb', line 1006

def capabilities_supported
  @capabilities_supported
end

#connected_account_idString

Unique identifier for the account associated with the device.

Returns:

  • (String)


1009
1010
1011
# File 'lib/seam/resources/unmanaged_device.rb', line 1009

def 
  @connected_account_id
end

#custom_metadataHash{String => String, Boolean}

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application. Keys set to null or to an empty string are omitted.

Returns:

  • (Hash{String => String, Boolean})


1012
1013
1014
# File 'lib/seam/resources/unmanaged_device.rb', line 1012

def 
  @custom_metadata
end

#device_idString

ID of the device.

Returns:

  • (String)


1015
1016
1017
# File 'lib/seam/resources/unmanaged_device.rb', line 1015

def device_id
  @device_id
end

#device_typeString

Type of the device. Known values:

  • akuvox_lock
  • august_lock
  • brivo_access_point
  • butterflymx_panel
  • avigilon_alta_entry
  • doorking_lock
  • genie_door
  • igloo_lock
  • linear_lock
  • lockly_lock
  • kwikset_lock
  • nuki_lock
  • salto_lock
  • schlage_lock
  • smartthings_lock
  • wyze_lock
  • yale_lock
  • two_n_intercom
  • controlbyweb_device
  • ttlock_lock
  • igloohome_lock
  • four_suites_door
  • dormakaba_oracode_door
  • tedee_lock
  • akiles_lock
  • ultraloq_lock
  • yacan_lock
  • keyincode_lock
  • omnitec_lock
  • kisi_lock
  • aqara_lock
  • keynest_key
  • noiseaware_activity_zone
  • minut_sensor
  • ecobee_thermostat
  • nest_thermostat
  • honeywell_resideo_thermostat
  • tado_thermostat
  • sensi_thermostat
  • smartthings_thermostat
  • ios_phone
  • android_phone
  • ring_camera

Returns:

  • (String)


1062
1063
1064
# File 'lib/seam/resources/unmanaged_device.rb', line 1062

def device_type
  @device_type
end

#display_nameString

Display name of the device, defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the device easily, especially when there are numerous devices.

Returns:

  • (String)


1065
1066
1067
# File 'lib/seam/resources/unmanaged_device.rb', line 1065

def display_name
  @display_name
end

#is_managedFalseClass

Indicates that Seam does not manage the device.

Returns:

  • (FalseClass)


1068
1069
1070
# File 'lib/seam/resources/unmanaged_device.rb', line 1068

def is_managed
  @is_managed
end

#workspace_idString

Unique identifier for the Seam workspace associated with the device.

Returns:

  • (String)


1071
1072
1073
# File 'lib/seam/resources/unmanaged_device.rb', line 1071

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the device object was created.

Returns:

  • (Time)


1075
# File 'lib/seam/resources/unmanaged_device.rb', line 1075

date_accessor :created_at

#errorsArray<Errors>

Array of errors associated with the device. Each error object within the array contains two fields: error_code and message. error_code is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. message provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.

Returns:



933
# File 'lib/seam/resources/unmanaged_device.rb', line 933

resource_list_accessor :errors, Errors

#locationLocation?

Location information for the device.

Returns:



927
# File 'lib/seam/resources/unmanaged_device.rb', line 927

resource_accessor :location, Location

#propertiesProperties

properties of the device.

Returns:



930
# File 'lib/seam/resources/unmanaged_device.rb', line 930

resource_accessor :properties, Properties

#warningsArray<Warnings>

Array of warnings associated with the device. Each warning object within the array contains two fields: warning_code and message. warning_code is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. message provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.

Returns:



936
# File 'lib/seam/resources/unmanaged_device.rb', line 936

resource_list_accessor :warnings, Warnings