Class: Seam::Resources::UnmanagedDevice::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


10
11
12
# File 'lib/seam/resources/unmanaged_device.rb', line 10

def error_code
  @error_code
end

#is_bridge_errorBoolean?

Indicates whether the error is related to Seam Bridge.

Returns:

  • (Boolean, nil)


13
14
15
# File 'lib/seam/resources/unmanaged_device.rb', line 13

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorBoolean?

Returns:

  • (Boolean, nil)


15
16
17
# File 'lib/seam/resources/unmanaged_device.rb', line 15

def 
  @is_connected_account_error
end

#is_device_errorBoolean

Returns:

  • (Boolean)


17
18
19
# File 'lib/seam/resources/unmanaged_device.rb', line 17

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


20
21
22
# File 'lib/seam/resources/unmanaged_device.rb', line 20

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


23
# File 'lib/seam/resources/unmanaged_device.rb', line 23

date_accessor :created_at