Class: Seam::Resources::UnmanagedDevice::Errors::AugustLockNotAuthorized

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the user is not authorized to use the August lock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • august_lock_not_authorized

Returns:

  • (String)


189
190
191
# File 'lib/seam/resources/unmanaged_device.rb', line 189

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


192
193
194
# File 'lib/seam/resources/unmanaged_device.rb', line 192

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


195
196
197
# File 'lib/seam/resources/unmanaged_device.rb', line 195

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


198
# File 'lib/seam/resources/unmanaged_device.rb', line 198

date_accessor :created_at