Class: Seam::Resources::UnmanagedDevice::Errors::DeviceDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedDevice::Errors::DeviceDisconnected
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the device is disconnected.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
device_disconnected
153 154 155 |
# File 'lib/seam/resources/unmanaged_device.rb', line 153 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
156 157 158 |
# File 'lib/seam/resources/unmanaged_device.rb', line 156 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
159 160 161 |
# File 'lib/seam/resources/unmanaged_device.rb', line 159 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
162 |
# File 'lib/seam/resources/unmanaged_device.rb', line 162 date_accessor :created_at |