Class: Seam::Resources::UnmanagedDevice::Errors::DeviceOffline

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device is offline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • device_offline

Returns:

  • (String)


99
100
101
# File 'lib/seam/resources/unmanaged_device.rb', line 99

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


102
103
104
# File 'lib/seam/resources/unmanaged_device.rb', line 102

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


105
106
107
# File 'lib/seam/resources/unmanaged_device.rb', line 105

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


108
# File 'lib/seam/resources/unmanaged_device.rb', line 108

date_accessor :created_at