Class: Seam::Resources::UnmanagedDevice::Errors::DeviceRemoved

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device has been removed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • device_removed

Returns:

  • (String)


117
118
119
# File 'lib/seam/resources/unmanaged_device.rb', line 117

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


120
121
122
# File 'lib/seam/resources/unmanaged_device.rb', line 120

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


123
124
125
# File 'lib/seam/resources/unmanaged_device.rb', line 123

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


126
# File 'lib/seam/resources/unmanaged_device.rb', line 126

date_accessor :created_at