Class: Seam::Resources::UnmanagedDevice::Errors::DormakabaSitesDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that one or more dormakaba sites associated with the connected account could not be connected. Contact dormakaba support.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • dormakaba_sites_disconnected

Returns:

  • (String)


78
79
80
# File 'lib/seam/resources/unmanaged_device.rb', line 78

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


81
82
83
# File 'lib/seam/resources/unmanaged_device.rb', line 81

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


84
85
86
# File 'lib/seam/resources/unmanaged_device.rb', line 84

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


87
88
89
# File 'lib/seam/resources/unmanaged_device.rb', line 87

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


90
# File 'lib/seam/resources/unmanaged_device.rb', line 90

date_accessor :created_at