Class: Seam::Resources::UnmanagedDevice::Errors::EmptyBackupAccessCodePool
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedDevice::Errors::EmptyBackupAccessCodePool
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the backup access code pool is empty.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
empty_backup_access_code_pool
171 172 173 |
# File 'lib/seam/resources/unmanaged_device.rb', line 171 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
174 175 176 |
# File 'lib/seam/resources/unmanaged_device.rb', line 174 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
177 178 179 |
# File 'lib/seam/resources/unmanaged_device.rb', line 177 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
180 |
# File 'lib/seam/resources/unmanaged_device.rb', line 180 date_accessor :created_at |