Class: Seam::Resources::UnmanagedDevice::Errors::SaltoKsSubscriptionLimitExceeded

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the Salto site user limit has been reached.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_subscription_limit_exceeded

Returns:

  • (String)


36
37
38
# File 'lib/seam/resources/unmanaged_device.rb', line 36

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


39
40
41
# File 'lib/seam/resources/unmanaged_device.rb', line 39

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


42
43
44
# File 'lib/seam/resources/unmanaged_device.rb', line 42

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


45
46
47
# File 'lib/seam/resources/unmanaged_device.rb', line 45

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


48
# File 'lib/seam/resources/unmanaged_device.rb', line 48

date_accessor :created_at