Class: Seam::Resources::UnmanagedDevice::Errors::SubscriptionRequired

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that a subscription is required to connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • subscription_required

Returns:

  • (String)


243
244
245
# File 'lib/seam/resources/unmanaged_device.rb', line 243

def error_code
  @error_code
end

#is_device_errorTrueClass

Indicates that the error is a device error.

Returns:

  • (TrueClass)


246
247
248
# File 'lib/seam/resources/unmanaged_device.rb', line 246

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


249
250
251
# File 'lib/seam/resources/unmanaged_device.rb', line 249

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


252
# File 'lib/seam/resources/unmanaged_device.rb', line 252

date_accessor :created_at