Class: Seam::Resources::UnmanagedDevice::Properties::AccessoryKeypad
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice::Properties::AccessoryKeypad
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Defined Under Namespace
Classes: Battery
Instance Attribute Summary collapse
-
#is_connected ⇒ Boolean
Indicates if an accessory keypad is connected to the device.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#battery ⇒ Battery?
Keypad battery properties.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#is_connected ⇒ Boolean
Indicates if an accessory keypad is connected to the device.
54 55 56 |
# File 'lib/seam/resources/unmanaged_device.rb', line 54 def is_connected @is_connected end |