Class: Seam::Resources::UnmanagedDevice::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice::Warnings
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Instance Attribute Summary collapse
-
#active_access_code_count ⇒ Integer
Number of active access codes on the device when the warning was set.
-
#max_active_access_code_count ⇒ Integer
Maximum number of active access codes supported by the device.
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#active_access_code_count ⇒ Integer
Number of active access codes on the device when the warning was set.
131 132 133 |
# File 'lib/seam/resources/unmanaged_device.rb', line 131 def active_access_code_count @active_access_code_count end |
#max_active_access_code_count ⇒ Integer
Maximum number of active access codes supported by the device.
134 135 136 |
# File 'lib/seam/resources/unmanaged_device.rb', line 134 def max_active_access_code_count @max_active_access_code_count end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
137 138 139 |
# File 'lib/seam/resources/unmanaged_device.rb', line 137 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
140 141 142 |
# File 'lib/seam/resources/unmanaged_device.rb', line 140 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
143 |
# File 'lib/seam/resources/unmanaged_device.rb', line 143 date_accessor :created_at |