Class: Seam::Resources::UnmanagedDevice::Warnings::AccessoryKeypadSetupRequired

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the accessory keypad exists, but is not linked to the Igloohome Bridge. Online access code programming will fail until the keypad is linked to the Igloohome Bridge in the Igloohome app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


792
793
794
# File 'lib/seam/resources/unmanaged_device.rb', line 792

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • accessory_keypad_setup_required

Returns:

  • (String)


797
798
799
# File 'lib/seam/resources/unmanaged_device.rb', line 797

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


800
# File 'lib/seam/resources/unmanaged_device.rb', line 800

date_accessor :created_at