Class: Seam::Resources::UnmanagedDevice::Warnings::DeviceHasFlakyConnection

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device has a flaky connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


567
568
569
# File 'lib/seam/resources/unmanaged_device.rb', line 567

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • device_has_flaky_connection

Returns:

  • (String)


572
573
574
# File 'lib/seam/resources/unmanaged_device.rb', line 572

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


575
# File 'lib/seam/resources/unmanaged_device.rb', line 575

date_accessor :created_at