Class: Seam::Resources::UnmanagedDevice::Warnings::HubRequiredForAdditionalCapabilities

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that a hub or relay must be connected to unlock additional capabilities such as remote unlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


747
748
749
# File 'lib/seam/resources/unmanaged_device.rb', line 747

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • hub_required_for_additional_capabilities

Returns:

  • (String)


752
753
754
# File 'lib/seam/resources/unmanaged_device.rb', line 752

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


755
# File 'lib/seam/resources/unmanaged_device.rb', line 755

date_accessor :created_at