Class: Seam::Resources::UnmanagedDevice::Warnings::KeynestUnsupportedLocker
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::KeynestUnsupportedLocker
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the key is in a locker that does not support the access codes API.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
777 778 779 |
# File 'lib/seam/resources/unmanaged_device.rb', line 777 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
keynest_unsupported_locker
782 783 784 |
# File 'lib/seam/resources/unmanaged_device.rb', line 782 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
785 |
# File 'lib/seam/resources/unmanaged_device.rb', line 785 date_accessor :created_at |