Class: Seam::Resources::UnmanagedDevice::Warnings::LocklyTimeZoneNotConfigured

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that Seam detected that the Lockly device does not have a time zone configured. Time-bound codes may not work as expected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


672
673
674
# File 'lib/seam/resources/unmanaged_device.rb', line 672

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • lockly_time_zone_not_configured

Returns:

  • (String)


677
678
679
# File 'lib/seam/resources/unmanaged_device.rb', line 677

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


680
# File 'lib/seam/resources/unmanaged_device.rb', line 680

date_accessor :created_at