Class: Seam::Resources::UnmanagedDevice::Warnings::ManyActiveBackupCodes
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::ManyActiveBackupCodes
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that there are too many backup codes.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
447 448 449 |
# File 'lib/seam/resources/unmanaged_device.rb', line 447 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
many_active_backup_codes
452 453 454 |
# File 'lib/seam/resources/unmanaged_device.rb', line 452 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
455 |
# File 'lib/seam/resources/unmanaged_device.rb', line 455 date_accessor :created_at |