Class: Seam::Resources::UnmanagedDevice::Warnings::MaxAccessCodesReached

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device has reached its maximum number of active access codes. Delete existing codes before creating new ones.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#active_access_code_countInteger

Number of active access codes on the device when the warning was set.

Returns:

  • (Integer)


837
838
839
# File 'lib/seam/resources/unmanaged_device.rb', line 837

def active_access_code_count
  @active_access_code_count
end

#max_active_access_code_countInteger

Maximum number of active access codes supported by the device.

Returns:

  • (Integer)


840
841
842
# File 'lib/seam/resources/unmanaged_device.rb', line 840

def max_active_access_code_count
  @max_active_access_code_count
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


843
844
845
# File 'lib/seam/resources/unmanaged_device.rb', line 843

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • max_access_codes_reached

Returns:

  • (String)


848
849
850
# File 'lib/seam/resources/unmanaged_device.rb', line 848

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


851
# File 'lib/seam/resources/unmanaged_device.rb', line 851

date_accessor :created_at