Class: Seam::Resources::UnmanagedDevice::Warnings::PartialBackupAccessCodePool
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::PartialBackupAccessCodePool
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the backup access code is unhealthy.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
432 433 434 |
# File 'lib/seam/resources/unmanaged_device.rb', line 432 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
partial_backup_access_code_pool
437 438 439 |
# File 'lib/seam/resources/unmanaged_device.rb', line 437 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
440 |
# File 'lib/seam/resources/unmanaged_device.rb', line 440 date_accessor :created_at |