Class: Seam::Resources::UnmanagedDevice::Warnings::PowerSavingMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device is in power saving mode and may have limited functionality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


507
508
509
# File 'lib/seam/resources/unmanaged_device.rb', line 507

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • power_saving_mode

Returns:

  • (String)


512
513
514
# File 'lib/seam/resources/unmanaged_device.rb', line 512

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


515
# File 'lib/seam/resources/unmanaged_device.rb', line 515

date_accessor :created_at