Class: Seam::Resources::UnmanagedDevice::Warnings::PrivacyMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the lock is in Privacy Mode. Access codes and remote unlock are blocked until Privacy Mode is disabled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


612
613
614
# File 'lib/seam/resources/unmanaged_device.rb', line 612

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • privacy_mode

Returns:

  • (String)


617
618
619
# File 'lib/seam/resources/unmanaged_device.rb', line 617

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


620
# File 'lib/seam/resources/unmanaged_device.rb', line 620

date_accessor :created_at