Class: Seam::Resources::UnmanagedDevice::Warnings::ProviderIssue

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates a provider-specific issue that may affect device functionality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


762
763
764
# File 'lib/seam/resources/unmanaged_device.rb', line 762

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • provider_issue

Returns:

  • (String)


767
768
769
# File 'lib/seam/resources/unmanaged_device.rb', line 767

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


770
# File 'lib/seam/resources/unmanaged_device.rb', line 770

date_accessor :created_at