Class: Seam::Resources::UnmanagedDevice::Warnings::SaltoKsOfficeMode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the Salto KS lock is in Office Mode. Access Codes will not unlock doors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


582
583
584
# File 'lib/seam/resources/unmanaged_device.rb', line 582

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • salto_ks_office_mode

Returns:

  • (String)


587
588
589
# File 'lib/seam/resources/unmanaged_device.rb', line 587

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


590
# File 'lib/seam/resources/unmanaged_device.rb', line 590

date_accessor :created_at