Class: Seam::Resources::UnmanagedDevice::Warnings::ScheduledMaintenanceWindow
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::ScheduledMaintenanceWindow
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that a scheduled maintenance window has been detected.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
552 553 554 |
# File 'lib/seam/resources/unmanaged_device.rb', line 552 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
scheduled_maintenance_window
557 558 559 |
# File 'lib/seam/resources/unmanaged_device.rb', line 557 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
560 |
# File 'lib/seam/resources/unmanaged_device.rb', line 560 date_accessor :created_at |