Class: Seam::Resources::UnmanagedDevice::Warnings::TemperatureThresholdExceeded
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::TemperatureThresholdExceeded
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the temperature threshold has been exceeded.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
522 523 524 |
# File 'lib/seam/resources/unmanaged_device.rb', line 522 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
temperature_threshold_exceeded
527 528 529 |
# File 'lib/seam/resources/unmanaged_device.rb', line 527 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
530 |
# File 'lib/seam/resources/unmanaged_device.rb', line 530 date_accessor :created_at |