Class: Seam::Resources::UnmanagedDevice::Warnings::ThirdPartyIntegrationDetected

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that a third-party integration has been detected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


462
463
464
# File 'lib/seam/resources/unmanaged_device.rb', line 462

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • third_party_integration_detected

Returns:

  • (String)


467
468
469
# File 'lib/seam/resources/unmanaged_device.rb', line 467

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


470
# File 'lib/seam/resources/unmanaged_device.rb', line 470

date_accessor :created_at