Class: Seam::Resources::UnmanagedDevice::Warnings::TimeZoneUnknown
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::TimeZoneUnknown
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that Seam does not know the device's time zone. Set a time zone to enable time-bound access codes.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
702 703 704 |
# File 'lib/seam/resources/unmanaged_device.rb', line 702 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
time_zone_unknown
707 708 709 |
# File 'lib/seam/resources/unmanaged_device.rb', line 707 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
710 |
# File 'lib/seam/resources/unmanaged_device.rb', line 710 date_accessor :created_at |