Class: Seam::Resources::UnmanagedDevice::Warnings::TtlockLockGatewayUnlockingNotEnabled

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the Remote Unlock feature is not enabled in the settings."

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


477
478
479
# File 'lib/seam/resources/unmanaged_device.rb', line 477

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • ttlock_lock_gateway_unlocking_not_enabled

Returns:

  • (String)


482
483
484
# File 'lib/seam/resources/unmanaged_device.rb', line 482

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


485
# File 'lib/seam/resources/unmanaged_device.rb', line 485

date_accessor :created_at