Class: Seam::Resources::UnmanagedDevice::Warnings::TtlockWeakGatewaySignal

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the gateway signal is weak.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


492
493
494
# File 'lib/seam/resources/unmanaged_device.rb', line 492

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • ttlock_weak_gateway_signal

Returns:

  • (String)


497
498
499
# File 'lib/seam/resources/unmanaged_device.rb', line 497

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


500
# File 'lib/seam/resources/unmanaged_device.rb', line 500

date_accessor :created_at