Class: Seam::Resources::UnmanagedDevice::Warnings::UltraloqTimeZoneUnknown

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that Seam does not know the time zone of the Ultraloq device. Set a time zone to enable time-bound access codes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


687
688
689
# File 'lib/seam/resources/unmanaged_device.rb', line 687

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • ultraloq_time_zone_unknown

Returns:

  • (String)


692
693
694
# File 'lib/seam/resources/unmanaged_device.rb', line 692

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


695
# File 'lib/seam/resources/unmanaged_device.rb', line 695

date_accessor :created_at