Class: Seam::Resources::UnmanagedUserIdentity

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_user_identity.rb

Overview

Represents an unmanaged user identity. Unmanaged user identities do not have keys.

Defined Under Namespace

Classes: Errors, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_user_idsArray<String>

Array of access system user IDs associated with the user identity.

Returns:

  • (Array<String>)


45
46
47
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 45

def acs_user_ids
  @acs_user_ids
end

#display_nameString

Display name for the user identity.

Returns:

  • (String)


48
49
50
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 48

def display_name
  @display_name
end

#email_addressString?

Unique email address for the user identity.

Returns:

  • (String, nil)


51
52
53
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 51

def email_address
  @email_address
end

#full_nameString?

Full name of the user associated with the user identity.

Returns:

  • (String, nil)


54
55
56
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 54

def full_name
  @full_name
end

#phone_numberString?

Unique phone number for the user identity in E.164 format (for example, +15555550100).

Returns:

  • (String, nil)


57
58
59
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 57

def phone_number
  @phone_number
end

#user_identity_idString

ID of the user identity.

Returns:

  • (String)


60
61
62
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 60

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the workspace that contains the user identity.

Returns:

  • (String)


63
64
65
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 63

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the user identity was created.

Returns:

  • (Time)


67
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 67

date_accessor :created_at

#errorsArray<Errors>

Array of errors associated with the user identity. Each error object within the array contains fields like "error_code" and "message." "error_code" is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. "message" provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.

Returns:



39
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 39

resource_list_accessor :errors, Errors

#warningsArray<Warnings>

Array of warnings associated with the user identity. Each warning object within the array contains two fields: "warning_code" and "message." "warning_code" is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. "message" provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.

Returns:



42
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 42

resource_list_accessor :warnings, Warnings