Class: Seam::Resources::UnmanagedUserIdentity::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_user_identity.rb

Overview

Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.

Defined Under Namespace

Classes: IssueWithAcsUser

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_system_idString

ID of the access system that the user identity is associated with.

Returns:

  • (String)


32
33
34
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 32

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the access system user that has an issue.

Returns:

  • (String)


35
36
37
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 35

def acs_user_id
  @acs_user_id
end

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • issue_with_acs_user

Returns:

  • (String)


40
41
42
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 40

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


43
44
45
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 43

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


46
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 46

date_accessor :created_at