Class: Seam::Resources::UnmanagedUserIdentity::Errors::IssueWithAcsUser

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_user_identity.rb

Overview

Indicates that there is an issue with an access system user associated with this user identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_system_idString

ID of the access system that the user identity is associated with.

Returns:

  • (String)


13
14
15
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 13

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the access system user that has an issue.

Returns:

  • (String)


16
17
18
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 16

def acs_user_id
  @acs_user_id
end

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • issue_with_acs_user

Returns:

  • (String)


21
22
23
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 21

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


24
25
26
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 24

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


27
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 27

date_accessor :created_at