Class: Seam::Resources::UnmanagedUserIdentity::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_user_identity.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


28
29
30
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 28

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


31
32
33
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 31

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


34
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 34

date_accessor :created_at