Class: Seam::Resources::UnmanagedUserIdentity::Warnings::AcsUserProfileDoesNotMatchUserIdentity

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_user_identity.rb

Overview

Indicates that the ACS user's profile does not match the user identity's profile

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


74
75
76
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 74

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • acs_user_profile_does_not_match_user_identity

Returns:

  • (String)


79
80
81
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 79

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


82
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 82

date_accessor :created_at