Class: Seam::Resources::UnmanagedUserIdentity::Warnings::BeingDeleted
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedUserIdentity::Warnings::BeingDeleted
- Defined in:
- lib/seam/resources/unmanaged_user_identity.rb
Overview
Indicates that the user identity is currently being deleted.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
59 60 61 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 59 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
being_deleted
64 65 66 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 64 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
67 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 67 date_accessor :created_at |