Class: Seam::Resources::UserIdentity

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/user_identity.rb

Overview

Represents a user identity associated with an application user account.

Defined Under Namespace

Classes: Errors, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_user_idsObject

Array of access system user IDs associated with the user identity.



32
33
34
# File 'lib/seam/resources/user_identity.rb', line 32

def acs_user_ids
  @acs_user_ids
end

#display_nameObject

Display name for the user identity.



34
35
36
# File 'lib/seam/resources/user_identity.rb', line 34

def display_name
  @display_name
end

#email_addressObject

Unique email address for the user identity.



36
37
38
# File 'lib/seam/resources/user_identity.rb', line 36

def email_address
  @email_address
end

#full_nameObject

Full name of the user associated with the user identity.



38
39
40
# File 'lib/seam/resources/user_identity.rb', line 38

def full_name
  @full_name
end

#phone_numberObject

Unique phone number for the user identity in E.164 format (for example, +15555550100).



40
41
42
# File 'lib/seam/resources/user_identity.rb', line 40

def phone_number
  @phone_number
end

#user_identity_idObject

ID of the user identity.



42
43
44
# File 'lib/seam/resources/user_identity.rb', line 42

def user_identity_id
  @user_identity_id
end

#user_identity_keyObject

Unique key for the user identity.



44
45
46
# File 'lib/seam/resources/user_identity.rb', line 44

def user_identity_key
  @user_identity_key
end

#workspace_idObject

ID of the workspace that contains the user identity.



46
47
48
# File 'lib/seam/resources/user_identity.rb', line 46

def workspace_id
  @workspace_id
end