Class: Seam::Resources::UserIdentity::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UserIdentity::Errors
- Defined in:
- lib/seam/resources/user_identity.rb
Overview
Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.
Defined Under Namespace
Classes: IssueWithAcsUser
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system that the user identity is associated with.
-
#acs_user_id ⇒ String
ID of the access system user that has an issue.
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system that the user identity is associated with.
32 33 34 |
# File 'lib/seam/resources/user_identity.rb', line 32 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the access system user that has an issue.
35 36 37 |
# File 'lib/seam/resources/user_identity.rb', line 35 def acs_user_id @acs_user_id end |
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
issue_with_acs_user
40 41 42 |
# File 'lib/seam/resources/user_identity.rb', line 40 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
43 44 45 |
# File 'lib/seam/resources/user_identity.rb', line 43 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
46 |
# File 'lib/seam/resources/user_identity.rb', line 46 date_accessor :created_at |