Class: Seam::Resources::UserIdentity::Warnings::BeingDeleted

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/user_identity.rb

Overview

Indicates that the user identity is currently being deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


59
60
61
# File 'lib/seam/resources/user_identity.rb', line 59

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • being_deleted

Returns:

  • (String)


64
65
66
# File 'lib/seam/resources/user_identity.rb', line 64

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


67
# File 'lib/seam/resources/user_identity.rb', line 67

date_accessor :created_at