Class: Seam::Resources::Webhook

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/webhook.rb

Overview

Represents a webhook that enables you to receive notifications of events. When you create a webhook, specify the endpoint URL at which you want to receive events and the set of event types that you want to receive.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#event_typesArray<String>

Types of events that the webhook should receive.

Returns:

  • (Array<String>)


9
10
11
# File 'lib/seam/resources/webhook.rb', line 9

def event_types
  @event_types
end

#secretString?

Secret associated with the webhook.

Returns:

  • (String, nil)


12
13
14
# File 'lib/seam/resources/webhook.rb', line 12

def secret
  @secret
end

#urlString

URL for the webhook.

Returns:

  • (String)


15
16
17
# File 'lib/seam/resources/webhook.rb', line 15

def url
  @url
end

#webhook_idString

ID of the webhook.

Returns:

  • (String)


18
19
20
# File 'lib/seam/resources/webhook.rb', line 18

def webhook_id
  @webhook_id
end