Class: Seam::Resources::Workspace
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Workspace
- Defined in:
- lib/seam/resources/workspace.rb
Overview
Represents a Seam workspace. A workspace is a top-level entity that encompasses all other resources below it, such as devices, connected accounts, and Connect Webviews. Seam provides two types of workspaces. A sandbox workspace is a special type of workspace designed for testing code. Sandbox workspaces offer test device accounts and virtual devices that you can connect and control. This ability to work with virtual devices is quite handy because it removes the need to own physical devices from multiple brands. To connect real devices and systems to Seam, use a production workspace.
Defined Under Namespace
Classes: ConnectWebviewCustomization
Instance Attribute Summary collapse
-
#company_name ⇒ String
Company name associated with the workspace.
-
#connect_partner_name ⇒ String?
deprecated
Deprecated.
Use
company_nameinstead. -
#is_publishable_key_auth_enabled ⇒ Boolean
Indicates whether publishable key authentication is enabled for this workspace.
-
#is_sandbox ⇒ Boolean
Indicates whether the workspace is a sandbox workspace.
-
#is_suspended ⇒ Boolean
Indicates whether the sandbox workspace is suspended.
-
#name ⇒ String
Name of the workspace.
-
#organization_id ⇒ String?
ID of the organization to which the workspace belongs, or
nullif the workspace is not assigned to an organization. -
#publishable_key ⇒ String?
Publishable key for the workspace.
-
#workspace_id ⇒ String
ID of the workspace.
Attributes inherited from BaseResource
Instance Method Summary collapse
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#company_name ⇒ String
Company name associated with the workspace.
29 30 31 |
# File 'lib/seam/resources/workspace.rb', line 29 def company_name @company_name end |
#connect_partner_name ⇒ String?
Use company_name instead.
32 33 34 |
# File 'lib/seam/resources/workspace.rb', line 32 def connect_partner_name @connect_partner_name end |
#is_publishable_key_auth_enabled ⇒ Boolean
Indicates whether publishable key authentication is enabled for this workspace.
35 36 37 |
# File 'lib/seam/resources/workspace.rb', line 35 def is_publishable_key_auth_enabled @is_publishable_key_auth_enabled end |
#is_sandbox ⇒ Boolean
Indicates whether the workspace is a sandbox workspace.
38 39 40 |
# File 'lib/seam/resources/workspace.rb', line 38 def is_sandbox @is_sandbox end |
#is_suspended ⇒ Boolean
Indicates whether the sandbox workspace is suspended. Seam suspends sandbox workspaces that have not been accessed in 14 days.
41 42 43 |
# File 'lib/seam/resources/workspace.rb', line 41 def is_suspended @is_suspended end |
#name ⇒ String
Name of the workspace.
44 45 46 |
# File 'lib/seam/resources/workspace.rb', line 44 def name @name end |
#organization_id ⇒ String?
ID of the organization to which the workspace belongs, or null if the workspace is not assigned to an organization.
47 48 49 |
# File 'lib/seam/resources/workspace.rb', line 47 def organization_id @organization_id end |
#publishable_key ⇒ String?
Publishable key for the workspace. This key is used to identify the workspace in client-side applications.
50 51 52 |
# File 'lib/seam/resources/workspace.rb', line 50 def publishable_key @publishable_key end |
#workspace_id ⇒ String
ID of the workspace.
53 54 55 |
# File 'lib/seam/resources/workspace.rb', line 53 def workspace_id @workspace_id end |
Instance Method Details
#connect_webview_customization ⇒ ConnectWebviewCustomization
26 |
# File 'lib/seam/resources/workspace.rb', line 26 resource_accessor :connect_webview_customization, ConnectWebviewCustomization |