Class: Seam::Resources::Workspace::ConnectWebviewCustomization

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/workspace.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#inviter_logo_urlString?

URL of the inviter logo for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.

Returns:

  • (String, nil)


10
11
12
# File 'lib/seam/resources/workspace.rb', line 10

def inviter_logo_url
  @inviter_logo_url
end

#logo_shapeString?

Logo shape for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.

Returns:

  • (String, nil)


13
14
15
# File 'lib/seam/resources/workspace.rb', line 13

def logo_shape
  @logo_shape
end

#primary_button_colorString?

Primary button color for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.

Returns:

  • (String, nil)


16
17
18
# File 'lib/seam/resources/workspace.rb', line 16

def primary_button_color
  @primary_button_color
end

#primary_button_text_colorString?

Primary button text color for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.

Returns:

  • (String, nil)


19
20
21
# File 'lib/seam/resources/workspace.rb', line 19

def primary_button_text_color
  @primary_button_text_color
end

#success_messageString?

Success message for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.

Returns:

  • (String, nil)


22
23
24
# File 'lib/seam/resources/workspace.rb', line 22

def success_message
  @success_message
end