Class: Seam::Clients::DevicesUnmanaged
- Inherits:
-
Object
- Object
- Seam::Clients::DevicesUnmanaged
- Defined in:
- lib/seam/routes/devices_unmanaged.rb
Instance Method Summary collapse
-
#get(device_id: nil, name: nil) ⇒ Seam::Resources::UnmanagedDevice
Returns a specified unmanaged device.
-
#initialize(client:, defaults:) ⇒ DevicesUnmanaged
constructor
A new instance of DevicesUnmanaged.
-
#list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil) ⇒ Seam::Resources::UnmanagedDevice
Returns a list of all unmanaged devices.
-
#update(device_id:, custom_metadata: nil, is_managed: nil) ⇒ nil
Updates a specified unmanaged device.
Constructor Details
#initialize(client:, defaults:) ⇒ DevicesUnmanaged
Returns a new instance of DevicesUnmanaged.
6 7 8 9 |
# File 'lib/seam/routes/devices_unmanaged.rb', line 6 def initialize(client:, defaults:) @client = client @defaults = defaults end |
Instance Method Details
#get(device_id: nil, name: nil) ⇒ Seam::Resources::UnmanagedDevice
Returns a specified unmanaged device.
An unmanaged device has a limited set of visible properties and a subset of supported events. You cannot control an unmanaged device. Any access codes on an unmanaged device are unmanaged. To control an unmanaged device with Seam, convert it to a managed device.
You must specify either device_id or name.
19 20 21 22 23 24 25 26 27 |
# File 'lib/seam/routes/devices_unmanaged.rb', line 19 def get(device_id: nil, name: nil) if device_id.nil? && name.nil? raise TypeError, "At least one parameter is required for /devices/unmanaged/get" end res = @client.get("/devices/unmanaged/get", {device_id: device_id, name: name}.compact) Seam::Resources::UnmanagedDevice.load_from_response(res.body["device"]) end |
#list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil) ⇒ Seam::Resources::UnmanagedDevice
Returns a list of all unmanaged devices.
An unmanaged device has a limited set of visible properties and a subset of supported events. You cannot control an unmanaged device. Any access codes on an unmanaged device are unmanaged. To control an unmanaged device with Seam, convert it to a managed device.
45 46 47 48 49 |
# File 'lib/seam/routes/devices_unmanaged.rb', line 45 def list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil) res = @client.post("/devices/unmanaged/list", {connect_webview_id: connect_webview_id, connected_account_id: connected_account_id, connected_account_ids: connected_account_ids, created_before: created_before, customer_key: customer_key, device_ids: device_ids, device_type: device_type, device_types: device_types, limit: limit, manufacturer: manufacturer, page_cursor: page_cursor, search: search}.compact) Seam::Resources::UnmanagedDevice.load_from_response(res.body["devices"]) end |
#update(device_id:, custom_metadata: nil, is_managed: nil) ⇒ nil
Updates a specified unmanaged device. To convert an unmanaged device to managed, set is_managed to true.
An unmanaged device has a limited set of visible properties and a subset of supported events. You cannot control an unmanaged device. Any access codes on an unmanaged device are unmanaged. To control an unmanaged device with Seam, convert it to a managed device.
58 59 60 61 62 |
# File 'lib/seam/routes/devices_unmanaged.rb', line 58 def update(device_id:, custom_metadata: nil, is_managed: nil) @client.patch("/devices/unmanaged/update", {device_id: device_id, custom_metadata: , is_managed: is_managed}.compact) nil end |