Class: Seam::Clients::Locks

Inherits:
Object
  • Object
show all
Defined in:
lib/seam/routes/locks.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:, defaults:) ⇒ Locks

Returns a new instance of Locks.



8
9
10
11
# File 'lib/seam/routes/locks.rb', line 8

def initialize(client:, defaults:)
  @client = client
  @defaults = defaults
end

Instance Method Details

#configure_auto_lock(auto_lock_enabled:, device_id:, auto_lock_delay_seconds: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt

Configures the auto-lock setting for a specified lock.

Parameters:

  • auto_lock_enabled

    Whether to enable or disable auto-lock.

  • device_id

    ID of the lock for which you want to configure the auto-lock.

  • auto_lock_delay_seconds (defaults to: nil)

    Delay in seconds before the lock automatically locks. Required when enabling auto-lock. Must be between 1 and 60.

Returns:



22
23
24
25
26
27
28
# File 'lib/seam/routes/locks.rb', line 22

def configure_auto_lock(auto_lock_enabled:, device_id:, auto_lock_delay_seconds: nil, wait_for_action_attempt: nil)
  res = @client.post("/locks/configure_auto_lock", {auto_lock_enabled: auto_lock_enabled, device_id: device_id, auto_lock_delay_seconds: auto_lock_delay_seconds}.compact)

  wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt

  Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt)
end

#get(device_id: nil, name: nil) ⇒ Seam::Resources::Device

Deprecated.

Use /devices/get instead.

Returns a specified lock.

Parameters:

  • device_id (defaults to: nil)

    ID of the lock that you want to get.

  • name (defaults to: nil)

    Name of the lock that you want to get.

Returns:



35
36
37
38
39
# File 'lib/seam/routes/locks.rb', line 35

def get(device_id: nil, name: nil)
  res = @client.post("/locks/get", {device_id: device_id, name: name}.compact)

  Seam::Resources::Device.load_from_response(res.body["device"])
end

#list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, custom_metadata_has: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil, space_id: nil, unstable_location_id: nil, user_identifier_key: nil) ⇒ Seam::Resources::Device

Deprecated.

unstable_location_id: Use space_id.

Returns a list of all locks.

Parameters:

  • connect_webview_id (defaults to: nil)

    ID of the Connect Webview for which you want to list devices.

  • connected_account_id (defaults to: nil)

    ID of the connected account for which you want to list devices.

  • connected_account_ids (defaults to: nil)

    Array of IDs of the connected accounts for which you want to list devices.

  • created_before (defaults to: nil)

    Timestamp by which to limit returned devices. Returns devices created before this timestamp.

  • custom_metadata_has (defaults to: nil)

    Set of key:value custom metadata pairs for which you want to list devices.

  • customer_key (defaults to: nil)

    Customer key for which you want to list devices.

  • device_ids (defaults to: nil)

    Array of device IDs for which you want to list devices.

  • device_type (defaults to: nil)

    Device type of the locks that you want to list.

  • device_types (defaults to: nil)

    Device types of the locks that you want to list.

  • limit (defaults to: nil)

    Numerical limit on the number of devices to return.

  • manufacturer (defaults to: nil)

    Manufacturer of the locks that you want to list.

  • page_cursor (defaults to: nil)

    Identifies the specific page of results to return, obtained from the previous page's next_page_cursor.

  • search (defaults to: nil)

    String for which to search. Filters returned devices to include all records that satisfy a partial match using device_id (full or partial UUID prefix, minimum 4 characters), connected_account_id, display_name, custom_metadata or location.location_name.

  • space_id (defaults to: nil)

    ID of the space for which you want to list devices.

  • unstable_location_id (defaults to: nil)
  • user_identifier_key (defaults to: nil)

    Your own internal user ID for the user for which you want to list devices.

Returns:



60
61
62
63
64
# File 'lib/seam/routes/locks.rb', line 60

def list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, custom_metadata_has: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil, space_id: nil, unstable_location_id: nil, user_identifier_key: nil)
  res = @client.post("/locks/list", {connect_webview_id: connect_webview_id, connected_account_id: , connected_account_ids: , created_before: created_before, custom_metadata_has: , customer_key: customer_key, device_ids: device_ids, device_type: device_type, device_types: device_types, limit: limit, manufacturer: manufacturer, page_cursor: page_cursor, search: search, space_id: space_id, unstable_location_id: unstable_location_id, user_identifier_key: user_identifier_key}.compact)

  Seam::Resources::Device.load_from_response(res.body["devices"])
end

#lock_door(device_id:, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt

Parameters:

  • device_id

    ID of the lock that you want to lock.

Returns:



69
70
71
72
73
74
75
# File 'lib/seam/routes/locks.rb', line 69

def lock_door(device_id:, wait_for_action_attempt: nil)
  res = @client.post("/locks/lock_door", {device_id: device_id}.compact)

  wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt

  Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt)
end

#simulateObject



13
14
15
# File 'lib/seam/routes/locks.rb', line 13

def simulate
  @simulate ||= Seam::Clients::LocksSimulate.new(client: @client, defaults: @defaults)
end

#unlock_door(device_id:, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt

Parameters:

  • device_id

    ID of the lock that you want to unlock.

Returns:



80
81
82
83
84
85
86
# File 'lib/seam/routes/locks.rb', line 80

def unlock_door(device_id:, wait_for_action_attempt: nil)
  res = @client.post("/locks/unlock_door", {device_id: device_id}.compact)

  wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt

  Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt)
end