Class: Seam::Clients::Thermostats
- Inherits:
-
Object
- Object
- Seam::Clients::Thermostats
- Defined in:
- lib/seam/routes/thermostats.rb
Instance Method Summary collapse
-
#activate_climate_preset(climate_preset_key:, device_id:, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Activates a specified climate preset for a specified thermostat.
-
#cool(device_id:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to cool mode.
-
#create_climate_preset(climate_preset_key:, device_id:, climate_preset_mode: nil, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, ecobee_metadata: nil, fan_mode_setting: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, hvac_mode_setting: nil, manual_override_allowed: nil, name: nil) ⇒ nil
deprecated
Deprecated.
manual_override_allowed: Use 'thermostat_schedule.is_override_allowed'
- #daily_programs ⇒ Object
-
#delete_climate_preset(climate_preset_key:, device_id:) ⇒ nil
Deletes a specified climate preset for a specified thermostat.
-
#heat(device_id:, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to heat mode.
-
#heat_cool(device_id:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to heat-cool ("auto") mode.
-
#initialize(client:, defaults:) ⇒ Thermostats
constructor
A new instance of Thermostats.
-
#list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, custom_metadata_has: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil, space_id: nil, unstable_location_id: nil, user_identifier_key: nil) ⇒ Seam::Resources::Device
deprecated
Deprecated.
unstable_location_id: Use
space_id. -
#off(device_id:, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to "off" mode.
- #schedules ⇒ Object
-
#set_fallback_climate_preset(climate_preset_key:, device_id:) ⇒ nil
Sets a specified climate preset as the "fallback" preset for a specified thermostat.
-
#set_fan_mode(device_id:, fan_mode: nil, fan_mode_setting: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
deprecated
Deprecated.
fan_mode: Use
fan_mode_settinginstead. -
#set_hvac_mode(device_id:, hvac_mode_setting:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets the HVAC mode for a specified thermostat.
-
#set_temperature_threshold(device_id:, lower_limit_celsius: nil, lower_limit_fahrenheit: nil, upper_limit_celsius: nil, upper_limit_fahrenheit: nil) ⇒ nil
Sets a temperature threshold for a specified thermostat.
- #simulate ⇒ Object
-
#update_climate_preset(climate_preset_key:, device_id:, climate_preset_mode: nil, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, ecobee_metadata: nil, fan_mode_setting: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, hvac_mode_setting: nil, manual_override_allowed: nil, name: nil) ⇒ nil
deprecated
Deprecated.
manual_override_allowed: Use 'thermostat_schedule.is_override_allowed'
-
#update_weekly_program(device_id:, friday_program_id: nil, monday_program_id: nil, saturday_program_id: nil, sunday_program_id: nil, thursday_program_id: nil, tuesday_program_id: nil, wednesday_program_id: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Updates the thermostat weekly program for a thermostat device.
Constructor Details
#initialize(client:, defaults:) ⇒ Thermostats
Returns a new instance of Thermostats.
8 9 10 11 |
# File 'lib/seam/routes/thermostats.rb', line 8 def initialize(client:, defaults:) @client = client @defaults = defaults end |
Instance Method Details
#activate_climate_preset(climate_preset_key:, device_id:, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Activates a specified climate preset for a specified thermostat.
29 30 31 32 33 34 35 |
# File 'lib/seam/routes/thermostats.rb', line 29 def activate_climate_preset(climate_preset_key:, device_id:, wait_for_action_attempt: nil) res = @client.post("/thermostats/activate_climate_preset", {climate_preset_key: climate_preset_key, device_id: device_id}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#cool(device_id:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to cool mode.
42 43 44 45 46 47 48 |
# File 'lib/seam/routes/thermostats.rb', line 42 def cool(device_id:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, wait_for_action_attempt: nil) res = @client.post("/thermostats/cool", {device_id: device_id, cooling_set_point_celsius: cooling_set_point_celsius, cooling_set_point_fahrenheit: cooling_set_point_fahrenheit}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#create_climate_preset(climate_preset_key:, device_id:, climate_preset_mode: nil, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, ecobee_metadata: nil, fan_mode_setting: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, hvac_mode_setting: nil, manual_override_allowed: nil, name: nil) ⇒ nil
manual_override_allowed: Use 'thermostat_schedule.is_override_allowed'
Creates a climate preset for a specified thermostat.
65 66 67 68 69 |
# File 'lib/seam/routes/thermostats.rb', line 65 def create_climate_preset(climate_preset_key:, device_id:, climate_preset_mode: nil, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, ecobee_metadata: nil, fan_mode_setting: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, hvac_mode_setting: nil, manual_override_allowed: nil, name: nil) @client.post("/thermostats/create_climate_preset", {climate_preset_key: climate_preset_key, device_id: device_id, climate_preset_mode: climate_preset_mode, cooling_set_point_celsius: cooling_set_point_celsius, cooling_set_point_fahrenheit: cooling_set_point_fahrenheit, ecobee_metadata: , fan_mode_setting: fan_mode_setting, heating_set_point_celsius: heating_set_point_celsius, heating_set_point_fahrenheit: heating_set_point_fahrenheit, hvac_mode_setting: hvac_mode_setting, manual_override_allowed: manual_override_allowed, name: name}.compact) nil end |
#daily_programs ⇒ Object
13 14 15 |
# File 'lib/seam/routes/thermostats.rb', line 13 def daily_programs @daily_programs ||= Seam::Clients::ThermostatsDailyPrograms.new(client: @client, defaults: @defaults) end |
#delete_climate_preset(climate_preset_key:, device_id:) ⇒ nil
Deletes a specified climate preset for a specified thermostat.
75 76 77 78 79 |
# File 'lib/seam/routes/thermostats.rb', line 75 def delete_climate_preset(climate_preset_key:, device_id:) @client.post("/thermostats/delete_climate_preset", {climate_preset_key: climate_preset_key, device_id: device_id}.compact) nil end |
#heat(device_id:, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to heat mode.
86 87 88 89 90 91 92 |
# File 'lib/seam/routes/thermostats.rb', line 86 def heat(device_id:, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) res = @client.post("/thermostats/heat", {device_id: device_id, heating_set_point_celsius: heating_set_point_celsius, heating_set_point_fahrenheit: heating_set_point_fahrenheit}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#heat_cool(device_id:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to heat-cool ("auto") mode.
101 102 103 104 105 106 107 |
# File 'lib/seam/routes/thermostats.rb', line 101 def heat_cool(device_id:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) res = @client.post("/thermostats/heat_cool", {device_id: device_id, cooling_set_point_celsius: cooling_set_point_celsius, cooling_set_point_fahrenheit: cooling_set_point_fahrenheit, heating_set_point_celsius: heating_set_point_celsius, heating_set_point_fahrenheit: heating_set_point_fahrenheit}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, custom_metadata_has: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil, space_id: nil, unstable_location_id: nil, user_identifier_key: nil) ⇒ Seam::Resources::Device
unstable_location_id: Use space_id.
Returns a list of all thermostats.
128 129 130 131 132 |
# File 'lib/seam/routes/thermostats.rb', line 128 def list(connect_webview_id: nil, connected_account_id: nil, connected_account_ids: nil, created_before: nil, custom_metadata_has: nil, customer_key: nil, device_ids: nil, device_type: nil, device_types: nil, limit: nil, manufacturer: nil, page_cursor: nil, search: nil, space_id: nil, unstable_location_id: nil, user_identifier_key: nil) res = @client.post("/thermostats/list", {connect_webview_id: connect_webview_id, connected_account_id: connected_account_id, connected_account_ids: connected_account_ids, created_before: created_before, custom_metadata_has: , customer_key: customer_key, device_ids: device_ids, device_type: device_type, device_types: device_types, limit: limit, manufacturer: manufacturer, page_cursor: page_cursor, search: search, space_id: space_id, unstable_location_id: unstable_location_id, user_identifier_key: user_identifier_key}.compact) Seam::Resources::Device.load_from_response(res.body["devices"]) end |
#off(device_id:, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets a specified thermostat to "off" mode.
137 138 139 140 141 142 143 |
# File 'lib/seam/routes/thermostats.rb', line 137 def off(device_id:, wait_for_action_attempt: nil) res = @client.post("/thermostats/off", {device_id: device_id}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#schedules ⇒ Object
17 18 19 |
# File 'lib/seam/routes/thermostats.rb', line 17 def schedules @schedules ||= Seam::Clients::ThermostatsSchedules.new(client: @client, defaults: @defaults) end |
#set_fallback_climate_preset(climate_preset_key:, device_id:) ⇒ nil
Sets a specified climate preset as the "fallback" preset for a specified thermostat.
149 150 151 152 153 |
# File 'lib/seam/routes/thermostats.rb', line 149 def set_fallback_climate_preset(climate_preset_key:, device_id:) @client.post("/thermostats/set_fallback_climate_preset", {climate_preset_key: climate_preset_key, device_id: device_id}.compact) nil end |
#set_fan_mode(device_id:, fan_mode: nil, fan_mode_setting: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
fan_mode: Use fan_mode_setting instead.
Sets the fan mode setting for a specified thermostat.
161 162 163 164 165 166 167 |
# File 'lib/seam/routes/thermostats.rb', line 161 def set_fan_mode(device_id:, fan_mode: nil, fan_mode_setting: nil, wait_for_action_attempt: nil) res = @client.post("/thermostats/set_fan_mode", {device_id: device_id, fan_mode: fan_mode, fan_mode_setting: fan_mode_setting}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#set_hvac_mode(device_id:, hvac_mode_setting:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Sets the HVAC mode for a specified thermostat.
177 178 179 180 181 182 183 |
# File 'lib/seam/routes/thermostats.rb', line 177 def set_hvac_mode(device_id:, hvac_mode_setting:, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, wait_for_action_attempt: nil) res = @client.post("/thermostats/set_hvac_mode", {device_id: device_id, hvac_mode_setting: hvac_mode_setting, cooling_set_point_celsius: cooling_set_point_celsius, cooling_set_point_fahrenheit: cooling_set_point_fahrenheit, heating_set_point_celsius: heating_set_point_celsius, heating_set_point_fahrenheit: heating_set_point_fahrenheit}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |
#set_temperature_threshold(device_id:, lower_limit_celsius: nil, lower_limit_fahrenheit: nil, upper_limit_celsius: nil, upper_limit_fahrenheit: nil) ⇒ nil
Sets a temperature threshold for a specified thermostat. Seam emits a thermostat.temperature_threshold_exceeded event and adds a warning on a thermostat if it reports a temperature outside the threshold range.
192 193 194 195 196 |
# File 'lib/seam/routes/thermostats.rb', line 192 def set_temperature_threshold(device_id:, lower_limit_celsius: nil, lower_limit_fahrenheit: nil, upper_limit_celsius: nil, upper_limit_fahrenheit: nil) @client.post("/thermostats/set_temperature_threshold", {device_id: device_id, lower_limit_celsius: lower_limit_celsius, lower_limit_fahrenheit: lower_limit_fahrenheit, upper_limit_celsius: upper_limit_celsius, upper_limit_fahrenheit: upper_limit_fahrenheit}.compact) nil end |
#simulate ⇒ Object
21 22 23 |
# File 'lib/seam/routes/thermostats.rb', line 21 def simulate @simulate ||= Seam::Clients::ThermostatsSimulate.new(client: @client, defaults: @defaults) end |
#update_climate_preset(climate_preset_key:, device_id:, climate_preset_mode: nil, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, ecobee_metadata: nil, fan_mode_setting: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, hvac_mode_setting: nil, manual_override_allowed: nil, name: nil) ⇒ nil
manual_override_allowed: Use 'thermostat_schedule.is_override_allowed'
Updates a specified climate preset for a specified thermostat.
213 214 215 216 217 |
# File 'lib/seam/routes/thermostats.rb', line 213 def update_climate_preset(climate_preset_key:, device_id:, climate_preset_mode: nil, cooling_set_point_celsius: nil, cooling_set_point_fahrenheit: nil, ecobee_metadata: nil, fan_mode_setting: nil, heating_set_point_celsius: nil, heating_set_point_fahrenheit: nil, hvac_mode_setting: nil, manual_override_allowed: nil, name: nil) @client.post("/thermostats/update_climate_preset", {climate_preset_key: climate_preset_key, device_id: device_id, climate_preset_mode: climate_preset_mode, cooling_set_point_celsius: cooling_set_point_celsius, cooling_set_point_fahrenheit: cooling_set_point_fahrenheit, ecobee_metadata: , fan_mode_setting: fan_mode_setting, heating_set_point_celsius: heating_set_point_celsius, heating_set_point_fahrenheit: heating_set_point_fahrenheit, hvac_mode_setting: hvac_mode_setting, manual_override_allowed: manual_override_allowed, name: name}.compact) nil end |
#update_weekly_program(device_id:, friday_program_id: nil, monday_program_id: nil, saturday_program_id: nil, sunday_program_id: nil, thursday_program_id: nil, tuesday_program_id: nil, wednesday_program_id: nil, wait_for_action_attempt: nil) ⇒ Seam::Resources::ActionAttempt
Updates the thermostat weekly program for a thermostat device. To configure a weekly program, specify the ID of the daily program that you want to use for each day of the week. When you update a weekly program, the set of programs that you specify overwrites any previous weekly program for the thermostat.
229 230 231 232 233 234 235 |
# File 'lib/seam/routes/thermostats.rb', line 229 def update_weekly_program(device_id:, friday_program_id: nil, monday_program_id: nil, saturday_program_id: nil, sunday_program_id: nil, thursday_program_id: nil, tuesday_program_id: nil, wednesday_program_id: nil, wait_for_action_attempt: nil) res = @client.post("/thermostats/update_weekly_program", {device_id: device_id, friday_program_id: friday_program_id, monday_program_id: monday_program_id, saturday_program_id: saturday_program_id, sunday_program_id: sunday_program_id, thursday_program_id: thursday_program_id, tuesday_program_id: tuesday_program_id, wednesday_program_id: wednesday_program_id}.compact) wait_for_action_attempt = wait_for_action_attempt.nil? ? @defaults.wait_for_action_attempt : wait_for_action_attempt Helpers::ActionAttempt.decide_and_wait(Seam::Resources::ActionAttempt.load_from_response(res.body["action_attempt"]), @client, wait_for_action_attempt) end |