Class: Seam::Resources::AccessCode

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Represents a smart lock access code.

An access code is a code used for a keypad or pinpad device. Unlike physical keys, which can easily be lost or duplicated, PIN codes can be customized, tracked, and altered on the fly. Using the Seam Access Code API, you can easily generate access codes on the hundreds of door lock models with which we integrate.

Seam supports programming two types of access codes: ongoing and time-bound. To differentiate between the two, refer to the type property of the access code. Ongoing codes display as ongoing, whereas time-bound codes are labeled time_bound. An ongoing access code is active, until it has been removed from the device. To specify an ongoing access code, leave both starts_at and ends_at empty. A time-bound access code will be programmed at the starts_at time and removed at the ends_at time.

In addition, for certain devices, Seam also supports offline access codes. Offline access (PIN) codes are designed for door locks that might not always maintain an internet connection. For this type of access code, the device manufacturer uses encryption keys (tokens) to create server-based registries of algorithmically-generated offline PIN codes. Because the tokens remain synchronized with the managed devices, the locks do not require an active internet connection—and you do not need to be near the locks—to create an offline access code. Then, owners or managers can share these offline codes with users through a variety of mechanisms, such as messaging applications. That is, lock users do not need to install a smartphone application to receive an offline access code.

For granting a person access to a space, Access Grants are the default and recommended approach and work across both standalone smart locks and access systems. Use the lower-level Access Codes API directly only when you specifically need to manage individual PIN codes.

Defined Under Namespace

Classes: DormakabaOracodeMetadata, Errors, PendingMutations, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_code_idString

Unique identifier for the access code.

Returns:

  • (String)


810
811
812
# File 'lib/seam/resources/access_code.rb', line 810

def access_code_id
  @access_code_id
end

#codeString?

Code used for access. Typically, a numeric or alphanumeric string.

Returns:

  • (String, nil)


813
814
815
# File 'lib/seam/resources/access_code.rb', line 813

def code
  @code
end

#common_code_keyString?

Unique identifier for a group of access codes that share the same code.

Returns:

  • (String, nil)


816
817
818
# File 'lib/seam/resources/access_code.rb', line 816

def common_code_key
  @common_code_key
end

#device_idString

Unique identifier for the device associated with the access code.

Returns:

  • (String)


819
820
821
# File 'lib/seam/resources/access_code.rb', line 819

def device_id
  @device_id
end

#is_backupBoolean?

Indicates whether the access code is a backup code.

Returns:

  • (Boolean, nil)


822
823
824
# File 'lib/seam/resources/access_code.rb', line 822

def is_backup
  @is_backup
end

#is_backup_access_code_availableBoolean

Indicates whether a backup access code is available for use if the primary access code is lost or compromised.

Returns:

  • (Boolean)


825
826
827
# File 'lib/seam/resources/access_code.rb', line 825

def is_backup_access_code_available
  @is_backup_access_code_available
end

#is_external_modification_allowedBoolean

Indicates whether changes to the access code from external sources are permitted.

Returns:

  • (Boolean)


828
829
830
# File 'lib/seam/resources/access_code.rb', line 828

def is_external_modification_allowed
  @is_external_modification_allowed
end

#is_managedTrueClass

Indicates whether Seam manages the access code.

Returns:

  • (TrueClass)


831
832
833
# File 'lib/seam/resources/access_code.rb', line 831

def is_managed
  @is_managed
end

#is_offline_access_codeBoolean

Indicates whether the access code is intended for use in offline scenarios. If true, this code can be created on a device without a network connection.

Returns:

  • (Boolean)


834
835
836
# File 'lib/seam/resources/access_code.rb', line 834

def is_offline_access_code
  @is_offline_access_code
end

#is_one_time_useBoolean

Indicates whether the access code can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean)


837
838
839
# File 'lib/seam/resources/access_code.rb', line 837

def is_one_time_use
  @is_one_time_use
end

#is_scheduled_on_deviceBoolean?

Indicates whether the code is set on the device according to a preconfigured schedule.

Returns:

  • (Boolean, nil)


840
841
842
# File 'lib/seam/resources/access_code.rb', line 840

def is_scheduled_on_device
  @is_scheduled_on_device
end

#is_waiting_for_code_assignmentBoolean?

Indicates whether the access code is waiting for a code assignment.

Returns:

  • (Boolean, nil)


843
844
845
# File 'lib/seam/resources/access_code.rb', line 843

def is_waiting_for_code_assignment
  @is_waiting_for_code_assignment
end

#nameString?

Name of the access code. Enables administrators and users to identify the access code easily, especially when there are numerous access codes. Note that the name provided on Seam is used to identify the code on Seam and is not necessarily the name that will appear in the lock provider's app or on the device. This is because lock providers may have constraints on names, such as length, uniqueness, or characters that can be used. In addition, some lock providers may break down names into components such as first_name and last_name. To provide a consistent experience, Seam identifies the code on Seam by its name but may modify the name that appears on the lock provider's app or on the device. For example, Seam may add additional characters or truncate the name to meet provider constraints. To help your users identify codes set by Seam, Seam provides the name exactly as it appears on the lock provider's app or on the device as a separate property called appearance. This is an object with a name property and, optionally, first_name and last_name properties (for providers that break down a name into components).

Returns:

  • (String, nil)


846
847
848
# File 'lib/seam/resources/access_code.rb', line 846

def name
  @name
end

#pulled_backup_access_code_idString?

Identifier of the pulled backup access code. Used to associate the pulled backup access code with the original access code.

Returns:

  • (String, nil)


849
850
851
# File 'lib/seam/resources/access_code.rb', line 849

def pulled_backup_access_code_id
  @pulled_backup_access_code_id
end

#statusString

Current status of the access code within the operational lifecycle. Values are setting, a transitional phase that indicates that the code is being configured or activated; set, which indicates that the code is active and operational; unset, which indicates a deactivated or unused state, either before activation or after deliberate deactivation; removing, which indicates a transitional period in which the code is being deleted or made inactive; and unknown, which indicates an indeterminate state, due to reasons such as system errors or incomplete data, that highlights a potential need for system review or troubleshooting. See also Lifecycle of Access Codes. Known values:

  • setting
  • set
  • unset
  • removing
  • unknown

Returns:

  • (String)


858
859
860
# File 'lib/seam/resources/access_code.rb', line 858

def status
  @status
end

#typeString

Type of the access code. ongoing access codes are active continuously until deactivated manually. time_bound access codes have a specific duration. Known values:

  • time_bound
  • ongoing

Returns:

  • (String)


864
865
866
# File 'lib/seam/resources/access_code.rb', line 864

def type
  @type
end

#workspace_idString

Unique identifier for the Seam workspace associated with the access code.

Returns:

  • (String)


867
868
869
# File 'lib/seam/resources/access_code.rb', line 867

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the access code was created.

Returns:

  • (Time)


871
# File 'lib/seam/resources/access_code.rb', line 871

date_accessor :created_at

#dormakaba_oracode_metadataDormakabaOracodeMetadata?

Metadata for a dormakaba Oracode managed access code. Only present for access codes from dormakaba Oracode devices.

Returns:



798
# File 'lib/seam/resources/access_code.rb', line 798

resource_accessor :dormakaba_oracode_metadata, DormakabaOracodeMetadata

#ends_atTime?

Date and time after which the time-bound access code becomes inactive.

Returns:

  • (Time, nil)


875
# File 'lib/seam/resources/access_code.rb', line 875

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the access code.

Returns:



801
# File 'lib/seam/resources/access_code.rb', line 801

resource_list_accessor :errors, Errors

#pending_mutationsArray<PendingMutations>

Collection of pending mutations for the access code. Indicates changes that Seam is in the process of pushing to the device.

Returns:



804
# File 'lib/seam/resources/access_code.rb', line 804

resource_list_accessor :pending_mutations, PendingMutations

#starts_atTime?

Date and time at which the time-bound access code becomes active.

Returns:

  • (Time, nil)


879
# File 'lib/seam/resources/access_code.rb', line 879

date_accessor :starts_at

#warningsArray<Warnings>

Warnings associated with the access code.

Returns:



807
# File 'lib/seam/resources/access_code.rb', line 807

resource_list_accessor :warnings, Warnings