Class: Seam::Resources::AccessCode

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/access_code.rb

Overview

Represents a smart lock access code.

An access code is a code used for a keypad or pinpad device. Unlike physical keys, which can easily be lost or duplicated, PIN codes can be customized, tracked, and altered on the fly. Using the Seam Access Code API, you can easily generate access codes on the hundreds of door lock models with which we integrate.

Seam supports programming two types of access codes: ongoing and time-bound. To differentiate between the two, refer to the type property of the access code. Ongoing codes display as ongoing, whereas time-bound codes are labeled time_bound. An ongoing access code is active, until it has been removed from the device. To specify an ongoing access code, leave both starts_at and ends_at empty. A time-bound access code will be programmed at the starts_at time and removed at the ends_at time.

In addition, for certain devices, Seam also supports offline access codes. Offline access (PIN) codes are designed for door locks that might not always maintain an internet connection. For this type of access code, the device manufacturer uses encryption keys (tokens) to create server-based registries of algorithmically-generated offline PIN codes. Because the tokens remain synchronized with the managed devices, the locks do not require an active internet connection—and you do not need to be near the locks—to create an offline access code. Then, owners or managers can share these offline codes with users through a variety of mechanisms, such as messaging applications. That is, lock users do not need to install a smartphone application to receive an offline access code.

For granting a person access to a space, Access Grants are the default and recommended approach and work across both standalone smart locks and access systems. Use the lower-level Access Codes API directly only when you specifically need to manage individual PIN codes.

Defined Under Namespace

Classes: DormakabaOracodeMetadata, Errors, PendingMutations, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_code_idObject

Unique identifier for the access code.



125
126
127
# File 'lib/seam/resources/access_code.rb', line 125

def access_code_id
  @access_code_id
end

#codeObject

Code used for access. Typically, a numeric or alphanumeric string.



127
128
129
# File 'lib/seam/resources/access_code.rb', line 127

def code
  @code
end

#common_code_keyObject

Unique identifier for a group of access codes that share the same code.



129
130
131
# File 'lib/seam/resources/access_code.rb', line 129

def common_code_key
  @common_code_key
end

#device_idObject

Unique identifier for the device associated with the access code.



131
132
133
# File 'lib/seam/resources/access_code.rb', line 131

def device_id
  @device_id
end

#is_backupObject

Indicates whether the access code is a backup code.



133
134
135
# File 'lib/seam/resources/access_code.rb', line 133

def is_backup
  @is_backup
end

#is_backup_access_code_availableObject

Indicates whether a backup access code is available for use if the primary access code is lost or compromised.



135
136
137
# File 'lib/seam/resources/access_code.rb', line 135

def is_backup_access_code_available
  @is_backup_access_code_available
end

#is_external_modification_allowedObject

Indicates whether changes to the access code from external sources are permitted.



137
138
139
# File 'lib/seam/resources/access_code.rb', line 137

def is_external_modification_allowed
  @is_external_modification_allowed
end

#is_managedObject

Indicates whether Seam manages the access code.



139
140
141
# File 'lib/seam/resources/access_code.rb', line 139

def is_managed
  @is_managed
end

#is_offline_access_codeObject

Indicates whether the access code is intended for use in offline scenarios. If true, this code can be created on a device without a network connection.



141
142
143
# File 'lib/seam/resources/access_code.rb', line 141

def is_offline_access_code
  @is_offline_access_code
end

#is_one_time_useObject

Indicates whether the access code can only be used once. If true, the code becomes invalid after the first use.



143
144
145
# File 'lib/seam/resources/access_code.rb', line 143

def is_one_time_use
  @is_one_time_use
end

#is_scheduled_on_deviceObject

Indicates whether the code is set on the device according to a preconfigured schedule.



145
146
147
# File 'lib/seam/resources/access_code.rb', line 145

def is_scheduled_on_device
  @is_scheduled_on_device
end

#is_waiting_for_code_assignmentObject

Indicates whether the access code is waiting for a code assignment.



147
148
149
# File 'lib/seam/resources/access_code.rb', line 147

def is_waiting_for_code_assignment
  @is_waiting_for_code_assignment
end

#nameObject

Name of the access code. Enables administrators and users to identify the access code easily, especially when there are numerous access codes. Note that the name provided on Seam is used to identify the code on Seam and is not necessarily the name that will appear in the lock provider's app or on the device. This is because lock providers may have constraints on names, such as length, uniqueness, or characters that can be used. In addition, some lock providers may break down names into components such as first_name and last_name. To provide a consistent experience, Seam identifies the code on Seam by its name but may modify the name that appears on the lock provider's app or on the device. For example, Seam may add additional characters or truncate the name to meet provider constraints. To help your users identify codes set by Seam, Seam provides the name exactly as it appears on the lock provider's app or on the device as a separate property called appearance. This is an object with a name property and, optionally, first_name and last_name properties (for providers that break down a name into components).



149
150
151
# File 'lib/seam/resources/access_code.rb', line 149

def name
  @name
end

#pulled_backup_access_code_idObject

Identifier of the pulled backup access code. Used to associate the pulled backup access code with the original access code.



151
152
153
# File 'lib/seam/resources/access_code.rb', line 151

def pulled_backup_access_code_id
  @pulled_backup_access_code_id
end

#statusObject

Current status of the access code within the operational lifecycle. Values are setting, a transitional phase that indicates that the code is being configured or activated; set, which indicates that the code is active and operational; unset, which indicates a deactivated or unused state, either before activation or after deliberate deactivation; removing, which indicates a transitional period in which the code is being deleted or made inactive; and unknown, which indicates an indeterminate state, due to reasons such as system errors or incomplete data, that highlights a potential need for system review or troubleshooting. See also Lifecycle of Access Codes.



153
154
155
# File 'lib/seam/resources/access_code.rb', line 153

def status
  @status
end

#typeObject

Type of the access code. ongoing access codes are active continuously until deactivated manually. time_bound access codes have a specific duration.



155
156
157
# File 'lib/seam/resources/access_code.rb', line 155

def type
  @type
end

#workspace_idObject

Unique identifier for the Seam workspace associated with the access code.



157
158
159
# File 'lib/seam/resources/access_code.rb', line 157

def workspace_id
  @workspace_id
end