Class: Seam::Resources::AccessCode
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessCode
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Represents a smart lock access code.
An access code is a code used for a keypad or pinpad device. Unlike physical keys, which can easily be lost or duplicated, PIN codes can be customized, tracked, and altered on the fly. Using the Seam Access Code API, you can easily generate access codes on the hundreds of door lock models with which we integrate.
Seam supports programming two types of access codes: ongoing and time-bound. To differentiate between the two, refer to the type property of the access code. Ongoing codes display as ongoing, whereas time-bound codes are labeled time_bound. An ongoing access code is active, until it has been removed from the device. To specify an ongoing access code, leave both starts_at and ends_at empty. A time-bound access code will be programmed at the starts_at time and removed at the ends_at time.
In addition, for certain devices, Seam also supports offline access codes. Offline access (PIN) codes are designed for door locks that might not always maintain an internet connection. For this type of access code, the device manufacturer uses encryption keys (tokens) to create server-based registries of algorithmically-generated offline PIN codes. Because the tokens remain synchronized with the managed devices, the locks do not require an active internet connection—and you do not need to be near the locks—to create an offline access code. Then, owners or managers can share these offline codes with users through a variety of mechanisms, such as messaging applications. That is, lock users do not need to install a smartphone application to receive an offline access code.
For granting a person access to a space, Access Grants are the default and recommended approach and work across both standalone smart locks and access systems. Use the lower-level Access Codes API directly only when you specifically need to manage individual PIN codes.
Instance Attribute Summary collapse
-
#access_code_id ⇒ Object
Unique identifier for the access code.
-
#code ⇒ Object
Code used for access.
-
#common_code_key ⇒ Object
Unique identifier for a group of access codes that share the same code.
-
#device_id ⇒ Object
Unique identifier for the device associated with the access code.
-
#dormakaba_oracode_metadata ⇒ Object
Metadata for a dormakaba Oracode managed access code.
-
#is_backup ⇒ Object
Indicates whether the access code is a backup code.
-
#is_backup_access_code_available ⇒ Object
Indicates whether a backup access code is available for use if the primary access code is lost or compromised.
-
#is_external_modification_allowed ⇒ Object
Indicates whether changes to the access code from external sources are permitted.
-
#is_managed ⇒ Object
Indicates whether Seam manages the access code.
-
#is_offline_access_code ⇒ Object
Indicates whether the access code is intended for use in offline scenarios.
-
#is_one_time_use ⇒ Object
Indicates whether the access code can only be used once.
-
#is_scheduled_on_device ⇒ Object
Indicates whether the code is set on the device according to a preconfigured schedule.
-
#is_waiting_for_code_assignment ⇒ Object
Indicates whether the access code is waiting for a code assignment.
-
#name ⇒ Object
Name of the access code.
-
#pending_mutations ⇒ Object
Collection of pending mutations for the access code.
-
#pulled_backup_access_code_id ⇒ Object
Identifier of the pulled backup access code.
-
#status ⇒ Object
Current status of the access code within the operational lifecycle.
-
#type ⇒ Object
Type of the access code.
-
#workspace_id ⇒ Object
Unique identifier for the Seam workspace associated with the access code.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_code_id ⇒ Object
Unique identifier for the access code.
16 17 18 |
# File 'lib/seam/resources/access_code.rb', line 16 def access_code_id @access_code_id end |
#code ⇒ Object
Code used for access. Typically, a numeric or alphanumeric string.
18 19 20 |
# File 'lib/seam/resources/access_code.rb', line 18 def code @code end |
#common_code_key ⇒ Object
Unique identifier for a group of access codes that share the same code.
20 21 22 |
# File 'lib/seam/resources/access_code.rb', line 20 def common_code_key @common_code_key end |
#device_id ⇒ Object
Unique identifier for the device associated with the access code.
22 23 24 |
# File 'lib/seam/resources/access_code.rb', line 22 def device_id @device_id end |
#dormakaba_oracode_metadata ⇒ Object
Metadata for a dormakaba Oracode managed access code. Only present for access codes from dormakaba Oracode devices.
24 25 26 |
# File 'lib/seam/resources/access_code.rb', line 24 def @dormakaba_oracode_metadata end |
#is_backup ⇒ Object
Indicates whether the access code is a backup code.
26 27 28 |
# File 'lib/seam/resources/access_code.rb', line 26 def is_backup @is_backup end |
#is_backup_access_code_available ⇒ Object
Indicates whether a backup access code is available for use if the primary access code is lost or compromised.
28 29 30 |
# File 'lib/seam/resources/access_code.rb', line 28 def is_backup_access_code_available @is_backup_access_code_available end |
#is_external_modification_allowed ⇒ Object
Indicates whether changes to the access code from external sources are permitted.
30 31 32 |
# File 'lib/seam/resources/access_code.rb', line 30 def is_external_modification_allowed @is_external_modification_allowed end |
#is_managed ⇒ Object
Indicates whether Seam manages the access code.
32 33 34 |
# File 'lib/seam/resources/access_code.rb', line 32 def is_managed @is_managed end |
#is_offline_access_code ⇒ Object
Indicates whether the access code is intended for use in offline scenarios. If true, this code can be created on a device without a network connection.
34 35 36 |
# File 'lib/seam/resources/access_code.rb', line 34 def is_offline_access_code @is_offline_access_code end |
#is_one_time_use ⇒ Object
Indicates whether the access code can only be used once. If true, the code becomes invalid after the first use.
36 37 38 |
# File 'lib/seam/resources/access_code.rb', line 36 def is_one_time_use @is_one_time_use end |
#is_scheduled_on_device ⇒ Object
Indicates whether the code is set on the device according to a preconfigured schedule.
38 39 40 |
# File 'lib/seam/resources/access_code.rb', line 38 def is_scheduled_on_device @is_scheduled_on_device end |
#is_waiting_for_code_assignment ⇒ Object
Indicates whether the access code is waiting for a code assignment.
40 41 42 |
# File 'lib/seam/resources/access_code.rb', line 40 def is_waiting_for_code_assignment @is_waiting_for_code_assignment end |
#name ⇒ Object
Name of the access code. Enables administrators and users to identify the access code easily, especially when there are numerous access codes. Note that the name provided on Seam is used to identify the code on Seam and is not necessarily the name that will appear in the lock provider's app or on the device. This is because lock providers may have constraints on names, such as length, uniqueness, or characters that can be used. In addition, some lock providers may break down names into components such as first_name and last_name. To provide a consistent experience, Seam identifies the code on Seam by its name but may modify the name that appears on the lock provider's app or on the device. For example, Seam may add additional characters or truncate the name to meet provider constraints. To help your users identify codes set by Seam, Seam provides the name exactly as it appears on the lock provider's app or on the device as a separate property called appearance. This is an object with a name property and, optionally, first_name and last_name properties (for providers that break down a name into components).
42 43 44 |
# File 'lib/seam/resources/access_code.rb', line 42 def name @name end |
#pending_mutations ⇒ Object
Collection of pending mutations for the access code. Indicates changes that Seam is in the process of pushing to the device.
44 45 46 |
# File 'lib/seam/resources/access_code.rb', line 44 def pending_mutations @pending_mutations end |
#pulled_backup_access_code_id ⇒ Object
Identifier of the pulled backup access code. Used to associate the pulled backup access code with the original access code.
46 47 48 |
# File 'lib/seam/resources/access_code.rb', line 46 def pulled_backup_access_code_id @pulled_backup_access_code_id end |
#status ⇒ Object
Current status of the access code within the operational lifecycle. Values are setting, a transitional phase that indicates that the code is being configured or activated; set, which indicates that the code is active and operational; unset, which indicates a deactivated or unused state, either before activation or after deliberate deactivation; removing, which indicates a transitional period in which the code is being deleted or made inactive; and unknown, which indicates an indeterminate state, due to reasons such as system errors or incomplete data, that highlights a potential need for system review or troubleshooting. See also Lifecycle of Access Codes.
48 49 50 |
# File 'lib/seam/resources/access_code.rb', line 48 def status @status end |
#type ⇒ Object
Type of the access code. ongoing access codes are active continuously until deactivated manually. time_bound access codes have a specific duration.
50 51 52 |
# File 'lib/seam/resources/access_code.rb', line 50 def type @type end |
#workspace_id ⇒ Object
Unique identifier for the Seam workspace associated with the access code.
52 53 54 |
# File 'lib/seam/resources/access_code.rb', line 52 def workspace_id @workspace_id end |