Class: Seam::Resources::AccessCode::DormakabaOracodeMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#is_cancellableObject

Indicates whether the stay can be cancelled via the Dormakaba Oracode API.



17
18
19
# File 'lib/seam/resources/access_code.rb', line 17

def is_cancellable
  @is_cancellable
end

#is_early_checkin_ableObject

Indicates whether early check-in is available for this stay.



19
20
21
# File 'lib/seam/resources/access_code.rb', line 19

def is_early_checkin_able
  @is_early_checkin_able
end

#is_extendableObject

Indicates whether the stay can be extended via the Dormakaba Oracode API.



21
22
23
# File 'lib/seam/resources/access_code.rb', line 21

def is_extendable
  @is_extendable
end

#is_overridableObject

Indicates whether the access code can be overridden. When false, the maximum number of overrides has been reached.



23
24
25
# File 'lib/seam/resources/access_code.rb', line 23

def is_overridable
  @is_overridable
end

#site_nameObject

Dormakaba Oracode site name associated with this access code.



25
26
27
# File 'lib/seam/resources/access_code.rb', line 25

def site_name
  @site_name
end

#stay_idObject

Dormakaba Oracode stay ID associated with this access code.



27
28
29
# File 'lib/seam/resources/access_code.rb', line 27

def stay_id
  @stay_id
end

#user_level_idObject

Dormakaba Oracode user level ID associated with this access code.



29
30
31
# File 'lib/seam/resources/access_code.rb', line 29

def user_level_id
  @user_level_id
end

#user_level_nameObject

Dormakaba Oracode user level name associated with this access code.



31
32
33
# File 'lib/seam/resources/access_code.rb', line 31

def user_level_name
  @user_level_name
end