Class: Seam::Resources::AccessCode::Errors::AugustLockNotAuthorized
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::AugustLockNotAuthorized
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that the user is not authorized to use the August lock.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
august_lock_not_authorized
377 378 379 |
# File 'lib/seam/resources/access_code.rb', line 377 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
380 381 382 |
# File 'lib/seam/resources/access_code.rb', line 380 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
383 384 385 |
# File 'lib/seam/resources/access_code.rb', line 383 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
386 |
# File 'lib/seam/resources/access_code.rb', line 386 date_accessor :created_at |