Class: Seam::Resources::AccessCode::Errors::CodeConstraintsViolated
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::CodeConstraintsViolated
- Defined in:
- lib/seam/resources/access_code.rb
Overview
The code cannot be set on the device because it violates the device's code constraints (for example, its length, digits, or a too-simple value). The code will not be retried until you change it. See the device's code_constraints and supported_code_lengths.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
code_constraints_violated
203 204 205 |
# File 'lib/seam/resources/access_code.rb', line 203 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
206 207 208 |
# File 'lib/seam/resources/access_code.rb', line 206 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
209 210 211 |
# File 'lib/seam/resources/access_code.rb', line 209 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
212 |
# File 'lib/seam/resources/access_code.rb', line 212 date_accessor :created_at |