Class: Seam::Resources::AccessCode::Errors::ConflictingExternalModification
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::ConflictingExternalModification
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Code was modified or removed externally after Seam successfully set it on the device. The external change conflicts with the state that Seam is trying to apply, so Seam will attempt to set the code on the device again.
Defined Under Namespace
Classes: ModifiedFields
Instance Attribute Summary collapse
-
#change_type ⇒ String?
Indicates the type of external modification.
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
-
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
Instance Attribute Details
#change_type ⇒ String?
Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.
Known values:
modifiedremoved
162 163 164 |
# File 'lib/seam/resources/access_code.rb', line 162 def change_type @change_type end |
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
conflicting_external_modification
167 168 169 |
# File 'lib/seam/resources/access_code.rb', line 167 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
170 171 172 |
# File 'lib/seam/resources/access_code.rb', line 170 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
173 174 175 |
# File 'lib/seam/resources/access_code.rb', line 173 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
176 |
# File 'lib/seam/resources/access_code.rb', line 176 date_accessor :created_at |
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
156 |
# File 'lib/seam/resources/access_code.rb', line 156 resource_list_accessor :modified_fields, ModifiedFields |