Class: Seam::Resources::AccessCode::Errors::FailedToExpire
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::FailedToExpire
- Defined in:
- lib/seam/resources/access_code.rb
Overview
This access code is still active on the device even though its ends_at has passed, so the recipient may still be able to unlock the device after their access window ended. Seam is attempting to remove it, and this error clears automatically once the access code is no longer active.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_expire
257 258 259 |
# File 'lib/seam/resources/access_code.rb', line 257 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
260 261 262 |
# File 'lib/seam/resources/access_code.rb', line 260 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
263 264 265 |
# File 'lib/seam/resources/access_code.rb', line 263 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
266 |
# File 'lib/seam/resources/access_code.rb', line 266 date_accessor :created_at |