Class: Seam::Resources::AccessCode::Errors::MissingDeviceCredentials
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessCode::Errors::MissingDeviceCredentials
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Indicates that device credentials are missing.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
missing_device_credentials
395 396 397 |
# File 'lib/seam/resources/access_code.rb', line 395 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
398 399 400 |
# File 'lib/seam/resources/access_code.rb', line 398 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
401 402 403 |
# File 'lib/seam/resources/access_code.rb', line 401 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
404 |
# File 'lib/seam/resources/access_code.rb', line 404 date_accessor :created_at |