Class: Seam::Resources::AccessCode::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessCode::PendingMutations
- Defined in:
- lib/seam/resources/access_code.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the mutation.
- #mutation_code ⇒ String
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the mutation was created.
- #from ⇒ From
-
#scheduled_at ⇒ Time
Date and time at which Seam will attempt to program this access code on the device.
- #to ⇒ To
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the mutation.
125 126 127 |
# File 'lib/seam/resources/access_code.rb', line 125 def @message end |
#mutation_code ⇒ String
127 128 129 |
# File 'lib/seam/resources/access_code.rb', line 127 def mutation_code @mutation_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the mutation was created.
130 |
# File 'lib/seam/resources/access_code.rb', line 130 date_accessor :created_at |
#scheduled_at ⇒ Time
Date and time at which Seam will attempt to program this access code on the device.
133 |
# File 'lib/seam/resources/access_code.rb', line 133 date_accessor :scheduled_at |