Class: Seam::Resources::AccessCode::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessCode::Warnings
- Defined in:
- lib/seam/resources/access_code.rb
Defined Under Namespace
Classes: ModifiedFields
Instance Attribute Summary collapse
-
#change_type ⇒ Object
Indicates the type of external modification.
-
#message ⇒ Object
Detailed description of the warning.
-
#warning_code ⇒ Object
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#change_type ⇒ Object
Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.
111 112 113 |
# File 'lib/seam/resources/access_code.rb', line 111 def change_type @change_type end |
#message ⇒ Object
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
113 114 115 |
# File 'lib/seam/resources/access_code.rb', line 113 def @message end |
#warning_code ⇒ Object
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
115 116 117 |
# File 'lib/seam/resources/access_code.rb', line 115 def warning_code @warning_code end |