Class: Seam::Resources::AccessCode::Warnings::CodeRotatesPeriodically

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/access_code.rb

Overview

The access code's PIN rotates periodically when the code is renewed. Retrieve the latest code before each use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


577
578
579
# File 'lib/seam/resources/access_code.rb', line 577

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • code_rotates_periodically

Returns:

  • (String)


582
583
584
# File 'lib/seam/resources/access_code.rb', line 582

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


585
# File 'lib/seam/resources/access_code.rb', line 585

date_accessor :created_at