Class: Seam::Resources::AccessCode::Warnings::CodeRotatesPeriodically
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessCode::Warnings::CodeRotatesPeriodically
- Defined in:
- lib/seam/resources/access_code.rb
Overview
The access code's PIN rotates periodically when the code is renewed. Retrieve the latest code before each use.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
577 578 579 |
# File 'lib/seam/resources/access_code.rb', line 577 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
code_rotates_periodically
582 583 584 |
# File 'lib/seam/resources/access_code.rb', line 582 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
585 |
# File 'lib/seam/resources/access_code.rb', line 585 date_accessor :created_at |