Class: Seam::Resources::AccessCode::Warnings::ExternalModificationInEffect
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessCode::Warnings::ExternalModificationInEffect
- Defined in:
- lib/seam/resources/access_code.rb
Overview
Code was modified or removed externally after Seam successfully set it on the device. External modification is allowed for this code, so the externally modified state is being honored.
Defined Under Namespace
Classes: ModifiedFields
Instance Attribute Summary collapse
-
#change_type ⇒ String?
Indicates the type of external modification.
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
-
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
Instance Attribute Details
#change_type ⇒ String?
Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.
Known values:
modifiedremoved
625 626 627 |
# File 'lib/seam/resources/access_code.rb', line 625 def change_type @change_type end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
628 629 630 |
# File 'lib/seam/resources/access_code.rb', line 628 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
external_modification_in_effect
633 634 635 |
# File 'lib/seam/resources/access_code.rb', line 633 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
636 |
# File 'lib/seam/resources/access_code.rb', line 636 date_accessor :created_at |
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
619 |
# File 'lib/seam/resources/access_code.rb', line 619 resource_list_accessor :modified_fields, ModifiedFields |