Class: Seam::Resources::AccessGrant

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/access_grant.rb

Overview

Represents an Access Grant. Access Grants enable you to grant a user identity access to spaces, entrances, and devices through one or more access methods, such as mobile keys, plastic cards, and PIN codes. You can create an Access Grant for an existing user identity, or you can create a new user identity while creating the new Access Grant.

Defined Under Namespace

Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_grant_idString

ID of the Access Grant.

Returns:

  • (String)


307
308
309
# File 'lib/seam/resources/access_grant.rb', line 307

def access_grant_id
  @access_grant_id
end

#access_grant_keyString?

Unique key for the access grant within the workspace.

Returns:

  • (String, nil)


310
311
312
# File 'lib/seam/resources/access_grant.rb', line 310

def access_grant_key
  @access_grant_key
end

#access_method_idsArray<String>

IDs of the access methods created for the Access Grant.

Returns:

  • (Array<String>)


313
314
315
# File 'lib/seam/resources/access_grant.rb', line 313

def access_method_ids
  @access_method_ids
end

#client_session_tokenString?

Client Session Token. Only returned if the Access Grant has a mobile_key access method.

Returns:

  • (String, nil)


316
317
318
# File 'lib/seam/resources/access_grant.rb', line 316

def client_session_token
  @client_session_token
end

#customization_profile_idString?

ID of the customization profile associated with the Access Grant.

Returns:

  • (String, nil)


319
320
321
# File 'lib/seam/resources/access_grant.rb', line 319

def customization_profile_id
  @customization_profile_id
end

#display_nameString

Display name of the Access Grant.

Returns:

  • (String)


322
323
324
# File 'lib/seam/resources/access_grant.rb', line 322

def display_name
  @display_name
end

#instant_key_urlString?

Instant Key URL. Only returned if the Access Grant has a single mobile_key access_method.

Returns:

  • (String, nil)


325
326
327
# File 'lib/seam/resources/access_grant.rb', line 325

def instant_key_url
  @instant_key_url
end

#location_idsArray<String>

Deprecated.

Use space_ids.

Returns:

  • (Array<String>)


328
329
330
# File 'lib/seam/resources/access_grant.rb', line 328

def location_ids
  @location_ids
end

#nameString?

Name of the Access Grant. If not provided, the display name will be computed.

Returns:

  • (String, nil)


331
332
333
# File 'lib/seam/resources/access_grant.rb', line 331

def name
  @name
end

#reservation_keyString?

Reservation key for the access grant.

Returns:

  • (String, nil)


334
335
336
# File 'lib/seam/resources/access_grant.rb', line 334

def reservation_key
  @reservation_key
end

#space_idsArray<String>

IDs of the spaces to which the Access Grant gives access.

Returns:

  • (Array<String>)


337
338
339
# File 'lib/seam/resources/access_grant.rb', line 337

def space_ids
  @space_ids
end

#user_identity_idString

ID of user identity to which the Access Grant gives access.

Returns:

  • (String)


340
341
342
# File 'lib/seam/resources/access_grant.rb', line 340

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the Seam workspace associated with the Access Grant.

Returns:

  • (String)


343
344
345
# File 'lib/seam/resources/access_grant.rb', line 343

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the Access Grant was created.

Returns:

  • (Time)


347
# File 'lib/seam/resources/access_grant.rb', line 347

date_accessor :created_at

#ends_atTime?

Date and time at which the Access Grant ends.

Returns:

  • (Time, nil)


351
# File 'lib/seam/resources/access_grant.rb', line 351

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the access grant.

Returns:



295
# File 'lib/seam/resources/access_grant.rb', line 295

resource_list_accessor :errors, Errors

#pending_mutationsArray<PendingMutations>

List of pending mutations for the access grant. This shows updates that are in progress.

Returns:



298
# File 'lib/seam/resources/access_grant.rb', line 298

resource_list_accessor :pending_mutations, PendingMutations

#requested_access_methodsArray<RequestedAccessMethods>

Access methods that the user requested for the Access Grant.

Returns:



301
# File 'lib/seam/resources/access_grant.rb', line 301

resource_list_accessor :requested_access_methods, RequestedAccessMethods

#starts_atTime

Date and time at which the Access Grant starts.

Returns:

  • (Time)


355
# File 'lib/seam/resources/access_grant.rb', line 355

date_accessor :starts_at

#warningsArray<Warnings>

Warnings associated with the access grant.

Returns:



304
# File 'lib/seam/resources/access_grant.rb', line 304

resource_list_accessor :warnings, Warnings