Class: Seam::Resources::AccessGrant
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessGrant
- Defined in:
- lib/seam/resources/access_grant.rb
Overview
Represents an Access Grant. Access Grants enable you to grant a user identity access to spaces, entrances, and devices through one or more access methods, such as mobile keys, plastic cards, and PIN codes. You can create an Access Grant for an existing user identity, or you can create a new user identity while creating the new Access Grant.
Defined Under Namespace
Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the Access Grant.
-
#access_grant_key ⇒ String?
Unique key for the access grant within the workspace.
-
#access_method_ids ⇒ Array<String>
IDs of the access methods created for the Access Grant.
-
#client_session_token ⇒ String?
Client Session Token.
-
#customization_profile_id ⇒ String?
ID of the customization profile associated with the Access Grant.
-
#display_name ⇒ String
Display name of the Access Grant.
-
#instant_key_url ⇒ String?
Instant Key URL.
-
#location_ids ⇒ Array<String>
deprecated
Deprecated.
Use
space_ids. -
#name ⇒ String?
Name of the Access Grant.
-
#reservation_key ⇒ String?
Reservation key for the access grant.
-
#space_ids ⇒ Array<String>
IDs of the spaces to which the Access Grant gives access.
-
#user_identity_id ⇒ String
ID of user identity to which the Access Grant gives access.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the Access Grant.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the Access Grant was created.
-
#ends_at ⇒ Time?
Date and time at which the Access Grant ends.
-
#errors ⇒ Array<Errors>
Errors associated with the access grant.
-
#pending_mutations ⇒ Array<PendingMutations>
List of pending mutations for the access grant.
-
#requested_access_methods ⇒ Array<RequestedAccessMethods>
Access methods that the user requested for the Access Grant.
-
#starts_at ⇒ Time
Date and time at which the Access Grant starts.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access grant.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_grant_id ⇒ String
ID of the Access Grant.
307 308 309 |
# File 'lib/seam/resources/access_grant.rb', line 307 def access_grant_id @access_grant_id end |
#access_grant_key ⇒ String?
Unique key for the access grant within the workspace.
310 311 312 |
# File 'lib/seam/resources/access_grant.rb', line 310 def access_grant_key @access_grant_key end |
#access_method_ids ⇒ Array<String>
IDs of the access methods created for the Access Grant.
313 314 315 |
# File 'lib/seam/resources/access_grant.rb', line 313 def access_method_ids @access_method_ids end |
#client_session_token ⇒ String?
Client Session Token. Only returned if the Access Grant has a mobile_key access method.
316 317 318 |
# File 'lib/seam/resources/access_grant.rb', line 316 def client_session_token @client_session_token end |
#customization_profile_id ⇒ String?
ID of the customization profile associated with the Access Grant.
319 320 321 |
# File 'lib/seam/resources/access_grant.rb', line 319 def customization_profile_id @customization_profile_id end |
#display_name ⇒ String
Display name of the Access Grant.
322 323 324 |
# File 'lib/seam/resources/access_grant.rb', line 322 def display_name @display_name end |
#instant_key_url ⇒ String?
Instant Key URL. Only returned if the Access Grant has a single mobile_key access_method.
325 326 327 |
# File 'lib/seam/resources/access_grant.rb', line 325 def instant_key_url @instant_key_url end |
#location_ids ⇒ Array<String>
Use space_ids.
328 329 330 |
# File 'lib/seam/resources/access_grant.rb', line 328 def location_ids @location_ids end |
#name ⇒ String?
Name of the Access Grant. If not provided, the display name will be computed.
331 332 333 |
# File 'lib/seam/resources/access_grant.rb', line 331 def name @name end |
#reservation_key ⇒ String?
Reservation key for the access grant.
334 335 336 |
# File 'lib/seam/resources/access_grant.rb', line 334 def reservation_key @reservation_key end |
#space_ids ⇒ Array<String>
IDs of the spaces to which the Access Grant gives access.
337 338 339 |
# File 'lib/seam/resources/access_grant.rb', line 337 def space_ids @space_ids end |
#user_identity_id ⇒ String
ID of user identity to which the Access Grant gives access.
340 341 342 |
# File 'lib/seam/resources/access_grant.rb', line 340 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the Access Grant.
343 344 345 |
# File 'lib/seam/resources/access_grant.rb', line 343 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the Access Grant was created.
347 |
# File 'lib/seam/resources/access_grant.rb', line 347 date_accessor :created_at |
#ends_at ⇒ Time?
Date and time at which the Access Grant ends.
351 |
# File 'lib/seam/resources/access_grant.rb', line 351 date_accessor :ends_at |
#errors ⇒ Array<Errors>
Errors associated with the access grant.
295 |
# File 'lib/seam/resources/access_grant.rb', line 295 resource_list_accessor :errors, Errors |
#pending_mutations ⇒ Array<PendingMutations>
List of pending mutations for the access grant. This shows updates that are in progress.
298 |
# File 'lib/seam/resources/access_grant.rb', line 298 resource_list_accessor :pending_mutations, PendingMutations |
#requested_access_methods ⇒ Array<RequestedAccessMethods>
Access methods that the user requested for the Access Grant.
301 |
# File 'lib/seam/resources/access_grant.rb', line 301 resource_list_accessor :requested_access_methods, RequestedAccessMethods |
#starts_at ⇒ Time
Date and time at which the Access Grant starts.
355 |
# File 'lib/seam/resources/access_grant.rb', line 355 date_accessor :starts_at |
#warnings ⇒ Array<Warnings>
Warnings associated with the access grant.
304 |
# File 'lib/seam/resources/access_grant.rb', line 304 resource_list_accessor :warnings, Warnings |