Class: Seam::Resources::AccessGrant

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/access_grant.rb

Overview

Represents an Access Grant. Access Grants enable you to grant a user identity access to spaces, entrances, and devices through one or more access methods, such as mobile keys, plastic cards, and PIN codes. You can create an Access Grant for an existing user identity, or you can create a new user identity while creating the new Access Grant.

Defined Under Namespace

Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_grant_idString

ID of the Access Grant.

Returns:

  • (String)


143
144
145
# File 'lib/seam/resources/access_grant.rb', line 143

def access_grant_id
  @access_grant_id
end

#access_grant_keyString?

Unique key for the access grant within the workspace.

Returns:

  • (String, nil)


146
147
148
# File 'lib/seam/resources/access_grant.rb', line 146

def access_grant_key
  @access_grant_key
end

#access_method_idsArray<String>

IDs of the access methods created for the Access Grant.

Returns:

  • (Array<String>)


149
150
151
# File 'lib/seam/resources/access_grant.rb', line 149

def access_method_ids
  @access_method_ids
end

#client_session_tokenString?

Client Session Token. Only returned if the Access Grant has a mobile_key access method.

Returns:

  • (String, nil)


152
153
154
# File 'lib/seam/resources/access_grant.rb', line 152

def client_session_token
  @client_session_token
end

#customization_profile_idString?

ID of the customization profile associated with the Access Grant.

Returns:

  • (String, nil)


155
156
157
# File 'lib/seam/resources/access_grant.rb', line 155

def customization_profile_id
  @customization_profile_id
end

#display_nameString

Display name of the Access Grant.

Returns:

  • (String)


158
159
160
# File 'lib/seam/resources/access_grant.rb', line 158

def display_name
  @display_name
end

#instant_key_urlString?

Instant Key URL. Only returned if the Access Grant has a single mobile_key access_method.

Returns:

  • (String, nil)


161
162
163
# File 'lib/seam/resources/access_grant.rb', line 161

def instant_key_url
  @instant_key_url
end

#location_idsArray<String>

Deprecated.

Use space_ids.

Returns:

  • (Array<String>)


164
165
166
# File 'lib/seam/resources/access_grant.rb', line 164

def location_ids
  @location_ids
end

#nameString?

Name of the Access Grant. If not provided, the display name will be computed.

Returns:

  • (String, nil)


167
168
169
# File 'lib/seam/resources/access_grant.rb', line 167

def name
  @name
end

#reservation_keyString?

Reservation key for the access grant.

Returns:

  • (String, nil)


170
171
172
# File 'lib/seam/resources/access_grant.rb', line 170

def reservation_key
  @reservation_key
end

#space_idsArray<String>

IDs of the spaces to which the Access Grant gives access.

Returns:

  • (Array<String>)


173
174
175
# File 'lib/seam/resources/access_grant.rb', line 173

def space_ids
  @space_ids
end

#user_identity_idString

ID of user identity to which the Access Grant gives access.

Returns:

  • (String)


176
177
178
# File 'lib/seam/resources/access_grant.rb', line 176

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the Seam workspace associated with the Access Grant.

Returns:

  • (String)


179
180
181
# File 'lib/seam/resources/access_grant.rb', line 179

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the Access Grant was created.

Returns:

  • (Time)


183
# File 'lib/seam/resources/access_grant.rb', line 183

date_accessor :created_at

#ends_atTime?

Date and time at which the Access Grant ends.

Returns:

  • (Time, nil)


187
# File 'lib/seam/resources/access_grant.rb', line 187

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the access grant.

Returns:



131
# File 'lib/seam/resources/access_grant.rb', line 131

resource_list_accessor :errors, Errors

#pending_mutationsArray<PendingMutations>

List of pending mutations for the access grant. This shows updates that are in progress.

Returns:



134
# File 'lib/seam/resources/access_grant.rb', line 134

resource_list_accessor :pending_mutations, PendingMutations

#requested_access_methodsArray<RequestedAccessMethods>

Access methods that the user requested for the Access Grant.

Returns:



137
# File 'lib/seam/resources/access_grant.rb', line 137

resource_list_accessor :requested_access_methods, RequestedAccessMethods

#starts_atTime

Date and time at which the Access Grant starts.

Returns:

  • (Time)


191
# File 'lib/seam/resources/access_grant.rb', line 191

date_accessor :starts_at

#warningsArray<Warnings>

Warnings associated with the access grant.

Returns:



140
# File 'lib/seam/resources/access_grant.rb', line 140

resource_list_accessor :warnings, Warnings