Class: Seam::Resources::AccessGrant
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessGrant
- Defined in:
- lib/seam/resources/access_grant.rb
Overview
Represents an Access Grant. Access Grants enable you to grant a user identity access to spaces, entrances, and devices through one or more access methods, such as mobile keys, plastic cards, and PIN codes. You can create an Access Grant for an existing user identity, or you can create a new user identity while creating the new Access Grant.
Defined Under Namespace
Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings
Instance Attribute Summary collapse
-
#access_grant_id ⇒ Object
ID of the Access Grant.
-
#access_grant_key ⇒ Object
Unique key for the access grant within the workspace.
-
#access_method_ids ⇒ Object
IDs of the access methods created for the Access Grant.
-
#client_session_token ⇒ Object
Client Session Token.
-
#customization_profile_id ⇒ Object
ID of the customization profile associated with the Access Grant.
-
#display_name ⇒ Object
Display name of the Access Grant.
-
#instant_key_url ⇒ Object
Instant Key URL.
-
#location_ids ⇒ Object
deprecated
Deprecated.
Use
space_ids. -
#name ⇒ Object
Name of the Access Grant.
-
#reservation_key ⇒ Object
Reservation key for the access grant.
-
#space_ids ⇒ Object
IDs of the spaces to which the Access Grant gives access.
-
#user_identity_id ⇒ Object
ID of user identity to which the Access Grant gives access.
-
#workspace_id ⇒ Object
ID of the Seam workspace associated with the Access Grant.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_grant_id ⇒ Object
ID of the Access Grant.
98 99 100 |
# File 'lib/seam/resources/access_grant.rb', line 98 def access_grant_id @access_grant_id end |
#access_grant_key ⇒ Object
Unique key for the access grant within the workspace.
100 101 102 |
# File 'lib/seam/resources/access_grant.rb', line 100 def access_grant_key @access_grant_key end |
#access_method_ids ⇒ Object
IDs of the access methods created for the Access Grant.
102 103 104 |
# File 'lib/seam/resources/access_grant.rb', line 102 def access_method_ids @access_method_ids end |
#client_session_token ⇒ Object
Client Session Token. Only returned if the Access Grant has a mobile_key access method.
104 105 106 |
# File 'lib/seam/resources/access_grant.rb', line 104 def client_session_token @client_session_token end |
#customization_profile_id ⇒ Object
ID of the customization profile associated with the Access Grant.
106 107 108 |
# File 'lib/seam/resources/access_grant.rb', line 106 def customization_profile_id @customization_profile_id end |
#display_name ⇒ Object
Display name of the Access Grant.
108 109 110 |
# File 'lib/seam/resources/access_grant.rb', line 108 def display_name @display_name end |
#instant_key_url ⇒ Object
Instant Key URL. Only returned if the Access Grant has a single mobile_key access_method.
110 111 112 |
# File 'lib/seam/resources/access_grant.rb', line 110 def instant_key_url @instant_key_url end |
#location_ids ⇒ Object
Use space_ids.
112 113 114 |
# File 'lib/seam/resources/access_grant.rb', line 112 def location_ids @location_ids end |
#name ⇒ Object
Name of the Access Grant. If not provided, the display name will be computed.
114 115 116 |
# File 'lib/seam/resources/access_grant.rb', line 114 def name @name end |
#reservation_key ⇒ Object
Reservation key for the access grant.
116 117 118 |
# File 'lib/seam/resources/access_grant.rb', line 116 def reservation_key @reservation_key end |
#space_ids ⇒ Object
IDs of the spaces to which the Access Grant gives access.
118 119 120 |
# File 'lib/seam/resources/access_grant.rb', line 118 def space_ids @space_ids end |
#user_identity_id ⇒ Object
ID of user identity to which the Access Grant gives access.
120 121 122 |
# File 'lib/seam/resources/access_grant.rb', line 120 def user_identity_id @user_identity_id end |
#workspace_id ⇒ Object
ID of the Seam workspace associated with the Access Grant.
122 123 124 |
# File 'lib/seam/resources/access_grant.rb', line 122 def workspace_id @workspace_id end |