Class: Seam::Resources::AccessGrant
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessGrant
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/access_grant.rb
Overview
Represents an Access Grant. Access Grants enable you to grant a user identity access to spaces, entrances, and devices through one or more access methods, such as mobile keys, plastic cards, and PIN codes. You can create an Access Grant for an existing user identity, or you can create a new user identity while creating the new Access Grant.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ Object
ID of the Access Grant.
-
#access_grant_key ⇒ Object
Unique key for the access grant within the workspace.
-
#access_method_ids ⇒ Object
IDs of the access methods created for the Access Grant.
-
#client_session_token ⇒ Object
Client Session Token.
-
#customization_profile_id ⇒ Object
ID of the customization profile associated with the Access Grant.
-
#display_name ⇒ Object
Display name of the Access Grant.
-
#instant_key_url ⇒ Object
Instant Key URL.
-
#location_ids ⇒ Object
deprecated
Deprecated.
Use
space_ids. -
#name ⇒ Object
Name of the Access Grant.
-
#pending_mutations ⇒ Object
List of pending mutations for the access grant.
-
#requested_access_methods ⇒ Object
Access methods that the user requested for the Access Grant.
-
#reservation_key ⇒ Object
Reservation key for the access grant.
-
#space_ids ⇒ Object
IDs of the spaces to which the Access Grant gives access.
-
#user_identity_id ⇒ Object
ID of user identity to which the Access Grant gives access.
-
#workspace_id ⇒ Object
ID of the Seam workspace associated with the Access Grant.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_grant_id ⇒ Object
ID of the Access Grant.
8 9 10 |
# File 'lib/seam/resources/access_grant.rb', line 8 def access_grant_id @access_grant_id end |
#access_grant_key ⇒ Object
Unique key for the access grant within the workspace.
10 11 12 |
# File 'lib/seam/resources/access_grant.rb', line 10 def access_grant_key @access_grant_key end |
#access_method_ids ⇒ Object
IDs of the access methods created for the Access Grant.
12 13 14 |
# File 'lib/seam/resources/access_grant.rb', line 12 def access_method_ids @access_method_ids end |
#client_session_token ⇒ Object
Client Session Token. Only returned if the Access Grant has a mobile_key access method.
14 15 16 |
# File 'lib/seam/resources/access_grant.rb', line 14 def client_session_token @client_session_token end |
#customization_profile_id ⇒ Object
ID of the customization profile associated with the Access Grant.
16 17 18 |
# File 'lib/seam/resources/access_grant.rb', line 16 def customization_profile_id @customization_profile_id end |
#display_name ⇒ Object
Display name of the Access Grant.
18 19 20 |
# File 'lib/seam/resources/access_grant.rb', line 18 def display_name @display_name end |
#instant_key_url ⇒ Object
Instant Key URL. Only returned if the Access Grant has a single mobile_key access_method.
20 21 22 |
# File 'lib/seam/resources/access_grant.rb', line 20 def instant_key_url @instant_key_url end |
#location_ids ⇒ Object
Use space_ids.
22 23 24 |
# File 'lib/seam/resources/access_grant.rb', line 22 def location_ids @location_ids end |
#name ⇒ Object
Name of the Access Grant. If not provided, the display name will be computed.
24 25 26 |
# File 'lib/seam/resources/access_grant.rb', line 24 def name @name end |
#pending_mutations ⇒ Object
List of pending mutations for the access grant. This shows updates that are in progress.
26 27 28 |
# File 'lib/seam/resources/access_grant.rb', line 26 def pending_mutations @pending_mutations end |
#requested_access_methods ⇒ Object
Access methods that the user requested for the Access Grant.
28 29 30 |
# File 'lib/seam/resources/access_grant.rb', line 28 def requested_access_methods @requested_access_methods end |
#reservation_key ⇒ Object
Reservation key for the access grant.
30 31 32 |
# File 'lib/seam/resources/access_grant.rb', line 30 def reservation_key @reservation_key end |
#space_ids ⇒ Object
IDs of the spaces to which the Access Grant gives access.
32 33 34 |
# File 'lib/seam/resources/access_grant.rb', line 32 def space_ids @space_ids end |
#user_identity_id ⇒ Object
ID of user identity to which the Access Grant gives access.
34 35 36 |
# File 'lib/seam/resources/access_grant.rb', line 34 def user_identity_id @user_identity_id end |
#workspace_id ⇒ Object
ID of the Seam workspace associated with the Access Grant.
36 37 38 |
# File 'lib/seam/resources/access_grant.rb', line 36 def workspace_id @workspace_id end |