Class: Seam::Resources::AccessGrant::Errors::CannotCreateRequestedAccessMethods
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessGrant::Errors::CannotCreateRequestedAccessMethods
- Defined in:
- lib/seam/resources/access_grant.rb
Overview
Indicates that Seam could not create one or more of the requested access methods for the access grant.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
-
#missing_device_ids ⇒ Array<String>
IDs of the devices that did not receive an access code at grant creation.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
cannot_create_requested_access_methods
15 16 17 |
# File 'lib/seam/resources/access_grant.rb', line 15 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
18 19 20 |
# File 'lib/seam/resources/access_grant.rb', line 18 def @message end |
#missing_device_ids ⇒ Array<String>
IDs of the devices that did not receive an access code at grant creation. Use these to identify which specific devices failed when the message reports a partial failure.
21 22 23 |
# File 'lib/seam/resources/access_grant.rb', line 21 def missing_device_ids @missing_device_ids end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
24 |
# File 'lib/seam/resources/access_grant.rb', line 24 date_accessor :created_at |