Class: Seam::Resources::AccessGrant::RequestedAccessMethods
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessGrant::RequestedAccessMethods
- Defined in:
- lib/seam/resources/access_grant.rb
Instance Attribute Summary collapse
-
#code ⇒ String?
Specific PIN code to use for this access method.
-
#created_access_method_ids ⇒ Array<String>
IDs of the access methods created for the requested access method.
-
#display_name ⇒ String
Display name of the access method.
-
#instant_key_max_use_count ⇒ Integer?
Maximum number of times the instant key can be used.
-
#mode ⇒ String
Access method mode.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the requested access method was added to the Access Grant.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#code ⇒ String?
Specific PIN code to use for this access method. Only applicable when mode is 'code'.
94 95 96 |
# File 'lib/seam/resources/access_grant.rb', line 94 def code @code end |
#created_access_method_ids ⇒ Array<String>
IDs of the access methods created for the requested access method.
97 98 99 |
# File 'lib/seam/resources/access_grant.rb', line 97 def created_access_method_ids @created_access_method_ids end |
#display_name ⇒ String
Display name of the access method.
100 101 102 |
# File 'lib/seam/resources/access_grant.rb', line 100 def display_name @display_name end |
#instant_key_max_use_count ⇒ Integer?
Maximum number of times the instant key can be used. Only applicable when mode is 'mobile_key'. Defaults to 1 if not specified.
103 104 105 |
# File 'lib/seam/resources/access_grant.rb', line 103 def instant_key_max_use_count @instant_key_max_use_count end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
111 112 113 |
# File 'lib/seam/resources/access_grant.rb', line 111 def mode @mode end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the requested access method was added to the Access Grant.
114 |
# File 'lib/seam/resources/access_grant.rb', line 114 date_accessor :created_at |