Class: Seam::Resources::AccessGrant::RequestedAccessMethods
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessGrant::RequestedAccessMethods
- Defined in:
- lib/seam/resources/access_grant.rb
Instance Attribute Summary collapse
-
#code ⇒ String?
Specific PIN code to use for this access method.
-
#created_access_method_ids ⇒ Array<String>
IDs of the access methods created for the requested access method.
-
#display_name ⇒ String
Display name of the access method.
-
#instant_key_max_use_count ⇒ Integer?
Maximum number of times the instant key can be used.
-
#mode ⇒ String
Access method mode.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the requested access method was added to the Access Grant.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#code ⇒ String?
Specific PIN code to use for this access method. Only applicable when mode is 'code'.
70 71 72 |
# File 'lib/seam/resources/access_grant.rb', line 70 def code @code end |
#created_access_method_ids ⇒ Array<String>
IDs of the access methods created for the requested access method.
73 74 75 |
# File 'lib/seam/resources/access_grant.rb', line 73 def created_access_method_ids @created_access_method_ids end |
#display_name ⇒ String
Display name of the access method.
76 77 78 |
# File 'lib/seam/resources/access_grant.rb', line 76 def display_name @display_name end |
#instant_key_max_use_count ⇒ Integer?
Maximum number of times the instant key can be used. Only applicable when mode is 'mobile_key'. Defaults to 1 if not specified.
79 80 81 |
# File 'lib/seam/resources/access_grant.rb', line 79 def instant_key_max_use_count @instant_key_max_use_count end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
82 83 84 |
# File 'lib/seam/resources/access_grant.rb', line 82 def mode @mode end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the requested access method was added to the Access Grant.
85 |
# File 'lib/seam/resources/access_grant.rb', line 85 date_accessor :created_at |