Class: Seam::Resources::AccessGrant::RequestedAccessMethods

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/access_grant.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#codeObject

Specific PIN code to use for this access method. Only applicable when mode is 'code'.



52
53
54
# File 'lib/seam/resources/access_grant.rb', line 52

def code
  @code
end

#created_access_method_idsObject

IDs of the access methods created for the requested access method.



54
55
56
# File 'lib/seam/resources/access_grant.rb', line 54

def created_access_method_ids
  @created_access_method_ids
end

#display_nameObject

Display name of the access method.



56
57
58
# File 'lib/seam/resources/access_grant.rb', line 56

def display_name
  @display_name
end

#instant_key_max_use_countObject

Maximum number of times the instant key can be used. Only applicable when mode is 'mobile_key'. Defaults to 1 if not specified.



58
59
60
# File 'lib/seam/resources/access_grant.rb', line 58

def instant_key_max_use_count
  @instant_key_max_use_count
end

#modeObject

Access method mode. Supported values: code, card, mobile_key, cloud_key.



60
61
62
# File 'lib/seam/resources/access_grant.rb', line 60

def mode
  @mode
end