Class: Seam::Resources::AccessGrant::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessGrant::Warnings
- Defined in:
- lib/seam/resources/access_grant.rb
Defined Under Namespace
Classes: FailedDevices
Instance Attribute Summary collapse
-
#access_method_ids ⇒ Array<String>
IDs of the access methods being updated.
- #device_id ⇒ String
-
#message ⇒ String
Detailed description of the warning.
-
#new_code ⇒ String
The new PIN code that was assigned instead.
-
#original_code ⇒ String
The originally requested PIN code that was unavailable.
-
#reason ⇒ String
Specific reason why the grant's times are not programmable on the device.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
-
#failed_devices ⇒ Array<FailedDevices>
Devices whose access codes could not be revoked during reconciliation.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_ids ⇒ Array<String>
IDs of the access methods being updated.
106 107 108 |
# File 'lib/seam/resources/access_grant.rb', line 106 def access_method_ids @access_method_ids end |
#device_id ⇒ String
108 109 110 |
# File 'lib/seam/resources/access_grant.rb', line 108 def device_id @device_id end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
111 112 113 |
# File 'lib/seam/resources/access_grant.rb', line 111 def @message end |
#new_code ⇒ String
The new PIN code that was assigned instead.
114 115 116 |
# File 'lib/seam/resources/access_grant.rb', line 114 def new_code @new_code end |
#original_code ⇒ String
The originally requested PIN code that was unavailable.
117 118 119 |
# File 'lib/seam/resources/access_grant.rb', line 117 def original_code @original_code end |
#reason ⇒ String
Specific reason why the grant's times are not programmable on the device.
120 121 122 |
# File 'lib/seam/resources/access_grant.rb', line 120 def reason @reason end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
123 124 125 |
# File 'lib/seam/resources/access_grant.rb', line 123 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
126 |
# File 'lib/seam/resources/access_grant.rb', line 126 date_accessor :created_at |
#failed_devices ⇒ Array<FailedDevices>
Devices whose access codes could not be revoked during reconciliation. Present when the provider does not support revoking an offline access code (e.g. Dormakaba oracode with exhausted override budget).
103 |
# File 'lib/seam/resources/access_grant.rb', line 103 resource_list_accessor :failed_devices, FailedDevices |