Class: Seam::Resources::AccessMethod
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessMethod
- Defined in:
- lib/seam/resources/access_method.rb
Overview
Represents an access method for an Access Grant. Access methods describe the modes of access, such as PIN codes, plastic cards, and mobile keys. For a mobile key, the access method also stores the URL for the associated Instant Key.
Defined Under Namespace
Classes: Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_method_id ⇒ String
ID of the access method.
-
#client_session_token ⇒ String?
Token of the client session associated with the access method.
-
#code ⇒ String?
The actual PIN code for code access methods.
-
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
-
#display_name ⇒ String
Display name of the access method.
-
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ String
Access method mode.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the access method was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access method.
-
#issued_at ⇒ Time?
Date and time at which the access method was issued.
-
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ String
ID of the access method.
179 180 181 |
# File 'lib/seam/resources/access_method.rb', line 179 def access_method_id @access_method_id end |
#client_session_token ⇒ String?
Token of the client session associated with the access method.
182 183 184 |
# File 'lib/seam/resources/access_method.rb', line 182 def client_session_token @client_session_token end |
#code ⇒ String?
The actual PIN code for code access methods.
185 186 187 |
# File 'lib/seam/resources/access_method.rb', line 185 def code @code end |
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
188 189 190 |
# File 'lib/seam/resources/access_method.rb', line 188 def customization_profile_id @customization_profile_id end |
#display_name ⇒ String
Display name of the access method.
191 192 193 |
# File 'lib/seam/resources/access_method.rb', line 191 def display_name @display_name end |
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
194 195 196 |
# File 'lib/seam/resources/access_method.rb', line 194 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
197 198 199 |
# File 'lib/seam/resources/access_method.rb', line 197 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
200 201 202 |
# File 'lib/seam/resources/access_method.rb', line 200 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
203 204 205 |
# File 'lib/seam/resources/access_method.rb', line 203 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
206 207 208 |
# File 'lib/seam/resources/access_method.rb', line 206 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
209 210 211 |
# File 'lib/seam/resources/access_method.rb', line 209 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
217 218 219 |
# File 'lib/seam/resources/access_method.rb', line 217 def mode @mode end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
220 221 222 |
# File 'lib/seam/resources/access_method.rb', line 220 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the access method was created.
224 |
# File 'lib/seam/resources/access_method.rb', line 224 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access method.
170 |
# File 'lib/seam/resources/access_method.rb', line 170 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the access method was issued.
228 |
# File 'lib/seam/resources/access_method.rb', line 228 date_accessor :issued_at |
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method. Indicates operations that are in progress.
173 |
# File 'lib/seam/resources/access_method.rb', line 173 resource_list_accessor :pending_mutations, PendingMutations |
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
176 |
# File 'lib/seam/resources/access_method.rb', line 176 resource_list_accessor :warnings, Warnings |