Class: Seam::Resources::AccessMethod
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessMethod
- Defined in:
- lib/seam/resources/access_method.rb
Overview
Represents an access method for an Access Grant. Access methods describe the modes of access, such as PIN codes, plastic cards, and mobile keys. For a mobile key, the access method also stores the URL for the associated Instant Key.
Defined Under Namespace
Classes: Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_method_id ⇒ String
ID of the access method.
-
#client_session_token ⇒ String?
Token of the client session associated with the access method.
-
#code ⇒ String?
The actual PIN code for code access methods.
-
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
-
#display_name ⇒ String
Display name of the access method.
-
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ String
Access method mode.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the access method was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access method.
-
#issued_at ⇒ Time?
Date and time at which the access method was issued.
-
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ String
ID of the access method.
82 83 84 |
# File 'lib/seam/resources/access_method.rb', line 82 def access_method_id @access_method_id end |
#client_session_token ⇒ String?
Token of the client session associated with the access method.
85 86 87 |
# File 'lib/seam/resources/access_method.rb', line 85 def client_session_token @client_session_token end |
#code ⇒ String?
The actual PIN code for code access methods.
88 89 90 |
# File 'lib/seam/resources/access_method.rb', line 88 def code @code end |
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
91 92 93 |
# File 'lib/seam/resources/access_method.rb', line 91 def customization_profile_id @customization_profile_id end |
#display_name ⇒ String
Display name of the access method.
94 95 96 |
# File 'lib/seam/resources/access_method.rb', line 94 def display_name @display_name end |
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
97 98 99 |
# File 'lib/seam/resources/access_method.rb', line 97 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
100 101 102 |
# File 'lib/seam/resources/access_method.rb', line 100 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
103 104 105 |
# File 'lib/seam/resources/access_method.rb', line 103 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
106 107 108 |
# File 'lib/seam/resources/access_method.rb', line 106 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
109 110 111 |
# File 'lib/seam/resources/access_method.rb', line 109 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
112 113 114 |
# File 'lib/seam/resources/access_method.rb', line 112 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
115 116 117 |
# File 'lib/seam/resources/access_method.rb', line 115 def mode @mode end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
118 119 120 |
# File 'lib/seam/resources/access_method.rb', line 118 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the access method was created.
122 |
# File 'lib/seam/resources/access_method.rb', line 122 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access method.
73 |
# File 'lib/seam/resources/access_method.rb', line 73 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the access method was issued.
126 |
# File 'lib/seam/resources/access_method.rb', line 126 date_accessor :issued_at |
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method. Indicates operations that are in progress.
76 |
# File 'lib/seam/resources/access_method.rb', line 76 resource_list_accessor :pending_mutations, PendingMutations |
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
79 |
# File 'lib/seam/resources/access_method.rb', line 79 resource_list_accessor :warnings, Warnings |