Class: Seam::Resources::AccessMethod
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessMethod
- Defined in:
- lib/seam/resources/access_method.rb
Overview
Represents an access method for an Access Grant. Access methods describe the modes of access, such as PIN codes, plastic cards, and mobile keys. For a mobile key, the access method also stores the URL for the associated Instant Key.
Defined Under Namespace
Classes: Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_method_id ⇒ Object
ID of the access method.
-
#client_session_token ⇒ Object
Token of the client session associated with the access method.
-
#code ⇒ Object
The actual PIN code for code access methods.
-
#customization_profile_id ⇒ Object
ID of the customization profile associated with the access method.
-
#display_name ⇒ Object
Display name of the access method.
-
#instant_key_url ⇒ Object
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Object
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ Object
Access method mode.
-
#workspace_id ⇒ Object
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ Object
ID of the access method.
57 58 59 |
# File 'lib/seam/resources/access_method.rb', line 57 def access_method_id @access_method_id end |
#client_session_token ⇒ Object
Token of the client session associated with the access method.
59 60 61 |
# File 'lib/seam/resources/access_method.rb', line 59 def client_session_token @client_session_token end |
#code ⇒ Object
The actual PIN code for code access methods.
61 62 63 |
# File 'lib/seam/resources/access_method.rb', line 61 def code @code end |
#customization_profile_id ⇒ Object
ID of the customization profile associated with the access method.
63 64 65 |
# File 'lib/seam/resources/access_method.rb', line 63 def customization_profile_id @customization_profile_id end |
#display_name ⇒ Object
Display name of the access method.
65 66 67 |
# File 'lib/seam/resources/access_method.rb', line 65 def display_name @display_name end |
#instant_key_url ⇒ Object
URL of the Instant Key for mobile key access methods.
67 68 69 |
# File 'lib/seam/resources/access_method.rb', line 67 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
69 70 71 |
# File 'lib/seam/resources/access_method.rb', line 69 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
71 72 73 |
# File 'lib/seam/resources/access_method.rb', line 71 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Object
Indicates whether the access method has been issued.
73 74 75 |
# File 'lib/seam/resources/access_method.rb', line 73 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
75 76 77 |
# File 'lib/seam/resources/access_method.rb', line 75 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
77 78 79 |
# File 'lib/seam/resources/access_method.rb', line 77 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ Object
Access method mode. Supported values: code, card, mobile_key, cloud_key.
79 80 81 |
# File 'lib/seam/resources/access_method.rb', line 79 def mode @mode end |
#workspace_id ⇒ Object
ID of the Seam workspace associated with the access method.
81 82 83 |
# File 'lib/seam/resources/access_method.rb', line 81 def workspace_id @workspace_id end |