Class: Seam::Resources::AccessMethod
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessMethod
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/access_method.rb
Overview
Represents an access method for an Access Grant. Access methods describe the modes of access, such as PIN codes, plastic cards, and mobile keys. For a mobile key, the access method also stores the URL for the associated Instant Key.
Instance Attribute Summary collapse
-
#access_method_id ⇒ Object
ID of the access method.
-
#client_session_token ⇒ Object
Token of the client session associated with the access method.
-
#code ⇒ Object
The actual PIN code for code access methods.
-
#customization_profile_id ⇒ Object
ID of the customization profile associated with the access method.
-
#display_name ⇒ Object
Display name of the access method.
-
#instant_key_url ⇒ Object
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Object
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ Object
Access method mode.
-
#pending_mutations ⇒ Object
Pending mutations for the access method.
-
#workspace_id ⇒ Object
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ Object
ID of the access method.
8 9 10 |
# File 'lib/seam/resources/access_method.rb', line 8 def access_method_id @access_method_id end |
#client_session_token ⇒ Object
Token of the client session associated with the access method.
10 11 12 |
# File 'lib/seam/resources/access_method.rb', line 10 def client_session_token @client_session_token end |
#code ⇒ Object
The actual PIN code for code access methods.
12 13 14 |
# File 'lib/seam/resources/access_method.rb', line 12 def code @code end |
#customization_profile_id ⇒ Object
ID of the customization profile associated with the access method.
14 15 16 |
# File 'lib/seam/resources/access_method.rb', line 14 def customization_profile_id @customization_profile_id end |
#display_name ⇒ Object
Display name of the access method.
16 17 18 |
# File 'lib/seam/resources/access_method.rb', line 16 def display_name @display_name end |
#instant_key_url ⇒ Object
URL of the Instant Key for mobile key access methods.
18 19 20 |
# File 'lib/seam/resources/access_method.rb', line 18 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
20 21 22 |
# File 'lib/seam/resources/access_method.rb', line 20 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
22 23 24 |
# File 'lib/seam/resources/access_method.rb', line 22 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Object
Indicates whether the access method has been issued.
24 25 26 |
# File 'lib/seam/resources/access_method.rb', line 24 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
26 27 28 |
# File 'lib/seam/resources/access_method.rb', line 26 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
28 29 30 |
# File 'lib/seam/resources/access_method.rb', line 28 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ Object
Access method mode. Supported values: code, card, mobile_key, cloud_key.
30 31 32 |
# File 'lib/seam/resources/access_method.rb', line 30 def mode @mode end |
#pending_mutations ⇒ Object
Pending mutations for the access method. Indicates operations that are in progress.
32 33 34 |
# File 'lib/seam/resources/access_method.rb', line 32 def pending_mutations @pending_mutations end |
#workspace_id ⇒ Object
ID of the Seam workspace associated with the access method.
34 35 36 |
# File 'lib/seam/resources/access_method.rb', line 34 def workspace_id @workspace_id end |