Class: Seam::Resources::AccessMethod::Errors::FailedToIssue
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AccessMethod::Errors::FailedToIssue
- Defined in:
- lib/seam/resources/access_method.rb
Overview
Indicates that Seam was unable to issue this access method before its access grant started, so the recipient may be unable to access the space. This usually points to a problem that needs attention, such as an offline or disconnected device. Seam keeps retrying, and this error clears automatically if the access method is eventually issued.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_issue
15 16 17 |
# File 'lib/seam/resources/access_method.rb', line 15 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
18 19 20 |
# File 'lib/seam/resources/access_method.rb', line 18 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
21 |
# File 'lib/seam/resources/access_method.rb', line 21 date_accessor :created_at |