Class: Seam::Resources::AccessMethod::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AccessMethod::Warnings
- Defined in:
- lib/seam/resources/access_method.rb
Instance Attribute Summary collapse
-
#message ⇒ Object
Detailed description of the warning.
-
#original_access_method_id ⇒ Object
ID of the original access method from which this backup access method was split, if applicable.
-
#warning_code ⇒ Object
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ Object
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
44 45 46 |
# File 'lib/seam/resources/access_method.rb', line 44 def @message end |
#original_access_method_id ⇒ Object
ID of the original access method from which this backup access method was split, if applicable.
46 47 48 |
# File 'lib/seam/resources/access_method.rb', line 46 def original_access_method_id @original_access_method_id end |
#warning_code ⇒ Object
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
48 49 50 |
# File 'lib/seam/resources/access_method.rb', line 48 def warning_code @warning_code end |