Class: Seam::Resources::AccessMethod::Warnings::PulledBackupAccessCode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AccessMethod::Warnings::PulledBackupAccessCode
- Defined in:
- lib/seam/resources/access_method.rb
Overview
Indicates that all attempts to create an access code on this device before the start time failed and a backup access code was used to ensure access was provided in time.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
116 117 118 |
# File 'lib/seam/resources/access_method.rb', line 116 def @message end |
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
119 120 121 |
# File 'lib/seam/resources/access_method.rb', line 119 def original_access_method_id @original_access_method_id end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
pulled_backup_access_code
124 125 126 |
# File 'lib/seam/resources/access_method.rb', line 124 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
127 |
# File 'lib/seam/resources/access_method.rb', line 127 date_accessor :created_at |