Class: Seam::Resources::AcsAccessGroup
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsAccessGroup
- Defined in:
- lib/seam/resources/acs_access_group.rb
Overview
Group that defines the entrances to which a set of users has access and, in some cases, the access schedule for these entrances and users.
Some access control systems use access group, which are sets of users, combined with sets of permissions. These permissions include both the set of areas or assets that the users can access and the schedule during which the users can access these areas or assets. Instead of assigning access rights individually to each access control system user, which can be time-consuming and error-prone, administrators can assign users to an access group, thereby ensuring that the users inherit all the permissions associated with the access group. Using access groups streamlines the process of managing large numbers of access control system users, especially in bigger organizations or complexes.
To learn whether your access control system supports access groups, see the corresponding system integration guide.
Defined Under Namespace
Classes: AccessSchedule, Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_group_type ⇒ String
deprecated
Deprecated.
Use
external_type. -
#access_group_type_display_name ⇒ String
deprecated
Deprecated.
Use
external_type_display_name. -
#acs_access_group_id ⇒ String
ID of the access group.
-
#acs_system_id ⇒ String
ID of the access control system that contains the access group.
-
#connected_account_id ⇒ String
ID of the connected account that contains the access group.
-
#display_name ⇒ String
Display name for the access group.
-
#external_type ⇒ String
Brand-specific terminology for the access group type.
-
#external_type_display_name ⇒ String
Display name that corresponds to the brand-specific terminology for the access group type.
-
#is_managed ⇒ Boolean
Indicates whether Seam manages the access group.
-
#name ⇒ String
Name of the access group.
-
#workspace_id ⇒ String
ID of the workspace that contains the access group.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#access_schedule ⇒ AccessSchedule?
starts_atandends_attimestamps for the access group's access. -
#created_at ⇒ Time
Date and time at which the access group was created.
-
#errors ⇒ Array<Errors>
Errors associated with the
acs_access_group. -
#pending_mutations ⇒ Array<PendingMutations>
Collection of pending mutations for the access group.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the
acs_access_group.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_group_type ⇒ String
Use external_type.
115 116 117 |
# File 'lib/seam/resources/acs_access_group.rb', line 115 def access_group_type @access_group_type end |
#access_group_type_display_name ⇒ String
Use external_type_display_name.
118 119 120 |
# File 'lib/seam/resources/acs_access_group.rb', line 118 def access_group_type_display_name @access_group_type_display_name end |
#acs_access_group_id ⇒ String
ID of the access group.
121 122 123 |
# File 'lib/seam/resources/acs_access_group.rb', line 121 def acs_access_group_id @acs_access_group_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the access group.
124 125 126 |
# File 'lib/seam/resources/acs_access_group.rb', line 124 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String
ID of the connected account that contains the access group.
127 128 129 |
# File 'lib/seam/resources/acs_access_group.rb', line 127 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name for the access group.
130 131 132 |
# File 'lib/seam/resources/acs_access_group.rb', line 130 def display_name @display_name end |
#external_type ⇒ String
Brand-specific terminology for the access group type.
133 134 135 |
# File 'lib/seam/resources/acs_access_group.rb', line 133 def external_type @external_type end |
#external_type_display_name ⇒ String
Display name that corresponds to the brand-specific terminology for the access group type.
136 137 138 |
# File 'lib/seam/resources/acs_access_group.rb', line 136 def external_type_display_name @external_type_display_name end |
#is_managed ⇒ Boolean
Indicates whether Seam manages the access group.
139 140 141 |
# File 'lib/seam/resources/acs_access_group.rb', line 139 def is_managed @is_managed end |
#name ⇒ String
Name of the access group.
142 143 144 |
# File 'lib/seam/resources/acs_access_group.rb', line 142 def name @name end |
#workspace_id ⇒ String
ID of the workspace that contains the access group.
145 146 147 |
# File 'lib/seam/resources/acs_access_group.rb', line 145 def workspace_id @workspace_id end |
Instance Method Details
#access_schedule ⇒ AccessSchedule?
starts_at and ends_at timestamps for the access group's access.
103 |
# File 'lib/seam/resources/acs_access_group.rb', line 103 resource_accessor :access_schedule, AccessSchedule |
#created_at ⇒ Time
Date and time at which the access group was created.
149 |
# File 'lib/seam/resources/acs_access_group.rb', line 149 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the acs_access_group.
106 |
# File 'lib/seam/resources/acs_access_group.rb', line 106 resource_list_accessor :errors, Errors |
#pending_mutations ⇒ Array<PendingMutations>
Collection of pending mutations for the access group. Represents operations that have been requested but not yet completed on the integrated access system.
109 |
# File 'lib/seam/resources/acs_access_group.rb', line 109 resource_list_accessor :pending_mutations, PendingMutations |