Class: Seam::Resources::AcsAccessGroup
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsAccessGroup
- Defined in:
- lib/seam/resources/acs_access_group.rb
Overview
Group that defines the entrances to which a set of users has access and, in some cases, the access schedule for these entrances and users.
Some access control systems use access group, which are sets of users, combined with sets of permissions. These permissions include both the set of areas or assets that the users can access and the schedule during which the users can access these areas or assets. Instead of assigning access rights individually to each access control system user, which can be time-consuming and error-prone, administrators can assign users to an access group, thereby ensuring that the users inherit all the permissions associated with the access group. Using access groups streamlines the process of managing large numbers of access control system users, especially in bigger organizations or complexes.
To learn whether your access control system supports access groups, see the corresponding system integration guide.
Defined Under Namespace
Classes: AccessSchedule, Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_group_type ⇒ Object
deprecated
Deprecated.
Use
external_type. -
#access_group_type_display_name ⇒ Object
deprecated
Deprecated.
Use
external_type_display_name. -
#acs_access_group_id ⇒ Object
ID of the access group.
-
#acs_system_id ⇒ Object
ID of the access control system that contains the access group.
-
#connected_account_id ⇒ Object
ID of the connected account that contains the access group.
-
#display_name ⇒ Object
Display name for the access group.
-
#external_type ⇒ Object
Brand-specific terminology for the access group type.
-
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access group type.
-
#is_managed ⇒ Object
Indicates whether Seam manages the access group.
-
#name ⇒ Object
Name of the access group.
-
#workspace_id ⇒ Object
ID of the workspace that contains the access group.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_group_type ⇒ Object
Use external_type.
81 82 83 |
# File 'lib/seam/resources/acs_access_group.rb', line 81 def access_group_type @access_group_type end |
#access_group_type_display_name ⇒ Object
Use external_type_display_name.
83 84 85 |
# File 'lib/seam/resources/acs_access_group.rb', line 83 def access_group_type_display_name @access_group_type_display_name end |
#acs_access_group_id ⇒ Object
ID of the access group.
85 86 87 |
# File 'lib/seam/resources/acs_access_group.rb', line 85 def acs_access_group_id @acs_access_group_id end |
#acs_system_id ⇒ Object
ID of the access control system that contains the access group.
87 88 89 |
# File 'lib/seam/resources/acs_access_group.rb', line 87 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ Object
ID of the connected account that contains the access group.
89 90 91 |
# File 'lib/seam/resources/acs_access_group.rb', line 89 def connected_account_id @connected_account_id end |
#display_name ⇒ Object
Display name for the access group.
91 92 93 |
# File 'lib/seam/resources/acs_access_group.rb', line 91 def display_name @display_name end |
#external_type ⇒ Object
Brand-specific terminology for the access group type.
93 94 95 |
# File 'lib/seam/resources/acs_access_group.rb', line 93 def external_type @external_type end |
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access group type.
95 96 97 |
# File 'lib/seam/resources/acs_access_group.rb', line 95 def external_type_display_name @external_type_display_name end |
#is_managed ⇒ Object
Indicates whether Seam manages the access group.
97 98 99 |
# File 'lib/seam/resources/acs_access_group.rb', line 97 def is_managed @is_managed end |
#name ⇒ Object
Name of the access group.
99 100 101 |
# File 'lib/seam/resources/acs_access_group.rb', line 99 def name @name end |
#workspace_id ⇒ Object
ID of the workspace that contains the access group.
101 102 103 |
# File 'lib/seam/resources/acs_access_group.rb', line 101 def workspace_id @workspace_id end |