Class: Seam::Resources::AcsAccessGroup
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsAccessGroup
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/acs_access_group.rb
Overview
Group that defines the entrances to which a set of users has access and, in some cases, the access schedule for these entrances and users.
Some access control systems use access group, which are sets of users, combined with sets of permissions. These permissions include both the set of areas or assets that the users can access and the schedule during which the users can access these areas or assets. Instead of assigning access rights individually to each access control system user, which can be time-consuming and error-prone, administrators can assign users to an access group, thereby ensuring that the users inherit all the permissions associated with the access group. Using access groups streamlines the process of managing large numbers of access control system users, especially in bigger organizations or complexes.
To learn whether your access control system supports access groups, see the corresponding system integration guide.
Instance Attribute Summary collapse
-
#access_group_type ⇒ Object
deprecated
Deprecated.
Use
external_type. -
#access_group_type_display_name ⇒ Object
deprecated
Deprecated.
Use
external_type_display_name. -
#access_schedule ⇒ Object
starts_atandends_attimestamps for the access group's access. -
#acs_access_group_id ⇒ Object
ID of the access group.
-
#acs_system_id ⇒ Object
ID of the access control system that contains the access group.
-
#connected_account_id ⇒ Object
ID of the connected account that contains the access group.
-
#display_name ⇒ Object
Display name for the access group.
-
#external_type ⇒ Object
Brand-specific terminology for the access group type.
-
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access group type.
-
#is_managed ⇒ Object
Indicates whether Seam manages the access group.
-
#name ⇒ Object
Name of the access group.
-
#pending_mutations ⇒ Object
Collection of pending mutations for the access group.
-
#workspace_id ⇒ Object
ID of the workspace that contains the access group.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_group_type ⇒ Object
Use external_type.
12 13 14 |
# File 'lib/seam/resources/acs_access_group.rb', line 12 def access_group_type @access_group_type end |
#access_group_type_display_name ⇒ Object
Use external_type_display_name.
14 15 16 |
# File 'lib/seam/resources/acs_access_group.rb', line 14 def access_group_type_display_name @access_group_type_display_name end |
#access_schedule ⇒ Object
starts_at and ends_at timestamps for the access group's access.
16 17 18 |
# File 'lib/seam/resources/acs_access_group.rb', line 16 def access_schedule @access_schedule end |
#acs_access_group_id ⇒ Object
ID of the access group.
18 19 20 |
# File 'lib/seam/resources/acs_access_group.rb', line 18 def acs_access_group_id @acs_access_group_id end |
#acs_system_id ⇒ Object
ID of the access control system that contains the access group.
20 21 22 |
# File 'lib/seam/resources/acs_access_group.rb', line 20 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ Object
ID of the connected account that contains the access group.
22 23 24 |
# File 'lib/seam/resources/acs_access_group.rb', line 22 def connected_account_id @connected_account_id end |
#display_name ⇒ Object
Display name for the access group.
24 25 26 |
# File 'lib/seam/resources/acs_access_group.rb', line 24 def display_name @display_name end |
#external_type ⇒ Object
Brand-specific terminology for the access group type.
26 27 28 |
# File 'lib/seam/resources/acs_access_group.rb', line 26 def external_type @external_type end |
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access group type.
28 29 30 |
# File 'lib/seam/resources/acs_access_group.rb', line 28 def external_type_display_name @external_type_display_name end |
#is_managed ⇒ Object
Indicates whether Seam manages the access group.
30 31 32 |
# File 'lib/seam/resources/acs_access_group.rb', line 30 def is_managed @is_managed end |
#name ⇒ Object
Name of the access group.
32 33 34 |
# File 'lib/seam/resources/acs_access_group.rb', line 32 def name @name end |
#pending_mutations ⇒ Object
Collection of pending mutations for the access group. Represents operations that have been requested but not yet completed on the integrated access system.
34 35 36 |
# File 'lib/seam/resources/acs_access_group.rb', line 34 def pending_mutations @pending_mutations end |
#workspace_id ⇒ Object
ID of the workspace that contains the access group.
36 37 38 |
# File 'lib/seam/resources/acs_access_group.rb', line 36 def workspace_id @workspace_id end |