Class: Seam::Resources::AcsAccessGroup::Errors::FailedToCreateOnAcsSystem
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsAccessGroup::Errors::FailedToCreateOnAcsSystem
- Defined in:
- lib/seam/resources/acs_access_group.rb
Overview
Indicates that the access group was not created on the access system. This is likely due to an internal unexpected error. Contact Seam support.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_create_on_acs_system
28 29 30 |
# File 'lib/seam/resources/acs_access_group.rb', line 28 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
31 32 33 |
# File 'lib/seam/resources/acs_access_group.rb', line 31 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
34 |
# File 'lib/seam/resources/acs_access_group.rb', line 34 date_accessor :created_at |