Class: Seam::Resources::AcsAccessGroup::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsAccessGroup::PendingMutations
- Defined in:
- lib/seam/resources/acs_access_group.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#acs_user_id ⇒ Object
ID of the user involved in the scheduled change.
-
#message ⇒ Object
Detailed description of the mutation.
-
#mutation_code ⇒ Object
Returns the value of attribute mutation_code.
-
#variant ⇒ Object
Whether the user is scheduled to be added to or removed from this access group.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_user_id ⇒ Object
ID of the user involved in the scheduled change.
57 58 59 |
# File 'lib/seam/resources/acs_access_group.rb', line 57 def acs_user_id @acs_user_id end |
#message ⇒ Object
Detailed description of the mutation.
59 60 61 |
# File 'lib/seam/resources/acs_access_group.rb', line 59 def @message end |
#mutation_code ⇒ Object
Returns the value of attribute mutation_code.
60 61 62 |
# File 'lib/seam/resources/acs_access_group.rb', line 60 def mutation_code @mutation_code end |
#variant ⇒ Object
Whether the user is scheduled to be added to or removed from this access group.
62 63 64 |
# File 'lib/seam/resources/acs_access_group.rb', line 62 def variant @variant end |