Class: Seam::Resources::AcsCredential
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsCredential
- Defined in:
- lib/seam/resources/acs_credential.rb
Overview
Means by which an access control system user gains access at an entrance. The acs_credential object represents a credential that provides an ACS user access within an access control system.
An access control system generally uses digital means of access to authorize a user trying to get through a specific entrance. Examples of credentials include plastic key cards, mobile keys, biometric identifiers, and PIN codes. The electronic nature of these credentials, as well as the fact that access is centralized, enables both the rapid provisioning and rescinding of access and the ability to compile access audit logs.
For each acs_credential, you define the access method. You can also specify additional properties, such as a PIN code, depending on the credential type.
For granting a person access to a space, Access Grants are the default and recommended approach. Use the lower-level ACS credential API directly only when you specifically need to manage individual credentials.
Defined Under Namespace
Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ String
Access method for the credential.
-
#acs_credential_id ⇒ String
ID of the credential.
-
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ String?
Number of the card associated with the credential.
-
#code ⇒ String?
Access (PIN) code for the credential.
-
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
-
#display_name ⇒ String
Display name that corresponds to the credential type.
-
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ String?
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
-
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
-
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
-
#is_managed ⇒ TrueClass
Indicates whether Seam manages the credential.
-
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once.
-
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
-
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
-
#workspace_id ⇒ String
ID of the workspace that contains the credential.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
-
#created_at ⇒ Time
Date and time at which the credential was created.
-
#errors ⇒ Array<Errors>
Errors associated with the credential.
-
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
-
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ String
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
244 245 246 |
# File 'lib/seam/resources/acs_credential.rb', line 244 def access_method @access_method end |
#acs_credential_id ⇒ String
ID of the credential.
247 248 249 |
# File 'lib/seam/resources/acs_credential.rb', line 247 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
250 251 252 |
# File 'lib/seam/resources/acs_credential.rb', line 250 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
253 254 255 |
# File 'lib/seam/resources/acs_credential.rb', line 253 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
256 257 258 |
# File 'lib/seam/resources/acs_credential.rb', line 256 def acs_user_id @acs_user_id end |
#card_number ⇒ String?
Number of the card associated with the credential.
259 260 261 |
# File 'lib/seam/resources/acs_credential.rb', line 259 def card_number @card_number end |
#code ⇒ String?
Access (PIN) code for the credential.
262 263 264 |
# File 'lib/seam/resources/acs_credential.rb', line 262 def code @code end |
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
265 266 267 |
# File 'lib/seam/resources/acs_credential.rb', line 265 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name that corresponds to the credential type.
268 269 270 |
# File 'lib/seam/resources/acs_credential.rb', line 268 def display_name @display_name end |
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
271 272 273 |
# File 'lib/seam/resources/acs_credential.rb', line 271 def ends_at @ends_at end |
#external_type ⇒ String?
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
Known values:
pti_cardbrivo_credentialhid_credentialvisionline_cardsalto_ks_credentialassa_abloy_vostio_keysalto_space_keylatch_accessdormakaba_ambiance_credentialhotek_cardsalto_ks_tagavigilon_alta_credentialkisi_credentialakiles_credential
289 290 291 |
# File 'lib/seam/resources/acs_credential.rb', line 289 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
292 293 294 |
# File 'lib/seam/resources/acs_credential.rb', line 292 def external_type_display_name @external_type_display_name end |
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
295 296 297 |
# File 'lib/seam/resources/acs_credential.rb', line 295 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
298 299 300 |
# File 'lib/seam/resources/acs_credential.rb', line 298 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ TrueClass
Indicates whether Seam manages the credential.
301 302 303 |
# File 'lib/seam/resources/acs_credential.rb', line 301 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
304 305 306 |
# File 'lib/seam/resources/acs_credential.rb', line 304 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
307 308 309 |
# File 'lib/seam/resources/acs_credential.rb', line 307 def is_one_time_use @is_one_time_use end |
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
310 311 312 |
# File 'lib/seam/resources/acs_credential.rb', line 310 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
313 314 315 |
# File 'lib/seam/resources/acs_credential.rb', line 313 def starts_at @starts_at end |
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
316 317 318 |
# File 'lib/seam/resources/acs_credential.rb', line 316 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the credential.
319 320 321 |
# File 'lib/seam/resources/acs_credential.rb', line 319 def workspace_id @workspace_id end |
Instance Method Details
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
224 |
# File 'lib/seam/resources/acs_credential.rb', line 224 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
227 |
# File 'lib/seam/resources/acs_credential.rb', line 227 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#created_at ⇒ Time
Date and time at which the credential was created.
323 |
# File 'lib/seam/resources/acs_credential.rb', line 323 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the credential.
233 |
# File 'lib/seam/resources/acs_credential.rb', line 233 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
327 |
# File 'lib/seam/resources/acs_credential.rb', line 327 date_accessor :issued_at |
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
331 |
# File 'lib/seam/resources/acs_credential.rb', line 331 date_accessor :latest_desired_state_synced_with_provider_at |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
230 |
# File 'lib/seam/resources/acs_credential.rb', line 230 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
236 |
# File 'lib/seam/resources/acs_credential.rb', line 236 resource_list_accessor :warnings, Warnings |