Class: Seam::Resources::AcsCredential

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Means by which an access control system user gains access at an entrance. The acs_credential object represents a credential that provides an ACS user access within an access control system.

An access control system generally uses digital means of access to authorize a user trying to get through a specific entrance. Examples of credentials include plastic key cards, mobile keys, biometric identifiers, and PIN codes. The electronic nature of these credentials, as well as the fact that access is centralized, enables both the rapid provisioning and rescinding of access and the ability to compile access audit logs.

For each acs_credential, you define the access method. You can also specify additional properties, such as a PIN code, depending on the credential type.

For granting a person access to a space, Access Grants are the default and recommended approach. Use the lower-level ACS credential API directly only when you specifically need to manage individual credentials.

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodString

Access method for the credential. Supported values: code, card, mobile_key, cloud_key.

Returns:

  • (String)


112
113
114
# File 'lib/seam/resources/acs_credential.rb', line 112

def access_method
  @access_method
end

#acs_credential_idString

ID of the credential.

Returns:

  • (String)


115
116
117
# File 'lib/seam/resources/acs_credential.rb', line 115

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idString?

ID of the credential pool to which the credential belongs.

Returns:

  • (String, nil)


118
119
120
# File 'lib/seam/resources/acs_credential.rb', line 118

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idString

ID of the access control system that contains the credential.

Returns:

  • (String)


121
122
123
# File 'lib/seam/resources/acs_credential.rb', line 121

def acs_system_id
  @acs_system_id
end

#acs_user_idString?

ID of the ACS user to whom the credential belongs.

Returns:

  • (String, nil)


124
125
126
# File 'lib/seam/resources/acs_credential.rb', line 124

def acs_user_id
  @acs_user_id
end

#card_numberString?

Number of the card associated with the credential.

Returns:

  • (String, nil)


127
128
129
# File 'lib/seam/resources/acs_credential.rb', line 127

def card_number
  @card_number
end

#codeString?

Access (PIN) code for the credential.

Returns:

  • (String, nil)


130
131
132
# File 'lib/seam/resources/acs_credential.rb', line 130

def code
  @code
end

#connected_account_idString

ID of the connected account to which the credential belongs.

Returns:

  • (String)


133
134
135
# File 'lib/seam/resources/acs_credential.rb', line 133

def 
  @connected_account_id
end

#display_nameString

Display name that corresponds to the credential type.

Returns:

  • (String)


136
137
138
# File 'lib/seam/resources/acs_credential.rb', line 136

def display_name
  @display_name
end

#ends_atString?

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.

Returns:

  • (String, nil)


139
140
141
# File 'lib/seam/resources/acs_credential.rb', line 139

def ends_at
  @ends_at
end

#external_typeString?

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.

Returns:

  • (String, nil)


142
143
144
# File 'lib/seam/resources/acs_credential.rb', line 142

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the credential type.

Returns:

  • (String, nil)


145
146
147
# File 'lib/seam/resources/acs_credential.rb', line 145

def external_type_display_name
  @external_type_display_name
end

#is_issuedBoolean?

Indicates whether the credential has been encoded onto a card.

Returns:

  • (Boolean, nil)


148
149
150
# File 'lib/seam/resources/acs_credential.rb', line 148

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerBoolean?

Indicates whether the latest state of the credential has been synced from Seam to the provider.

Returns:

  • (Boolean, nil)


151
152
153
# File 'lib/seam/resources/acs_credential.rb', line 151

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedBoolean

Indicates whether Seam manages the credential.

Returns:

  • (Boolean)


154
155
156
# File 'lib/seam/resources/acs_credential.rb', line 154

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialBoolean?

Indicates whether the credential is a multi-phone sync credential.

Returns:

  • (Boolean, nil)


157
158
159
# File 'lib/seam/resources/acs_credential.rb', line 157

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useBoolean?

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean, nil)


160
161
162
# File 'lib/seam/resources/acs_credential.rb', line 160

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idString?

ID of the parent credential.

Returns:

  • (String, nil)


163
164
165
# File 'lib/seam/resources/acs_credential.rb', line 163

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atString?

Date and time at which the credential validity starts, in ISO 8601 format.

Returns:

  • (String, nil)


166
167
168
# File 'lib/seam/resources/acs_credential.rb', line 166

def starts_at
  @starts_at
end

#user_identity_idString?

ID of the user identity to whom the credential belongs.

Returns:

  • (String, nil)


169
170
171
# File 'lib/seam/resources/acs_credential.rb', line 169

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the workspace that contains the credential.

Returns:

  • (String)


172
173
174
# File 'lib/seam/resources/acs_credential.rb', line 172

def workspace_id
  @workspace_id
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata for the credential.

Returns:



97
# File 'lib/seam/resources/acs_credential.rb', line 97

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

Vostio-specific metadata for the credential.

Returns:



100
# File 'lib/seam/resources/acs_credential.rb', line 100

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#created_atTime

Date and time at which the credential was created.

Returns:

  • (Time)


176
# File 'lib/seam/resources/acs_credential.rb', line 176

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the credential.

Returns:



106
# File 'lib/seam/resources/acs_credential.rb', line 106

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the credential was encoded onto a card.

Returns:

  • (Time, nil)


180
# File 'lib/seam/resources/acs_credential.rb', line 180

date_accessor :issued_at

#latest_desired_state_synced_with_provider_atTime?

Date and time at which the state of the credential was most recently synced from Seam to the provider.

Returns:

  • (Time, nil)


184
# File 'lib/seam/resources/acs_credential.rb', line 184

date_accessor :latest_desired_state_synced_with_provider_at

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the credential.

Returns:



103
# File 'lib/seam/resources/acs_credential.rb', line 103

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the credential.

Returns:



109
# File 'lib/seam/resources/acs_credential.rb', line 109

resource_list_accessor :warnings, Warnings