Class: Seam::Resources::AcsCredential

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Means by which an access control system user gains access at an entrance. The acs_credential object represents a credential that provides an ACS user access within an access control system.

An access control system generally uses digital means of access to authorize a user trying to get through a specific entrance. Examples of credentials include plastic key cards, mobile keys, biometric identifiers, and PIN codes. The electronic nature of these credentials, as well as the fact that access is centralized, enables both the rapid provisioning and rescinding of access and the ability to compile access audit logs.

For each acs_credential, you define the access method. You can also specify additional properties, such as a PIN code, depending on the credential type.

For granting a person access to a space, Access Grants are the default and recommended approach. Use the lower-level ACS credential API directly only when you specifically need to manage individual credentials.

Defined Under Namespace

Classes: AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodObject

Access method for the credential. Supported values: code, card, mobile_key, cloud_key.



68
69
70
# File 'lib/seam/resources/acs_credential.rb', line 68

def access_method
  @access_method
end

#acs_credential_idObject

ID of the credential.



70
71
72
# File 'lib/seam/resources/acs_credential.rb', line 70

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idObject

ID of the credential pool to which the credential belongs.



72
73
74
# File 'lib/seam/resources/acs_credential.rb', line 72

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idObject

ID of the access control system that contains the credential.



74
75
76
# File 'lib/seam/resources/acs_credential.rb', line 74

def acs_system_id
  @acs_system_id
end

#acs_user_idObject

ID of the ACS user to whom the credential belongs.



76
77
78
# File 'lib/seam/resources/acs_credential.rb', line 76

def acs_user_id
  @acs_user_id
end

#card_numberObject

Number of the card associated with the credential.



78
79
80
# File 'lib/seam/resources/acs_credential.rb', line 78

def card_number
  @card_number
end

#codeObject

Access (PIN) code for the credential.



80
81
82
# File 'lib/seam/resources/acs_credential.rb', line 80

def code
  @code
end

#connected_account_idObject

ID of the connected account to which the credential belongs.



82
83
84
# File 'lib/seam/resources/acs_credential.rb', line 82

def 
  @connected_account_id
end

#display_nameObject

Display name that corresponds to the credential type.



84
85
86
# File 'lib/seam/resources/acs_credential.rb', line 84

def display_name
  @display_name
end

#ends_atObject

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.



86
87
88
# File 'lib/seam/resources/acs_credential.rb', line 86

def ends_at
  @ends_at
end

#external_typeObject

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.



88
89
90
# File 'lib/seam/resources/acs_credential.rb', line 88

def external_type
  @external_type
end

#external_type_display_nameObject

Display name that corresponds to the brand-specific terminology for the credential type.



90
91
92
# File 'lib/seam/resources/acs_credential.rb', line 90

def external_type_display_name
  @external_type_display_name
end

#is_issuedObject

Indicates whether the credential has been encoded onto a card.



92
93
94
# File 'lib/seam/resources/acs_credential.rb', line 92

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerObject

Indicates whether the latest state of the credential has been synced from Seam to the provider.



94
95
96
# File 'lib/seam/resources/acs_credential.rb', line 94

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedObject

Indicates whether Seam manages the credential.



96
97
98
# File 'lib/seam/resources/acs_credential.rb', line 96

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialObject

Indicates whether the credential is a multi-phone sync credential.



98
99
100
# File 'lib/seam/resources/acs_credential.rb', line 98

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useObject

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.



100
101
102
# File 'lib/seam/resources/acs_credential.rb', line 100

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idObject

ID of the parent credential.



102
103
104
# File 'lib/seam/resources/acs_credential.rb', line 102

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atObject

Date and time at which the credential validity starts, in ISO 8601 format.



104
105
106
# File 'lib/seam/resources/acs_credential.rb', line 104

def starts_at
  @starts_at
end

#user_identity_idObject

ID of the user identity to whom the credential belongs.



106
107
108
# File 'lib/seam/resources/acs_credential.rb', line 106

def user_identity_id
  @user_identity_id
end

#workspace_idObject

ID of the workspace that contains the credential.



108
109
110
# File 'lib/seam/resources/acs_credential.rb', line 108

def workspace_id
  @workspace_id
end