Class: Seam::Resources::AcsCredential

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport, ResourceWarningsSupport
Defined in:
lib/seam/resources/acs_credential.rb

Overview

Means by which an access control system user gains access at an entrance. The acs_credential object represents a credential that provides an ACS user access within an access control system.

An access control system generally uses digital means of access to authorize a user trying to get through a specific entrance. Examples of credentials include plastic key cards, mobile keys, biometric identifiers, and PIN codes. The electronic nature of these credentials, as well as the fact that access is centralized, enables both the rapid provisioning and rescinding of access and the ability to compile access audit logs.

For each acs_credential, you define the access method. You can also specify additional properties, such as a PIN code, depending on the credential type.

For granting a person access to a space, Access Grants are the default and recommended approach. Use the lower-level ACS credential API directly only when you specifically need to manage individual credentials.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceWarningsSupport

#warnings

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodObject

Access method for the credential. Supported values: code, card, mobile_key, cloud_key.



14
15
16
# File 'lib/seam/resources/acs_credential.rb', line 14

def access_method
  @access_method
end

#acs_credential_idObject

ID of the credential.



16
17
18
# File 'lib/seam/resources/acs_credential.rb', line 16

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idObject

ID of the credential pool to which the credential belongs.



18
19
20
# File 'lib/seam/resources/acs_credential.rb', line 18

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idObject

ID of the access control system that contains the credential.



20
21
22
# File 'lib/seam/resources/acs_credential.rb', line 20

def acs_system_id
  @acs_system_id
end

#acs_user_idObject

ID of the ACS user to whom the credential belongs.



22
23
24
# File 'lib/seam/resources/acs_credential.rb', line 22

def acs_user_id
  @acs_user_id
end

#assa_abloy_vostio_metadataObject

Vostio-specific metadata for the credential.



24
25
26
# File 'lib/seam/resources/acs_credential.rb', line 24

def 
  @assa_abloy_vostio_metadata
end

#card_numberObject

Number of the card associated with the credential.



26
27
28
# File 'lib/seam/resources/acs_credential.rb', line 26

def card_number
  @card_number
end

#codeObject

Access (PIN) code for the credential.



28
29
30
# File 'lib/seam/resources/acs_credential.rb', line 28

def code
  @code
end

#connected_account_idObject

ID of the connected account to which the credential belongs.



30
31
32
# File 'lib/seam/resources/acs_credential.rb', line 30

def 
  @connected_account_id
end

#display_nameObject

Display name that corresponds to the credential type.



32
33
34
# File 'lib/seam/resources/acs_credential.rb', line 32

def display_name
  @display_name
end

#ends_atObject

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.



34
35
36
# File 'lib/seam/resources/acs_credential.rb', line 34

def ends_at
  @ends_at
end

#external_typeObject

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.



36
37
38
# File 'lib/seam/resources/acs_credential.rb', line 36

def external_type
  @external_type
end

#external_type_display_nameObject

Display name that corresponds to the brand-specific terminology for the credential type.



38
39
40
# File 'lib/seam/resources/acs_credential.rb', line 38

def external_type_display_name
  @external_type_display_name
end

#is_issuedObject

Indicates whether the credential has been encoded onto a card.



40
41
42
# File 'lib/seam/resources/acs_credential.rb', line 40

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerObject

Indicates whether the latest state of the credential has been synced from Seam to the provider.



42
43
44
# File 'lib/seam/resources/acs_credential.rb', line 42

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedObject

Indicates whether Seam manages the credential.



44
45
46
# File 'lib/seam/resources/acs_credential.rb', line 44

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialObject

Indicates whether the credential is a multi-phone sync credential.



46
47
48
# File 'lib/seam/resources/acs_credential.rb', line 46

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useObject

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.



48
49
50
# File 'lib/seam/resources/acs_credential.rb', line 48

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idObject

ID of the parent credential.



50
51
52
# File 'lib/seam/resources/acs_credential.rb', line 50

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atObject

Date and time at which the credential validity starts, in ISO 8601 format.



52
53
54
# File 'lib/seam/resources/acs_credential.rb', line 52

def starts_at
  @starts_at
end

#user_identity_idObject

ID of the user identity to whom the credential belongs.



54
55
56
# File 'lib/seam/resources/acs_credential.rb', line 54

def user_identity_id
  @user_identity_id
end

#visionline_metadataObject

Visionline-specific metadata for the credential.



56
57
58
# File 'lib/seam/resources/acs_credential.rb', line 56

def 
  @visionline_metadata
end

#workspace_idObject

ID of the workspace that contains the credential.



58
59
60
# File 'lib/seam/resources/acs_credential.rb', line 58

def workspace_id
  @workspace_id
end