Class: Seam::Resources::AcsCredential::AssaAbloyVostioMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsCredential::AssaAbloyVostioMetadata
- Defined in:
- lib/seam/resources/acs_credential.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Object
Indicates whether the credential should auto-join.
-
#door_names ⇒ Object
Names of the doors to which to grant access in the Vostio access system.
-
#endpoint_id ⇒ Object
Endpoint ID in the Vostio access system.
-
#key_id ⇒ Object
Key ID in the Vostio access system.
-
#key_issuing_request_id ⇒ Object
Key issuing request ID in the Vostio access system.
-
#override_guest_acs_entrance_ids ⇒ Object
IDs of the guest entrances to override in the Vostio access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Object
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
15 16 17 |
# File 'lib/seam/resources/acs_credential.rb', line 15 def auto_join @auto_join end |
#door_names ⇒ Object
Names of the doors to which to grant access in the Vostio access system.
17 18 19 |
# File 'lib/seam/resources/acs_credential.rb', line 17 def door_names @door_names end |
#endpoint_id ⇒ Object
Endpoint ID in the Vostio access system.
19 20 21 |
# File 'lib/seam/resources/acs_credential.rb', line 19 def endpoint_id @endpoint_id end |
#key_id ⇒ Object
Key ID in the Vostio access system.
21 22 23 |
# File 'lib/seam/resources/acs_credential.rb', line 21 def key_id @key_id end |
#key_issuing_request_id ⇒ Object
Key issuing request ID in the Vostio access system.
23 24 25 |
# File 'lib/seam/resources/acs_credential.rb', line 23 def key_issuing_request_id @key_issuing_request_id end |
#override_guest_acs_entrance_ids ⇒ Object
IDs of the guest entrances to override in the Vostio access system.
25 26 27 |
# File 'lib/seam/resources/acs_credential.rb', line 25 def override_guest_acs_entrance_ids @override_guest_acs_entrance_ids end |