Class: Seam::Resources::AcsCredential::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsCredential::VisionlineMetadata
- Defined in:
- lib/seam/resources/acs_credential.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Object
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ Object
Card function type in the Visionline access system.
-
#card_id ⇒ Object
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Object
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ Object
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Object
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Object
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Object
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Object
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
37 38 39 |
# File 'lib/seam/resources/acs_credential.rb', line 37 def auto_join @auto_join end |
#card_function_type ⇒ Object
Card function type in the Visionline access system.
39 40 41 |
# File 'lib/seam/resources/acs_credential.rb', line 39 def card_function_type @card_function_type end |
#card_id ⇒ Object
ID of the card in the Visionline access system.
41 42 43 |
# File 'lib/seam/resources/acs_credential.rb', line 41 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Object
Common entrance IDs in the Visionline access system.
43 44 45 |
# File 'lib/seam/resources/acs_credential.rb', line 43 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ Object
ID of the credential in the Visionline access system.
45 46 47 |
# File 'lib/seam/resources/acs_credential.rb', line 45 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Object
Guest entrance IDs in the Visionline access system.
47 48 49 |
# File 'lib/seam/resources/acs_credential.rb', line 47 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Object
Indicates whether the credential is valid.
49 50 51 |
# File 'lib/seam/resources/acs_credential.rb', line 49 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Object
IDs of the credentials to which you want to join.
51 52 53 |
# File 'lib/seam/resources/acs_credential.rb', line 51 def joiner_acs_credential_ids @joiner_acs_credential_ids end |