Class: Seam::Resources::AcsCredential::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinObject

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.



37
38
39
# File 'lib/seam/resources/acs_credential.rb', line 37

def auto_join
  @auto_join
end

#card_function_typeObject

Card function type in the Visionline access system.



39
40
41
# File 'lib/seam/resources/acs_credential.rb', line 39

def card_function_type
  @card_function_type
end

#card_idObject

ID of the card in the Visionline access system.



41
42
43
# File 'lib/seam/resources/acs_credential.rb', line 41

def card_id
  @card_id
end

#common_acs_entrance_idsObject

Common entrance IDs in the Visionline access system.



43
44
45
# File 'lib/seam/resources/acs_credential.rb', line 43

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#credential_idObject

ID of the credential in the Visionline access system.



45
46
47
# File 'lib/seam/resources/acs_credential.rb', line 45

def credential_id
  @credential_id
end

#guest_acs_entrance_idsObject

Guest entrance IDs in the Visionline access system.



47
48
49
# File 'lib/seam/resources/acs_credential.rb', line 47

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#is_validObject

Indicates whether the credential is valid.



49
50
51
# File 'lib/seam/resources/acs_credential.rb', line 49

def is_valid
  @is_valid
end

#joiner_acs_credential_idsObject

IDs of the credentials to which you want to join.



51
52
53
# File 'lib/seam/resources/acs_credential.rb', line 51

def joiner_acs_credential_ids
  @joiner_acs_credential_ids
end