Class: Seam::Resources::AcsCredential::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsCredential::Warnings
- Defined in:
- lib/seam/resources/acs_credential.rb
Overview
Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.
Defined Under Namespace
Classes: BeingDeleted, NeedsToBeReissued, RequestedCodeUnavailable, ScheduleExternallyModified, ScheduleModified, UnknownIssueWithAcsCredential, WaitingToBeIssued
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
195 196 197 |
# File 'lib/seam/resources/acs_credential.rb', line 195 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
waiting_to_be_issuedschedule_externally_modifiedschedule_modifiedbeing_deletedunknown_issue_with_acs_credentialneeds_to_be_reissuedrequested_code_unavailable
206 207 208 |
# File 'lib/seam/resources/acs_credential.rb', line 206 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
209 |
# File 'lib/seam/resources/acs_credential.rb', line 209 date_accessor :created_at |