Class: Seam::Resources::AcsCredential::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_credential.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


80
81
82
# File 'lib/seam/resources/acs_credential.rb', line 80

def message
  @message
end

#new_codeString

The PIN code that was assigned instead.

Returns:

  • (String)


83
84
85
# File 'lib/seam/resources/acs_credential.rb', line 83

def new_code
  @new_code
end

#original_codeString

The originally requested PIN code that could not be used.

Returns:

  • (String)


86
87
88
# File 'lib/seam/resources/acs_credential.rb', line 86

def original_code
  @original_code
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


89
90
91
# File 'lib/seam/resources/acs_credential.rb', line 89

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


92
# File 'lib/seam/resources/acs_credential.rb', line 92

date_accessor :created_at