Class: Seam::Resources::AcsCredential::Warnings::NeedsToBeReissued
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsCredential::Warnings::NeedsToBeReissued
- Defined in:
- lib/seam/resources/acs_credential.rb
Overview
Access permissions for the credential have changed. Reissue (re-encode) the credential. This issue may affect the proper functioning of the credential.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
161 162 163 |
# File 'lib/seam/resources/acs_credential.rb', line 161 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
needs_to_be_reissued
166 167 168 |
# File 'lib/seam/resources/acs_credential.rb', line 166 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
169 |
# File 'lib/seam/resources/acs_credential.rb', line 169 date_accessor :created_at |