Class: Seam::Resources::AcsCredential::Warnings::RequestedCodeUnavailable
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsCredential::Warnings::RequestedCodeUnavailable
- Defined in:
- lib/seam/resources/acs_credential.rb
Overview
Indicates that the requested PIN code could not be used, so the access system assigned a different code. Give the guest the assigned code.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#new_code ⇒ String
The PIN code that was assigned instead.
-
#original_code ⇒ String
The originally requested PIN code that could not be used.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
176 177 178 |
# File 'lib/seam/resources/acs_credential.rb', line 176 def @message end |
#new_code ⇒ String
The PIN code that was assigned instead.
179 180 181 |
# File 'lib/seam/resources/acs_credential.rb', line 179 def new_code @new_code end |
#original_code ⇒ String
The originally requested PIN code that could not be used.
182 183 184 |
# File 'lib/seam/resources/acs_credential.rb', line 182 def original_code @original_code end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
requested_code_unavailable
187 188 189 |
# File 'lib/seam/resources/acs_credential.rb', line 187 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
190 |
# File 'lib/seam/resources/acs_credential.rb', line 190 date_accessor :created_at |