Class: Seam::Resources::AcsCredential::Warnings::UnknownIssueWithAcsCredential
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsCredential::Warnings::UnknownIssueWithAcsCredential
- Defined in:
- lib/seam/resources/acs_credential.rb
Overview
An unknown issue occurred while syncing the state of the credential with the provider. This issue may affect the proper functioning of the credential.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
146 147 148 |
# File 'lib/seam/resources/acs_credential.rb', line 146 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
unknown_issue_with_acs_credential
151 152 153 |
# File 'lib/seam/resources/acs_credential.rb', line 151 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
154 |
# File 'lib/seam/resources/acs_credential.rb', line 154 date_accessor :created_at |