Class: Seam::Resources::AcsEncoder

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport
Defined in:
lib/seam/resources/acs_encoder.rb

Overview

Represents a hardware device that encodes credential data onto physical cards within an access control system.

Some access control systems require credentials to be encoded onto plastic key cards using a card encoder. This process involves the following two key steps:

  1. Credential creation Configure the access parameters for the credential.
  2. Card encoding Write the credential data onto the card using a compatible card encoder.

Separately, the Seam API also supports card scanning, which enables you to scan and read the encoded data on a card. You can use this action to confirm consistency with access control system records or diagnose discrepancies if needed.

See Working with Card Encoders and Scanners.

To verify if your access control system requires a card encoder, see the corresponding system integration guide.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_encoder_idObject

ID of the encoder.



21
22
23
# File 'lib/seam/resources/acs_encoder.rb', line 21

def acs_encoder_id
  @acs_encoder_id
end

#acs_system_idObject

ID of the access control system that contains the encoder.



23
24
25
# File 'lib/seam/resources/acs_encoder.rb', line 23

def acs_system_id
  @acs_system_id
end

#connected_account_idObject

ID of the connected account that contains the encoder.



25
26
27
# File 'lib/seam/resources/acs_encoder.rb', line 25

def 
  @connected_account_id
end

#display_nameObject

Display name for the encoder.



27
28
29
# File 'lib/seam/resources/acs_encoder.rb', line 27

def display_name
  @display_name
end

#workspace_idObject

ID of the workspace that contains the encoder.



29
30
31
# File 'lib/seam/resources/acs_encoder.rb', line 29

def workspace_id
  @workspace_id
end