Class: Seam::Resources::AcsEncoder::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEncoder::Errors
- Defined in:
- lib/seam/resources/acs_encoder.rb
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
23 24 25 |
# File 'lib/seam/resources/acs_encoder.rb', line 23 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
26 27 28 |
# File 'lib/seam/resources/acs_encoder.rb', line 26 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
29 |
# File 'lib/seam/resources/acs_encoder.rb', line 29 date_accessor :created_at |