Class: Seam::Resources::AcsEntrance

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Represents an entrance within an access control system.

In an access control system, an entrance is a secured door, gate, zone, or other method of entry. You can list details for all the acs_entrance resources in your workspace or get these details for a specific acs_entrance. You can also list all entrances associated with a specific credential, and you can list all credentials associated with a specific entrance.

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, AvigilonAltaMetadata, BrivoMetadata, DormakabaAmbianceMetadata, DormakabaCommunityMetadata, Errors, HotekMetadata, LatchMetadata, SaltoKsMetadata, SaltoSpaceMetadata, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_entrance_idString

ID of the entrance.

Returns:

  • (String)


260
261
262
# File 'lib/seam/resources/acs_entrance.rb', line 260

def acs_entrance_id
  @acs_entrance_id
end

#acs_system_idString

ID of the access control system that contains the entrance.

Returns:

  • (String)


263
264
265
# File 'lib/seam/resources/acs_entrance.rb', line 263

def acs_system_id
  @acs_system_id
end

#can_belong_to_reservationBoolean?

Indicates whether the ACS entrance can belong to a reservation via an access_grant.reservation_key.

Returns:

  • (Boolean, nil)


266
267
268
# File 'lib/seam/resources/acs_entrance.rb', line 266

def can_belong_to_reservation
  @can_belong_to_reservation
end

#can_unlock_with_cardBoolean?

Indicates whether the ACS entrance can be unlocked with card credentials.

Returns:

  • (Boolean, nil)


269
270
271
# File 'lib/seam/resources/acs_entrance.rb', line 269

def can_unlock_with_card
  @can_unlock_with_card
end

#can_unlock_with_cloud_keyBoolean?

Indicates whether the ACS entrance can be unlocked with cloud key credentials.

Returns:

  • (Boolean, nil)


272
273
274
# File 'lib/seam/resources/acs_entrance.rb', line 272

def can_unlock_with_cloud_key
  @can_unlock_with_cloud_key
end

#can_unlock_with_codeBoolean?

Indicates whether the ACS entrance can be unlocked with pin codes.

Returns:

  • (Boolean, nil)


275
276
277
# File 'lib/seam/resources/acs_entrance.rb', line 275

def can_unlock_with_code
  @can_unlock_with_code
end

#can_unlock_with_mobile_keyBoolean?

Indicates whether the ACS entrance can be unlocked with mobile key credentials.

Returns:

  • (Boolean, nil)


278
279
280
# File 'lib/seam/resources/acs_entrance.rb', line 278

def can_unlock_with_mobile_key
  @can_unlock_with_mobile_key
end

#connected_account_idString

ID of the connected account associated with the entrance.

Returns:

  • (String)


281
282
283
# File 'lib/seam/resources/acs_entrance.rb', line 281

def 
  @connected_account_id
end

#display_nameString

Display name for the entrance.

Returns:

  • (String)


284
285
286
# File 'lib/seam/resources/acs_entrance.rb', line 284

def display_name
  @display_name
end

#is_lockedBoolean?

Indicates whether the entrance is currently locked.

Returns:

  • (Boolean, nil)


287
288
289
# File 'lib/seam/resources/acs_entrance.rb', line 287

def is_locked
  @is_locked
end

#space_idsArray<String>

IDs of the spaces that the entrance is in.

Returns:

  • (Array<String>)


290
291
292
# File 'lib/seam/resources/acs_entrance.rb', line 290

def space_ids
  @space_ids
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata associated with the entrance.

Returns:



221
# File 'lib/seam/resources/acs_entrance.rb', line 221

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

ASSA ABLOY Vostio-specific metadata associated with the entrance.

Returns:



224
# File 'lib/seam/resources/acs_entrance.rb', line 224

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#avigilon_alta_metadataAvigilonAltaMetadata?

Avigilon Alta-specific metadata associated with the entrance.

Returns:



227
# File 'lib/seam/resources/acs_entrance.rb', line 227

resource_accessor :avigilon_alta_metadata, AvigilonAltaMetadata

#brivo_metadataBrivoMetadata?

Brivo-specific metadata associated with the entrance.

Returns:



230
# File 'lib/seam/resources/acs_entrance.rb', line 230

resource_accessor :brivo_metadata, BrivoMetadata

#created_atTime

Date and time at which the entrance was created.

Returns:

  • (Time)


294
# File 'lib/seam/resources/acs_entrance.rb', line 294

date_accessor :created_at

#dormakaba_ambiance_metadataDormakabaAmbianceMetadata?

dormakaba Ambiance-specific metadata associated with the entrance.

Returns:



233
# File 'lib/seam/resources/acs_entrance.rb', line 233

resource_accessor :dormakaba_ambiance_metadata, DormakabaAmbianceMetadata

#dormakaba_community_metadataDormakabaCommunityMetadata?

dormakaba Community-specific metadata associated with the entrance.

Returns:



236
# File 'lib/seam/resources/acs_entrance.rb', line 236

resource_accessor :dormakaba_community_metadata, DormakabaCommunityMetadata

#errorsArray<Errors>

Errors associated with the entrance.

Returns:



254
# File 'lib/seam/resources/acs_entrance.rb', line 254

resource_list_accessor :errors, Errors

#hotek_metadataHotekMetadata?

Hotek-specific metadata associated with the entrance.

Returns:



239
# File 'lib/seam/resources/acs_entrance.rb', line 239

resource_accessor :hotek_metadata, HotekMetadata

#latch_metadataLatchMetadata?

Latch-specific metadata associated with the entrance.

Returns:



242
# File 'lib/seam/resources/acs_entrance.rb', line 242

resource_accessor :latch_metadata, LatchMetadata

#salto_ks_metadataSaltoKsMetadata?

Salto KS-specific metadata associated with the entrance.

Returns:



245
# File 'lib/seam/resources/acs_entrance.rb', line 245

resource_accessor :salto_ks_metadata, SaltoKsMetadata

#salto_space_metadataSaltoSpaceMetadata?

Salto Space-specific metadata associated with the entrance.

Returns:



248
# File 'lib/seam/resources/acs_entrance.rb', line 248

resource_accessor :salto_space_metadata, SaltoSpaceMetadata

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata associated with the entrance.

Returns:



251
# File 'lib/seam/resources/acs_entrance.rb', line 251

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the entrance.

Returns:



257
# File 'lib/seam/resources/acs_entrance.rb', line 257

resource_list_accessor :warnings, Warnings