Class: Seam::Resources::AcsEntrance
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance
- Defined in:
- lib/seam/resources/acs_entrance.rb
Overview
Represents an entrance within an access control system.
In an access control system, an entrance is a secured door, gate, zone, or other method of entry. You can list details for all the acs_entrance resources in your workspace or get these details for a specific acs_entrance. You can also list all entrances associated with a specific credential, and you can list all credentials associated with a specific entrance.
Defined Under Namespace
Classes: AkilesMetadata, AssaAbloyVostioMetadata, AvigilonAltaMetadata, BrivoMetadata, DormakabaAmbianceMetadata, DormakabaCommunityMetadata, Errors, HotekMetadata, LatchMetadata, SaltoKsMetadata, SaltoSpaceMetadata, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#acs_entrance_id ⇒ String
ID of the entrance.
-
#acs_system_id ⇒ String
ID of the access control system that contains the entrance.
-
#can_belong_to_reservation ⇒ Boolean?
Indicates whether the ACS entrance can belong to a reservation via an access_grant.reservation_key.
-
#can_unlock_with_card ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with card credentials.
-
#can_unlock_with_cloud_key ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with cloud key credentials.
-
#can_unlock_with_code ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with pin codes.
-
#can_unlock_with_mobile_key ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with mobile key credentials.
-
#connected_account_id ⇒ String
ID of the connected account associated with the entrance.
-
#display_name ⇒ String
Display name for the entrance.
-
#is_locked ⇒ Boolean?
Indicates whether the entrance is currently locked.
-
#space_ids ⇒ Array<String>
IDs of the spaces that the entrance is in.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata associated with the entrance.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
ASSA ABLOY Vostio-specific metadata associated with the entrance.
-
#avigilon_alta_metadata ⇒ AvigilonAltaMetadata?
Avigilon Alta-specific metadata associated with the entrance.
-
#brivo_metadata ⇒ BrivoMetadata?
Brivo-specific metadata associated with the entrance.
-
#created_at ⇒ Time
Date and time at which the entrance was created.
-
#dormakaba_ambiance_metadata ⇒ DormakabaAmbianceMetadata?
dormakaba Ambiance-specific metadata associated with the entrance.
-
#dormakaba_community_metadata ⇒ DormakabaCommunityMetadata?
dormakaba Community-specific metadata associated with the entrance.
-
#errors ⇒ Array<Errors>
Errors associated with the entrance.
-
#hotek_metadata ⇒ HotekMetadata?
Hotek-specific metadata associated with the entrance.
-
#latch_metadata ⇒ LatchMetadata?
Latch-specific metadata associated with the entrance.
-
#salto_ks_metadata ⇒ SaltoKsMetadata?
Salto KS-specific metadata associated with the entrance.
-
#salto_space_metadata ⇒ SaltoSpaceMetadata?
Salto Space-specific metadata associated with the entrance.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata associated with the entrance.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the entrance.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_entrance_id ⇒ String
ID of the entrance.
260 261 262 |
# File 'lib/seam/resources/acs_entrance.rb', line 260 def acs_entrance_id @acs_entrance_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the entrance.
263 264 265 |
# File 'lib/seam/resources/acs_entrance.rb', line 263 def acs_system_id @acs_system_id end |
#can_belong_to_reservation ⇒ Boolean?
Indicates whether the ACS entrance can belong to a reservation via an access_grant.reservation_key.
266 267 268 |
# File 'lib/seam/resources/acs_entrance.rb', line 266 def can_belong_to_reservation @can_belong_to_reservation end |
#can_unlock_with_card ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with card credentials.
269 270 271 |
# File 'lib/seam/resources/acs_entrance.rb', line 269 def can_unlock_with_card @can_unlock_with_card end |
#can_unlock_with_cloud_key ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with cloud key credentials.
272 273 274 |
# File 'lib/seam/resources/acs_entrance.rb', line 272 def can_unlock_with_cloud_key @can_unlock_with_cloud_key end |
#can_unlock_with_code ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with pin codes.
275 276 277 |
# File 'lib/seam/resources/acs_entrance.rb', line 275 def can_unlock_with_code @can_unlock_with_code end |
#can_unlock_with_mobile_key ⇒ Boolean?
Indicates whether the ACS entrance can be unlocked with mobile key credentials.
278 279 280 |
# File 'lib/seam/resources/acs_entrance.rb', line 278 def can_unlock_with_mobile_key @can_unlock_with_mobile_key end |
#connected_account_id ⇒ String
ID of the connected account associated with the entrance.
281 282 283 |
# File 'lib/seam/resources/acs_entrance.rb', line 281 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name for the entrance.
284 285 286 |
# File 'lib/seam/resources/acs_entrance.rb', line 284 def display_name @display_name end |
#is_locked ⇒ Boolean?
Indicates whether the entrance is currently locked.
287 288 289 |
# File 'lib/seam/resources/acs_entrance.rb', line 287 def is_locked @is_locked end |
#space_ids ⇒ Array<String>
IDs of the spaces that the entrance is in.
290 291 292 |
# File 'lib/seam/resources/acs_entrance.rb', line 290 def space_ids @space_ids end |
Instance Method Details
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata associated with the entrance.
221 |
# File 'lib/seam/resources/acs_entrance.rb', line 221 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
ASSA ABLOY Vostio-specific metadata associated with the entrance.
224 |
# File 'lib/seam/resources/acs_entrance.rb', line 224 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#avigilon_alta_metadata ⇒ AvigilonAltaMetadata?
Avigilon Alta-specific metadata associated with the entrance.
227 |
# File 'lib/seam/resources/acs_entrance.rb', line 227 resource_accessor :avigilon_alta_metadata, AvigilonAltaMetadata |
#brivo_metadata ⇒ BrivoMetadata?
Brivo-specific metadata associated with the entrance.
230 |
# File 'lib/seam/resources/acs_entrance.rb', line 230 resource_accessor :brivo_metadata, BrivoMetadata |
#created_at ⇒ Time
Date and time at which the entrance was created.
294 |
# File 'lib/seam/resources/acs_entrance.rb', line 294 date_accessor :created_at |
#dormakaba_ambiance_metadata ⇒ DormakabaAmbianceMetadata?
dormakaba Ambiance-specific metadata associated with the entrance.
233 |
# File 'lib/seam/resources/acs_entrance.rb', line 233 resource_accessor :dormakaba_ambiance_metadata, DormakabaAmbianceMetadata |
#dormakaba_community_metadata ⇒ DormakabaCommunityMetadata?
dormakaba Community-specific metadata associated with the entrance.
236 |
# File 'lib/seam/resources/acs_entrance.rb', line 236 resource_accessor :dormakaba_community_metadata, DormakabaCommunityMetadata |
#errors ⇒ Array<Errors>
Errors associated with the entrance.
254 |
# File 'lib/seam/resources/acs_entrance.rb', line 254 resource_list_accessor :errors, Errors |
#hotek_metadata ⇒ HotekMetadata?
Hotek-specific metadata associated with the entrance.
239 |
# File 'lib/seam/resources/acs_entrance.rb', line 239 resource_accessor :hotek_metadata, HotekMetadata |
#latch_metadata ⇒ LatchMetadata?
Latch-specific metadata associated with the entrance.
242 |
# File 'lib/seam/resources/acs_entrance.rb', line 242 resource_accessor :latch_metadata, LatchMetadata |
#salto_ks_metadata ⇒ SaltoKsMetadata?
Salto KS-specific metadata associated with the entrance.
245 |
# File 'lib/seam/resources/acs_entrance.rb', line 245 resource_accessor :salto_ks_metadata, SaltoKsMetadata |
#salto_space_metadata ⇒ SaltoSpaceMetadata?
Salto Space-specific metadata associated with the entrance.
248 |
# File 'lib/seam/resources/acs_entrance.rb', line 248 resource_accessor :salto_space_metadata, SaltoSpaceMetadata |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata associated with the entrance.
251 |
# File 'lib/seam/resources/acs_entrance.rb', line 251 resource_accessor :visionline_metadata, VisionlineMetadata |