Class: Seam::Resources::AcsEntrance

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Represents an entrance within an access control system.

In an access control system, an entrance is a secured door, gate, zone, or other method of entry. You can list details for all the acs_entrance resources in your workspace or get these details for a specific acs_entrance. You can also list all entrances associated with a specific credential, and you can list all credentials associated with a specific entrance.

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, AvigilonAltaMetadata, BrivoMetadata, DormakabaAmbianceMetadata, DormakabaCommunityMetadata, Errors, HotekMetadata, LatchMetadata, SaltoKsMetadata, SaltoSpaceMetadata, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_entrance_idObject

ID of the entrance.



176
177
178
# File 'lib/seam/resources/acs_entrance.rb', line 176

def acs_entrance_id
  @acs_entrance_id
end

#acs_system_idObject

ID of the access control system that contains the entrance.



178
179
180
# File 'lib/seam/resources/acs_entrance.rb', line 178

def acs_system_id
  @acs_system_id
end

#can_belong_to_reservationObject

Indicates whether the ACS entrance can belong to a reservation via an access_grant.reservation_key.



180
181
182
# File 'lib/seam/resources/acs_entrance.rb', line 180

def can_belong_to_reservation
  @can_belong_to_reservation
end

#can_unlock_with_cardObject

Indicates whether the ACS entrance can be unlocked with card credentials.



182
183
184
# File 'lib/seam/resources/acs_entrance.rb', line 182

def can_unlock_with_card
  @can_unlock_with_card
end

#can_unlock_with_cloud_keyObject

Indicates whether the ACS entrance can be unlocked with cloud key credentials.



184
185
186
# File 'lib/seam/resources/acs_entrance.rb', line 184

def can_unlock_with_cloud_key
  @can_unlock_with_cloud_key
end

#can_unlock_with_codeObject

Indicates whether the ACS entrance can be unlocked with pin codes.



186
187
188
# File 'lib/seam/resources/acs_entrance.rb', line 186

def can_unlock_with_code
  @can_unlock_with_code
end

#can_unlock_with_mobile_keyObject

Indicates whether the ACS entrance can be unlocked with mobile key credentials.



188
189
190
# File 'lib/seam/resources/acs_entrance.rb', line 188

def can_unlock_with_mobile_key
  @can_unlock_with_mobile_key
end

#connected_account_idObject

ID of the connected account associated with the entrance.



190
191
192
# File 'lib/seam/resources/acs_entrance.rb', line 190

def 
  @connected_account_id
end

#display_nameObject

Display name for the entrance.



192
193
194
# File 'lib/seam/resources/acs_entrance.rb', line 192

def display_name
  @display_name
end

#is_lockedObject

Indicates whether the entrance is currently locked.



194
195
196
# File 'lib/seam/resources/acs_entrance.rb', line 194

def is_locked
  @is_locked
end

#space_idsObject

IDs of the spaces that the entrance is in.



196
197
198
# File 'lib/seam/resources/acs_entrance.rb', line 196

def space_ids
  @space_ids
end