Class: Seam::Resources::AcsEntrance

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport, ResourceWarningsSupport
Defined in:
lib/seam/resources/acs_entrance.rb

Overview

Represents an entrance within an access control system.

In an access control system, an entrance is a secured door, gate, zone, or other method of entry. You can list details for all the acs_entrance resources in your workspace or get these details for a specific acs_entrance. You can also list all entrances associated with a specific credential, and you can list all credentials associated with a specific entrance.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceWarningsSupport

#warnings

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_entrance_idObject

ID of the entrance.



10
11
12
# File 'lib/seam/resources/acs_entrance.rb', line 10

def acs_entrance_id
  @acs_entrance_id
end

#acs_system_idObject

ID of the access control system that contains the entrance.



12
13
14
# File 'lib/seam/resources/acs_entrance.rb', line 12

def acs_system_id
  @acs_system_id
end

#akiles_metadataObject

Akiles-specific metadata associated with the entrance.



14
15
16
# File 'lib/seam/resources/acs_entrance.rb', line 14

def 
  @akiles_metadata
end

#assa_abloy_vostio_metadataObject

ASSA ABLOY Vostio-specific metadata associated with the entrance.



16
17
18
# File 'lib/seam/resources/acs_entrance.rb', line 16

def 
  @assa_abloy_vostio_metadata
end

#avigilon_alta_metadataObject

Avigilon Alta-specific metadata associated with the entrance.



18
19
20
# File 'lib/seam/resources/acs_entrance.rb', line 18

def 
  @avigilon_alta_metadata
end

#brivo_metadataObject

Brivo-specific metadata associated with the entrance.



20
21
22
# File 'lib/seam/resources/acs_entrance.rb', line 20

def 
  @brivo_metadata
end

#can_belong_to_reservationObject

Indicates whether the ACS entrance can belong to a reservation via an access_grant.reservation_key.



22
23
24
# File 'lib/seam/resources/acs_entrance.rb', line 22

def can_belong_to_reservation
  @can_belong_to_reservation
end

#can_unlock_with_cardObject

Indicates whether the ACS entrance can be unlocked with card credentials.



24
25
26
# File 'lib/seam/resources/acs_entrance.rb', line 24

def can_unlock_with_card
  @can_unlock_with_card
end

#can_unlock_with_cloud_keyObject

Indicates whether the ACS entrance can be unlocked with cloud key credentials.



26
27
28
# File 'lib/seam/resources/acs_entrance.rb', line 26

def can_unlock_with_cloud_key
  @can_unlock_with_cloud_key
end

#can_unlock_with_codeObject

Indicates whether the ACS entrance can be unlocked with pin codes.



28
29
30
# File 'lib/seam/resources/acs_entrance.rb', line 28

def can_unlock_with_code
  @can_unlock_with_code
end

#can_unlock_with_mobile_keyObject

Indicates whether the ACS entrance can be unlocked with mobile key credentials.



30
31
32
# File 'lib/seam/resources/acs_entrance.rb', line 30

def can_unlock_with_mobile_key
  @can_unlock_with_mobile_key
end

#connected_account_idObject

ID of the connected account associated with the entrance.



32
33
34
# File 'lib/seam/resources/acs_entrance.rb', line 32

def 
  @connected_account_id
end

#display_nameObject

Display name for the entrance.



34
35
36
# File 'lib/seam/resources/acs_entrance.rb', line 34

def display_name
  @display_name
end

#dormakaba_ambiance_metadataObject

dormakaba Ambiance-specific metadata associated with the entrance.



36
37
38
# File 'lib/seam/resources/acs_entrance.rb', line 36

def 
  @dormakaba_ambiance_metadata
end

#dormakaba_community_metadataObject

dormakaba Community-specific metadata associated with the entrance.



38
39
40
# File 'lib/seam/resources/acs_entrance.rb', line 38

def 
  @dormakaba_community_metadata
end

#hotek_metadataObject

Hotek-specific metadata associated with the entrance.



40
41
42
# File 'lib/seam/resources/acs_entrance.rb', line 40

def 
  @hotek_metadata
end

#is_lockedObject

Indicates whether the entrance is currently locked.



42
43
44
# File 'lib/seam/resources/acs_entrance.rb', line 42

def is_locked
  @is_locked
end

#latch_metadataObject

Latch-specific metadata associated with the entrance.



44
45
46
# File 'lib/seam/resources/acs_entrance.rb', line 44

def 
  @latch_metadata
end

#salto_ks_metadataObject

Salto KS-specific metadata associated with the entrance.



46
47
48
# File 'lib/seam/resources/acs_entrance.rb', line 46

def 
  @salto_ks_metadata
end

#salto_space_metadataObject

Salto Space-specific metadata associated with the entrance.



48
49
50
# File 'lib/seam/resources/acs_entrance.rb', line 48

def 
  @salto_space_metadata
end

#space_idsObject

IDs of the spaces that the entrance is in.



50
51
52
# File 'lib/seam/resources/acs_entrance.rb', line 50

def space_ids
  @space_ids
end

#visionline_metadataObject

Visionline-specific metadata associated with the entrance.



52
53
54
# File 'lib/seam/resources/acs_entrance.rb', line 52

def 
  @visionline_metadata
end