Class: Seam::Resources::AcsEntrance::AkilesMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::AkilesMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Defined Under Namespace
Classes: Actions
Instance Attribute Summary collapse
-
#gadget_id ⇒ Object
ID of the Akiles gadget.
-
#site_id ⇒ Object
ID of the Akiles site the gadget belongs to.
-
#site_name ⇒ Object
Name of the Akiles site the gadget belongs to.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#gadget_id ⇒ Object
ID of the Akiles gadget.
19 20 21 |
# File 'lib/seam/resources/acs_entrance.rb', line 19 def gadget_id @gadget_id end |
#site_id ⇒ Object
ID of the Akiles site the gadget belongs to.
21 22 23 |
# File 'lib/seam/resources/acs_entrance.rb', line 21 def site_id @site_id end |
#site_name ⇒ Object
Name of the Akiles site the gadget belongs to.
23 24 25 |
# File 'lib/seam/resources/acs_entrance.rb', line 23 def site_name @site_name end |