Class: Seam::Resources::AcsEntrance::AssaAbloyVostioMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#door_nameString?

Name of the door in the Vostio access system.

Returns:

  • (String, nil)


36
37
38
# File 'lib/seam/resources/acs_entrance.rb', line 36

def door_name
  @door_name
end

#door_numberFloat?

Number of the door in the Vostio access system.

Returns:

  • (Float, nil)


39
40
41
# File 'lib/seam/resources/acs_entrance.rb', line 39

def door_number
  @door_number
end

#door_typeString?

Type of the door in the Vostio access system.

Returns:

  • (String, nil)


42
43
44
# File 'lib/seam/resources/acs_entrance.rb', line 42

def door_type
  @door_type
end

#pms_idString?

PMS ID of the door in the Vostio access system.

Returns:

  • (String, nil)


45
46
47
# File 'lib/seam/resources/acs_entrance.rb', line 45

def pms_id
  @pms_id
end

#stand_openBoolean?

Indicates whether keys are allowed to set the door in stand open mode in the Vostio access system.

Returns:

  • (Boolean, nil)


48
49
50
# File 'lib/seam/resources/acs_entrance.rb', line 48

def stand_open
  @stand_open
end