Class: Seam::Resources::AcsEntrance::AssaAbloyVostioMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::AssaAbloyVostioMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#door_name ⇒ Object
Name of the door in the Vostio access system.
-
#door_number ⇒ Object
Number of the door in the Vostio access system.
-
#door_type ⇒ Object
Type of the door in the Vostio access system.
-
#pms_id ⇒ Object
PMS ID of the door in the Vostio access system.
-
#stand_open ⇒ Object
Indicates whether keys are allowed to set the door in stand open mode in the Vostio access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#door_name ⇒ Object
Name of the door in the Vostio access system.
28 29 30 |
# File 'lib/seam/resources/acs_entrance.rb', line 28 def door_name @door_name end |
#door_number ⇒ Object
Number of the door in the Vostio access system.
30 31 32 |
# File 'lib/seam/resources/acs_entrance.rb', line 30 def door_number @door_number end |
#door_type ⇒ Object
Type of the door in the Vostio access system.
32 33 34 |
# File 'lib/seam/resources/acs_entrance.rb', line 32 def door_type @door_type end |
#pms_id ⇒ Object
PMS ID of the door in the Vostio access system.
34 35 36 |
# File 'lib/seam/resources/acs_entrance.rb', line 34 def pms_id @pms_id end |
#stand_open ⇒ Object
Indicates whether keys are allowed to set the door in stand open mode in the Vostio access system.
36 37 38 |
# File 'lib/seam/resources/acs_entrance.rb', line 36 def stand_open @stand_open end |