Class: Seam::Resources::AcsEntrance::BrivoMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_point_idString?

ID of the access point in the Brivo access system.

Returns:

  • (String, nil)


78
79
80
# File 'lib/seam/resources/acs_entrance.rb', line 78

def access_point_id
  @access_point_id
end

#site_idFloat?

ID of the site that the access point belongs to.

Returns:

  • (Float, nil)


81
82
83
# File 'lib/seam/resources/acs_entrance.rb', line 81

def site_id
  @site_id
end

#site_nameString?

Name of the site that the access point belongs to.

Returns:

  • (String, nil)


84
85
86
# File 'lib/seam/resources/acs_entrance.rb', line 84

def site_name
  @site_name
end