Class: Seam::Resources::AcsEntrance::BrivoMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::BrivoMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#access_point_id ⇒ String?
ID of the access point in the Brivo access system.
-
#site_id ⇒ Float?
ID of the site that the access point belongs to.
-
#site_name ⇒ String?
Name of the site that the access point belongs to.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_point_id ⇒ String?
ID of the access point in the Brivo access system.
78 79 80 |
# File 'lib/seam/resources/acs_entrance.rb', line 78 def access_point_id @access_point_id end |
#site_id ⇒ Float?
ID of the site that the access point belongs to.
81 82 83 |
# File 'lib/seam/resources/acs_entrance.rb', line 81 def site_id @site_id end |
#site_name ⇒ String?
Name of the site that the access point belongs to.
84 85 86 |
# File 'lib/seam/resources/acs_entrance.rb', line 84 def site_name @site_name end |