Class: Seam::Resources::AcsEntrance::BrivoMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_point_idObject

ID of the access point in the Brivo access system.



58
59
60
# File 'lib/seam/resources/acs_entrance.rb', line 58

def access_point_id
  @access_point_id
end

#site_idObject

ID of the site that the access point belongs to.



60
61
62
# File 'lib/seam/resources/acs_entrance.rb', line 60

def site_id
  @site_id
end

#site_nameObject

Name of the site that the access point belongs to.



62
63
64
# File 'lib/seam/resources/acs_entrance.rb', line 62

def site_name
  @site_name
end