Class: Seam::Resources::AcsEntrance::LatchMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::LatchMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#accessibility_type ⇒ String?
Accessibility type in the Latch access system.
-
#door_name ⇒ String?
Name of the door in the Latch access system.
-
#door_type ⇒ String?
Type of the door in the Latch access system.
-
#is_connected ⇒ Boolean?
Indicates whether the entrance is connected.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#accessibility_type ⇒ String?
Accessibility type in the Latch access system.
131 132 133 |
# File 'lib/seam/resources/acs_entrance.rb', line 131 def accessibility_type @accessibility_type end |
#door_name ⇒ String?
Name of the door in the Latch access system.
134 135 136 |
# File 'lib/seam/resources/acs_entrance.rb', line 134 def door_name @door_name end |
#door_type ⇒ String?
Type of the door in the Latch access system.
137 138 139 |
# File 'lib/seam/resources/acs_entrance.rb', line 137 def door_type @door_type end |
#is_connected ⇒ Boolean?
Indicates whether the entrance is connected.
140 141 142 |
# File 'lib/seam/resources/acs_entrance.rb', line 140 def is_connected @is_connected end |