Class: Seam::Resources::AcsEntrance::LatchMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accessibility_typeString?

Accessibility type in the Latch access system.

Returns:

  • (String, nil)


126
127
128
# File 'lib/seam/resources/acs_entrance.rb', line 126

def accessibility_type
  @accessibility_type
end

#door_nameString?

Name of the door in the Latch access system.

Returns:

  • (String, nil)


129
130
131
# File 'lib/seam/resources/acs_entrance.rb', line 129

def door_name
  @door_name
end

#door_typeString?

Type of the door in the Latch access system.

Returns:

  • (String, nil)


132
133
134
# File 'lib/seam/resources/acs_entrance.rb', line 132

def door_type
  @door_type
end

#is_connectedBoolean?

Indicates whether the entrance is connected.

Returns:

  • (Boolean, nil)


135
136
137
# File 'lib/seam/resources/acs_entrance.rb', line 135

def is_connected
  @is_connected
end