Class: Seam::Resources::AcsEntrance::LatchMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::LatchMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#accessibility_type ⇒ String?
Accessibility type in the Latch access system.
-
#door_name ⇒ String?
Name of the door in the Latch access system.
-
#door_type ⇒ String?
Type of the door in the Latch access system.
-
#is_connected ⇒ Boolean?
Indicates whether the entrance is connected.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#accessibility_type ⇒ String?
Accessibility type in the Latch access system.
126 127 128 |
# File 'lib/seam/resources/acs_entrance.rb', line 126 def accessibility_type @accessibility_type end |
#door_name ⇒ String?
Name of the door in the Latch access system.
129 130 131 |
# File 'lib/seam/resources/acs_entrance.rb', line 129 def door_name @door_name end |
#door_type ⇒ String?
Type of the door in the Latch access system.
132 133 134 |
# File 'lib/seam/resources/acs_entrance.rb', line 132 def door_type @door_type end |
#is_connected ⇒ Boolean?
Indicates whether the entrance is connected.
135 136 137 |
# File 'lib/seam/resources/acs_entrance.rb', line 135 def is_connected @is_connected end |