Class: Seam::Resources::AcsEntrance::LatchMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::LatchMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#accessibility_type ⇒ Object
Accessibility type in the Latch access system.
-
#door_name ⇒ Object
Name of the door in the Latch access system.
-
#door_type ⇒ Object
Type of the door in the Latch access system.
-
#is_connected ⇒ Object
Indicates whether the entrance is connected.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#accessibility_type ⇒ Object
Accessibility type in the Latch access system.
95 96 97 |
# File 'lib/seam/resources/acs_entrance.rb', line 95 def accessibility_type @accessibility_type end |
#door_name ⇒ Object
Name of the door in the Latch access system.
97 98 99 |
# File 'lib/seam/resources/acs_entrance.rb', line 97 def door_name @door_name end |
#door_type ⇒ Object
Type of the door in the Latch access system.
99 100 101 |
# File 'lib/seam/resources/acs_entrance.rb', line 99 def door_type @door_type end |
#is_connected ⇒ Object
Indicates whether the entrance is connected.
101 102 103 |
# File 'lib/seam/resources/acs_entrance.rb', line 101 def is_connected @is_connected end |