Class: Seam::Resources::AcsEntrance::SaltoKsMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::SaltoKsMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#battery_level ⇒ String?
Battery level of the door access device.
-
#door_name ⇒ String?
Name of the door in the Salto KS access system.
-
#intrusion_alarm ⇒ Boolean?
Indicates whether an intrusion alarm is active on the door.
-
#left_open_alarm ⇒ Boolean?
Indicates whether the door is left open.
-
#lock_type ⇒ String?
Type of the lock in the Salto KS access system.
-
#locked_state ⇒ String?
Locked state of the door in the Salto KS access system.
-
#online ⇒ Boolean?
Indicates whether the door access device is online.
-
#privacy_mode ⇒ Boolean?
Indicates whether privacy mode is enabled for the lock.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#battery_level ⇒ String?
Battery level of the door access device.
146 147 148 |
# File 'lib/seam/resources/acs_entrance.rb', line 146 def battery_level @battery_level end |
#door_name ⇒ String?
Name of the door in the Salto KS access system.
149 150 151 |
# File 'lib/seam/resources/acs_entrance.rb', line 149 def door_name @door_name end |
#intrusion_alarm ⇒ Boolean?
Indicates whether an intrusion alarm is active on the door.
152 153 154 |
# File 'lib/seam/resources/acs_entrance.rb', line 152 def intrusion_alarm @intrusion_alarm end |
#left_open_alarm ⇒ Boolean?
Indicates whether the door is left open.
155 156 157 |
# File 'lib/seam/resources/acs_entrance.rb', line 155 def left_open_alarm @left_open_alarm end |
#lock_type ⇒ String?
Type of the lock in the Salto KS access system.
158 159 160 |
# File 'lib/seam/resources/acs_entrance.rb', line 158 def lock_type @lock_type end |
#locked_state ⇒ String?
Locked state of the door in the Salto KS access system.
161 162 163 |
# File 'lib/seam/resources/acs_entrance.rb', line 161 def locked_state @locked_state end |
#online ⇒ Boolean?
Indicates whether the door access device is online.
164 165 166 |
# File 'lib/seam/resources/acs_entrance.rb', line 164 def online @online end |
#privacy_mode ⇒ Boolean?
Indicates whether privacy mode is enabled for the lock.
167 168 169 |
# File 'lib/seam/resources/acs_entrance.rb', line 167 def privacy_mode @privacy_mode end |