Class: Seam::Resources::AcsEntrance::SaltoKsMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#battery_levelString?

Battery level of the door access device.

Returns:

  • (String, nil)


141
142
143
# File 'lib/seam/resources/acs_entrance.rb', line 141

def battery_level
  @battery_level
end

#door_nameString?

Name of the door in the Salto KS access system.

Returns:

  • (String, nil)


144
145
146
# File 'lib/seam/resources/acs_entrance.rb', line 144

def door_name
  @door_name
end

#intrusion_alarmBoolean?

Indicates whether an intrusion alarm is active on the door.

Returns:

  • (Boolean, nil)


147
148
149
# File 'lib/seam/resources/acs_entrance.rb', line 147

def intrusion_alarm
  @intrusion_alarm
end

#left_open_alarmBoolean?

Indicates whether the door is left open.

Returns:

  • (Boolean, nil)


150
151
152
# File 'lib/seam/resources/acs_entrance.rb', line 150

def left_open_alarm
  @left_open_alarm
end

#lock_typeString?

Type of the lock in the Salto KS access system.

Returns:

  • (String, nil)


153
154
155
# File 'lib/seam/resources/acs_entrance.rb', line 153

def lock_type
  @lock_type
end

#locked_stateString?

Locked state of the door in the Salto KS access system.

Returns:

  • (String, nil)


156
157
158
# File 'lib/seam/resources/acs_entrance.rb', line 156

def locked_state
  @locked_state
end

#onlineBoolean?

Indicates whether the door access device is online.

Returns:

  • (Boolean, nil)


159
160
161
# File 'lib/seam/resources/acs_entrance.rb', line 159

def online
  @online
end

#privacy_modeBoolean?

Indicates whether privacy mode is enabled for the lock.

Returns:

  • (Boolean, nil)


162
163
164
# File 'lib/seam/resources/acs_entrance.rb', line 162

def privacy_mode
  @privacy_mode
end