Class: Seam::Resources::AcsEntrance::SaltoKsMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#battery_levelObject

Battery level of the door access device.



106
107
108
# File 'lib/seam/resources/acs_entrance.rb', line 106

def battery_level
  @battery_level
end

#door_nameObject

Name of the door in the Salto KS access system.



108
109
110
# File 'lib/seam/resources/acs_entrance.rb', line 108

def door_name
  @door_name
end

#intrusion_alarmObject

Indicates whether an intrusion alarm is active on the door.



110
111
112
# File 'lib/seam/resources/acs_entrance.rb', line 110

def intrusion_alarm
  @intrusion_alarm
end

#left_open_alarmObject

Indicates whether the door is left open.



112
113
114
# File 'lib/seam/resources/acs_entrance.rb', line 112

def left_open_alarm
  @left_open_alarm
end

#lock_typeObject

Type of the lock in the Salto KS access system.



114
115
116
# File 'lib/seam/resources/acs_entrance.rb', line 114

def lock_type
  @lock_type
end

#locked_stateObject

Locked state of the door in the Salto KS access system.



116
117
118
# File 'lib/seam/resources/acs_entrance.rb', line 116

def locked_state
  @locked_state
end

#onlineObject

Indicates whether the door access device is online.



118
119
120
# File 'lib/seam/resources/acs_entrance.rb', line 118

def online
  @online
end

#privacy_modeObject

Indicates whether privacy mode is enabled for the lock.



120
121
122
# File 'lib/seam/resources/acs_entrance.rb', line 120

def privacy_mode
  @privacy_mode
end