Class: Seam::Resources::AcsEntrance::SaltoSpaceMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::SaltoSpaceMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#audit_on_keys ⇒ Boolean?
Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.
-
#door_description ⇒ String?
Description of the door in the Salto Space access system.
-
#door_id ⇒ String?
Door ID in the Salto Space access system.
-
#door_name ⇒ String?
Name of the door in the Salto Space access system.
-
#room_description ⇒ String?
Description of the room in the Salto Space access system.
-
#room_name ⇒ String?
Name of the room in the Salto Space access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#audit_on_keys ⇒ Boolean?
Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.
173 174 175 |
# File 'lib/seam/resources/acs_entrance.rb', line 173 def audit_on_keys @audit_on_keys end |
#door_description ⇒ String?
Description of the door in the Salto Space access system.
176 177 178 |
# File 'lib/seam/resources/acs_entrance.rb', line 176 def door_description @door_description end |
#door_id ⇒ String?
Door ID in the Salto Space access system.
179 180 181 |
# File 'lib/seam/resources/acs_entrance.rb', line 179 def door_id @door_id end |
#door_name ⇒ String?
Name of the door in the Salto Space access system.
182 183 184 |
# File 'lib/seam/resources/acs_entrance.rb', line 182 def door_name @door_name end |
#room_description ⇒ String?
Description of the room in the Salto Space access system.
185 186 187 |
# File 'lib/seam/resources/acs_entrance.rb', line 185 def room_description @room_description end |
#room_name ⇒ String?
Name of the room in the Salto Space access system.
188 189 190 |
# File 'lib/seam/resources/acs_entrance.rb', line 188 def room_name @room_name end |