Class: Seam::Resources::AcsEntrance::SaltoSpaceMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#audit_on_keysBoolean?

Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.

Returns:

  • (Boolean, nil)


168
169
170
# File 'lib/seam/resources/acs_entrance.rb', line 168

def audit_on_keys
  @audit_on_keys
end

#door_descriptionString?

Description of the door in the Salto Space access system.

Returns:

  • (String, nil)


171
172
173
# File 'lib/seam/resources/acs_entrance.rb', line 171

def door_description
  @door_description
end

#door_idString?

Door ID in the Salto Space access system.

Returns:

  • (String, nil)


174
175
176
# File 'lib/seam/resources/acs_entrance.rb', line 174

def door_id
  @door_id
end

#door_nameString?

Name of the door in the Salto Space access system.

Returns:

  • (String, nil)


177
178
179
# File 'lib/seam/resources/acs_entrance.rb', line 177

def door_name
  @door_name
end

#room_descriptionString?

Description of the room in the Salto Space access system.

Returns:

  • (String, nil)


180
181
182
# File 'lib/seam/resources/acs_entrance.rb', line 180

def room_description
  @room_description
end

#room_nameString?

Name of the room in the Salto Space access system.

Returns:

  • (String, nil)


183
184
185
# File 'lib/seam/resources/acs_entrance.rb', line 183

def room_name
  @room_name
end