Class: Seam::Resources::AcsEntrance::SaltoSpaceMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::SaltoSpaceMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Instance Attribute Summary collapse
-
#audit_on_keys ⇒ Boolean?
Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.
-
#door_description ⇒ String?
Description of the door in the Salto Space access system.
-
#door_id ⇒ String?
Door ID in the Salto Space access system.
-
#door_name ⇒ String?
Name of the door in the Salto Space access system.
-
#room_description ⇒ String?
Description of the room in the Salto Space access system.
-
#room_name ⇒ String?
Name of the room in the Salto Space access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#audit_on_keys ⇒ Boolean?
Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.
168 169 170 |
# File 'lib/seam/resources/acs_entrance.rb', line 168 def audit_on_keys @audit_on_keys end |
#door_description ⇒ String?
Description of the door in the Salto Space access system.
171 172 173 |
# File 'lib/seam/resources/acs_entrance.rb', line 171 def door_description @door_description end |
#door_id ⇒ String?
Door ID in the Salto Space access system.
174 175 176 |
# File 'lib/seam/resources/acs_entrance.rb', line 174 def door_id @door_id end |
#door_name ⇒ String?
Name of the door in the Salto Space access system.
177 178 179 |
# File 'lib/seam/resources/acs_entrance.rb', line 177 def door_name @door_name end |
#room_description ⇒ String?
Description of the room in the Salto Space access system.
180 181 182 |
# File 'lib/seam/resources/acs_entrance.rb', line 180 def room_description @room_description end |
#room_name ⇒ String?
Name of the room in the Salto Space access system.
183 184 185 |
# File 'lib/seam/resources/acs_entrance.rb', line 183 def room_name @room_name end |