Class: Seam::Resources::AcsEntrance::SaltoSpaceMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#audit_on_keysObject

Indicates whether AuditOnKeys is enabled for the door in the Salto Space access system.



125
126
127
# File 'lib/seam/resources/acs_entrance.rb', line 125

def audit_on_keys
  @audit_on_keys
end

#door_descriptionObject

Description of the door in the Salto Space access system.



127
128
129
# File 'lib/seam/resources/acs_entrance.rb', line 127

def door_description
  @door_description
end

#door_idObject

Door ID in the Salto Space access system.



129
130
131
# File 'lib/seam/resources/acs_entrance.rb', line 129

def door_id
  @door_id
end

#door_nameObject

Name of the door in the Salto Space access system.



131
132
133
# File 'lib/seam/resources/acs_entrance.rb', line 131

def door_name
  @door_name
end

#room_descriptionObject

Description of the room in the Salto Space access system.



133
134
135
# File 'lib/seam/resources/acs_entrance.rb', line 133

def room_description
  @room_description
end

#room_nameObject

Name of the room in the Salto Space access system.



135
136
137
# File 'lib/seam/resources/acs_entrance.rb', line 135

def room_name
  @room_name
end