Class: Seam::Resources::AcsEntrance::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_entrance.rb

Defined Under Namespace

Classes: Profiles

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#door_categoryString?

Category of the door in the Visionline access system.

Returns:

  • (String, nil)


201
202
203
# File 'lib/seam/resources/acs_entrance.rb', line 201

def door_category
  @door_category
end

#door_nameString?

Name of the door in the Visionline access system.

Returns:

  • (String, nil)


204
205
206
# File 'lib/seam/resources/acs_entrance.rb', line 204

def door_name
  @door_name
end

Instance Method Details

#profilesArray<Profiles>

Profile for the door in the Visionline access system.

Returns:



198
# File 'lib/seam/resources/acs_entrance.rb', line 198

resource_list_accessor :profiles, Profiles