Class: Seam::Resources::AcsEntrance::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::VisionlineMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Defined Under Namespace
Classes: Profiles
Instance Attribute Summary collapse
-
#door_category ⇒ String?
Category of the door in the Visionline access system.
-
#door_name ⇒ String?
Name of the door in the Visionline access system.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#profiles ⇒ Array<Profiles>
Profile for the door in the Visionline access system.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#door_category ⇒ String?
Category of the door in the Visionline access system.
201 202 203 |
# File 'lib/seam/resources/acs_entrance.rb', line 201 def door_category @door_category end |
#door_name ⇒ String?
Name of the door in the Visionline access system.
204 205 206 |
# File 'lib/seam/resources/acs_entrance.rb', line 204 def door_name @door_name end |