Class: Seam::Resources::AcsEntrance::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsEntrance::VisionlineMetadata
- Defined in:
- lib/seam/resources/acs_entrance.rb
Defined Under Namespace
Classes: Profiles
Instance Attribute Summary collapse
-
#door_category ⇒ Object
Category of the door in the Visionline access system.
-
#door_name ⇒ Object
Name of the door in the Visionline access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#door_category ⇒ Object
Category of the door in the Visionline access system.
148 149 150 |
# File 'lib/seam/resources/acs_entrance.rb', line 148 def door_category @door_category end |
#door_name ⇒ Object
Name of the door in the Visionline access system.
150 151 152 |
# File 'lib/seam/resources/acs_entrance.rb', line 150 def door_name @door_name end |