Class: Seam::Resources::AcsEntrance::Warnings::EntranceSetupRequired
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsEntrance::Warnings::EntranceSetupRequired
- Defined in:
- lib/seam/resources/acs_entrance.rb
Overview
Indicates that this entrance requires additional configuration in the access control system before Seam can fully manage it.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
258 259 260 |
# File 'lib/seam/resources/acs_entrance.rb', line 258 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
entrance_setup_required
263 264 265 |
# File 'lib/seam/resources/acs_entrance.rb', line 263 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
266 |
# File 'lib/seam/resources/acs_entrance.rb', line 266 date_accessor :created_at |