Class: Seam::Resources::AcsEntrance::Warnings::PrivacyMode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsEntrance::Warnings::PrivacyMode
- Defined in:
- lib/seam/resources/acs_entrance.rb
Overview
Indicates that this entrance is in privacy mode. When privacy mode is enabled, access codes, mobile keys, and remote unlocks will not work unless the user has admin access.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
288 289 290 |
# File 'lib/seam/resources/acs_entrance.rb', line 288 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
privacy_mode
293 294 295 |
# File 'lib/seam/resources/acs_entrance.rb', line 293 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
296 |
# File 'lib/seam/resources/acs_entrance.rb', line 296 date_accessor :created_at |