Class: Seam::Resources::AcsEntrance::Warnings::SaltoKsPrivacyMode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsEntrance::Warnings::SaltoKsPrivacyMode
- Defined in:
- lib/seam/resources/acs_entrance.rb
Overview
Indicates that this entrance is in privacy mode. When privacy mode is enabled, access codes, mobile keys, and remote unlocks will not work unless the user has admin access.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
273 274 275 |
# File 'lib/seam/resources/acs_entrance.rb', line 273 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
salto_ks_privacy_mode
278 279 280 |
# File 'lib/seam/resources/acs_entrance.rb', line 278 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
281 |
# File 'lib/seam/resources/acs_entrance.rb', line 281 date_accessor :created_at |