Class: Seam::Resources::AcsSystem
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Represents an access control system.
Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.
For details about the resources associated with an access control system, see the access control systems namespace.
Defined Under Namespace
Classes: Errors, Location, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#acs_access_group_count ⇒ Float?
Number of access groups in the access control system.
-
#acs_system_id ⇒ String
ID of the access control system.
-
#acs_user_count ⇒ Float?
Number of users in the access control system.
-
#connected_account_id ⇒ String
ID of the connected account associated with the access control system.
-
#connected_account_ids ⇒ Array<String>
deprecated
Deprecated.
Use
connected_account_id. -
#default_credential_manager_acs_system_id ⇒ String?
ID of the default credential manager
acs_systemfor this access control system. -
#external_type ⇒ String?
Brand-specific terminology for the access control system type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the access control system type.
-
#image_alt_text ⇒ String
Alternative text for the access control system image.
-
#image_url ⇒ String
URL for the image that represents the access control system.
-
#is_credential_manager ⇒ Boolean
Indicates whether the
acs_systemis a credential manager. -
#name ⇒ String
Name of the access control system.
-
#system_type ⇒ String?
deprecated
Deprecated.
Use
external_type. -
#system_type_display_name ⇒ String?
deprecated
Deprecated.
Use
external_type_display_name. -
#workspace_id ⇒ String
ID of the workspace that contains the access control system.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the access control system was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access control system.
-
#location ⇒ Location
Location information for the access control system.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the access control system.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access control system.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_access_group_count ⇒ Float?
Number of access groups in the access control system.
309 310 311 |
# File 'lib/seam/resources/acs_system.rb', line 309 def acs_access_group_count @acs_access_group_count end |
#acs_system_id ⇒ String
ID of the access control system.
312 313 314 |
# File 'lib/seam/resources/acs_system.rb', line 312 def acs_system_id @acs_system_id end |
#acs_user_count ⇒ Float?
Number of users in the access control system.
315 316 317 |
# File 'lib/seam/resources/acs_system.rb', line 315 def acs_user_count @acs_user_count end |
#connected_account_id ⇒ String
ID of the connected account associated with the access control system.
318 319 320 |
# File 'lib/seam/resources/acs_system.rb', line 318 def connected_account_id @connected_account_id end |
#connected_account_ids ⇒ Array<String>
Use connected_account_id.
IDs of the connected accounts associated with the access control system.
322 323 324 |
# File 'lib/seam/resources/acs_system.rb', line 322 def connected_account_ids @connected_account_ids end |
#default_credential_manager_acs_system_id ⇒ String?
ID of the default credential manager acs_system for this access control system.
325 326 327 |
# File 'lib/seam/resources/acs_system.rb', line 325 def default_credential_manager_acs_system_id @default_credential_manager_acs_system_id end |
#external_type ⇒ String?
Brand-specific terminology for the access control system type. Known values:
pti_siteavigilon_alta_orgsalto_ks_sitesalto_space_systembrivo_accounthid_credential_manager_organizationvisionline_systemassa_abloy_credential_servicelatch_buildingdormakaba_community_sitedormakaba_ambiance_sitelegic_connect_credential_serviceassa_abloy_vostioassa_abloy_vostio_credential_servicehotek_sitekisi_organizationakiles_organization
346 347 348 |
# File 'lib/seam/resources/acs_system.rb', line 346 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the access control system type.
349 350 351 |
# File 'lib/seam/resources/acs_system.rb', line 349 def external_type_display_name @external_type_display_name end |
#image_alt_text ⇒ String
Alternative text for the access control system image.
352 353 354 |
# File 'lib/seam/resources/acs_system.rb', line 352 def image_alt_text @image_alt_text end |
#image_url ⇒ String
URL for the image that represents the access control system.
355 356 357 |
# File 'lib/seam/resources/acs_system.rb', line 355 def image_url @image_url end |
#is_credential_manager ⇒ Boolean
Indicates whether the acs_system is a credential manager.
358 359 360 |
# File 'lib/seam/resources/acs_system.rb', line 358 def is_credential_manager @is_credential_manager end |
#name ⇒ String
Name of the access control system.
361 362 363 |
# File 'lib/seam/resources/acs_system.rb', line 361 def name @name end |
#system_type ⇒ String?
Use external_type.
Known values:
pti_siteavigilon_alta_orgsalto_ks_sitesalto_space_systembrivo_accounthid_credential_manager_organizationvisionline_systemassa_abloy_credential_servicelatch_buildingdormakaba_community_sitedormakaba_ambiance_sitelegic_connect_credential_serviceassa_abloy_vostioassa_abloy_vostio_credential_servicehotek_sitekisi_organizationakiles_organization
382 383 384 |
# File 'lib/seam/resources/acs_system.rb', line 382 def system_type @system_type end |
#system_type_display_name ⇒ String?
Use external_type_display_name.
385 386 387 |
# File 'lib/seam/resources/acs_system.rb', line 385 def system_type_display_name @system_type_display_name end |
#workspace_id ⇒ String
ID of the workspace that contains the access control system.
388 389 390 |
# File 'lib/seam/resources/acs_system.rb', line 388 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the access control system was created.
392 |
# File 'lib/seam/resources/acs_system.rb', line 392 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access control system.
303 |
# File 'lib/seam/resources/acs_system.rb', line 303 resource_list_accessor :errors, Errors |
#location ⇒ Location
Location information for the access control system.
297 |
# File 'lib/seam/resources/acs_system.rb', line 297 resource_accessor :location, Location |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the access control system.
300 |
# File 'lib/seam/resources/acs_system.rb', line 300 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the access control system.
306 |
# File 'lib/seam/resources/acs_system.rb', line 306 resource_list_accessor :warnings, Warnings |