Class: Seam::Resources::AcsSystem

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Represents an access control system.

Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.

For details about the resources associated with an access control system, see the access control systems namespace.

Defined Under Namespace

Classes: Errors, Location, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_access_group_countFloat?

Number of access groups in the access control system.

Returns:

  • (Float, nil)


73
74
75
# File 'lib/seam/resources/acs_system.rb', line 73

def acs_access_group_count
  @acs_access_group_count
end

#acs_system_idString

Returns:

  • (String)


76
77
78
# File 'lib/seam/resources/acs_system.rb', line 76

def acs_system_id
  @acs_system_id
end

#acs_user_countFloat?

Number of users in the access control system.

Returns:

  • (Float, nil)


79
80
81
# File 'lib/seam/resources/acs_system.rb', line 79

def acs_user_count
  @acs_user_count
end

#connected_account_idString

ID of the connected account associated with the access control system.

Returns:

  • (String)


82
83
84
# File 'lib/seam/resources/acs_system.rb', line 82

def 
  @connected_account_id
end

#connected_account_idsArray<String>

Deprecated.

Use connected_account_id.

IDs of the connected accounts associated with the access control system.

Returns:

  • (Array<String>)


86
87
88
# File 'lib/seam/resources/acs_system.rb', line 86

def 
  @connected_account_ids
end

#default_credential_manager_acs_system_idString?

ID of the default credential manager acs_system for this access control system.

Returns:

  • (String, nil)


89
90
91
# File 'lib/seam/resources/acs_system.rb', line 89

def default_credential_manager_acs_system_id
  @default_credential_manager_acs_system_id
end

#external_typeString?

Brand-specific terminology for the access control system type.

Returns:

  • (String, nil)


92
93
94
# File 'lib/seam/resources/acs_system.rb', line 92

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the access control system type.

Returns:

  • (String, nil)


95
96
97
# File 'lib/seam/resources/acs_system.rb', line 95

def external_type_display_name
  @external_type_display_name
end

#image_alt_textString

Alternative text for the access control system image.

Returns:

  • (String)


98
99
100
# File 'lib/seam/resources/acs_system.rb', line 98

def image_alt_text
  @image_alt_text
end

#image_urlString

URL for the image that represents the access control system.

Returns:

  • (String)


101
102
103
# File 'lib/seam/resources/acs_system.rb', line 101

def image_url
  @image_url
end

#is_credential_managerBoolean

Indicates whether the acs_system is a credential manager.

Returns:

  • (Boolean)


104
105
106
# File 'lib/seam/resources/acs_system.rb', line 104

def is_credential_manager
  @is_credential_manager
end

#nameString

Name of the access control system.

Returns:

  • (String)


107
108
109
# File 'lib/seam/resources/acs_system.rb', line 107

def name
  @name
end

#system_typeString?

Deprecated.

Use external_type.

Returns:

  • (String, nil)


110
111
112
# File 'lib/seam/resources/acs_system.rb', line 110

def system_type
  @system_type
end

#system_type_display_nameString?

Deprecated.

Use external_type_display_name.

Returns:

  • (String, nil)


113
114
115
# File 'lib/seam/resources/acs_system.rb', line 113

def system_type_display_name
  @system_type_display_name
end

#workspace_idString

ID of the workspace that contains the access control system.

Returns:

  • (String)


116
117
118
# File 'lib/seam/resources/acs_system.rb', line 116

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the access control system was created.

Returns:

  • (Time)


120
# File 'lib/seam/resources/acs_system.rb', line 120

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the access control system.

Returns:



67
# File 'lib/seam/resources/acs_system.rb', line 67

resource_list_accessor :errors, Errors

#locationLocation

Location information for the access control system.

Returns:



61
# File 'lib/seam/resources/acs_system.rb', line 61

resource_accessor :location, Location

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the access control system.

Returns:



64
# File 'lib/seam/resources/acs_system.rb', line 64

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the access control system.

Returns:



70
# File 'lib/seam/resources/acs_system.rb', line 70

resource_list_accessor :warnings, Warnings