Class: Seam::Resources::AcsSystem
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Represents an access control system.
Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.
For details about the resources associated with an access control system, see the access control systems namespace.
Defined Under Namespace
Classes: Errors, Location, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#acs_access_group_count ⇒ Float?
Number of access groups in the access control system.
-
#acs_system_id ⇒ String
ID of the access control system.
-
#acs_user_count ⇒ Float?
Number of users in the access control system.
-
#connected_account_id ⇒ String
ID of the connected account associated with the access control system.
-
#connected_account_ids ⇒ Array<String>
deprecated
Deprecated.
Use
connected_account_id. -
#default_credential_manager_acs_system_id ⇒ String?
ID of the default credential manager
acs_systemfor this access control system. -
#external_type ⇒ String?
Brand-specific terminology for the access control system type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the access control system type.
-
#image_alt_text ⇒ String
Alternative text for the access control system image.
-
#image_url ⇒ String
URL for the image that represents the access control system.
-
#is_credential_manager ⇒ Boolean
Indicates whether the
acs_systemis a credential manager. -
#name ⇒ String
Name of the access control system.
-
#system_type ⇒ String?
deprecated
Deprecated.
Use
external_type. -
#system_type_display_name ⇒ String?
deprecated
Deprecated.
Use
external_type_display_name. -
#workspace_id ⇒ String
ID of the workspace that contains the access control system.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the access control system was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access control system.
-
#location ⇒ Location
Location information for the access control system.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the access control system.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access control system.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_access_group_count ⇒ Float?
Number of access groups in the access control system.
73 74 75 |
# File 'lib/seam/resources/acs_system.rb', line 73 def acs_access_group_count @acs_access_group_count end |
#acs_system_id ⇒ String
ID of the access control system.
76 77 78 |
# File 'lib/seam/resources/acs_system.rb', line 76 def acs_system_id @acs_system_id end |
#acs_user_count ⇒ Float?
Number of users in the access control system.
79 80 81 |
# File 'lib/seam/resources/acs_system.rb', line 79 def acs_user_count @acs_user_count end |
#connected_account_id ⇒ String
ID of the connected account associated with the access control system.
82 83 84 |
# File 'lib/seam/resources/acs_system.rb', line 82 def connected_account_id @connected_account_id end |
#connected_account_ids ⇒ Array<String>
Use connected_account_id.
IDs of the connected accounts associated with the access control system.
86 87 88 |
# File 'lib/seam/resources/acs_system.rb', line 86 def connected_account_ids @connected_account_ids end |
#default_credential_manager_acs_system_id ⇒ String?
ID of the default credential manager acs_system for this access control system.
89 90 91 |
# File 'lib/seam/resources/acs_system.rb', line 89 def default_credential_manager_acs_system_id @default_credential_manager_acs_system_id end |
#external_type ⇒ String?
Brand-specific terminology for the access control system type.
92 93 94 |
# File 'lib/seam/resources/acs_system.rb', line 92 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the access control system type.
95 96 97 |
# File 'lib/seam/resources/acs_system.rb', line 95 def external_type_display_name @external_type_display_name end |
#image_alt_text ⇒ String
Alternative text for the access control system image.
98 99 100 |
# File 'lib/seam/resources/acs_system.rb', line 98 def image_alt_text @image_alt_text end |
#image_url ⇒ String
URL for the image that represents the access control system.
101 102 103 |
# File 'lib/seam/resources/acs_system.rb', line 101 def image_url @image_url end |
#is_credential_manager ⇒ Boolean
Indicates whether the acs_system is a credential manager.
104 105 106 |
# File 'lib/seam/resources/acs_system.rb', line 104 def is_credential_manager @is_credential_manager end |
#name ⇒ String
Name of the access control system.
107 108 109 |
# File 'lib/seam/resources/acs_system.rb', line 107 def name @name end |
#system_type ⇒ String?
Use external_type.
110 111 112 |
# File 'lib/seam/resources/acs_system.rb', line 110 def system_type @system_type end |
#system_type_display_name ⇒ String?
Use external_type_display_name.
113 114 115 |
# File 'lib/seam/resources/acs_system.rb', line 113 def system_type_display_name @system_type_display_name end |
#workspace_id ⇒ String
ID of the workspace that contains the access control system.
116 117 118 |
# File 'lib/seam/resources/acs_system.rb', line 116 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the access control system was created.
120 |
# File 'lib/seam/resources/acs_system.rb', line 120 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access control system.
67 |
# File 'lib/seam/resources/acs_system.rb', line 67 resource_list_accessor :errors, Errors |
#location ⇒ Location
Location information for the access control system.
61 |
# File 'lib/seam/resources/acs_system.rb', line 61 resource_accessor :location, Location |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the access control system.
64 |
# File 'lib/seam/resources/acs_system.rb', line 64 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the access control system.
70 |
# File 'lib/seam/resources/acs_system.rb', line 70 resource_list_accessor :warnings, Warnings |