Class: Seam::Resources::AcsSystem

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_system.rb

Overview

Represents an access control system.

Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.

For details about the resources associated with an access control system, see the access control systems namespace.

Defined Under Namespace

Classes: Errors, Location, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_access_group_countObject

Number of access groups in the access control system.



52
53
54
# File 'lib/seam/resources/acs_system.rb', line 52

def acs_access_group_count
  @acs_access_group_count
end

#acs_system_idObject



54
55
56
# File 'lib/seam/resources/acs_system.rb', line 54

def acs_system_id
  @acs_system_id
end

#acs_user_countObject

Number of users in the access control system.



56
57
58
# File 'lib/seam/resources/acs_system.rb', line 56

def acs_user_count
  @acs_user_count
end

#connected_account_idObject

ID of the connected account associated with the access control system.



58
59
60
# File 'lib/seam/resources/acs_system.rb', line 58

def 
  @connected_account_id
end

#connected_account_idsObject

Deprecated.

Use connected_account_id.

IDs of the connected accounts associated with the access control system.



61
62
63
# File 'lib/seam/resources/acs_system.rb', line 61

def 
  @connected_account_ids
end

#default_credential_manager_acs_system_idObject

ID of the default credential manager acs_system for this access control system.



63
64
65
# File 'lib/seam/resources/acs_system.rb', line 63

def default_credential_manager_acs_system_id
  @default_credential_manager_acs_system_id
end

#external_typeObject

Brand-specific terminology for the access control system type.



65
66
67
# File 'lib/seam/resources/acs_system.rb', line 65

def external_type
  @external_type
end

#external_type_display_nameObject

Display name that corresponds to the brand-specific terminology for the access control system type.



67
68
69
# File 'lib/seam/resources/acs_system.rb', line 67

def external_type_display_name
  @external_type_display_name
end

#image_alt_textObject

Alternative text for the access control system image.



69
70
71
# File 'lib/seam/resources/acs_system.rb', line 69

def image_alt_text
  @image_alt_text
end

#image_urlObject

URL for the image that represents the access control system.



71
72
73
# File 'lib/seam/resources/acs_system.rb', line 71

def image_url
  @image_url
end

#is_credential_managerObject

Indicates whether the acs_system is a credential manager.



73
74
75
# File 'lib/seam/resources/acs_system.rb', line 73

def is_credential_manager
  @is_credential_manager
end

#nameObject

Name of the access control system.



75
76
77
# File 'lib/seam/resources/acs_system.rb', line 75

def name
  @name
end

#system_typeObject

Deprecated.

Use external_type.



77
78
79
# File 'lib/seam/resources/acs_system.rb', line 77

def system_type
  @system_type
end

#system_type_display_nameObject

Deprecated.

Use external_type_display_name.



79
80
81
# File 'lib/seam/resources/acs_system.rb', line 79

def system_type_display_name
  @system_type_display_name
end

#workspace_idObject

ID of the workspace that contains the access control system.



81
82
83
# File 'lib/seam/resources/acs_system.rb', line 81

def workspace_id
  @workspace_id
end