Class: Seam::Resources::AcsSystem
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Represents an access control system.
Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.
For details about the resources associated with an access control system, see the access control systems namespace.
Defined Under Namespace
Classes: Errors, Location, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#acs_access_group_count ⇒ Object
Number of access groups in the access control system.
-
#acs_system_id ⇒ Object
ID of the access control system.
-
#acs_user_count ⇒ Object
Number of users in the access control system.
-
#connected_account_id ⇒ Object
ID of the connected account associated with the access control system.
-
#connected_account_ids ⇒ Object
deprecated
Deprecated.
Use
connected_account_id. -
#default_credential_manager_acs_system_id ⇒ Object
ID of the default credential manager
acs_systemfor this access control system. -
#external_type ⇒ Object
Brand-specific terminology for the access control system type.
-
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access control system type.
-
#image_alt_text ⇒ Object
Alternative text for the access control system image.
-
#image_url ⇒ Object
URL for the image that represents the access control system.
-
#is_credential_manager ⇒ Object
Indicates whether the
acs_systemis a credential manager. -
#name ⇒ Object
Name of the access control system.
-
#system_type ⇒ Object
deprecated
Deprecated.
Use
external_type. -
#system_type_display_name ⇒ Object
deprecated
Deprecated.
Use
external_type_display_name. -
#workspace_id ⇒ Object
ID of the workspace that contains the access control system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_access_group_count ⇒ Object
Number of access groups in the access control system.
52 53 54 |
# File 'lib/seam/resources/acs_system.rb', line 52 def acs_access_group_count @acs_access_group_count end |
#acs_system_id ⇒ Object
ID of the access control system.
54 55 56 |
# File 'lib/seam/resources/acs_system.rb', line 54 def acs_system_id @acs_system_id end |
#acs_user_count ⇒ Object
Number of users in the access control system.
56 57 58 |
# File 'lib/seam/resources/acs_system.rb', line 56 def acs_user_count @acs_user_count end |
#connected_account_id ⇒ Object
ID of the connected account associated with the access control system.
58 59 60 |
# File 'lib/seam/resources/acs_system.rb', line 58 def connected_account_id @connected_account_id end |
#connected_account_ids ⇒ Object
Use connected_account_id.
IDs of the connected accounts associated with the access control system.
61 62 63 |
# File 'lib/seam/resources/acs_system.rb', line 61 def connected_account_ids @connected_account_ids end |
#default_credential_manager_acs_system_id ⇒ Object
ID of the default credential manager acs_system for this access control system.
63 64 65 |
# File 'lib/seam/resources/acs_system.rb', line 63 def default_credential_manager_acs_system_id @default_credential_manager_acs_system_id end |
#external_type ⇒ Object
Brand-specific terminology for the access control system type.
65 66 67 |
# File 'lib/seam/resources/acs_system.rb', line 65 def external_type @external_type end |
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access control system type.
67 68 69 |
# File 'lib/seam/resources/acs_system.rb', line 67 def external_type_display_name @external_type_display_name end |
#image_alt_text ⇒ Object
Alternative text for the access control system image.
69 70 71 |
# File 'lib/seam/resources/acs_system.rb', line 69 def image_alt_text @image_alt_text end |
#image_url ⇒ Object
URL for the image that represents the access control system.
71 72 73 |
# File 'lib/seam/resources/acs_system.rb', line 71 def image_url @image_url end |
#is_credential_manager ⇒ Object
Indicates whether the acs_system is a credential manager.
73 74 75 |
# File 'lib/seam/resources/acs_system.rb', line 73 def is_credential_manager @is_credential_manager end |
#name ⇒ Object
Name of the access control system.
75 76 77 |
# File 'lib/seam/resources/acs_system.rb', line 75 def name @name end |
#system_type ⇒ Object
Use external_type.
77 78 79 |
# File 'lib/seam/resources/acs_system.rb', line 77 def system_type @system_type end |
#system_type_display_name ⇒ Object
Use external_type_display_name.
79 80 81 |
# File 'lib/seam/resources/acs_system.rb', line 79 def system_type_display_name @system_type_display_name end |
#workspace_id ⇒ Object
ID of the workspace that contains the access control system.
81 82 83 |
# File 'lib/seam/resources/acs_system.rb', line 81 def workspace_id @workspace_id end |