Class: Seam::Resources::AcsSystem
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Represents an access control system.
Within an acs_system, create acs_users and acs_credentials to grant access to the acs_users.
For details about the resources associated with an access control system, see the access control systems namespace.
Instance Attribute Summary collapse
-
#acs_access_group_count ⇒ Object
Number of access groups in the access control system.
-
#acs_system_id ⇒ Object
ID of the access control system.
-
#acs_user_count ⇒ Object
Number of users in the access control system.
-
#connected_account_id ⇒ Object
ID of the connected account associated with the access control system.
-
#connected_account_ids ⇒ Object
deprecated
Deprecated.
Use
connected_account_id. -
#default_credential_manager_acs_system_id ⇒ Object
ID of the default credential manager
acs_systemfor this access control system. -
#external_type ⇒ Object
Brand-specific terminology for the access control system type.
-
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access control system type.
-
#image_alt_text ⇒ Object
Alternative text for the access control system image.
-
#image_url ⇒ Object
URL for the image that represents the access control system.
-
#is_credential_manager ⇒ Object
Indicates whether the
acs_systemis a credential manager. -
#location ⇒ Object
Location information for the access control system.
-
#name ⇒ Object
Name of the access control system.
-
#system_type ⇒ Object
deprecated
Deprecated.
Use
external_type. -
#system_type_display_name ⇒ Object
deprecated
Deprecated.
Use
external_type_display_name. -
#visionline_metadata ⇒ Object
Visionline-specific metadata for the access control system.
-
#workspace_id ⇒ Object
ID of the workspace that contains the access control system.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_access_group_count ⇒ Object
Number of access groups in the access control system.
12 13 14 |
# File 'lib/seam/resources/acs_system.rb', line 12 def acs_access_group_count @acs_access_group_count end |
#acs_system_id ⇒ Object
ID of the access control system.
14 15 16 |
# File 'lib/seam/resources/acs_system.rb', line 14 def acs_system_id @acs_system_id end |
#acs_user_count ⇒ Object
Number of users in the access control system.
16 17 18 |
# File 'lib/seam/resources/acs_system.rb', line 16 def acs_user_count @acs_user_count end |
#connected_account_id ⇒ Object
ID of the connected account associated with the access control system.
18 19 20 |
# File 'lib/seam/resources/acs_system.rb', line 18 def connected_account_id @connected_account_id end |
#connected_account_ids ⇒ Object
Use connected_account_id.
IDs of the connected accounts associated with the access control system.
21 22 23 |
# File 'lib/seam/resources/acs_system.rb', line 21 def connected_account_ids @connected_account_ids end |
#default_credential_manager_acs_system_id ⇒ Object
ID of the default credential manager acs_system for this access control system.
23 24 25 |
# File 'lib/seam/resources/acs_system.rb', line 23 def default_credential_manager_acs_system_id @default_credential_manager_acs_system_id end |
#external_type ⇒ Object
Brand-specific terminology for the access control system type.
25 26 27 |
# File 'lib/seam/resources/acs_system.rb', line 25 def external_type @external_type end |
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the access control system type.
27 28 29 |
# File 'lib/seam/resources/acs_system.rb', line 27 def external_type_display_name @external_type_display_name end |
#image_alt_text ⇒ Object
Alternative text for the access control system image.
29 30 31 |
# File 'lib/seam/resources/acs_system.rb', line 29 def image_alt_text @image_alt_text end |
#image_url ⇒ Object
URL for the image that represents the access control system.
31 32 33 |
# File 'lib/seam/resources/acs_system.rb', line 31 def image_url @image_url end |
#is_credential_manager ⇒ Object
Indicates whether the acs_system is a credential manager.
33 34 35 |
# File 'lib/seam/resources/acs_system.rb', line 33 def is_credential_manager @is_credential_manager end |
#location ⇒ Object
Location information for the access control system.
35 36 37 |
# File 'lib/seam/resources/acs_system.rb', line 35 def location @location end |
#name ⇒ Object
Name of the access control system.
37 38 39 |
# File 'lib/seam/resources/acs_system.rb', line 37 def name @name end |
#system_type ⇒ Object
Use external_type.
39 40 41 |
# File 'lib/seam/resources/acs_system.rb', line 39 def system_type @system_type end |
#system_type_display_name ⇒ Object
Use external_type_display_name.
41 42 43 |
# File 'lib/seam/resources/acs_system.rb', line 41 def system_type_display_name @system_type_display_name end |
#visionline_metadata ⇒ Object
Visionline-specific metadata for the access control system.
43 44 45 |
# File 'lib/seam/resources/acs_system.rb', line 43 def @visionline_metadata end |
#workspace_id ⇒ Object
ID of the workspace that contains the access control system.
45 46 47 |
# File 'lib/seam/resources/acs_system.rb', line 45 def workspace_id @workspace_id end |