Class: Seam::Resources::AcsSystem::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem::Errors
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.
Defined Under Namespace
Classes: AccountDisconnected, AcsSystemDisconnected, BridgeDisconnected, InsufficientPermissions, ProviderServiceUnavailable, SaltoKsCertificationExpired, SaltoKsSubscriptionLimitExceeded, SeamBridgeDisconnected, VisionlineInstanceUnreachable
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
seam_bridge_disconnectedbridge_disconnectedvisionline_instance_unreachablesalto_ks_subscription_limit_exceededinsufficient_permissionsacs_system_disconnectedaccount_disconnectedsalto_ks_certification_expiredprovider_service_unavailable
168 169 170 |
# File 'lib/seam/resources/acs_system.rb', line 168 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
171 172 173 |
# File 'lib/seam/resources/acs_system.rb', line 171 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
174 |
# File 'lib/seam/resources/acs_system.rb', line 174 date_accessor :created_at |