Class: Seam::Resources::AcsSystem::Errors::AccountDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsSystem::Errors::AccountDisconnected
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that the login credentials are invalid. Reconnect the account using a Connect Webview to restore access.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
account_disconnected
117 118 119 |
# File 'lib/seam/resources/acs_system.rb', line 117 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
120 121 122 |
# File 'lib/seam/resources/acs_system.rb', line 120 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
123 |
# File 'lib/seam/resources/acs_system.rb', line 123 date_accessor :created_at |