Class: Seam::Resources::AcsSystem::Errors::InsufficientPermissions
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsSystem::Errors::InsufficientPermissions
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that Seam's integration user does not have sufficient permissions on the provider's system backing this access control system. Access cannot be managed until permissions are restored. See the error message for specifics, then either reauthorize the connected account in Seam or grant the integration user the required permissions in the provider's system.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
insufficient_permissions
87 88 89 |
# File 'lib/seam/resources/acs_system.rb', line 87 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
90 91 92 |
# File 'lib/seam/resources/acs_system.rb', line 90 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
93 |
# File 'lib/seam/resources/acs_system.rb', line 93 date_accessor :created_at |