Class: Seam::Resources::AcsSystem::Errors::ProviderServiceUnavailable
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsSystem::Errors::ProviderServiceUnavailable
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that the access control system provider's service is temporarily unavailable. Seam will automatically retry and reconnect when the service becomes available again.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
provider_service_unavailable
147 148 149 |
# File 'lib/seam/resources/acs_system.rb', line 147 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
150 151 152 |
# File 'lib/seam/resources/acs_system.rb', line 150 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
153 |
# File 'lib/seam/resources/acs_system.rb', line 153 date_accessor :created_at |