Class: Seam::Resources::AcsSystem::Errors::SaltoKsSubscriptionLimitExceeded
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsSystem::Errors::SaltoKsSubscriptionLimitExceeded
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that the maximum number of users allowed for the site has been reached. This means that new access codes cannot be created. Contact Salto support to increase the user limit.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
salto_ks_subscription_limit_exceeded
72 73 74 |
# File 'lib/seam/resources/acs_system.rb', line 72 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
75 76 77 |
# File 'lib/seam/resources/acs_system.rb', line 75 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
78 |
# File 'lib/seam/resources/acs_system.rb', line 78 date_accessor :created_at |