Class: Seam::Resources::AcsSystem::Errors::SeamBridgeDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsSystem::Errors::SeamBridgeDisconnected
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that the Seam API cannot communicate with Seam Bridge, for example, if Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. This error might also occur if Seam Bridge is connected to the wrong workspace. See also Troubleshooting Your Access Control System.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
seam_bridge_disconnected
21 22 23 |
# File 'lib/seam/resources/acs_system.rb', line 21 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
24 25 26 |
# File 'lib/seam/resources/acs_system.rb', line 24 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
27 |
# File 'lib/seam/resources/acs_system.rb', line 27 date_accessor :created_at |