Class: Seam::Resources::AcsSystem::Errors::VisionlineInstanceUnreachable
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsSystem::Errors::VisionlineInstanceUnreachable
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that Seam Bridge is functioning correctly and the Seam API can communicate with Seam Bridge, but the Seam API cannot connect to the on-premises Visionline access control system. For example, the IP address of the on-premises access control system may be set incorrectly within the Seam workspace. See also Troubleshooting Your Access Control System.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
visionline_instance_unreachable
57 58 59 |
# File 'lib/seam/resources/acs_system.rb', line 57 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
60 61 62 |
# File 'lib/seam/resources/acs_system.rb', line 60 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
63 |
# File 'lib/seam/resources/acs_system.rb', line 63 date_accessor :created_at |