Class: Seam::Resources::AcsSystem::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/acs_system.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#lan_addressString?

IP address or hostname of the main Visionline server relative to Seam Bridge on the local network.

Returns:

  • (String, nil)


35
36
37
# File 'lib/seam/resources/acs_system.rb', line 35

def lan_address
  @lan_address
end

#mobile_access_uuidString?

Keyset loaded into a reader. Mobile keys and reader administration tools securely authenticate only with readers programmed with a matching keyset.

Returns:

  • (String, nil)


38
39
40
# File 'lib/seam/resources/acs_system.rb', line 38

def mobile_access_uuid
  @mobile_access_uuid
end

#system_idString?

Unique ID assigned by the ASSA ABLOY licensing team that identifies each hotel in your credential manager.

Returns:

  • (String, nil)


41
42
43
# File 'lib/seam/resources/acs_system.rb', line 41

def system_id
  @system_id
end