Class: Seam::Resources::AcsSystem::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem::VisionlineMetadata
- Defined in:
- lib/seam/resources/acs_system.rb
Instance Attribute Summary collapse
-
#lan_address ⇒ Object
IP address or hostname of the main Visionline server relative to Seam Bridge on the local network.
-
#mobile_access_uuid ⇒ Object
Keyset loaded into a reader.
-
#system_id ⇒ Object
Unique ID assigned by the ASSA ABLOY licensing team that identifies each hotel in your credential manager.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#lan_address ⇒ Object
IP address or hostname of the main Visionline server relative to Seam Bridge on the local network.
29 30 31 |
# File 'lib/seam/resources/acs_system.rb', line 29 def lan_address @lan_address end |
#mobile_access_uuid ⇒ Object
Keyset loaded into a reader. Mobile keys and reader administration tools securely authenticate only with readers programmed with a matching keyset.
31 32 33 |
# File 'lib/seam/resources/acs_system.rb', line 31 def mobile_access_uuid @mobile_access_uuid end |
#system_id ⇒ Object
Unique ID assigned by the ASSA ABLOY licensing team that identifies each hotel in your credential manager.
33 34 35 |
# File 'lib/seam/resources/acs_system.rb', line 33 def system_id @system_id end |