Class: Seam::Resources::AcsSystem::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsSystem::Warnings
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.
Defined Under Namespace
Classes: SaltoKsSubscriptionLimitAlmostReached, SetupRequired, TimeZoneDoesNotMatchLocation, UnknownIssueWithAcsSystem
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
274 275 276 |
# File 'lib/seam/resources/acs_system.rb', line 274 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
salto_ks_subscription_limit_almost_reachedtime_zone_does_not_match_locationsetup_requiredunknown_issue_with_acs_system
282 283 284 |
# File 'lib/seam/resources/acs_system.rb', line 282 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
285 |
# File 'lib/seam/resources/acs_system.rb', line 285 date_accessor :created_at |