Class: Seam::Resources::AcsSystem::Warnings

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_system.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


47
48
49
# File 'lib/seam/resources/acs_system.rb', line 47

def message
  @message
end

#misconfigured_acs_entrance_idsArray<String>

Deprecated.

this field is deprecated.

Returns:

  • (Array<String>)


50
51
52
# File 'lib/seam/resources/acs_system.rb', line 50

def misconfigured_acs_entrance_ids
  @misconfigured_acs_entrance_ids
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


53
54
55
# File 'lib/seam/resources/acs_system.rb', line 53

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


56
# File 'lib/seam/resources/acs_system.rb', line 56

date_accessor :created_at