Class: Seam::Resources::AcsSystem::Warnings::SaltoKsSubscriptionLimitAlmostReached
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsSystem::Warnings::SaltoKsSubscriptionLimitAlmostReached
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that the Salto KS site has exceeded 80% of the maximum number of allowed users. Increase your subscription limit or delete some users from your site to rectify the issue.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
213 214 215 |
# File 'lib/seam/resources/acs_system.rb', line 213 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
salto_ks_subscription_limit_almost_reached
218 219 220 |
# File 'lib/seam/resources/acs_system.rb', line 218 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
221 |
# File 'lib/seam/resources/acs_system.rb', line 221 date_accessor :created_at |