Class: Seam::Resources::AcsSystem::Warnings::SetupRequired
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsSystem::Warnings::SetupRequired
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates that the access control system requires additional setup before it can be fully operational. Follow the instructions in the warning message to complete the setup.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
246 247 248 |
# File 'lib/seam/resources/acs_system.rb', line 246 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
setup_required
251 252 253 |
# File 'lib/seam/resources/acs_system.rb', line 251 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
254 |
# File 'lib/seam/resources/acs_system.rb', line 254 date_accessor :created_at |