Class: Seam::Resources::AcsSystem::Warnings::TimeZoneDoesNotMatchLocation
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsSystem::Warnings::TimeZoneDoesNotMatchLocation
- Defined in:
- lib/seam/resources/acs_system.rb
Overview
Indicates the access control system time zone could not be determined because the reported physical location does not match the time zone configured on the physical ACS entrances.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#misconfigured_acs_entrance_ids ⇒ Array<String>
deprecated
Deprecated.
this field is deprecated.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
228 229 230 |
# File 'lib/seam/resources/acs_system.rb', line 228 def @message end |
#misconfigured_acs_entrance_ids ⇒ Array<String>
Deprecated.
this field is deprecated.
231 232 233 |
# File 'lib/seam/resources/acs_system.rb', line 231 def misconfigured_acs_entrance_ids @misconfigured_acs_entrance_ids end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
time_zone_does_not_match_location
236 237 238 |
# File 'lib/seam/resources/acs_system.rb', line 236 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
239 |
# File 'lib/seam/resources/acs_system.rb', line 239 date_accessor :created_at |