Class: Seam::Resources::AcsUser
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Represents a user in an access system.
An access system user typically refers to an individual who requires access, like an employee or resident. Each user can possess multiple credentials that serve as their keys or identifiers for access. The type of credential can vary widely. For example, in the Salto system, a user can have a PIN code, a mobile app account, and a fob. In other platforms, it is not uncommon for a user to have more than one of the same credential type, such as multiple key cards. Additionally, these credentials can have a schedule or validity period.
For details about how to configure users in your access system, see the corresponding system integration guide.
Defined Under Namespace
Classes: AccessSchedule, Errors, PendingMutations, SaltoKsMetadata, SaltoSpaceMetadata, Warnings
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system that contains the access system user.
-
#acs_user_id ⇒ String
ID of the access system user.
-
#connected_account_id ⇒ String
The ID of the connected account that is associated with the access system user.
-
#display_name ⇒ String
Display name for the access system user.
-
#email ⇒ String?
deprecated
Deprecated.
use email_address.
-
#email_address ⇒ String?
Email address of the access system user.
-
#external_type ⇒ String?
Brand-specific terminology for the access system user type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the access system user type.
-
#full_name ⇒ String?
Full name of the access system user.
-
#hid_acs_system_id ⇒ String?
ID of the HID access control system associated with the user.
-
#is_managed ⇒ TrueClass
Indicates whether Seam manages the access system user.
-
#is_suspended ⇒ Boolean?
Indicates whether the access system user is currently suspended.
-
#phone_number ⇒ String?
Phone number of the access system user in E.164 format (for example,
+15555550100). -
#user_identity_email_address ⇒ String?
Email address of the user identity associated with the access system user.
-
#user_identity_full_name ⇒ String?
Full name of the user identity associated with the access system user.
-
#user_identity_id ⇒ String?
ID of the user identity associated with the access system user.
-
#user_identity_phone_number ⇒ String?
Phone number of the user identity associated with the access system user in E.164 format (for example,
+15555550100). -
#workspace_id ⇒ String
ID of the workspace that contains the access system user.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#access_schedule ⇒ AccessSchedule?
starts_atandends_attimestamps for the access system user's access. -
#created_at ⇒ Time
Date and time at which the access system user was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access system user.
-
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations associated with the access system user.
-
#salto_ks_metadata ⇒ SaltoKsMetadata?
Salto KS-specific metadata associated with the access system user.
-
#salto_space_metadata ⇒ SaltoSpaceMetadata?
Salto Space-specific metadata associated with the access system user.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access system user.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system that contains the access system user.
344 345 346 |
# File 'lib/seam/resources/acs_user.rb', line 344 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the access system user.
347 348 349 |
# File 'lib/seam/resources/acs_user.rb', line 347 def acs_user_id @acs_user_id end |
#connected_account_id ⇒ String
The ID of the connected account that is associated with the access system user.
350 351 352 |
# File 'lib/seam/resources/acs_user.rb', line 350 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name for the access system user.
353 354 355 |
# File 'lib/seam/resources/acs_user.rb', line 353 def display_name @display_name end |
#email ⇒ String?
use email_address.
356 357 358 |
# File 'lib/seam/resources/acs_user.rb', line 356 def email @email end |
#email_address ⇒ String?
Email address of the access system user.
359 360 361 |
# File 'lib/seam/resources/acs_user.rb', line 359 def email_address @email_address end |
#external_type ⇒ String?
Brand-specific terminology for the access system user type. Known values:
pti_userbrivo_userhid_credential_manager_usersalto_site_userlatch_userdormakaba_community_usersalto_space_useravigilon_alta_userkisi_user
372 373 374 |
# File 'lib/seam/resources/acs_user.rb', line 372 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the access system user type.
375 376 377 |
# File 'lib/seam/resources/acs_user.rb', line 375 def external_type_display_name @external_type_display_name end |
#full_name ⇒ String?
Full name of the access system user.
378 379 380 |
# File 'lib/seam/resources/acs_user.rb', line 378 def full_name @full_name end |
#hid_acs_system_id ⇒ String?
ID of the HID access control system associated with the user.
381 382 383 |
# File 'lib/seam/resources/acs_user.rb', line 381 def hid_acs_system_id @hid_acs_system_id end |
#is_managed ⇒ TrueClass
Indicates whether Seam manages the access system user.
384 385 386 |
# File 'lib/seam/resources/acs_user.rb', line 384 def is_managed @is_managed end |
#is_suspended ⇒ Boolean?
Indicates whether the access system user is currently suspended.
387 388 389 |
# File 'lib/seam/resources/acs_user.rb', line 387 def is_suspended @is_suspended end |
#phone_number ⇒ String?
Phone number of the access system user in E.164 format (for example, +15555550100).
390 391 392 |
# File 'lib/seam/resources/acs_user.rb', line 390 def phone_number @phone_number end |
#user_identity_email_address ⇒ String?
Email address of the user identity associated with the access system user.
393 394 395 |
# File 'lib/seam/resources/acs_user.rb', line 393 def user_identity_email_address @user_identity_email_address end |
#user_identity_full_name ⇒ String?
Full name of the user identity associated with the access system user.
396 397 398 |
# File 'lib/seam/resources/acs_user.rb', line 396 def user_identity_full_name @user_identity_full_name end |
#user_identity_id ⇒ String?
ID of the user identity associated with the access system user.
399 400 401 |
# File 'lib/seam/resources/acs_user.rb', line 399 def user_identity_id @user_identity_id end |
#user_identity_phone_number ⇒ String?
Phone number of the user identity associated with the access system user in E.164 format (for example, +15555550100).
402 403 404 |
# File 'lib/seam/resources/acs_user.rb', line 402 def user_identity_phone_number @user_identity_phone_number end |
#workspace_id ⇒ String
ID of the workspace that contains the access system user.
405 406 407 |
# File 'lib/seam/resources/acs_user.rb', line 405 def workspace_id @workspace_id end |
Instance Method Details
#access_schedule ⇒ AccessSchedule?
starts_at and ends_at timestamps for the access system user's access.
326 |
# File 'lib/seam/resources/acs_user.rb', line 326 resource_accessor :access_schedule, AccessSchedule |
#created_at ⇒ Time
Date and time at which the access system user was created.
409 |
# File 'lib/seam/resources/acs_user.rb', line 409 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access system user.
335 |
# File 'lib/seam/resources/acs_user.rb', line 335 resource_list_accessor :errors, Errors |
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations associated with the access system user. Seam is in the process of pushing these mutations to the integrated access system.
338 |
# File 'lib/seam/resources/acs_user.rb', line 338 resource_list_accessor :pending_mutations, PendingMutations |
#salto_ks_metadata ⇒ SaltoKsMetadata?
Salto KS-specific metadata associated with the access system user.
329 |
# File 'lib/seam/resources/acs_user.rb', line 329 resource_accessor :salto_ks_metadata, SaltoKsMetadata |
#salto_space_metadata ⇒ SaltoSpaceMetadata?
Salto Space-specific metadata associated with the access system user.
332 |
# File 'lib/seam/resources/acs_user.rb', line 332 resource_accessor :salto_space_metadata, SaltoSpaceMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the access system user.
341 |
# File 'lib/seam/resources/acs_user.rb', line 341 resource_list_accessor :warnings, Warnings |