Class: Seam::Resources::AcsUser

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Represents a user in an access system.

An access system user typically refers to an individual who requires access, like an employee or resident. Each user can possess multiple credentials that serve as their keys or identifiers for access. The type of credential can vary widely. For example, in the Salto system, a user can have a PIN code, a mobile app account, and a fob. In other platforms, it is not uncommon for a user to have more than one of the same credential type, such as multiple key cards. Additionally, these credentials can have a schedule or validity period.

For details about how to configure users in your access system, see the corresponding system integration guide.

Defined Under Namespace

Classes: AccessSchedule, Errors, PendingMutations, SaltoKsMetadata, SaltoSpaceMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_system_idString

ID of the access system that contains the access system user.

Returns:

  • (String)


153
154
155
# File 'lib/seam/resources/acs_user.rb', line 153

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the access system user.

Returns:

  • (String)


156
157
158
# File 'lib/seam/resources/acs_user.rb', line 156

def acs_user_id
  @acs_user_id
end

#connected_account_idString

The ID of the connected account that is associated with the access system user.

Returns:

  • (String)


159
160
161
# File 'lib/seam/resources/acs_user.rb', line 159

def 
  @connected_account_id
end

#display_nameString

Display name for the access system user.

Returns:

  • (String)


162
163
164
# File 'lib/seam/resources/acs_user.rb', line 162

def display_name
  @display_name
end

#emailString?

Deprecated.

use email_address.

Returns:

  • (String, nil)


165
166
167
# File 'lib/seam/resources/acs_user.rb', line 165

def email
  @email
end

#email_addressString?

Email address of the access system user.

Returns:

  • (String, nil)


168
169
170
# File 'lib/seam/resources/acs_user.rb', line 168

def email_address
  @email_address
end

#external_typeString?

Brand-specific terminology for the access system user type.

Returns:

  • (String, nil)


171
172
173
# File 'lib/seam/resources/acs_user.rb', line 171

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the access system user type.

Returns:

  • (String, nil)


174
175
176
# File 'lib/seam/resources/acs_user.rb', line 174

def external_type_display_name
  @external_type_display_name
end

#full_nameString?

Full name of the access system user.

Returns:

  • (String, nil)


177
178
179
# File 'lib/seam/resources/acs_user.rb', line 177

def full_name
  @full_name
end

#hid_acs_system_idString?

ID of the HID access control system associated with the user.

Returns:

  • (String, nil)


180
181
182
# File 'lib/seam/resources/acs_user.rb', line 180

def hid_acs_system_id
  @hid_acs_system_id
end

#is_managedBoolean

Indicates whether Seam manages the access system user.

Returns:

  • (Boolean)


183
184
185
# File 'lib/seam/resources/acs_user.rb', line 183

def is_managed
  @is_managed
end

#is_suspendedBoolean?

Indicates whether the access system user is currently suspended.

Returns:

  • (Boolean, nil)


186
187
188
# File 'lib/seam/resources/acs_user.rb', line 186

def is_suspended
  @is_suspended
end

#phone_numberString?

Phone number of the access system user in E.164 format (for example, +15555550100).

Returns:

  • (String, nil)


189
190
191
# File 'lib/seam/resources/acs_user.rb', line 189

def phone_number
  @phone_number
end

#user_identity_email_addressString?

Email address of the user identity associated with the access system user.

Returns:

  • (String, nil)


192
193
194
# File 'lib/seam/resources/acs_user.rb', line 192

def user_identity_email_address
  @user_identity_email_address
end

#user_identity_full_nameString?

Full name of the user identity associated with the access system user.

Returns:

  • (String, nil)


195
196
197
# File 'lib/seam/resources/acs_user.rb', line 195

def user_identity_full_name
  @user_identity_full_name
end

#user_identity_idString?

ID of the user identity associated with the access system user.

Returns:

  • (String, nil)


198
199
200
# File 'lib/seam/resources/acs_user.rb', line 198

def user_identity_id
  @user_identity_id
end

#user_identity_phone_numberString?

Phone number of the user identity associated with the access system user in E.164 format (for example, +15555550100).

Returns:

  • (String, nil)


201
202
203
# File 'lib/seam/resources/acs_user.rb', line 201

def user_identity_phone_number
  @user_identity_phone_number
end

#workspace_idString

ID of the workspace that contains the access system user.

Returns:

  • (String)


204
205
206
# File 'lib/seam/resources/acs_user.rb', line 204

def workspace_id
  @workspace_id
end

Instance Method Details

#access_scheduleAccessSchedule?

starts_at and ends_at timestamps for the access system user's access.

Returns:



135
# File 'lib/seam/resources/acs_user.rb', line 135

resource_accessor :access_schedule, AccessSchedule

#created_atTime

Date and time at which the access system user was created.

Returns:

  • (Time)


208
# File 'lib/seam/resources/acs_user.rb', line 208

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the access system user.

Returns:



144
# File 'lib/seam/resources/acs_user.rb', line 144

resource_list_accessor :errors, Errors

#pending_mutationsArray<PendingMutations>

Pending mutations associated with the access system user. Seam is in the process of pushing these mutations to the integrated access system.

Returns:



147
# File 'lib/seam/resources/acs_user.rb', line 147

resource_list_accessor :pending_mutations, PendingMutations

#salto_ks_metadataSaltoKsMetadata?

Salto KS-specific metadata associated with the access system user.

Returns:



138
# File 'lib/seam/resources/acs_user.rb', line 138

resource_accessor :salto_ks_metadata, SaltoKsMetadata

#salto_space_metadataSaltoSpaceMetadata?

Salto Space-specific metadata associated with the access system user.

Returns:



141
# File 'lib/seam/resources/acs_user.rb', line 141

resource_accessor :salto_space_metadata, SaltoSpaceMetadata

#warningsArray<Warnings>

Warnings associated with the access system user.

Returns:



150
# File 'lib/seam/resources/acs_user.rb', line 150

resource_list_accessor :warnings, Warnings