Class: Seam::Resources::AcsUser

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/acs_user.rb

Overview

Represents a user in an access system.

An access system user typically refers to an individual who requires access, like an employee or resident. Each user can possess multiple credentials that serve as their keys or identifiers for access. The type of credential can vary widely. For example, in the Salto system, a user can have a PIN code, a mobile app account, and a fob. In other platforms, it is not uncommon for a user to have more than one of the same credential type, such as multiple key cards. Additionally, these credentials can have a schedule or validity period.

For details about how to configure users in your access system, see the corresponding system integration guide.

Defined Under Namespace

Classes: AccessSchedule, Errors, PendingMutations, SaltoKsMetadata, SaltoSpaceMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_system_idObject

ID of the access system that contains the access system user.



105
106
107
# File 'lib/seam/resources/acs_user.rb', line 105

def acs_system_id
  @acs_system_id
end

#acs_user_idObject

ID of the access system user.



107
108
109
# File 'lib/seam/resources/acs_user.rb', line 107

def acs_user_id
  @acs_user_id
end

#connected_account_idObject

The ID of the connected account that is associated with the access system user.



109
110
111
# File 'lib/seam/resources/acs_user.rb', line 109

def 
  @connected_account_id
end

#display_nameObject

Display name for the access system user.



111
112
113
# File 'lib/seam/resources/acs_user.rb', line 111

def display_name
  @display_name
end

#emailObject

Deprecated.

use email_address.



113
114
115
# File 'lib/seam/resources/acs_user.rb', line 113

def email
  @email
end

#email_addressObject

Email address of the access system user.



115
116
117
# File 'lib/seam/resources/acs_user.rb', line 115

def email_address
  @email_address
end

#external_typeObject

Brand-specific terminology for the access system user type.



117
118
119
# File 'lib/seam/resources/acs_user.rb', line 117

def external_type
  @external_type
end

#external_type_display_nameObject

Display name that corresponds to the brand-specific terminology for the access system user type.



119
120
121
# File 'lib/seam/resources/acs_user.rb', line 119

def external_type_display_name
  @external_type_display_name
end

#full_nameObject

Full name of the access system user.



121
122
123
# File 'lib/seam/resources/acs_user.rb', line 121

def full_name
  @full_name
end

#hid_acs_system_idObject

ID of the HID access control system associated with the user.



123
124
125
# File 'lib/seam/resources/acs_user.rb', line 123

def hid_acs_system_id
  @hid_acs_system_id
end

#is_managedObject

Indicates whether Seam manages the access system user.



125
126
127
# File 'lib/seam/resources/acs_user.rb', line 125

def is_managed
  @is_managed
end

#is_suspendedObject

Indicates whether the access system user is currently suspended.



127
128
129
# File 'lib/seam/resources/acs_user.rb', line 127

def is_suspended
  @is_suspended
end

#phone_numberObject

Phone number of the access system user in E.164 format (for example, +15555550100).



129
130
131
# File 'lib/seam/resources/acs_user.rb', line 129

def phone_number
  @phone_number
end

#user_identity_email_addressObject

Email address of the user identity associated with the access system user.



131
132
133
# File 'lib/seam/resources/acs_user.rb', line 131

def user_identity_email_address
  @user_identity_email_address
end

#user_identity_full_nameObject

Full name of the user identity associated with the access system user.



133
134
135
# File 'lib/seam/resources/acs_user.rb', line 133

def user_identity_full_name
  @user_identity_full_name
end

#user_identity_idObject

ID of the user identity associated with the access system user.



135
136
137
# File 'lib/seam/resources/acs_user.rb', line 135

def user_identity_id
  @user_identity_id
end

#user_identity_phone_numberObject

Phone number of the user identity associated with the access system user in E.164 format (for example, +15555550100).



137
138
139
# File 'lib/seam/resources/acs_user.rb', line 137

def user_identity_phone_number
  @user_identity_phone_number
end

#workspace_idObject

ID of the workspace that contains the access system user.



139
140
141
# File 'lib/seam/resources/acs_user.rb', line 139

def workspace_id
  @workspace_id
end