Class: Seam::Resources::AcsUser

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport, ResourceWarningsSupport
Defined in:
lib/seam/resources/acs_user.rb

Overview

Represents a user in an access system.

An access system user typically refers to an individual who requires access, like an employee or resident. Each user can possess multiple credentials that serve as their keys or identifiers for access. The type of credential can vary widely. For example, in the Salto system, a user can have a PIN code, a mobile app account, and a fob. In other platforms, it is not uncommon for a user to have more than one of the same credential type, such as multiple key cards. Additionally, these credentials can have a schedule or validity period.

For details about how to configure users in your access system, see the corresponding system integration guide.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceWarningsSupport

#warnings

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_scheduleObject

starts_at and ends_at timestamps for the access system user's access.



12
13
14
# File 'lib/seam/resources/acs_user.rb', line 12

def access_schedule
  @access_schedule
end

#acs_system_idObject

ID of the access system that contains the access system user.



14
15
16
# File 'lib/seam/resources/acs_user.rb', line 14

def acs_system_id
  @acs_system_id
end

#acs_user_idObject

ID of the access system user.



16
17
18
# File 'lib/seam/resources/acs_user.rb', line 16

def acs_user_id
  @acs_user_id
end

#connected_account_idObject

The ID of the connected account that is associated with the access system user.



18
19
20
# File 'lib/seam/resources/acs_user.rb', line 18

def 
  @connected_account_id
end

#display_nameObject

Display name for the access system user.



20
21
22
# File 'lib/seam/resources/acs_user.rb', line 20

def display_name
  @display_name
end

#emailObject

Deprecated.

use email_address.



22
23
24
# File 'lib/seam/resources/acs_user.rb', line 22

def email
  @email
end

#email_addressObject

Email address of the access system user.



24
25
26
# File 'lib/seam/resources/acs_user.rb', line 24

def email_address
  @email_address
end

#external_typeObject

Brand-specific terminology for the access system user type.



26
27
28
# File 'lib/seam/resources/acs_user.rb', line 26

def external_type
  @external_type
end

#external_type_display_nameObject

Display name that corresponds to the brand-specific terminology for the access system user type.



28
29
30
# File 'lib/seam/resources/acs_user.rb', line 28

def external_type_display_name
  @external_type_display_name
end

#full_nameObject

Full name of the access system user.



30
31
32
# File 'lib/seam/resources/acs_user.rb', line 30

def full_name
  @full_name
end

#hid_acs_system_idObject

ID of the HID access control system associated with the user.



32
33
34
# File 'lib/seam/resources/acs_user.rb', line 32

def hid_acs_system_id
  @hid_acs_system_id
end

#is_managedObject

Indicates whether Seam manages the access system user.



34
35
36
# File 'lib/seam/resources/acs_user.rb', line 34

def is_managed
  @is_managed
end

#is_suspendedObject

Indicates whether the access system user is currently suspended.



36
37
38
# File 'lib/seam/resources/acs_user.rb', line 36

def is_suspended
  @is_suspended
end

#pending_mutationsObject

Pending mutations associated with the access system user. Seam is in the process of pushing these mutations to the integrated access system.



38
39
40
# File 'lib/seam/resources/acs_user.rb', line 38

def pending_mutations
  @pending_mutations
end

#phone_numberObject

Phone number of the access system user in E.164 format (for example, +15555550100).



40
41
42
# File 'lib/seam/resources/acs_user.rb', line 40

def phone_number
  @phone_number
end

#salto_ks_metadataObject

Salto KS-specific metadata associated with the access system user.



42
43
44
# File 'lib/seam/resources/acs_user.rb', line 42

def 
  @salto_ks_metadata
end

#salto_space_metadataObject

Salto Space-specific metadata associated with the access system user.



44
45
46
# File 'lib/seam/resources/acs_user.rb', line 44

def 
  @salto_space_metadata
end

#user_identity_email_addressObject

Email address of the user identity associated with the access system user.



46
47
48
# File 'lib/seam/resources/acs_user.rb', line 46

def user_identity_email_address
  @user_identity_email_address
end

#user_identity_full_nameObject

Full name of the user identity associated with the access system user.



48
49
50
# File 'lib/seam/resources/acs_user.rb', line 48

def user_identity_full_name
  @user_identity_full_name
end

#user_identity_idObject

ID of the user identity associated with the access system user.



50
51
52
# File 'lib/seam/resources/acs_user.rb', line 50

def user_identity_id
  @user_identity_id
end

#user_identity_phone_numberObject

Phone number of the user identity associated with the access system user in E.164 format (for example, +15555550100).



52
53
54
# File 'lib/seam/resources/acs_user.rb', line 52

def user_identity_phone_number
  @user_identity_phone_number
end

#workspace_idObject

ID of the workspace that contains the access system user.



54
55
56
# File 'lib/seam/resources/acs_user.rb', line 54

def workspace_id
  @workspace_id
end