Class: Seam::Resources::AcsUser::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser::Errors
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Known error_code values load as subclasses; unknown values remain Errors instances for forward compatibility.
Defined Under Namespace
Classes: DeletedExternally, FailedToCreateOnAcsSystem, FailedToDeleteOnAcsSystem, FailedToUpdateOnAcsSystem, LatchConflictWithResidentUser, SaltoKsSubscriptionLimitExceeded
Instance Attribute Summary collapse
-
#error_code ⇒ String
Known values: -
deleted_externally-salto_ks_subscription_limit_exceeded-failed_to_create_on_acs_system-failed_to_update_on_acs_system-failed_to_delete_on_acs_system-latch_conflict_with_resident_user. -
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
Known values:
deleted_externallysalto_ks_subscription_limit_exceededfailed_to_create_on_acs_systemfailed_to_update_on_acs_systemfailed_to_delete_on_acs_systemlatch_conflict_with_resident_user
114 115 116 |
# File 'lib/seam/resources/acs_user.rb', line 114 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
117 118 119 |
# File 'lib/seam/resources/acs_user.rb', line 117 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
120 |
# File 'lib/seam/resources/acs_user.rb', line 120 date_accessor :created_at |