Class: Seam::Resources::AcsUser::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser::Errors
- Defined in:
- lib/seam/resources/acs_user.rb
Instance Attribute Summary collapse
- #error_code ⇒ String
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
22 23 24 |
# File 'lib/seam/resources/acs_user.rb', line 22 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
25 26 27 |
# File 'lib/seam/resources/acs_user.rb', line 25 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
28 |
# File 'lib/seam/resources/acs_user.rb', line 28 date_accessor :created_at |