Class: Seam::Resources::AcsUser::Errors::DeletedExternally
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsUser::Errors::DeletedExternally
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user was deleted from the access system outside of Seam.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Known values: -
deleted_externally. -
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Known values:
deleted_externally
27 28 29 |
# File 'lib/seam/resources/acs_user.rb', line 27 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
30 31 32 |
# File 'lib/seam/resources/acs_user.rb', line 30 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
33 |
# File 'lib/seam/resources/acs_user.rb', line 33 date_accessor :created_at |