Class: Seam::Resources::AcsUser::Errors::FailedToUpdateOnAcsSystem
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsUser::Errors::FailedToUpdateOnAcsSystem
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user was not updated on the access system. This is likely due to an internal unexpected error. Contact Seam support.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Known values: -
failed_to_update_on_acs_system. -
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Known values:
failed_to_update_on_acs_system
69 70 71 |
# File 'lib/seam/resources/acs_user.rb', line 69 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
72 73 74 |
# File 'lib/seam/resources/acs_user.rb', line 72 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
75 |
# File 'lib/seam/resources/acs_user.rb', line 75 date_accessor :created_at |