Class: Seam::Resources::AcsUser::Errors::LatchConflictWithResidentUser
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsUser::Errors::LatchConflictWithResidentUser
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user was created from the Seam API but also exists on Mission Control. This is unsupported. Contact Seam support.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Known values: -
latch_conflict_with_resident_user. -
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Known values:
latch_conflict_with_resident_user
97 98 99 |
# File 'lib/seam/resources/acs_user.rb', line 97 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
100 101 102 |
# File 'lib/seam/resources/acs_user.rb', line 100 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
103 |
# File 'lib/seam/resources/acs_user.rb', line 103 date_accessor :created_at |