Class: Seam::Resources::AcsUser::Errors::SaltoKsSubscriptionLimitExceeded
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::AcsUser::Errors::SaltoKsSubscriptionLimitExceeded
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user could not be subscribed on Salto KS because the subscription limit has been exceeded.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Known values: -
salto_ks_subscription_limit_exceeded. -
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Known values:
salto_ks_subscription_limit_exceeded
41 42 43 |
# File 'lib/seam/resources/acs_user.rb', line 41 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
44 45 46 |
# File 'lib/seam/resources/acs_user.rb', line 44 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
47 |
# File 'lib/seam/resources/acs_user.rb', line 47 date_accessor :created_at |