Class: Seam::Resources::AcsUser::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser::PendingMutations
- Defined in:
- lib/seam/resources/acs_user.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#acs_access_group_id ⇒ Object
ID of the access group involved in the scheduled change.
-
#message ⇒ Object
Detailed description of the mutation.
-
#mutation_code ⇒ Object
Returns the value of attribute mutation_code.
-
#variant ⇒ Object
Whether the user is scheduled to be added to or removed from the access group.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_access_group_id ⇒ Object
ID of the access group involved in the scheduled change.
66 67 68 |
# File 'lib/seam/resources/acs_user.rb', line 66 def acs_access_group_id @acs_access_group_id end |
#message ⇒ Object
Detailed description of the mutation.
68 69 70 |
# File 'lib/seam/resources/acs_user.rb', line 68 def @message end |
#mutation_code ⇒ Object
Returns the value of attribute mutation_code.
69 70 71 |
# File 'lib/seam/resources/acs_user.rb', line 69 def mutation_code @mutation_code end |
#variant ⇒ Object
Whether the user is scheduled to be added to or removed from the access group.
71 72 73 |
# File 'lib/seam/resources/acs_user.rb', line 71 def variant @variant end |