Class: Seam::Resources::AcsUser::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::AcsUser::Warnings
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.
Defined Under Namespace
Classes: AcsUserInactive, BeingDeleted, LatchResidentUser, SaltoKsUserNotSubscribed, UnknownIssueWithAcsUser
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Known values: -
being_deleted-salto_ks_user_not_subscribed-acs_user_inactive-unknown_issue_with_acs_user-latch_resident_user.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
302 303 304 |
# File 'lib/seam/resources/acs_user.rb', line 302 def @message end |
#warning_code ⇒ String
Known values:
being_deletedsalto_ks_user_not_subscribedacs_user_inactiveunknown_issue_with_acs_userlatch_resident_user
310 311 312 |
# File 'lib/seam/resources/acs_user.rb', line 310 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
313 |
# File 'lib/seam/resources/acs_user.rb', line 313 date_accessor :created_at |