Class: Seam::Resources::AcsUser::Warnings::AcsUserInactive
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsUser::Warnings::AcsUserInactive
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user exists but is not currently able to gain access—for example, because their access schedule has not started yet or has ended, the access system has reached its limit for active users, or they have been unsubscribed or deactivated. Refer to the warning message for the provider-specific reason. This is distinct from is_suspended, which indicates the user has been explicitly blocked.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Known values: -
acs_user_inactive.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
262 263 264 |
# File 'lib/seam/resources/acs_user.rb', line 262 def @message end |
#warning_code ⇒ String
Known values:
acs_user_inactive
266 267 268 |
# File 'lib/seam/resources/acs_user.rb', line 266 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
269 |
# File 'lib/seam/resources/acs_user.rb', line 269 date_accessor :created_at |