Class: Seam::Resources::AcsUser::Warnings::LatchResidentUser
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsUser::Warnings::LatchResidentUser
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
Indicates that the access system user was created on Latch Mission Control. Please use the Latch Mission Control to manage this user.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Known values: -
latch_resident_user.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
290 291 292 |
# File 'lib/seam/resources/acs_user.rb', line 290 def @message end |
#warning_code ⇒ String
Known values:
latch_resident_user
294 295 296 |
# File 'lib/seam/resources/acs_user.rb', line 294 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
297 |
# File 'lib/seam/resources/acs_user.rb', line 297 date_accessor :created_at |