Class: Seam::Resources::AcsUser::Warnings::UnknownIssueWithAcsUser
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::AcsUser::Warnings::UnknownIssueWithAcsUser
- Defined in:
- lib/seam/resources/acs_user.rb
Overview
An unknown issue occurred while syncing the state of this access system user with the provider. This issue may affect the proper functioning of this user.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Known values: -
unknown_issue_with_acs_user.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
276 277 278 |
# File 'lib/seam/resources/acs_user.rb', line 276 def @message end |
#warning_code ⇒ String
Known values:
unknown_issue_with_acs_user
280 281 282 |
# File 'lib/seam/resources/acs_user.rb', line 280 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
283 |
# File 'lib/seam/resources/acs_user.rb', line 283 date_accessor :created_at |