Class: Seam::Resources::ActionAttempt::ActivateClimatePreset
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::ActivateClimatePreset
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Activating a climate preset is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of a climate preset activation.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1208 1209 1210 |
# File 'lib/seam/resources/action_attempt.rb', line 1208 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of a climate preset activation. Known values:
ACTIVATE_CLIMATE_PRESET
1213 1214 1215 |
# File 'lib/seam/resources/action_attempt.rb', line 1213 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1219 1220 1221 |
# File 'lib/seam/resources/action_attempt.rb', line 1219 def status @status end |