Class: Seam::Resources::ActionAttempt::AssignCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::AssignCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Assigning a credential to an access method is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of assigning a pre-registered card credential to an access method.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Only present when
statusiserror;nilotherwise. -
#result ⇒ Result?
Result of assigning a credential.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1091 1092 1093 |
# File 'lib/seam/resources/action_attempt.rb', line 1091 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of assigning a pre-registered card credential to an access method. Known values:
ASSIGN_CREDENTIAL
1096 1097 1098 |
# File 'lib/seam/resources/action_attempt.rb', line 1096 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1102 1103 1104 |
# File 'lib/seam/resources/action_attempt.rb', line 1102 def status @status end |