Class: Seam::Resources::ActionAttempt::AssignCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Assigning a credential to an access method is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


1067
1068
1069
# File 'lib/seam/resources/action_attempt.rb', line 1067

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of assigning a pre-registered card credential to an access method. Known values:

  • ASSIGN_CREDENTIAL

Returns:

  • (String)


1072
1073
1074
# File 'lib/seam/resources/action_attempt.rb', line 1072

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


1078
1079
1080
# File 'lib/seam/resources/action_attempt.rb', line 1078

def status
  @status
end

Instance Method Details

#errorError?

Returns:



1061
# File 'lib/seam/resources/action_attempt.rb', line 1061

resource_accessor :error, Error

#resultResult?

Result of assigning a credential. If successful, includes the updated access method with the assigned credential.

Returns:



1064
# File 'lib/seam/resources/action_attempt.rb', line 1064

resource_accessor :result, Result