Class: Seam::Resources::ActionAttempt::AssignCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::AssignCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Assigning a credential to an access method is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of assigning a pre-registered card credential to an access method.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
- #error ⇒ Error?
-
#result ⇒ Result?
Result of assigning a credential.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1067 1068 1069 |
# File 'lib/seam/resources/action_attempt.rb', line 1067 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of assigning a pre-registered card credential to an access method. Known values:
ASSIGN_CREDENTIAL
1072 1073 1074 |
# File 'lib/seam/resources/action_attempt.rb', line 1072 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1078 1079 1080 |
# File 'lib/seam/resources/action_attempt.rb', line 1078 def status @status end |