Class: Seam::Resources::ActionAttempt::AssignCredential::Result

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: Errors, PendingMutations, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_method_idString

ID of the access method.

Returns:

  • (String)


1007
1008
1009
# File 'lib/seam/resources/action_attempt.rb', line 1007

def access_method_id
  @access_method_id
end

#client_session_tokenString?

Token of the client session associated with the access method.

Returns:

  • (String, nil)


1010
1011
1012
# File 'lib/seam/resources/action_attempt.rb', line 1010

def client_session_token
  @client_session_token
end

#codeString?

The actual PIN code for code access methods.

Returns:

  • (String, nil)


1013
1014
1015
# File 'lib/seam/resources/action_attempt.rb', line 1013

def code
  @code
end

#customization_profile_idString?

ID of the customization profile associated with the access method.

Returns:

  • (String, nil)


1016
1017
1018
# File 'lib/seam/resources/action_attempt.rb', line 1016

def customization_profile_id
  @customization_profile_id
end

#display_nameString

Display name of the access method.

Returns:

  • (String)


1019
1020
1021
# File 'lib/seam/resources/action_attempt.rb', line 1019

def display_name
  @display_name
end

#instant_key_urlString?

URL of the Instant Key for mobile key access methods.

Returns:

  • (String, nil)


1022
1023
1024
# File 'lib/seam/resources/action_attempt.rb', line 1022

def instant_key_url
  @instant_key_url
end

#is_assignment_requiredBoolean?

Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.

Returns:

  • (Boolean, nil)


1025
1026
1027
# File 'lib/seam/resources/action_attempt.rb', line 1025

def is_assignment_required
  @is_assignment_required
end

#is_encoding_requiredBoolean?

Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.

Returns:

  • (Boolean, nil)


1028
1029
1030
# File 'lib/seam/resources/action_attempt.rb', line 1028

def is_encoding_required
  @is_encoding_required
end

#is_issuedBoolean

Indicates whether the access method has been issued.

Returns:

  • (Boolean)


1031
1032
1033
# File 'lib/seam/resources/action_attempt.rb', line 1031

def is_issued
  @is_issued
end

#is_ready_for_assignmentBoolean?

Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.

Returns:

  • (Boolean, nil)


1034
1035
1036
# File 'lib/seam/resources/action_attempt.rb', line 1034

def is_ready_for_assignment
  @is_ready_for_assignment
end

#is_ready_for_encodingBoolean?

Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.

Returns:

  • (Boolean, nil)


1037
1038
1039
# File 'lib/seam/resources/action_attempt.rb', line 1037

def is_ready_for_encoding
  @is_ready_for_encoding
end

#modeString

Access method mode. Supported values: code, card, mobile_key, cloud_key. Known values:

  • code
  • card
  • mobile_key
  • cloud_key

Returns:

  • (String)


1045
1046
1047
# File 'lib/seam/resources/action_attempt.rb', line 1045

def mode
  @mode
end

#workspace_idString

ID of the Seam workspace associated with the access method.

Returns:

  • (String)


1048
1049
1050
# File 'lib/seam/resources/action_attempt.rb', line 1048

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the access method was created.

Returns:

  • (Time)


1051
# File 'lib/seam/resources/action_attempt.rb', line 1051

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the access method.

Returns:



998
# File 'lib/seam/resources/action_attempt.rb', line 998

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the access method was issued.

Returns:

  • (Time, nil)


1054
# File 'lib/seam/resources/action_attempt.rb', line 1054

date_accessor :issued_at

#pending_mutationsArray<PendingMutations>

Pending mutations for the access method. Indicates operations that are in progress.

Returns:



1001
# File 'lib/seam/resources/action_attempt.rb', line 1001

resource_list_accessor :pending_mutations, PendingMutations

#warningsArray<Warnings>

Warnings associated with the access method.

Returns:



1004
# File 'lib/seam/resources/action_attempt.rb', line 1004

resource_list_accessor :warnings, Warnings