Class: Seam::Resources::ActionAttempt::AssignCredential::Result
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::AssignCredential::Result
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_method_id ⇒ String
ID of the access method.
-
#client_session_token ⇒ String?
Token of the client session associated with the access method.
-
#code ⇒ String?
The actual PIN code for code access methods.
-
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
-
#display_name ⇒ String
Display name of the access method.
-
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ String
Access method mode.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the access method was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access method.
-
#issued_at ⇒ Time?
Date and time at which the access method was issued.
-
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ String
ID of the access method.
1007 1008 1009 |
# File 'lib/seam/resources/action_attempt.rb', line 1007 def access_method_id @access_method_id end |
#client_session_token ⇒ String?
Token of the client session associated with the access method.
1010 1011 1012 |
# File 'lib/seam/resources/action_attempt.rb', line 1010 def client_session_token @client_session_token end |
#code ⇒ String?
The actual PIN code for code access methods.
1013 1014 1015 |
# File 'lib/seam/resources/action_attempt.rb', line 1013 def code @code end |
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
1016 1017 1018 |
# File 'lib/seam/resources/action_attempt.rb', line 1016 def customization_profile_id @customization_profile_id end |
#display_name ⇒ String
Display name of the access method.
1019 1020 1021 |
# File 'lib/seam/resources/action_attempt.rb', line 1019 def display_name @display_name end |
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
1022 1023 1024 |
# File 'lib/seam/resources/action_attempt.rb', line 1022 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
1025 1026 1027 |
# File 'lib/seam/resources/action_attempt.rb', line 1025 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
1028 1029 1030 |
# File 'lib/seam/resources/action_attempt.rb', line 1028 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
1031 1032 1033 |
# File 'lib/seam/resources/action_attempt.rb', line 1031 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
1034 1035 1036 |
# File 'lib/seam/resources/action_attempt.rb', line 1034 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
1037 1038 1039 |
# File 'lib/seam/resources/action_attempt.rb', line 1037 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
1045 1046 1047 |
# File 'lib/seam/resources/action_attempt.rb', line 1045 def mode @mode end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
1048 1049 1050 |
# File 'lib/seam/resources/action_attempt.rb', line 1048 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the access method was created.
1051 |
# File 'lib/seam/resources/action_attempt.rb', line 1051 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access method.
998 |
# File 'lib/seam/resources/action_attempt.rb', line 998 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the access method was issued.
1054 |
# File 'lib/seam/resources/action_attempt.rb', line 1054 date_accessor :issued_at |
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method. Indicates operations that are in progress.
1001 |
# File 'lib/seam/resources/action_attempt.rb', line 1001 resource_list_accessor :pending_mutations, PendingMutations |
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
1004 |
# File 'lib/seam/resources/action_attempt.rb', line 1004 resource_list_accessor :warnings, Warnings |