Class: Seam::Resources::ActionAttempt::AssignCredential::Result::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::AssignCredential::Result::PendingMutations
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the mutation.
-
#mutation_code ⇒ String
Mutation code to indicate that Seam is in the process of updating the access times for this access method.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the mutation was created.
-
#from ⇒ From
Previous access time configuration.
-
#to ⇒ To
New access time configuration.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the mutation.
963 964 965 |
# File 'lib/seam/resources/action_attempt.rb', line 963 def @message end |
#mutation_code ⇒ String
Mutation code to indicate that Seam is in the process of updating the access times for this access method. Known values:
provisioning_accessrevoking_accessupdating_access_times
970 971 972 |
# File 'lib/seam/resources/action_attempt.rb', line 970 def mutation_code @mutation_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the mutation was created.
973 |
# File 'lib/seam/resources/action_attempt.rb', line 973 date_accessor :created_at |