Class: Seam::Resources::ActionAttempt::AssignCredential::Result::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


979
980
981
# File 'lib/seam/resources/action_attempt.rb', line 979

def message
  @message
end

#original_access_method_idString?

ID of the original access method from which this backup access method was split, if applicable.

Returns:

  • (String, nil)


990
991
992
# File 'lib/seam/resources/action_attempt.rb', line 990

def original_access_method_id
  @original_access_method_id
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • being_deleted
  • updating_access_times
  • pulled_backup_access_code
  • delay_in_issuing

Returns:

  • (String)


987
988
989
# File 'lib/seam/resources/action_attempt.rb', line 987

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


993
# File 'lib/seam/resources/action_attempt.rb', line 993

date_accessor :created_at