Class: Seam::Resources::ActionAttempt::AssignCredential::Result::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::AssignCredential::Result::Warnings
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
979 980 981 |
# File 'lib/seam/resources/action_attempt.rb', line 979 def @message end |
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
990 991 992 |
# File 'lib/seam/resources/action_attempt.rb', line 990 def original_access_method_id @original_access_method_id end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
being_deletedupdating_access_timespulled_backup_access_codedelay_in_issuing
987 988 989 |
# File 'lib/seam/resources/action_attempt.rb', line 987 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
993 |
# File 'lib/seam/resources/action_attempt.rb', line 993 date_accessor :created_at |