Class: Seam::Resources::ActionAttempt::EncodeCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Encoding credential data from the physical encoder onto a card is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


653
654
655
# File 'lib/seam/resources/action_attempt.rb', line 653

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of encoding credential data from the physical encoder onto a card. Known values:

  • ENCODE_CREDENTIAL

Returns:

  • (String)


658
659
660
# File 'lib/seam/resources/action_attempt.rb', line 658

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


664
665
666
# File 'lib/seam/resources/action_attempt.rb', line 664

def status
  @status
end

Instance Method Details

#errorError?

Returns:



647
# File 'lib/seam/resources/action_attempt.rb', line 647

resource_accessor :error, Error

#resultResult?

Result of an encoding attempt. If the attempt was successful, includes the credential data that was encoded onto the card.

Returns:



650
# File 'lib/seam/resources/action_attempt.rb', line 650

resource_accessor :result, Result