Class: Seam::Resources::ActionAttempt::EncodeCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::EncodeCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Encoding credential data from the physical encoder onto a card is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of encoding credential data from the physical encoder onto a card.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
- #error ⇒ Error?
-
#result ⇒ Result?
Result of an encoding attempt.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
653 654 655 |
# File 'lib/seam/resources/action_attempt.rb', line 653 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of encoding credential data from the physical encoder onto a card. Known values:
ENCODE_CREDENTIAL
658 659 660 |
# File 'lib/seam/resources/action_attempt.rb', line 658 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
664 665 666 |
# File 'lib/seam/resources/action_attempt.rb', line 664 def status @status end |