Class: Seam::Resources::ActionAttempt::EncodeCredential::Result

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodString

Access method for the credential. Supported values: code, card, mobile_key, cloud_key. Known values:

  • code
  • card
  • mobile_key
  • cloud_key

Returns:

  • (String)


560
561
562
# File 'lib/seam/resources/action_attempt.rb', line 560

def access_method
  @access_method
end

#acs_credential_idString

ID of the credential.

Returns:

  • (String)


563
564
565
# File 'lib/seam/resources/action_attempt.rb', line 563

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idString?

ID of the credential pool to which the credential belongs.

Returns:

  • (String, nil)


566
567
568
# File 'lib/seam/resources/action_attempt.rb', line 566

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idString

ID of the access control system that contains the credential.

Returns:

  • (String)


569
570
571
# File 'lib/seam/resources/action_attempt.rb', line 569

def acs_system_id
  @acs_system_id
end

#acs_user_idString?

ID of the ACS user to whom the credential belongs.

Returns:

  • (String, nil)


572
573
574
# File 'lib/seam/resources/action_attempt.rb', line 572

def acs_user_id
  @acs_user_id
end

#card_numberString?

Number of the card associated with the credential.

Returns:

  • (String, nil)


575
576
577
# File 'lib/seam/resources/action_attempt.rb', line 575

def card_number
  @card_number
end

#codeString?

Access (PIN) code for the credential.

Returns:

  • (String, nil)


578
579
580
# File 'lib/seam/resources/action_attempt.rb', line 578

def code
  @code
end

#connected_account_idString

ID of the connected account to which the credential belongs.

Returns:

  • (String)


581
582
583
# File 'lib/seam/resources/action_attempt.rb', line 581

def 
  @connected_account_id
end

#display_nameString

Display name that corresponds to the credential type.

Returns:

  • (String)


584
585
586
# File 'lib/seam/resources/action_attempt.rb', line 584

def display_name
  @display_name
end

#ends_atString?

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.

Returns:

  • (String, nil)


587
588
589
# File 'lib/seam/resources/action_attempt.rb', line 587

def ends_at
  @ends_at
end

#external_typeString?

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card. Known values:

  • pti_card
  • brivo_credential
  • hid_credential
  • visionline_card
  • salto_ks_credential
  • assa_abloy_vostio_key
  • salto_space_key
  • latch_access
  • dormakaba_ambiance_credential
  • hotek_card
  • salto_ks_tag
  • avigilon_alta_credential
  • kisi_credential
  • akiles_credential

Returns:

  • (String, nil)


605
606
607
# File 'lib/seam/resources/action_attempt.rb', line 605

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the credential type.

Returns:

  • (String, nil)


608
609
610
# File 'lib/seam/resources/action_attempt.rb', line 608

def external_type_display_name
  @external_type_display_name
end

#is_issuedBoolean?

Indicates whether the credential has been encoded onto a card.

Returns:

  • (Boolean, nil)


611
612
613
# File 'lib/seam/resources/action_attempt.rb', line 611

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerBoolean?

Indicates whether the latest state of the credential has been synced from Seam to the provider.

Returns:

  • (Boolean, nil)


614
615
616
# File 'lib/seam/resources/action_attempt.rb', line 614

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedBoolean

Returns:

  • (Boolean)


616
617
618
# File 'lib/seam/resources/action_attempt.rb', line 616

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialBoolean?

Indicates whether the credential is a multi-phone sync credential.

Returns:

  • (Boolean, nil)


619
620
621
# File 'lib/seam/resources/action_attempt.rb', line 619

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useBoolean?

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean, nil)


622
623
624
# File 'lib/seam/resources/action_attempt.rb', line 622

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idString?

ID of the parent credential.

Returns:

  • (String, nil)


625
626
627
# File 'lib/seam/resources/action_attempt.rb', line 625

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atString?

Date and time at which the credential validity starts, in ISO 8601 format.

Returns:

  • (String, nil)


628
629
630
# File 'lib/seam/resources/action_attempt.rb', line 628

def starts_at
  @starts_at
end

#user_identity_idString?

ID of the user identity to whom the credential belongs.

Returns:

  • (String, nil)


631
632
633
# File 'lib/seam/resources/action_attempt.rb', line 631

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the workspace that contains the credential.

Returns:

  • (String)


634
635
636
# File 'lib/seam/resources/action_attempt.rb', line 634

def workspace_id
  @workspace_id
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata for the credential.

Returns:



540
# File 'lib/seam/resources/action_attempt.rb', line 540

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

Vostio-specific metadata for the credential.

Returns:



543
# File 'lib/seam/resources/action_attempt.rb', line 543

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#created_atTime

Date and time at which the credential was created.

Returns:

  • (Time)


637
# File 'lib/seam/resources/action_attempt.rb', line 637

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the credential.

Returns:



549
# File 'lib/seam/resources/action_attempt.rb', line 549

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the credential was encoded onto a card.

Returns:

  • (Time, nil)


640
# File 'lib/seam/resources/action_attempt.rb', line 640

date_accessor :issued_at

#latest_desired_state_synced_with_provider_atTime?

Date and time at which the state of the credential was most recently synced from Seam to the provider.

Returns:

  • (Time, nil)


643
# File 'lib/seam/resources/action_attempt.rb', line 643

date_accessor :latest_desired_state_synced_with_provider_at

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the credential.

Returns:



546
# File 'lib/seam/resources/action_attempt.rb', line 546

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the credential.

Returns:



552
# File 'lib/seam/resources/action_attempt.rb', line 552

resource_list_accessor :warnings, Warnings