Class: Seam::Resources::ActionAttempt::EncodeCredential::Result::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::EncodeCredential::Result::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ String?
Card function type in the Visionline access system.
-
#card_id ⇒ String?
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
485 486 487 |
# File 'lib/seam/resources/action_attempt.rb', line 485 def auto_join @auto_join end |
#card_function_type ⇒ String?
Card function type in the Visionline access system. Known values:
gueststaff
491 492 493 |
# File 'lib/seam/resources/action_attempt.rb', line 491 def card_function_type @card_function_type end |
#card_id ⇒ String?
ID of the card in the Visionline access system.
494 495 496 |
# File 'lib/seam/resources/action_attempt.rb', line 494 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
497 498 499 |
# File 'lib/seam/resources/action_attempt.rb', line 497 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
500 501 502 |
# File 'lib/seam/resources/action_attempt.rb', line 500 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
503 504 505 |
# File 'lib/seam/resources/action_attempt.rb', line 503 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
506 507 508 |
# File 'lib/seam/resources/action_attempt.rb', line 506 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
509 510 511 |
# File 'lib/seam/resources/action_attempt.rb', line 509 def joiner_acs_credential_ids @joiner_acs_credential_ids end |