Class: Seam::Resources::ActionAttempt::PushThermostatPrograms
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::PushThermostatPrograms
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Pushing thermostat weekly programs is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of pushing thermostat programs.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1316 1317 1318 |
# File 'lib/seam/resources/action_attempt.rb', line 1316 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of pushing thermostat programs. Known values:
PUSH_THERMOSTAT_PROGRAMS
1321 1322 1323 |
# File 'lib/seam/resources/action_attempt.rb', line 1321 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1327 1328 1329 |
# File 'lib/seam/resources/action_attempt.rb', line 1327 def status @status end |