Class: Seam::Resources::ActionAttempt::Result
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AcsCredentialOnEncoder, AcsCredentialOnSeam, AkilesMetadata, AssaAbloyVostioMetadata, Errors, PendingMutations, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
- #access_code ⇒ Hash?
-
#access_method ⇒ String
Access method for the credential.
-
#access_method_id ⇒ String
ID of the access method.
-
#acs_credential_id ⇒ String
ID of the credential.
-
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ String?
Number of the card associated with the credential.
-
#client_session_token ⇒ String?
Token of the client session associated with the access method.
- #code ⇒ String?
-
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
-
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
- #display_name ⇒ String
-
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ String?
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
-
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
- #is_issued ⇒ Boolean?
-
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
-
#is_managed ⇒ Boolean
Indicates whether Seam manages the credential.
-
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once.
-
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ String
Access method mode.
- #noise_threshold ⇒ Hash
-
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
-
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
- #was_confirmed_by_device ⇒ Boolean?
- #workspace_id ⇒ String
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#acs_credential_on_encoder ⇒ AcsCredentialOnEncoder?
Snapshot of credential data read from the physical encoder.
-
#acs_credential_on_seam ⇒ AcsCredentialOnSeam?
Corresponding credential data as stored on Seam and the access system.
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
- #created_at ⇒ Time
- #errors ⇒ Array<Errors>
- #issued_at ⇒ Time?
-
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
-
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
- #warnings ⇒ Array<Warnings>
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_code ⇒ Hash?
395 396 397 |
# File 'lib/seam/resources/action_attempt.rb', line 395 def access_code @access_code end |
#access_method ⇒ String
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
398 399 400 |
# File 'lib/seam/resources/action_attempt.rb', line 398 def access_method @access_method end |
#access_method_id ⇒ String
ID of the access method.
401 402 403 |
# File 'lib/seam/resources/action_attempt.rb', line 401 def access_method_id @access_method_id end |
#acs_credential_id ⇒ String
ID of the credential.
404 405 406 |
# File 'lib/seam/resources/action_attempt.rb', line 404 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
407 408 409 |
# File 'lib/seam/resources/action_attempt.rb', line 407 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
410 411 412 |
# File 'lib/seam/resources/action_attempt.rb', line 410 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
413 414 415 |
# File 'lib/seam/resources/action_attempt.rb', line 413 def acs_user_id @acs_user_id end |
#card_number ⇒ String?
Number of the card associated with the credential.
416 417 418 |
# File 'lib/seam/resources/action_attempt.rb', line 416 def card_number @card_number end |
#client_session_token ⇒ String?
Token of the client session associated with the access method.
419 420 421 |
# File 'lib/seam/resources/action_attempt.rb', line 419 def client_session_token @client_session_token end |
#code ⇒ String?
421 422 423 |
# File 'lib/seam/resources/action_attempt.rb', line 421 def code @code end |
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
424 425 426 |
# File 'lib/seam/resources/action_attempt.rb', line 424 def connected_account_id @connected_account_id end |
#customization_profile_id ⇒ String?
ID of the customization profile associated with the access method.
427 428 429 |
# File 'lib/seam/resources/action_attempt.rb', line 427 def customization_profile_id @customization_profile_id end |
#display_name ⇒ String
429 430 431 |
# File 'lib/seam/resources/action_attempt.rb', line 429 def display_name @display_name end |
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
432 433 434 |
# File 'lib/seam/resources/action_attempt.rb', line 432 def ends_at @ends_at end |
#external_type ⇒ String?
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
435 436 437 |
# File 'lib/seam/resources/action_attempt.rb', line 435 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
438 439 440 |
# File 'lib/seam/resources/action_attempt.rb', line 438 def external_type_display_name @external_type_display_name end |
#instant_key_url ⇒ String?
URL of the Instant Key for mobile key access methods.
441 442 443 |
# File 'lib/seam/resources/action_attempt.rb', line 441 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
444 445 446 |
# File 'lib/seam/resources/action_attempt.rb', line 444 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
447 448 449 |
# File 'lib/seam/resources/action_attempt.rb', line 447 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Boolean?
449 450 451 |
# File 'lib/seam/resources/action_attempt.rb', line 449 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
452 453 454 |
# File 'lib/seam/resources/action_attempt.rb', line 452 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ Boolean
Indicates whether Seam manages the credential.
455 456 457 |
# File 'lib/seam/resources/action_attempt.rb', line 455 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
458 459 460 |
# File 'lib/seam/resources/action_attempt.rb', line 458 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
461 462 463 |
# File 'lib/seam/resources/action_attempt.rb', line 461 def is_one_time_use @is_one_time_use end |
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
464 465 466 |
# File 'lib/seam/resources/action_attempt.rb', line 464 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
467 468 469 |
# File 'lib/seam/resources/action_attempt.rb', line 467 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
470 471 472 |
# File 'lib/seam/resources/action_attempt.rb', line 470 def mode @mode end |
#noise_threshold ⇒ Hash
472 473 474 |
# File 'lib/seam/resources/action_attempt.rb', line 472 def noise_threshold @noise_threshold end |
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
475 476 477 |
# File 'lib/seam/resources/action_attempt.rb', line 475 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
478 479 480 |
# File 'lib/seam/resources/action_attempt.rb', line 478 def starts_at @starts_at end |
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
481 482 483 |
# File 'lib/seam/resources/action_attempt.rb', line 481 def user_identity_id @user_identity_id end |
#was_confirmed_by_device ⇒ Boolean?
483 484 485 |
# File 'lib/seam/resources/action_attempt.rb', line 483 def was_confirmed_by_device @was_confirmed_by_device end |
#workspace_id ⇒ String
485 486 487 |
# File 'lib/seam/resources/action_attempt.rb', line 485 def workspace_id @workspace_id end |
Instance Method Details
#acs_credential_on_encoder ⇒ AcsCredentialOnEncoder?
Snapshot of credential data read from the physical encoder.
374 |
# File 'lib/seam/resources/action_attempt.rb', line 374 resource_accessor :acs_credential_on_encoder, AcsCredentialOnEncoder |
#acs_credential_on_seam ⇒ AcsCredentialOnSeam?
Corresponding credential data as stored on Seam and the access system.
377 |
# File 'lib/seam/resources/action_attempt.rb', line 377 resource_accessor :acs_credential_on_seam, AcsCredentialOnSeam |
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
380 |
# File 'lib/seam/resources/action_attempt.rb', line 380 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
383 |
# File 'lib/seam/resources/action_attempt.rb', line 383 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#created_at ⇒ Time
487 |
# File 'lib/seam/resources/action_attempt.rb', line 487 date_accessor :created_at |
#errors ⇒ Array<Errors>
388 |
# File 'lib/seam/resources/action_attempt.rb', line 388 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
489 |
# File 'lib/seam/resources/action_attempt.rb', line 489 date_accessor :issued_at |
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
492 |
# File 'lib/seam/resources/action_attempt.rb', line 492 date_accessor :latest_desired_state_synced_with_provider_at |
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method. Indicates operations that are in progress.
391 |
# File 'lib/seam/resources/action_attempt.rb', line 391 resource_list_accessor :pending_mutations, PendingMutations |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
386 |
# File 'lib/seam/resources/action_attempt.rb', line 386 resource_accessor :visionline_metadata, VisionlineMetadata |