Class: Seam::Resources::ActionAttempt::Result
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AcsCredentialOnEncoder, AcsCredentialOnSeam, AssaAbloyVostioMetadata, Errors, PendingMutations, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ Object
Access method for the credential.
-
#access_method_id ⇒ Object
ID of the access method.
-
#acs_credential_id ⇒ Object
ID of the credential.
-
#acs_credential_pool_id ⇒ Object
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ Object
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ Object
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ Object
Number of the card associated with the credential.
-
#client_session_token ⇒ Object
Token of the client session associated with the access method.
-
#code ⇒ Object
Returns the value of attribute code.
-
#connected_account_id ⇒ Object
ID of the connected account to which the credential belongs.
-
#customization_profile_id ⇒ Object
ID of the customization profile associated with the access method.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#ends_at ⇒ Object
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ Object
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the credential type.
-
#instant_key_url ⇒ Object
URL of the Instant Key for mobile key access methods.
-
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Object
Returns the value of attribute is_issued.
-
#is_latest_desired_state_synced_with_provider ⇒ Object
Indicates whether the latest state of the credential has been synced from Seam to the provider.
-
#is_managed ⇒ Object
Indicates whether Seam manages the credential.
-
#is_multi_phone_sync_credential ⇒ Object
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Object
Indicates whether the credential can only be used once.
-
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ Object
Access method mode.
-
#parent_acs_credential_id ⇒ Object
ID of the parent credential.
-
#starts_at ⇒ Object
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ Object
ID of the user identity to whom the credential belongs.
-
#was_confirmed_by_device ⇒ Object
Returns the value of attribute was_confirmed_by_device.
-
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ Object
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
247 248 249 |
# File 'lib/seam/resources/action_attempt.rb', line 247 def access_method @access_method end |
#access_method_id ⇒ Object
ID of the access method.
249 250 251 |
# File 'lib/seam/resources/action_attempt.rb', line 249 def access_method_id @access_method_id end |
#acs_credential_id ⇒ Object
ID of the credential.
251 252 253 |
# File 'lib/seam/resources/action_attempt.rb', line 251 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ Object
ID of the credential pool to which the credential belongs.
253 254 255 |
# File 'lib/seam/resources/action_attempt.rb', line 253 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ Object
ID of the access control system that contains the credential.
255 256 257 |
# File 'lib/seam/resources/action_attempt.rb', line 255 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ Object
ID of the ACS user to whom the credential belongs.
257 258 259 |
# File 'lib/seam/resources/action_attempt.rb', line 257 def acs_user_id @acs_user_id end |
#card_number ⇒ Object
Number of the card associated with the credential.
259 260 261 |
# File 'lib/seam/resources/action_attempt.rb', line 259 def card_number @card_number end |
#client_session_token ⇒ Object
Token of the client session associated with the access method.
261 262 263 |
# File 'lib/seam/resources/action_attempt.rb', line 261 def client_session_token @client_session_token end |
#code ⇒ Object
Returns the value of attribute code.
262 263 264 |
# File 'lib/seam/resources/action_attempt.rb', line 262 def code @code end |
#connected_account_id ⇒ Object
ID of the connected account to which the credential belongs.
264 265 266 |
# File 'lib/seam/resources/action_attempt.rb', line 264 def connected_account_id @connected_account_id end |
#customization_profile_id ⇒ Object
ID of the customization profile associated with the access method.
266 267 268 |
# File 'lib/seam/resources/action_attempt.rb', line 266 def customization_profile_id @customization_profile_id end |
#display_name ⇒ Object
Returns the value of attribute display_name.
267 268 269 |
# File 'lib/seam/resources/action_attempt.rb', line 267 def display_name @display_name end |
#ends_at ⇒ Object
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
269 270 271 |
# File 'lib/seam/resources/action_attempt.rb', line 269 def ends_at @ends_at end |
#external_type ⇒ Object
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
271 272 273 |
# File 'lib/seam/resources/action_attempt.rb', line 271 def external_type @external_type end |
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the credential type.
273 274 275 |
# File 'lib/seam/resources/action_attempt.rb', line 273 def external_type_display_name @external_type_display_name end |
#instant_key_url ⇒ Object
URL of the Instant Key for mobile key access methods.
275 276 277 |
# File 'lib/seam/resources/action_attempt.rb', line 275 def instant_key_url @instant_key_url end |
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
277 278 279 |
# File 'lib/seam/resources/action_attempt.rb', line 277 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
279 280 281 |
# File 'lib/seam/resources/action_attempt.rb', line 279 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Object
Returns the value of attribute is_issued.
280 281 282 |
# File 'lib/seam/resources/action_attempt.rb', line 280 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Object
Indicates whether the latest state of the credential has been synced from Seam to the provider.
282 283 284 |
# File 'lib/seam/resources/action_attempt.rb', line 282 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ Object
Indicates whether Seam manages the credential.
284 285 286 |
# File 'lib/seam/resources/action_attempt.rb', line 284 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Object
Indicates whether the credential is a multi-phone sync credential.
286 287 288 |
# File 'lib/seam/resources/action_attempt.rb', line 286 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Object
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
288 289 290 |
# File 'lib/seam/resources/action_attempt.rb', line 288 def is_one_time_use @is_one_time_use end |
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
290 291 292 |
# File 'lib/seam/resources/action_attempt.rb', line 290 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
292 293 294 |
# File 'lib/seam/resources/action_attempt.rb', line 292 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ Object
Access method mode. Supported values: code, card, mobile_key, cloud_key.
294 295 296 |
# File 'lib/seam/resources/action_attempt.rb', line 294 def mode @mode end |
#parent_acs_credential_id ⇒ Object
ID of the parent credential.
296 297 298 |
# File 'lib/seam/resources/action_attempt.rb', line 296 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ Object
Date and time at which the credential validity starts, in ISO 8601 format.
298 299 300 |
# File 'lib/seam/resources/action_attempt.rb', line 298 def starts_at @starts_at end |
#user_identity_id ⇒ Object
ID of the user identity to whom the credential belongs.
300 301 302 |
# File 'lib/seam/resources/action_attempt.rb', line 300 def user_identity_id @user_identity_id end |
#was_confirmed_by_device ⇒ Object
Returns the value of attribute was_confirmed_by_device.
301 302 303 |
# File 'lib/seam/resources/action_attempt.rb', line 301 def was_confirmed_by_device @was_confirmed_by_device end |
#workspace_id ⇒ Object
Returns the value of attribute workspace_id.
302 303 304 |
# File 'lib/seam/resources/action_attempt.rb', line 302 def workspace_id @workspace_id end |