Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: VisionlineMetadata
Instance Attribute Summary collapse
-
#card_number ⇒ Object
A number or string that physically identifies the card associated with the credential.
-
#is_issued ⇒ Object
Indicates whether the credential has been issued (encoded onto a card).
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#card_number ⇒ Object
A number or string that physically identifies the card associated with the credential.
44 45 46 |
# File 'lib/seam/resources/action_attempt.rb', line 44 def card_number @card_number end |
#is_issued ⇒ Object
Indicates whether the credential has been issued (encoded onto a card).
46 47 48 |
# File 'lib/seam/resources/action_attempt.rb', line 46 def is_issued @is_issued end |