Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#cancelled ⇒ Object
Indicates whether the card associated with the credential is cancelled.
-
#card_format ⇒ Object
Format of the card associated with the credential.
-
#card_holder ⇒ Object
Holder of the card associated with the credential.
-
#card_id ⇒ Object
Card ID for the Visionline card associated with the credential.
-
#common_acs_entrance_ids ⇒ Object
IDs of the common entrances for the credential.
-
#discarded ⇒ Object
Indicates whether the card associated with the credential is discarded.
-
#expired ⇒ Object
Indicates whether the card associated with the credential is expired.
-
#guest_acs_entrance_ids ⇒ Object
IDs of the guest entrances for the credential.
-
#number_of_issued_cards ⇒ Object
Number of issued cards associated with the credential.
-
#overridden ⇒ Object
Indicates whether the card associated with the credential is overridden.
-
#overwritten ⇒ Object
Indicates whether the card associated with the credential is overwritten.
-
#pending_auto_update ⇒ Object
Indicates whether the card associated with the credential is pending auto-update.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#cancelled ⇒ Object
Indicates whether the card associated with the credential is cancelled.
17 18 19 |
# File 'lib/seam/resources/action_attempt.rb', line 17 def cancelled @cancelled end |
#card_format ⇒ Object
Format of the card associated with the credential.
19 20 21 |
# File 'lib/seam/resources/action_attempt.rb', line 19 def card_format @card_format end |
#card_holder ⇒ Object
Holder of the card associated with the credential.
21 22 23 |
# File 'lib/seam/resources/action_attempt.rb', line 21 def card_holder @card_holder end |
#card_id ⇒ Object
Card ID for the Visionline card associated with the credential.
23 24 25 |
# File 'lib/seam/resources/action_attempt.rb', line 23 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Object
IDs of the common entrances for the credential.
25 26 27 |
# File 'lib/seam/resources/action_attempt.rb', line 25 def common_acs_entrance_ids @common_acs_entrance_ids end |
#discarded ⇒ Object
Indicates whether the card associated with the credential is discarded.
27 28 29 |
# File 'lib/seam/resources/action_attempt.rb', line 27 def discarded @discarded end |
#expired ⇒ Object
Indicates whether the card associated with the credential is expired.
29 30 31 |
# File 'lib/seam/resources/action_attempt.rb', line 29 def expired @expired end |
#guest_acs_entrance_ids ⇒ Object
IDs of the guest entrances for the credential.
31 32 33 |
# File 'lib/seam/resources/action_attempt.rb', line 31 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#number_of_issued_cards ⇒ Object
Number of issued cards associated with the credential.
33 34 35 |
# File 'lib/seam/resources/action_attempt.rb', line 33 def number_of_issued_cards @number_of_issued_cards end |
#overridden ⇒ Object
Indicates whether the card associated with the credential is overridden.
35 36 37 |
# File 'lib/seam/resources/action_attempt.rb', line 35 def overridden @overridden end |
#overwritten ⇒ Object
Indicates whether the card associated with the credential is overwritten.
37 38 39 |
# File 'lib/seam/resources/action_attempt.rb', line 37 def overwritten @overwritten end |
#pending_auto_update ⇒ Object
Indicates whether the card associated with the credential is pending auto-update.
39 40 41 |
# File 'lib/seam/resources/action_attempt.rb', line 39 def pending_auto_update @pending_auto_update end |