Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnEncoder::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#cancelledObject

Indicates whether the card associated with the credential is cancelled.



17
18
19
# File 'lib/seam/resources/action_attempt.rb', line 17

def cancelled
  @cancelled
end

#card_formatObject

Format of the card associated with the credential.



19
20
21
# File 'lib/seam/resources/action_attempt.rb', line 19

def card_format
  @card_format
end

#card_holderObject

Holder of the card associated with the credential.



21
22
23
# File 'lib/seam/resources/action_attempt.rb', line 21

def card_holder
  @card_holder
end

#card_idObject

Card ID for the Visionline card associated with the credential.



23
24
25
# File 'lib/seam/resources/action_attempt.rb', line 23

def card_id
  @card_id
end

#common_acs_entrance_idsObject

IDs of the common entrances for the credential.



25
26
27
# File 'lib/seam/resources/action_attempt.rb', line 25

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#discardedObject

Indicates whether the card associated with the credential is discarded.



27
28
29
# File 'lib/seam/resources/action_attempt.rb', line 27

def discarded
  @discarded
end

#expiredObject

Indicates whether the card associated with the credential is expired.



29
30
31
# File 'lib/seam/resources/action_attempt.rb', line 29

def expired
  @expired
end

#guest_acs_entrance_idsObject

IDs of the guest entrances for the credential.



31
32
33
# File 'lib/seam/resources/action_attempt.rb', line 31

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#number_of_issued_cardsObject

Number of issued cards associated with the credential.



33
34
35
# File 'lib/seam/resources/action_attempt.rb', line 33

def number_of_issued_cards
  @number_of_issued_cards
end

#overriddenObject

Indicates whether the card associated with the credential is overridden.



35
36
37
# File 'lib/seam/resources/action_attempt.rb', line 35

def overridden
  @overridden
end

#overwrittenObject

Indicates whether the card associated with the credential is overwritten.



37
38
39
# File 'lib/seam/resources/action_attempt.rb', line 37

def overwritten
  @overwritten
end

#pending_auto_updateObject

Indicates whether the card associated with the credential is pending auto-update.



39
40
41
# File 'lib/seam/resources/action_attempt.rb', line 39

def pending_auto_update
  @pending_auto_update
end