Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ String
Access method for the credential.
-
#acs_credential_id ⇒ String
ID of the credential.
-
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ String?
Number of the card associated with the credential.
-
#code ⇒ String?
Access (PIN) code for the credential.
-
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
-
#display_name ⇒ String
Display name that corresponds to the credential type.
-
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ String?
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
-
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
-
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
- #is_managed ⇒ Boolean
-
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once.
-
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
-
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
-
#workspace_id ⇒ String
ID of the workspace that contains the credential.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
-
#created_at ⇒ Time
Date and time at which the credential was created.
-
#errors ⇒ Array<Errors>
Errors associated with the credential.
-
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
-
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ String
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
176 177 178 |
# File 'lib/seam/resources/action_attempt.rb', line 176 def access_method @access_method end |
#acs_credential_id ⇒ String
ID of the credential.
179 180 181 |
# File 'lib/seam/resources/action_attempt.rb', line 179 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
182 183 184 |
# File 'lib/seam/resources/action_attempt.rb', line 182 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
185 186 187 |
# File 'lib/seam/resources/action_attempt.rb', line 185 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
188 189 190 |
# File 'lib/seam/resources/action_attempt.rb', line 188 def acs_user_id @acs_user_id end |
#card_number ⇒ String?
Number of the card associated with the credential.
191 192 193 |
# File 'lib/seam/resources/action_attempt.rb', line 191 def card_number @card_number end |
#code ⇒ String?
Access (PIN) code for the credential.
194 195 196 |
# File 'lib/seam/resources/action_attempt.rb', line 194 def code @code end |
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
197 198 199 |
# File 'lib/seam/resources/action_attempt.rb', line 197 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name that corresponds to the credential type.
200 201 202 |
# File 'lib/seam/resources/action_attempt.rb', line 200 def display_name @display_name end |
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
203 204 205 |
# File 'lib/seam/resources/action_attempt.rb', line 203 def ends_at @ends_at end |
#external_type ⇒ String?
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
206 207 208 |
# File 'lib/seam/resources/action_attempt.rb', line 206 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
209 210 211 |
# File 'lib/seam/resources/action_attempt.rb', line 209 def external_type_display_name @external_type_display_name end |
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
212 213 214 |
# File 'lib/seam/resources/action_attempt.rb', line 212 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
215 216 217 |
# File 'lib/seam/resources/action_attempt.rb', line 215 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ Boolean
217 218 219 |
# File 'lib/seam/resources/action_attempt.rb', line 217 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
220 221 222 |
# File 'lib/seam/resources/action_attempt.rb', line 220 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
223 224 225 |
# File 'lib/seam/resources/action_attempt.rb', line 223 def is_one_time_use @is_one_time_use end |
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
226 227 228 |
# File 'lib/seam/resources/action_attempt.rb', line 226 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
229 230 231 |
# File 'lib/seam/resources/action_attempt.rb', line 229 def starts_at @starts_at end |
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
232 233 234 |
# File 'lib/seam/resources/action_attempt.rb', line 232 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the credential.
235 236 237 |
# File 'lib/seam/resources/action_attempt.rb', line 235 def workspace_id @workspace_id end |
Instance Method Details
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
161 |
# File 'lib/seam/resources/action_attempt.rb', line 161 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
164 |
# File 'lib/seam/resources/action_attempt.rb', line 164 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#created_at ⇒ Time
Date and time at which the credential was created.
238 |
# File 'lib/seam/resources/action_attempt.rb', line 238 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the credential.
170 |
# File 'lib/seam/resources/action_attempt.rb', line 170 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
241 |
# File 'lib/seam/resources/action_attempt.rb', line 241 date_accessor :issued_at |
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
244 |
# File 'lib/seam/resources/action_attempt.rb', line 244 date_accessor :latest_desired_state_synced_with_provider_at |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
167 |
# File 'lib/seam/resources/action_attempt.rb', line 167 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
173 |
# File 'lib/seam/resources/action_attempt.rb', line 173 resource_list_accessor :warnings, Warnings |