Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ Object
Access method for the credential.
-
#acs_credential_id ⇒ Object
ID of the credential.
-
#acs_credential_pool_id ⇒ Object
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ Object
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ Object
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ Object
Number of the card associated with the credential.
-
#code ⇒ Object
Access (PIN) code for the credential.
-
#connected_account_id ⇒ Object
ID of the connected account to which the credential belongs.
-
#display_name ⇒ Object
Display name that corresponds to the credential type.
-
#ends_at ⇒ Object
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ Object
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the credential type.
-
#is_issued ⇒ Object
Indicates whether the credential has been encoded onto a card.
-
#is_latest_desired_state_synced_with_provider ⇒ Object
Indicates whether the latest state of the credential has been synced from Seam to the provider.
-
#is_managed ⇒ Object
Returns the value of attribute is_managed.
-
#is_multi_phone_sync_credential ⇒ Object
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Object
Indicates whether the credential can only be used once.
-
#parent_acs_credential_id ⇒ Object
ID of the parent credential.
-
#starts_at ⇒ Object
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ Object
ID of the user identity to whom the credential belongs.
-
#workspace_id ⇒ Object
ID of the workspace that contains the credential.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ Object
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
111 112 113 |
# File 'lib/seam/resources/action_attempt.rb', line 111 def access_method @access_method end |
#acs_credential_id ⇒ Object
ID of the credential.
113 114 115 |
# File 'lib/seam/resources/action_attempt.rb', line 113 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ Object
ID of the credential pool to which the credential belongs.
115 116 117 |
# File 'lib/seam/resources/action_attempt.rb', line 115 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ Object
ID of the access control system that contains the credential.
117 118 119 |
# File 'lib/seam/resources/action_attempt.rb', line 117 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ Object
ID of the ACS user to whom the credential belongs.
119 120 121 |
# File 'lib/seam/resources/action_attempt.rb', line 119 def acs_user_id @acs_user_id end |
#card_number ⇒ Object
Number of the card associated with the credential.
121 122 123 |
# File 'lib/seam/resources/action_attempt.rb', line 121 def card_number @card_number end |
#code ⇒ Object
Access (PIN) code for the credential.
123 124 125 |
# File 'lib/seam/resources/action_attempt.rb', line 123 def code @code end |
#connected_account_id ⇒ Object
ID of the connected account to which the credential belongs.
125 126 127 |
# File 'lib/seam/resources/action_attempt.rb', line 125 def connected_account_id @connected_account_id end |
#display_name ⇒ Object
Display name that corresponds to the credential type.
127 128 129 |
# File 'lib/seam/resources/action_attempt.rb', line 127 def display_name @display_name end |
#ends_at ⇒ Object
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
129 130 131 |
# File 'lib/seam/resources/action_attempt.rb', line 129 def ends_at @ends_at end |
#external_type ⇒ Object
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
131 132 133 |
# File 'lib/seam/resources/action_attempt.rb', line 131 def external_type @external_type end |
#external_type_display_name ⇒ Object
Display name that corresponds to the brand-specific terminology for the credential type.
133 134 135 |
# File 'lib/seam/resources/action_attempt.rb', line 133 def external_type_display_name @external_type_display_name end |
#is_issued ⇒ Object
Indicates whether the credential has been encoded onto a card.
135 136 137 |
# File 'lib/seam/resources/action_attempt.rb', line 135 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Object
Indicates whether the latest state of the credential has been synced from Seam to the provider.
137 138 139 |
# File 'lib/seam/resources/action_attempt.rb', line 137 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ Object
Returns the value of attribute is_managed.
138 139 140 |
# File 'lib/seam/resources/action_attempt.rb', line 138 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Object
Indicates whether the credential is a multi-phone sync credential.
140 141 142 |
# File 'lib/seam/resources/action_attempt.rb', line 140 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Object
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
142 143 144 |
# File 'lib/seam/resources/action_attempt.rb', line 142 def is_one_time_use @is_one_time_use end |
#parent_acs_credential_id ⇒ Object
ID of the parent credential.
144 145 146 |
# File 'lib/seam/resources/action_attempt.rb', line 144 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ Object
Date and time at which the credential validity starts, in ISO 8601 format.
146 147 148 |
# File 'lib/seam/resources/action_attempt.rb', line 146 def starts_at @starts_at end |
#user_identity_id ⇒ Object
ID of the user identity to whom the credential belongs.
148 149 150 |
# File 'lib/seam/resources/action_attempt.rb', line 148 def user_identity_id @user_identity_id end |
#workspace_id ⇒ Object
ID of the workspace that contains the credential.
150 151 152 |
# File 'lib/seam/resources/action_attempt.rb', line 150 def workspace_id @workspace_id end |