Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam::AssaAbloyVostioMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam::AssaAbloyVostioMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join.
-
#door_names ⇒ Array<String>
Names of the doors to which to grant access in the Vostio access system.
-
#endpoint_id ⇒ String?
Endpoint ID in the Vostio access system.
-
#key_id ⇒ String?
Key ID in the Vostio access system.
-
#key_issuing_request_id ⇒ String?
Key issuing request ID in the Vostio access system.
-
#override_guest_acs_entrance_ids ⇒ Array<String>
IDs of the guest entrances to override in the Vostio access system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
86 87 88 |
# File 'lib/seam/resources/action_attempt.rb', line 86 def auto_join @auto_join end |
#door_names ⇒ Array<String>
Names of the doors to which to grant access in the Vostio access system.
89 90 91 |
# File 'lib/seam/resources/action_attempt.rb', line 89 def door_names @door_names end |
#endpoint_id ⇒ String?
Endpoint ID in the Vostio access system.
92 93 94 |
# File 'lib/seam/resources/action_attempt.rb', line 92 def endpoint_id @endpoint_id end |
#key_id ⇒ String?
Key ID in the Vostio access system.
95 96 97 |
# File 'lib/seam/resources/action_attempt.rb', line 95 def key_id @key_id end |
#key_issuing_request_id ⇒ String?
Key issuing request ID in the Vostio access system.
98 99 100 |
# File 'lib/seam/resources/action_attempt.rb', line 98 def key_issuing_request_id @key_issuing_request_id end |
#override_guest_acs_entrance_ids ⇒ Array<String>
IDs of the guest entrances to override in the Vostio access system.
101 102 103 |
# File 'lib/seam/resources/action_attempt.rb', line 101 def override_guest_acs_entrance_ids @override_guest_acs_entrance_ids end |