Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam::AssaAbloyVostioMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinObject

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.



58
59
60
# File 'lib/seam/resources/action_attempt.rb', line 58

def auto_join
  @auto_join
end

#door_namesObject

Names of the doors to which to grant access in the Vostio access system.



60
61
62
# File 'lib/seam/resources/action_attempt.rb', line 60

def door_names
  @door_names
end

#endpoint_idObject

Endpoint ID in the Vostio access system.



62
63
64
# File 'lib/seam/resources/action_attempt.rb', line 62

def endpoint_id
  @endpoint_id
end

#key_idObject

Key ID in the Vostio access system.



64
65
66
# File 'lib/seam/resources/action_attempt.rb', line 64

def key_id
  @key_id
end

#key_issuing_request_idObject

Key issuing request ID in the Vostio access system.



66
67
68
# File 'lib/seam/resources/action_attempt.rb', line 66

def key_issuing_request_id
  @key_issuing_request_id
end

#override_guest_acs_entrance_idsObject

IDs of the guest entrances to override in the Vostio access system.



68
69
70
# File 'lib/seam/resources/action_attempt.rb', line 68

def override_guest_acs_entrance_ids
  @override_guest_acs_entrance_ids
end