Class: Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::AcsCredentialOnSeam::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Object
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ Object
Card function type in the Visionline access system.
-
#card_id ⇒ Object
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Object
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ Object
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Object
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Object
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Object
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Object
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
80 81 82 |
# File 'lib/seam/resources/action_attempt.rb', line 80 def auto_join @auto_join end |
#card_function_type ⇒ Object
Card function type in the Visionline access system.
82 83 84 |
# File 'lib/seam/resources/action_attempt.rb', line 82 def card_function_type @card_function_type end |
#card_id ⇒ Object
ID of the card in the Visionline access system.
84 85 86 |
# File 'lib/seam/resources/action_attempt.rb', line 84 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Object
Common entrance IDs in the Visionline access system.
86 87 88 |
# File 'lib/seam/resources/action_attempt.rb', line 86 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ Object
ID of the credential in the Visionline access system.
88 89 90 |
# File 'lib/seam/resources/action_attempt.rb', line 88 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Object
Guest entrance IDs in the Visionline access system.
90 91 92 |
# File 'lib/seam/resources/action_attempt.rb', line 90 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Object
Indicates whether the credential is valid.
92 93 94 |
# File 'lib/seam/resources/action_attempt.rb', line 92 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Object
IDs of the credentials to which you want to join.
94 95 96 |
# File 'lib/seam/resources/action_attempt.rb', line 94 def joiner_acs_credential_ids @joiner_acs_credential_ids end |