Class: Seam::Resources::ActionAttempt::Result::AssaAbloyVostioMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinObject

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.



161
162
163
# File 'lib/seam/resources/action_attempt.rb', line 161

def auto_join
  @auto_join
end

#door_namesObject

Names of the doors to which to grant access in the Vostio access system.



163
164
165
# File 'lib/seam/resources/action_attempt.rb', line 163

def door_names
  @door_names
end

#endpoint_idObject

Endpoint ID in the Vostio access system.



165
166
167
# File 'lib/seam/resources/action_attempt.rb', line 165

def endpoint_id
  @endpoint_id
end

#key_idObject

Key ID in the Vostio access system.



167
168
169
# File 'lib/seam/resources/action_attempt.rb', line 167

def key_id
  @key_id
end

#key_issuing_request_idObject

Key issuing request ID in the Vostio access system.



169
170
171
# File 'lib/seam/resources/action_attempt.rb', line 169

def key_issuing_request_id
  @key_issuing_request_id
end

#override_guest_acs_entrance_idsObject

IDs of the guest entrances to override in the Vostio access system.



171
172
173
# File 'lib/seam/resources/action_attempt.rb', line 171

def override_guest_acs_entrance_ids
  @override_guest_acs_entrance_ids
end