Class: Seam::Resources::ActionAttempt::Result::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::PendingMutations
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the mutation.
-
#mutation_code ⇒ String
Mutation code to indicate that Seam is in the process of updating the access times for this access method.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the mutation was created.
-
#from ⇒ From
Previous access time configuration.
-
#to ⇒ To
New access time configuration.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the mutation.
313 314 315 |
# File 'lib/seam/resources/action_attempt.rb', line 313 def @message end |
#mutation_code ⇒ String
Mutation code to indicate that Seam is in the process of updating the access times for this access method.
316 317 318 |
# File 'lib/seam/resources/action_attempt.rb', line 316 def mutation_code @mutation_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the mutation was created.
319 |
# File 'lib/seam/resources/action_attempt.rb', line 319 date_accessor :created_at |