Class: Seam::Resources::ActionAttempt::Result::PendingMutations
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::PendingMutations
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#message ⇒ Object
Detailed description of the mutation.
-
#mutation_code ⇒ Object
Mutation code to indicate that Seam is in the process of updating the access times for this access method.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ Object
Detailed description of the mutation.
201 202 203 |
# File 'lib/seam/resources/action_attempt.rb', line 201 def @message end |
#mutation_code ⇒ Object
Mutation code to indicate that Seam is in the process of updating the access times for this access method.
203 204 205 |
# File 'lib/seam/resources/action_attempt.rb', line 203 def mutation_code @mutation_code end |