Class: Seam::Resources::ActionAttempt::Result::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Object
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ Object
Card function type in the Visionline access system.
-
#card_id ⇒ Object
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Object
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ Object
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Object
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Object
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Object
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Object
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
210 211 212 |
# File 'lib/seam/resources/action_attempt.rb', line 210 def auto_join @auto_join end |
#card_function_type ⇒ Object
Card function type in the Visionline access system.
212 213 214 |
# File 'lib/seam/resources/action_attempt.rb', line 212 def card_function_type @card_function_type end |
#card_id ⇒ Object
ID of the card in the Visionline access system.
214 215 216 |
# File 'lib/seam/resources/action_attempt.rb', line 214 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Object
Common entrance IDs in the Visionline access system.
216 217 218 |
# File 'lib/seam/resources/action_attempt.rb', line 216 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ Object
ID of the credential in the Visionline access system.
218 219 220 |
# File 'lib/seam/resources/action_attempt.rb', line 218 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Object
Guest entrance IDs in the Visionline access system.
220 221 222 |
# File 'lib/seam/resources/action_attempt.rb', line 220 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Object
Indicates whether the credential is valid.
222 223 224 |
# File 'lib/seam/resources/action_attempt.rb', line 222 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Object
IDs of the credentials to which you want to join.
224 225 226 |
# File 'lib/seam/resources/action_attempt.rb', line 224 def joiner_acs_credential_ids @joiner_acs_credential_ids end |