Class: Seam::Resources::ActionAttempt::Result::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::Result::Warnings
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#new_code ⇒ String?
The PIN code that was assigned instead.
-
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
-
#original_code ⇒ String?
The originally requested PIN code that could not be used.
- #warning_code ⇒ String
-
#warning_message ⇒ String
Detailed description of the warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
352 353 354 |
# File 'lib/seam/resources/action_attempt.rb', line 352 def @message end |
#new_code ⇒ String?
The PIN code that was assigned instead.
355 356 357 |
# File 'lib/seam/resources/action_attempt.rb', line 355 def new_code @new_code end |
#original_access_method_id ⇒ String?
ID of the original access method from which this backup access method was split, if applicable.
358 359 360 |
# File 'lib/seam/resources/action_attempt.rb', line 358 def original_access_method_id @original_access_method_id end |
#original_code ⇒ String?
The originally requested PIN code that could not be used.
361 362 363 |
# File 'lib/seam/resources/action_attempt.rb', line 361 def original_code @original_code end |
#warning_code ⇒ String
363 364 365 |
# File 'lib/seam/resources/action_attempt.rb', line 363 def warning_code @warning_code end |
#warning_message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
366 367 368 |
# File 'lib/seam/resources/action_attempt.rb', line 366 def @warning_message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
369 |
# File 'lib/seam/resources/action_attempt.rb', line 369 date_accessor :created_at |