Class: Seam::Resources::ActionAttempt::Result::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageObject

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.



229
230
231
# File 'lib/seam/resources/action_attempt.rb', line 229

def message
  @message
end

#original_access_method_idObject

ID of the original access method from which this backup access method was split, if applicable.



231
232
233
# File 'lib/seam/resources/action_attempt.rb', line 231

def original_access_method_id
  @original_access_method_id
end

#warning_codeObject

Returns the value of attribute warning_code.



232
233
234
# File 'lib/seam/resources/action_attempt.rb', line 232

def warning_code
  @warning_code
end

#warning_messageObject

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.



234
235
236
# File 'lib/seam/resources/action_attempt.rb', line 234

def warning_message
  @warning_message
end