Class: Seam::Resources::ActionAttempt::ScanCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Reading credential data from the physical encoder is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


408
409
410
# File 'lib/seam/resources/action_attempt.rb', line 408

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of scanning a credential. Known values:

  • SCAN_CREDENTIAL

Returns:

  • (String)


413
414
415
# File 'lib/seam/resources/action_attempt.rb', line 413

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


419
420
421
# File 'lib/seam/resources/action_attempt.rb', line 419

def status
  @status
end

Instance Method Details

#errorError?

Returns:



402
# File 'lib/seam/resources/action_attempt.rb', line 402

resource_accessor :error, Error

#resultResult?

Result of scanning a card. If the attempt was successful, includes a snapshot of credential data read from the physical encoder, the corresponding data stored on Seam and the access system, and any associated warnings.

Returns:



405
# File 'lib/seam/resources/action_attempt.rb', line 405

resource_accessor :result, Result