Class: Seam::Resources::ActionAttempt::ScanCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::ScanCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Reading credential data from the physical encoder is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of scanning a credential.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
- #error ⇒ Error?
-
#result ⇒ Result?
Result of scanning a card.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
408 409 410 |
# File 'lib/seam/resources/action_attempt.rb', line 408 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of scanning a credential. Known values:
SCAN_CREDENTIAL
413 414 415 |
# File 'lib/seam/resources/action_attempt.rb', line 413 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
419 420 421 |
# File 'lib/seam/resources/action_attempt.rb', line 419 def status @status end |
Instance Method Details
#error ⇒ Error?
402 |
# File 'lib/seam/resources/action_attempt.rb', line 402 resource_accessor :error, Error |
#result ⇒ Result?
Result of scanning a card. If the attempt was successful, includes a snapshot of credential data read from the physical encoder, the corresponding data stored on Seam and the access system, and any associated warnings.
405 |
# File 'lib/seam/resources/action_attempt.rb', line 405 resource_accessor :result, Result |