Class: Seam::Resources::ActionAttempt::ScanCredential::Error
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Error
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the error.
-
#type ⇒ String
Error type to indicate that the Seam Bridge is disconnected or cannot reach the access control system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
99 100 101 |
# File 'lib/seam/resources/action_attempt.rb', line 99 def @message end |
#type ⇒ String
Error type to indicate that the Seam Bridge is disconnected or cannot reach the access control system. Known values:
uncategorized_erroraction_attempt_expiredno_credential_on_encoderencoder_not_onlineencoder_communication_timeoutbridge_disconnected
109 110 111 |
# File 'lib/seam/resources/action_attempt.rb', line 109 def type @type end |