Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnEncoder::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnEncoder::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#cancelled ⇒ Boolean?
Indicates whether the card associated with the credential is cancelled.
-
#card_format ⇒ String?
Format of the card associated with the credential.
-
#card_holder ⇒ String?
Holder of the card associated with the credential.
-
#card_id ⇒ String?
Card ID for the Visionline card associated with the credential.
-
#common_acs_entrance_ids ⇒ Array<String>
IDs of the common entrances for the credential.
-
#discarded ⇒ Boolean?
Indicates whether the card associated with the credential is discarded.
-
#expired ⇒ Boolean?
Indicates whether the card associated with the credential is expired.
-
#guest_acs_entrance_ids ⇒ Array<String>
IDs of the guest entrances for the credential.
-
#number_of_issued_cards ⇒ Float?
Number of issued cards associated with the credential.
-
#overridden ⇒ Boolean?
Indicates whether the card associated with the credential is overridden.
-
#overwritten ⇒ Boolean?
Indicates whether the card associated with the credential is overwritten.
-
#pending_auto_update ⇒ Boolean?
Indicates whether the card associated with the credential is pending auto-update.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#cancelled ⇒ Boolean?
Indicates whether the card associated with the credential is cancelled.
125 126 127 |
# File 'lib/seam/resources/action_attempt.rb', line 125 def cancelled @cancelled end |
#card_format ⇒ String?
Format of the card associated with the credential. Known values:
TLCoderfid48
131 132 133 |
# File 'lib/seam/resources/action_attempt.rb', line 131 def card_format @card_format end |
#card_holder ⇒ String?
Holder of the card associated with the credential.
134 135 136 |
# File 'lib/seam/resources/action_attempt.rb', line 134 def card_holder @card_holder end |
#card_id ⇒ String?
Card ID for the Visionline card associated with the credential.
137 138 139 |
# File 'lib/seam/resources/action_attempt.rb', line 137 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Array<String>
IDs of the common entrances for the credential.
140 141 142 |
# File 'lib/seam/resources/action_attempt.rb', line 140 def common_acs_entrance_ids @common_acs_entrance_ids end |
#discarded ⇒ Boolean?
Indicates whether the card associated with the credential is discarded.
143 144 145 |
# File 'lib/seam/resources/action_attempt.rb', line 143 def discarded @discarded end |
#expired ⇒ Boolean?
Indicates whether the card associated with the credential is expired.
146 147 148 |
# File 'lib/seam/resources/action_attempt.rb', line 146 def expired @expired end |
#guest_acs_entrance_ids ⇒ Array<String>
IDs of the guest entrances for the credential.
149 150 151 |
# File 'lib/seam/resources/action_attempt.rb', line 149 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#number_of_issued_cards ⇒ Float?
Number of issued cards associated with the credential.
152 153 154 |
# File 'lib/seam/resources/action_attempt.rb', line 152 def number_of_issued_cards @number_of_issued_cards end |
#overridden ⇒ Boolean?
Indicates whether the card associated with the credential is overridden.
155 156 157 |
# File 'lib/seam/resources/action_attempt.rb', line 155 def overridden @overridden end |
#overwritten ⇒ Boolean?
Indicates whether the card associated with the credential is overwritten.
158 159 160 |
# File 'lib/seam/resources/action_attempt.rb', line 158 def overwritten @overwritten end |
#pending_auto_update ⇒ Boolean?
Indicates whether the card associated with the credential is pending auto-update.
161 162 163 |
# File 'lib/seam/resources/action_attempt.rb', line 161 def pending_auto_update @pending_auto_update end |