Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnEncoder::VisionlineMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#cancelledBoolean?

Indicates whether the card associated with the credential is cancelled.

Returns:

  • (Boolean, nil)


117
118
119
# File 'lib/seam/resources/action_attempt.rb', line 117

def cancelled
  @cancelled
end

#card_formatString?

Format of the card associated with the credential. Known values:

  • TLCode
  • rfid48

Returns:

  • (String, nil)


123
124
125
# File 'lib/seam/resources/action_attempt.rb', line 123

def card_format
  @card_format
end

#card_holderString?

Holder of the card associated with the credential.

Returns:

  • (String, nil)


126
127
128
# File 'lib/seam/resources/action_attempt.rb', line 126

def card_holder
  @card_holder
end

#card_idString?

Card ID for the Visionline card associated with the credential.

Returns:

  • (String, nil)


129
130
131
# File 'lib/seam/resources/action_attempt.rb', line 129

def card_id
  @card_id
end

#common_acs_entrance_idsArray<String>

IDs of the common entrances for the credential.

Returns:

  • (Array<String>)


132
133
134
# File 'lib/seam/resources/action_attempt.rb', line 132

def common_acs_entrance_ids
  @common_acs_entrance_ids
end

#discardedBoolean?

Indicates whether the card associated with the credential is discarded.

Returns:

  • (Boolean, nil)


135
136
137
# File 'lib/seam/resources/action_attempt.rb', line 135

def discarded
  @discarded
end

#expiredBoolean?

Indicates whether the card associated with the credential is expired.

Returns:

  • (Boolean, nil)


138
139
140
# File 'lib/seam/resources/action_attempt.rb', line 138

def expired
  @expired
end

#guest_acs_entrance_idsArray<String>

IDs of the guest entrances for the credential.

Returns:

  • (Array<String>)


141
142
143
# File 'lib/seam/resources/action_attempt.rb', line 141

def guest_acs_entrance_ids
  @guest_acs_entrance_ids
end

#number_of_issued_cardsFloat?

Number of issued cards associated with the credential.

Returns:

  • (Float, nil)


144
145
146
# File 'lib/seam/resources/action_attempt.rb', line 144

def number_of_issued_cards
  @number_of_issued_cards
end

#overriddenBoolean?

Indicates whether the card associated with the credential is overridden.

Returns:

  • (Boolean, nil)


147
148
149
# File 'lib/seam/resources/action_attempt.rb', line 147

def overridden
  @overridden
end

#overwrittenBoolean?

Indicates whether the card associated with the credential is overwritten.

Returns:

  • (Boolean, nil)


150
151
152
# File 'lib/seam/resources/action_attempt.rb', line 150

def overwritten
  @overwritten
end

#pending_auto_updateBoolean?

Indicates whether the card associated with the credential is pending auto-update.

Returns:

  • (Boolean, nil)


153
154
155
# File 'lib/seam/resources/action_attempt.rb', line 153

def pending_auto_update
  @pending_auto_update
end