Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnEncoder::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnEncoder::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#cancelled ⇒ Boolean?
Indicates whether the card associated with the credential is cancelled.
-
#card_format ⇒ String?
Format of the card associated with the credential.
-
#card_holder ⇒ String?
Holder of the card associated with the credential.
-
#card_id ⇒ String?
Card ID for the Visionline card associated with the credential.
-
#common_acs_entrance_ids ⇒ Array<String>
IDs of the common entrances for the credential.
-
#discarded ⇒ Boolean?
Indicates whether the card associated with the credential is discarded.
-
#expired ⇒ Boolean?
Indicates whether the card associated with the credential is expired.
-
#guest_acs_entrance_ids ⇒ Array<String>
IDs of the guest entrances for the credential.
-
#number_of_issued_cards ⇒ Float?
Number of issued cards associated with the credential.
-
#overridden ⇒ Boolean?
Indicates whether the card associated with the credential is overridden.
-
#overwritten ⇒ Boolean?
Indicates whether the card associated with the credential is overwritten.
-
#pending_auto_update ⇒ Boolean?
Indicates whether the card associated with the credential is pending auto-update.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#cancelled ⇒ Boolean?
Indicates whether the card associated with the credential is cancelled.
117 118 119 |
# File 'lib/seam/resources/action_attempt.rb', line 117 def cancelled @cancelled end |
#card_format ⇒ String?
Format of the card associated with the credential. Known values:
TLCoderfid48
123 124 125 |
# File 'lib/seam/resources/action_attempt.rb', line 123 def card_format @card_format end |
#card_holder ⇒ String?
Holder of the card associated with the credential.
126 127 128 |
# File 'lib/seam/resources/action_attempt.rb', line 126 def card_holder @card_holder end |
#card_id ⇒ String?
Card ID for the Visionline card associated with the credential.
129 130 131 |
# File 'lib/seam/resources/action_attempt.rb', line 129 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Array<String>
IDs of the common entrances for the credential.
132 133 134 |
# File 'lib/seam/resources/action_attempt.rb', line 132 def common_acs_entrance_ids @common_acs_entrance_ids end |
#discarded ⇒ Boolean?
Indicates whether the card associated with the credential is discarded.
135 136 137 |
# File 'lib/seam/resources/action_attempt.rb', line 135 def discarded @discarded end |
#expired ⇒ Boolean?
Indicates whether the card associated with the credential is expired.
138 139 140 |
# File 'lib/seam/resources/action_attempt.rb', line 138 def expired @expired end |
#guest_acs_entrance_ids ⇒ Array<String>
IDs of the guest entrances for the credential.
141 142 143 |
# File 'lib/seam/resources/action_attempt.rb', line 141 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#number_of_issued_cards ⇒ Float?
Number of issued cards associated with the credential.
144 145 146 |
# File 'lib/seam/resources/action_attempt.rb', line 144 def number_of_issued_cards @number_of_issued_cards end |
#overridden ⇒ Boolean?
Indicates whether the card associated with the credential is overridden.
147 148 149 |
# File 'lib/seam/resources/action_attempt.rb', line 147 def overridden @overridden end |
#overwritten ⇒ Boolean?
Indicates whether the card associated with the credential is overwritten.
150 151 152 |
# File 'lib/seam/resources/action_attempt.rb', line 150 def overwritten @overwritten end |
#pending_auto_update ⇒ Boolean?
Indicates whether the card associated with the credential is pending auto-update.
153 154 155 |
# File 'lib/seam/resources/action_attempt.rb', line 153 def pending_auto_update @pending_auto_update end |