Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ String
Access method for the credential.
-
#acs_credential_id ⇒ String
ID of the credential.
-
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ String?
Number of the card associated with the credential.
-
#code ⇒ String?
Access (PIN) code for the credential.
-
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
-
#display_name ⇒ String
Display name that corresponds to the credential type.
-
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ String?
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
-
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
-
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
- #is_managed ⇒ Boolean
-
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once.
-
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
-
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
-
#workspace_id ⇒ String
ID of the workspace that contains the credential.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
-
#created_at ⇒ Time
Date and time at which the credential was created.
-
#errors ⇒ Array<Errors>
Errors associated with the credential.
-
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
-
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ String
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
292 293 294 |
# File 'lib/seam/resources/action_attempt.rb', line 292 def access_method @access_method end |
#acs_credential_id ⇒ String
ID of the credential.
295 296 297 |
# File 'lib/seam/resources/action_attempt.rb', line 295 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
298 299 300 |
# File 'lib/seam/resources/action_attempt.rb', line 298 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
301 302 303 |
# File 'lib/seam/resources/action_attempt.rb', line 301 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
304 305 306 |
# File 'lib/seam/resources/action_attempt.rb', line 304 def acs_user_id @acs_user_id end |
#card_number ⇒ String?
Number of the card associated with the credential.
307 308 309 |
# File 'lib/seam/resources/action_attempt.rb', line 307 def card_number @card_number end |
#code ⇒ String?
Access (PIN) code for the credential.
310 311 312 |
# File 'lib/seam/resources/action_attempt.rb', line 310 def code @code end |
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
313 314 315 |
# File 'lib/seam/resources/action_attempt.rb', line 313 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name that corresponds to the credential type.
316 317 318 |
# File 'lib/seam/resources/action_attempt.rb', line 316 def display_name @display_name end |
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
319 320 321 |
# File 'lib/seam/resources/action_attempt.rb', line 319 def ends_at @ends_at end |
#external_type ⇒ String?
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
Known values:
pti_cardbrivo_credentialhid_credentialvisionline_cardsalto_ks_credentialassa_abloy_vostio_keysalto_space_keylatch_accessdormakaba_ambiance_credentialhotek_cardsalto_ks_tagavigilon_alta_credentialkisi_credentialakiles_credential
337 338 339 |
# File 'lib/seam/resources/action_attempt.rb', line 337 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
340 341 342 |
# File 'lib/seam/resources/action_attempt.rb', line 340 def external_type_display_name @external_type_display_name end |
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
343 344 345 |
# File 'lib/seam/resources/action_attempt.rb', line 343 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
346 347 348 |
# File 'lib/seam/resources/action_attempt.rb', line 346 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ Boolean
348 349 350 |
# File 'lib/seam/resources/action_attempt.rb', line 348 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
351 352 353 |
# File 'lib/seam/resources/action_attempt.rb', line 351 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
354 355 356 |
# File 'lib/seam/resources/action_attempt.rb', line 354 def is_one_time_use @is_one_time_use end |
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
357 358 359 |
# File 'lib/seam/resources/action_attempt.rb', line 357 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
360 361 362 |
# File 'lib/seam/resources/action_attempt.rb', line 360 def starts_at @starts_at end |
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
363 364 365 |
# File 'lib/seam/resources/action_attempt.rb', line 363 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the credential.
366 367 368 |
# File 'lib/seam/resources/action_attempt.rb', line 366 def workspace_id @workspace_id end |
Instance Method Details
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
272 |
# File 'lib/seam/resources/action_attempt.rb', line 272 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
275 |
# File 'lib/seam/resources/action_attempt.rb', line 275 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#created_at ⇒ Time
Date and time at which the credential was created.
369 |
# File 'lib/seam/resources/action_attempt.rb', line 369 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the credential.
281 |
# File 'lib/seam/resources/action_attempt.rb', line 281 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
372 |
# File 'lib/seam/resources/action_attempt.rb', line 372 date_accessor :issued_at |
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
375 |
# File 'lib/seam/resources/action_attempt.rb', line 375 date_accessor :latest_desired_state_synced_with_provider_at |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
278 |
# File 'lib/seam/resources/action_attempt.rb', line 278 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
284 |
# File 'lib/seam/resources/action_attempt.rb', line 284 resource_list_accessor :warnings, Warnings |