Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::AssaAbloyVostioMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#auto_joinBoolean?

Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.

Returns:

  • (Boolean, nil)


186
187
188
# File 'lib/seam/resources/action_attempt.rb', line 186

def auto_join
  @auto_join
end

#door_namesArray<String>

Names of the doors to which to grant access in the Vostio access system.

Returns:

  • (Array<String>)


189
190
191
# File 'lib/seam/resources/action_attempt.rb', line 189

def door_names
  @door_names
end

#endpoint_idString?

Endpoint ID in the Vostio access system.

Returns:

  • (String, nil)


192
193
194
# File 'lib/seam/resources/action_attempt.rb', line 192

def endpoint_id
  @endpoint_id
end

#key_idString?

Key ID in the Vostio access system.

Returns:

  • (String, nil)


195
196
197
# File 'lib/seam/resources/action_attempt.rb', line 195

def key_id
  @key_id
end

#key_issuing_request_idString?

Key issuing request ID in the Vostio access system.

Returns:

  • (String, nil)


198
199
200
# File 'lib/seam/resources/action_attempt.rb', line 198

def key_issuing_request_id
  @key_issuing_request_id
end

#override_guest_acs_entrance_idsArray<String>

IDs of the guest entrances to override in the Vostio access system.

Returns:

  • (Array<String>)


201
202
203
# File 'lib/seam/resources/action_attempt.rb', line 201

def override_guest_acs_entrance_ids
  @override_guest_acs_entrance_ids
end