Class: Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanCredential::Result::AcsCredentialOnSeam::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ String?
Card function type in the Visionline access system.
-
#card_id ⇒ String?
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
217 218 219 |
# File 'lib/seam/resources/action_attempt.rb', line 217 def auto_join @auto_join end |
#card_function_type ⇒ String?
Card function type in the Visionline access system. Known values:
gueststaff
223 224 225 |
# File 'lib/seam/resources/action_attempt.rb', line 223 def card_function_type @card_function_type end |
#card_id ⇒ String?
ID of the card in the Visionline access system.
226 227 228 |
# File 'lib/seam/resources/action_attempt.rb', line 226 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
229 230 231 |
# File 'lib/seam/resources/action_attempt.rb', line 229 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
232 233 234 |
# File 'lib/seam/resources/action_attempt.rb', line 232 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
235 236 237 |
# File 'lib/seam/resources/action_attempt.rb', line 235 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
238 239 240 |
# File 'lib/seam/resources/action_attempt.rb', line 238 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
241 242 243 |
# File 'lib/seam/resources/action_attempt.rb', line 241 def joiner_acs_credential_ids @joiner_acs_credential_ids end |