Class: Seam::Resources::ActionAttempt::ScanToAssignCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::ScanToAssignCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Scanning a physical card and assigning the credential is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of scanning a physical card and assigning the credential to an ACS user.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Only present when
statusiserror;nilotherwise. -
#result ⇒ Result?
Result of a scan to assign attempt.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
912 913 914 |
# File 'lib/seam/resources/action_attempt.rb', line 912 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of scanning a physical card and assigning the credential to an ACS user. Known values:
SCAN_TO_ASSIGN_CREDENTIAL
917 918 919 |
# File 'lib/seam/resources/action_attempt.rb', line 917 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
923 924 925 |
# File 'lib/seam/resources/action_attempt.rb', line 923 def status @status end |