Class: Seam::Resources::ActionAttempt::ScanToAssignCredential

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Scanning a physical card and assigning the credential is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


892
893
894
# File 'lib/seam/resources/action_attempt.rb', line 892

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of scanning a physical card and assigning the credential to an ACS user. Known values:

  • SCAN_TO_ASSIGN_CREDENTIAL

Returns:

  • (String)


897
898
899
# File 'lib/seam/resources/action_attempt.rb', line 897

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


903
904
905
# File 'lib/seam/resources/action_attempt.rb', line 903

def status
  @status
end

Instance Method Details

#errorError?

Returns:



886
# File 'lib/seam/resources/action_attempt.rb', line 886

resource_accessor :error, Error

#resultResult?

Result of a scan to assign attempt. If the attempt was successful, includes the credential data that was scanned and assigned.

Returns:



889
# File 'lib/seam/resources/action_attempt.rb', line 889

resource_accessor :result, Result