Class: Seam::Resources::ActionAttempt::ScanToAssignCredential
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::ScanToAssignCredential
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Scanning a physical card and assigning the credential is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of scanning a physical card and assigning the credential to an ACS user.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
- #error ⇒ Error?
-
#result ⇒ Result?
Result of a scan to assign attempt.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
892 893 894 |
# File 'lib/seam/resources/action_attempt.rb', line 892 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of scanning a physical card and assigning the credential to an ACS user. Known values:
SCAN_TO_ASSIGN_CREDENTIAL
897 898 899 |
# File 'lib/seam/resources/action_attempt.rb', line 897 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
903 904 905 |
# File 'lib/seam/resources/action_attempt.rb', line 903 def status @status end |