Class: Seam::Resources::ActionAttempt::ScanToAssignCredential::Result

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Defined Under Namespace

Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_methodString

Access method for the credential. Supported values: code, card, mobile_key, cloud_key. Known values:

  • code
  • card
  • mobile_key
  • cloud_key

Returns:

  • (String)


798
799
800
# File 'lib/seam/resources/action_attempt.rb', line 798

def access_method
  @access_method
end

#acs_credential_idString

ID of the credential.

Returns:

  • (String)


801
802
803
# File 'lib/seam/resources/action_attempt.rb', line 801

def acs_credential_id
  @acs_credential_id
end

#acs_credential_pool_idString?

ID of the credential pool to which the credential belongs.

Returns:

  • (String, nil)


804
805
806
# File 'lib/seam/resources/action_attempt.rb', line 804

def acs_credential_pool_id
  @acs_credential_pool_id
end

#acs_system_idString

ID of the access control system that contains the credential.

Returns:

  • (String)


807
808
809
# File 'lib/seam/resources/action_attempt.rb', line 807

def acs_system_id
  @acs_system_id
end

#acs_user_idString?

ID of the ACS user to whom the credential belongs.

Returns:

  • (String, nil)


810
811
812
# File 'lib/seam/resources/action_attempt.rb', line 810

def acs_user_id
  @acs_user_id
end

#card_numberString?

Number of the card associated with the credential.

Returns:

  • (String, nil)


813
814
815
# File 'lib/seam/resources/action_attempt.rb', line 813

def card_number
  @card_number
end

#codeString?

Access (PIN) code for the credential.

Returns:

  • (String, nil)


816
817
818
# File 'lib/seam/resources/action_attempt.rb', line 816

def code
  @code
end

#connected_account_idString

ID of the connected account to which the credential belongs.

Returns:

  • (String)


819
820
821
# File 'lib/seam/resources/action_attempt.rb', line 819

def 
  @connected_account_id
end

#display_nameString

Display name that corresponds to the credential type.

Returns:

  • (String)


822
823
824
# File 'lib/seam/resources/action_attempt.rb', line 822

def display_name
  @display_name
end

#ends_atString?

Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.

Returns:

  • (String, nil)


825
826
827
# File 'lib/seam/resources/action_attempt.rb', line 825

def ends_at
  @ends_at
end

#external_typeString?

Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card. Known values:

  • pti_card
  • brivo_credential
  • hid_credential
  • visionline_card
  • salto_ks_credential
  • assa_abloy_vostio_key
  • salto_space_key
  • latch_access
  • dormakaba_ambiance_credential
  • hotek_card
  • salto_ks_tag
  • avigilon_alta_credential
  • kisi_credential
  • akiles_credential

Returns:

  • (String, nil)


843
844
845
# File 'lib/seam/resources/action_attempt.rb', line 843

def external_type
  @external_type
end

#external_type_display_nameString?

Display name that corresponds to the brand-specific terminology for the credential type.

Returns:

  • (String, nil)


846
847
848
# File 'lib/seam/resources/action_attempt.rb', line 846

def external_type_display_name
  @external_type_display_name
end

#is_issuedBoolean?

Indicates whether the credential has been encoded onto a card.

Returns:

  • (Boolean, nil)


849
850
851
# File 'lib/seam/resources/action_attempt.rb', line 849

def is_issued
  @is_issued
end

#is_latest_desired_state_synced_with_providerBoolean?

Indicates whether the latest state of the credential has been synced from Seam to the provider.

Returns:

  • (Boolean, nil)


852
853
854
# File 'lib/seam/resources/action_attempt.rb', line 852

def is_latest_desired_state_synced_with_provider
  @is_latest_desired_state_synced_with_provider
end

#is_managedTrueClass

Indicates whether Seam manages the credential.

Returns:

  • (TrueClass)


855
856
857
# File 'lib/seam/resources/action_attempt.rb', line 855

def is_managed
  @is_managed
end

#is_multi_phone_sync_credentialBoolean?

Indicates whether the credential is a multi-phone sync credential.

Returns:

  • (Boolean, nil)


858
859
860
# File 'lib/seam/resources/action_attempt.rb', line 858

def is_multi_phone_sync_credential
  @is_multi_phone_sync_credential
end

#is_one_time_useBoolean?

Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.

Returns:

  • (Boolean, nil)


861
862
863
# File 'lib/seam/resources/action_attempt.rb', line 861

def is_one_time_use
  @is_one_time_use
end

#parent_acs_credential_idString?

ID of the parent credential.

Returns:

  • (String, nil)


864
865
866
# File 'lib/seam/resources/action_attempt.rb', line 864

def parent_acs_credential_id
  @parent_acs_credential_id
end

#starts_atString?

Date and time at which the credential validity starts, in ISO 8601 format.

Returns:

  • (String, nil)


867
868
869
# File 'lib/seam/resources/action_attempt.rb', line 867

def starts_at
  @starts_at
end

#user_identity_idString?

ID of the user identity to whom the credential belongs.

Returns:

  • (String, nil)


870
871
872
# File 'lib/seam/resources/action_attempt.rb', line 870

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the workspace that contains the credential.

Returns:

  • (String)


873
874
875
# File 'lib/seam/resources/action_attempt.rb', line 873

def workspace_id
  @workspace_id
end

Instance Method Details

#akiles_metadataAkilesMetadata?

Akiles-specific metadata for the credential.

Returns:



778
# File 'lib/seam/resources/action_attempt.rb', line 778

resource_accessor :akiles_metadata, AkilesMetadata

#assa_abloy_vostio_metadataAssaAbloyVostioMetadata?

Vostio-specific metadata for the credential.

Returns:



781
# File 'lib/seam/resources/action_attempt.rb', line 781

resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata

#created_atTime

Date and time at which the credential was created.

Returns:

  • (Time)


876
# File 'lib/seam/resources/action_attempt.rb', line 876

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the credential.

Returns:



787
# File 'lib/seam/resources/action_attempt.rb', line 787

resource_list_accessor :errors, Errors

#issued_atTime?

Date and time at which the credential was encoded onto a card.

Returns:

  • (Time, nil)


879
# File 'lib/seam/resources/action_attempt.rb', line 879

date_accessor :issued_at

#latest_desired_state_synced_with_provider_atTime?

Date and time at which the state of the credential was most recently synced from Seam to the provider.

Returns:

  • (Time, nil)


882
# File 'lib/seam/resources/action_attempt.rb', line 882

date_accessor :latest_desired_state_synced_with_provider_at

#visionline_metadataVisionlineMetadata?

Visionline-specific metadata for the credential.

Returns:



784
# File 'lib/seam/resources/action_attempt.rb', line 784

resource_accessor :visionline_metadata, VisionlineMetadata

#warningsArray<Warnings>

Warnings associated with the credential.

Returns:



790
# File 'lib/seam/resources/action_attempt.rb', line 790

resource_list_accessor :warnings, Warnings