Class: Seam::Resources::ActionAttempt::ScanToAssignCredential::Result
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanToAssignCredential::Result
- Defined in:
- lib/seam/resources/action_attempt.rb
Defined Under Namespace
Classes: AkilesMetadata, AssaAbloyVostioMetadata, Errors, VisionlineMetadata, Warnings
Instance Attribute Summary collapse
-
#access_method ⇒ String
Access method for the credential.
-
#acs_credential_id ⇒ String
ID of the credential.
-
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
-
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
-
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
-
#card_number ⇒ String?
Number of the card associated with the credential.
-
#code ⇒ String?
Access (PIN) code for the credential.
-
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
-
#display_name ⇒ String
Display name that corresponds to the credential type.
-
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format.
-
#external_type ⇒ String?
Brand-specific terminology for the credential type.
-
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
-
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
-
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
-
#is_managed ⇒ TrueClass
Indicates whether Seam manages the credential.
-
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
-
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once.
-
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
-
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
-
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
-
#workspace_id ⇒ String
ID of the workspace that contains the credential.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
-
#created_at ⇒ Time
Date and time at which the credential was created.
-
#errors ⇒ Array<Errors>
Errors associated with the credential.
-
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
-
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
-
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method ⇒ String
Access method for the credential. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
798 799 800 |
# File 'lib/seam/resources/action_attempt.rb', line 798 def access_method @access_method end |
#acs_credential_id ⇒ String
ID of the credential.
801 802 803 |
# File 'lib/seam/resources/action_attempt.rb', line 801 def acs_credential_id @acs_credential_id end |
#acs_credential_pool_id ⇒ String?
ID of the credential pool to which the credential belongs.
804 805 806 |
# File 'lib/seam/resources/action_attempt.rb', line 804 def acs_credential_pool_id @acs_credential_pool_id end |
#acs_system_id ⇒ String
ID of the access control system that contains the credential.
807 808 809 |
# File 'lib/seam/resources/action_attempt.rb', line 807 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String?
ID of the ACS user to whom the credential belongs.
810 811 812 |
# File 'lib/seam/resources/action_attempt.rb', line 810 def acs_user_id @acs_user_id end |
#card_number ⇒ String?
Number of the card associated with the credential.
813 814 815 |
# File 'lib/seam/resources/action_attempt.rb', line 813 def card_number @card_number end |
#code ⇒ String?
Access (PIN) code for the credential.
816 817 818 |
# File 'lib/seam/resources/action_attempt.rb', line 816 def code @code end |
#connected_account_id ⇒ String
ID of the connected account to which the credential belongs.
819 820 821 |
# File 'lib/seam/resources/action_attempt.rb', line 819 def connected_account_id @connected_account_id end |
#display_name ⇒ String
Display name that corresponds to the credential type.
822 823 824 |
# File 'lib/seam/resources/action_attempt.rb', line 822 def display_name @display_name end |
#ends_at ⇒ String?
Date and time at which the credential validity ends, in ISO 8601 format. Must be a time in the future and after starts_at.
825 826 827 |
# File 'lib/seam/resources/action_attempt.rb', line 825 def ends_at @ends_at end |
#external_type ⇒ String?
Brand-specific terminology for the credential type. Supported values: pti_card, brivo_credential, hid_credential, visionline_card.
Known values:
pti_cardbrivo_credentialhid_credentialvisionline_cardsalto_ks_credentialassa_abloy_vostio_keysalto_space_keylatch_accessdormakaba_ambiance_credentialhotek_cardsalto_ks_tagavigilon_alta_credentialkisi_credentialakiles_credential
843 844 845 |
# File 'lib/seam/resources/action_attempt.rb', line 843 def external_type @external_type end |
#external_type_display_name ⇒ String?
Display name that corresponds to the brand-specific terminology for the credential type.
846 847 848 |
# File 'lib/seam/resources/action_attempt.rb', line 846 def external_type_display_name @external_type_display_name end |
#is_issued ⇒ Boolean?
Indicates whether the credential has been encoded onto a card.
849 850 851 |
# File 'lib/seam/resources/action_attempt.rb', line 849 def is_issued @is_issued end |
#is_latest_desired_state_synced_with_provider ⇒ Boolean?
Indicates whether the latest state of the credential has been synced from Seam to the provider.
852 853 854 |
# File 'lib/seam/resources/action_attempt.rb', line 852 def is_latest_desired_state_synced_with_provider @is_latest_desired_state_synced_with_provider end |
#is_managed ⇒ TrueClass
Indicates whether Seam manages the credential.
855 856 857 |
# File 'lib/seam/resources/action_attempt.rb', line 855 def is_managed @is_managed end |
#is_multi_phone_sync_credential ⇒ Boolean?
Indicates whether the credential is a multi-phone sync credential.
858 859 860 |
# File 'lib/seam/resources/action_attempt.rb', line 858 def is_multi_phone_sync_credential @is_multi_phone_sync_credential end |
#is_one_time_use ⇒ Boolean?
Indicates whether the credential can only be used once. If true, the code becomes invalid after the first use.
861 862 863 |
# File 'lib/seam/resources/action_attempt.rb', line 861 def is_one_time_use @is_one_time_use end |
#parent_acs_credential_id ⇒ String?
ID of the parent credential.
864 865 866 |
# File 'lib/seam/resources/action_attempt.rb', line 864 def parent_acs_credential_id @parent_acs_credential_id end |
#starts_at ⇒ String?
Date and time at which the credential validity starts, in ISO 8601 format.
867 868 869 |
# File 'lib/seam/resources/action_attempt.rb', line 867 def starts_at @starts_at end |
#user_identity_id ⇒ String?
ID of the user identity to whom the credential belongs.
870 871 872 |
# File 'lib/seam/resources/action_attempt.rb', line 870 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the credential.
873 874 875 |
# File 'lib/seam/resources/action_attempt.rb', line 873 def workspace_id @workspace_id end |
Instance Method Details
#akiles_metadata ⇒ AkilesMetadata?
Akiles-specific metadata for the credential.
778 |
# File 'lib/seam/resources/action_attempt.rb', line 778 resource_accessor :akiles_metadata, AkilesMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Vostio-specific metadata for the credential.
781 |
# File 'lib/seam/resources/action_attempt.rb', line 781 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#created_at ⇒ Time
Date and time at which the credential was created.
876 |
# File 'lib/seam/resources/action_attempt.rb', line 876 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the credential.
787 |
# File 'lib/seam/resources/action_attempt.rb', line 787 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the credential was encoded onto a card.
879 |
# File 'lib/seam/resources/action_attempt.rb', line 879 date_accessor :issued_at |
#latest_desired_state_synced_with_provider_at ⇒ Time?
Date and time at which the state of the credential was most recently synced from Seam to the provider.
882 |
# File 'lib/seam/resources/action_attempt.rb', line 882 date_accessor :latest_desired_state_synced_with_provider_at |
#visionline_metadata ⇒ VisionlineMetadata?
Visionline-specific metadata for the credential.
784 |
# File 'lib/seam/resources/action_attempt.rb', line 784 resource_accessor :visionline_metadata, VisionlineMetadata |
#warnings ⇒ Array<Warnings>
Warnings associated with the credential.
790 |
# File 'lib/seam/resources/action_attempt.rb', line 790 resource_list_accessor :warnings, Warnings |