Class: Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::VisionlineMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ActionAttempt::ScanToAssignCredential::Result::VisionlineMetadata
- Defined in:
- lib/seam/resources/action_attempt.rb
Instance Attribute Summary collapse
-
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join.
-
#card_function_type ⇒ String?
Card function type in the Visionline access system.
-
#card_id ⇒ String?
ID of the card in the Visionline access system.
-
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
-
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
-
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
-
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
-
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#auto_join ⇒ Boolean?
Indicates whether the credential should auto-join. For an auto-join credential, Seam automatically issues an override card if there are no other cards and a joiner card if there are existing cards on the doors.
723 724 725 |
# File 'lib/seam/resources/action_attempt.rb', line 723 def auto_join @auto_join end |
#card_function_type ⇒ String?
Card function type in the Visionline access system. Known values:
gueststaff
729 730 731 |
# File 'lib/seam/resources/action_attempt.rb', line 729 def card_function_type @card_function_type end |
#card_id ⇒ String?
ID of the card in the Visionline access system.
732 733 734 |
# File 'lib/seam/resources/action_attempt.rb', line 732 def card_id @card_id end |
#common_acs_entrance_ids ⇒ Array<String>
Common entrance IDs in the Visionline access system.
735 736 737 |
# File 'lib/seam/resources/action_attempt.rb', line 735 def common_acs_entrance_ids @common_acs_entrance_ids end |
#credential_id ⇒ String?
ID of the credential in the Visionline access system.
738 739 740 |
# File 'lib/seam/resources/action_attempt.rb', line 738 def credential_id @credential_id end |
#guest_acs_entrance_ids ⇒ Array<String>
Guest entrance IDs in the Visionline access system.
741 742 743 |
# File 'lib/seam/resources/action_attempt.rb', line 741 def guest_acs_entrance_ids @guest_acs_entrance_ids end |
#is_valid ⇒ Boolean?
Indicates whether the credential is valid.
744 745 746 |
# File 'lib/seam/resources/action_attempt.rb', line 744 def is_valid @is_valid end |
#joiner_acs_credential_ids ⇒ Array<String>
IDs of the credentials to which you want to join.
747 748 749 |
# File 'lib/seam/resources/action_attempt.rb', line 747 def joiner_acs_credential_ids @joiner_acs_credential_ids end |