Class: Seam::Resources::ActionAttempt::SetFanMode
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::SetFanMode
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Setting the fan mode is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of setting the fan mode on a thermostat.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1136 1137 1138 |
# File 'lib/seam/resources/action_attempt.rb', line 1136 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of setting the fan mode on a thermostat. Known values:
SET_FAN_MODE
1141 1142 1143 |
# File 'lib/seam/resources/action_attempt.rb', line 1141 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1147 1148 1149 |
# File 'lib/seam/resources/action_attempt.rb', line 1147 def status @status end |