Class: Seam::Resources::ActionAttempt::SimulateManualLockViaKeypad

Inherits:
ActionAttempt
  • Object
show all
Defined in:
lib/seam/resources/action_attempt.rb

Overview

Simulating a manual lock action using a keypad is pending.

Defined Under Namespace

Classes: Error, Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#action_attempt_idString

ID of the action attempt.

Returns:

  • (String)


1280
1281
1282
# File 'lib/seam/resources/action_attempt.rb', line 1280

def action_attempt_id
  @action_attempt_id
end

#action_typeString

Action attempt to track the status of simulating a manual lock action using a keypad. Known values:

  • SIMULATE_MANUAL_LOCK_VIA_KEYPAD

Returns:

  • (String)


1285
1286
1287
# File 'lib/seam/resources/action_attempt.rb', line 1285

def action_type
  @action_type
end

#statusString

Known values:

  • success
  • pending
  • error

Returns:

  • (String)


1291
1292
1293
# File 'lib/seam/resources/action_attempt.rb', line 1291

def status
  @status
end

Instance Method Details

#errorError?

Error associated with the action.

Returns:



1274
# File 'lib/seam/resources/action_attempt.rb', line 1274

resource_accessor :error, Error

#resultResult?

Result of the action.

Returns:



1277
# File 'lib/seam/resources/action_attempt.rb', line 1277

resource_accessor :result, Result