Class: Seam::Resources::ActionAttempt::SimulateManualLockViaKeypad
- Inherits:
-
ActionAttempt
- Object
- ActionAttempt
- Seam::Resources::ActionAttempt::SimulateManualLockViaKeypad
- Defined in:
- lib/seam/resources/action_attempt.rb
Overview
Simulating a manual lock action using a keypad is pending.
Defined Under Namespace
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the action attempt.
-
#action_type ⇒ String
Action attempt to track the status of simulating a manual lock action using a keypad.
-
#status ⇒ String
Known values: -
success-pending-error.
Instance Method Summary collapse
-
#error ⇒ Error?
Error associated with the action.
-
#result ⇒ Result?
Result of the action.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the action attempt.
1280 1281 1282 |
# File 'lib/seam/resources/action_attempt.rb', line 1280 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Action attempt to track the status of simulating a manual lock action using a keypad. Known values:
SIMULATE_MANUAL_LOCK_VIA_KEYPAD
1285 1286 1287 |
# File 'lib/seam/resources/action_attempt.rb', line 1285 def action_type @action_type end |
#status ⇒ String
Known values:
successpendingerror
1291 1292 1293 |
# File 'lib/seam/resources/action_attempt.rb', line 1291 def status @status end |