Class: Seam::Resources::ConnectWebview

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/connect_webview.rb

Overview

Represents a Connect Webview.

Connect Webviews are fully-embedded client-side components that you add to your app. Your users interact with your embedded Connect Webviews to link their IoT device or system accounts to Seam. That is, Connect Webviews walk your users through the process of logging in to their device or system accounts. Seam handles all the authentication steps, and—once your user has completed the authorization through your app—you can access and control their devices or systems using the Seam API.

Connect Webviews perform credential validation, multifactor authentication (when applicable), and error handling for each brand that Seam supports. Further, Connect Webviews work across all modern browsers and platforms, including Chrome, Safari, and Firefox.

To enable a user to connect their device or system account to Seam through your app, first create a connect_webview. Once created, this connect_webview includes a URL that you can use to open an iframe or new window containing the Connect Webview for your user.

When you create a Connect Webview, specify the desired provider category key in the provider_category parameter. Alternately, to specify a list of providers explicitly, use the accepted_providers parameter with a list of device provider keys.

To list all providers within a category, use /devices/list_device_providers with the desired provider_category filter. To list all provider keys, use /devices/list_device_providers with no filters.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accepted_capabilitiesObject

High-level device capabilities that the Connect Webview can accept. When creating a Connect Webview, you can specify the types of devices that it can connect to Seam. If you do not set custom accepted_capabilities, Seam uses a default set of accepted_capabilities for each provider. For example, if you create a Connect Webview that accepts SmartThing devices, without specifying accepted_capabilities, Seam accepts only SmartThings locks. To connect SmartThings thermostats and locks to Seam, create a Connect Webview and include both thermostat and lock in the accepted_capabilities.



18
19
20
# File 'lib/seam/resources/connect_webview.rb', line 18

def accepted_capabilities
  @accepted_capabilities
end

#accepted_providersObject

List of accepted provider keys.



20
21
22
# File 'lib/seam/resources/connect_webview.rb', line 20

def accepted_providers
  @accepted_providers
end

#any_provider_allowedObject

Indicates whether any provider is allowed.



22
23
24
# File 'lib/seam/resources/connect_webview.rb', line 22

def any_provider_allowed
  @any_provider_allowed
end

#automatically_manage_new_devicesObject

Indicates whether Seam should import all new devices for the connected account to make these devices available for use and management by the Seam API.



24
25
26
# File 'lib/seam/resources/connect_webview.rb', line 24

def automatically_manage_new_devices
  @automatically_manage_new_devices
end

#connect_webview_idObject

ID of the Connect Webview.



26
27
28
# File 'lib/seam/resources/connect_webview.rb', line 26

def connect_webview_id
  @connect_webview_id
end

#connected_account_idObject

ID of the connected account associated with the Connect Webview.



28
29
30
# File 'lib/seam/resources/connect_webview.rb', line 28

def 
  @connected_account_id
end

#custom_metadataObject

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.



30
31
32
# File 'lib/seam/resources/connect_webview.rb', line 30

def 
  @custom_metadata
end

#custom_redirect_failure_urlObject

URL to which the Connect Webview should redirect when an unexpected error occurs.



32
33
34
# File 'lib/seam/resources/connect_webview.rb', line 32

def custom_redirect_failure_url
  @custom_redirect_failure_url
end

#custom_redirect_urlObject

URL to which the Connect Webview should redirect when the user successfully pairs a device or system. If you do not set the custom_redirect_failure_url, the Connect Webview redirects to the custom_redirect_url when an unexpected error occurs.



34
35
36
# File 'lib/seam/resources/connect_webview.rb', line 34

def custom_redirect_url
  @custom_redirect_url
end

#customer_keyObject

The customer key associated with this webview, if any.



36
37
38
# File 'lib/seam/resources/connect_webview.rb', line 36

def customer_key
  @customer_key
end

#device_selection_modeObject

Device selection mode of the Connect Webview. Supported values: none, single, multiple.



38
39
40
# File 'lib/seam/resources/connect_webview.rb', line 38

def device_selection_mode
  @device_selection_mode
end

#login_successfulObject

Indicates whether the user logged in successfully using the Connect Webview.



40
41
42
# File 'lib/seam/resources/connect_webview.rb', line 40

def 
  @login_successful
end

#selected_providerObject

Selected provider of the Connect Webview, one of the provider keys.



42
43
44
# File 'lib/seam/resources/connect_webview.rb', line 42

def selected_provider
  @selected_provider
end

#statusObject

Status of the Connect Webview. authorized indicates that the user has successfully logged into their device or system account, thereby completing the Connect Webview.



44
45
46
# File 'lib/seam/resources/connect_webview.rb', line 44

def status
  @status
end

#urlObject

URL for the Connect Webview. You use the URL to display the Connect Webview flow to your user.



46
47
48
# File 'lib/seam/resources/connect_webview.rb', line 46

def url
  @url
end

#wait_for_device_creationObject

Indicates whether Seam should finish syncing all devices in a newly-connected account before completing the associated Connect Webview.



48
49
50
# File 'lib/seam/resources/connect_webview.rb', line 48

def wait_for_device_creation
  @wait_for_device_creation
end

#workspace_idObject

ID of the workspace that contains the Connect Webview.



50
51
52
# File 'lib/seam/resources/connect_webview.rb', line 50

def workspace_id
  @workspace_id
end