Class: Seam::Resources::ConnectedAccount

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/connected_account.rb

Overview

Represents a connected account. A connected account is an external third-party account to which your user has authorized Seam to get access, for example, an August account with a list of door locks.

Defined Under Namespace

Classes: Errors, UserIdentifier, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accepted_capabilitiesArray<String>

List of capabilities that were accepted during the account connection process.

Returns:

  • (Array<String>)


114
115
116
# File 'lib/seam/resources/connected_account.rb', line 114

def accepted_capabilities
  @accepted_capabilities
end

#account_typeString?

Type of connected account.

Returns:

  • (String, nil)


117
118
119
# File 'lib/seam/resources/connected_account.rb', line 117

def 
  @account_type
end

#account_type_display_nameString

Display name for the connected account type.

Returns:

  • (String)


120
121
122
# File 'lib/seam/resources/connected_account.rb', line 120

def 
  @account_type_display_name
end

#automatically_manage_new_devicesBoolean

Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.

Returns:

  • (Boolean)


123
124
125
# File 'lib/seam/resources/connected_account.rb', line 123

def automatically_manage_new_devices
  @automatically_manage_new_devices
end

#connected_account_idString

ID of the connected account.

Returns:

  • (String)


126
127
128
# File 'lib/seam/resources/connected_account.rb', line 126

def 
  @connected_account_id
end

#custom_metadataHash

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.

Returns:

  • (Hash)


129
130
131
# File 'lib/seam/resources/connected_account.rb', line 129

def 
  @custom_metadata
end

#customer_keyString?

Your unique key for the customer associated with this connected account.

Returns:

  • (String, nil)


132
133
134
# File 'lib/seam/resources/connected_account.rb', line 132

def customer_key
  @customer_key
end

#default_checkin_timeString?

Default reservation check-in time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration — set during the connect_webview for providers like Lodgify whose API does not expose check-in times.

Returns:

  • (String, nil)


135
136
137
# File 'lib/seam/resources/connected_account.rb', line 135

def default_checkin_time
  @default_checkin_time
end

#default_checkout_timeString?

Default reservation check-out time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration.

Returns:

  • (String, nil)


138
139
140
# File 'lib/seam/resources/connected_account.rb', line 138

def default_checkout_time
  @default_checkout_time
end

#display_nameString

Display name for the connected account.

Returns:

  • (String)


141
142
143
# File 'lib/seam/resources/connected_account.rb', line 141

def display_name
  @display_name
end

#ical_feed_originString?

For iCal connected accounts, the platform that produced the feed (for example, airbnb, vrbo, or booking), or unknown when it could not be determined. Intended for rendering the source platform's logo.

Returns:

  • (String, nil)


144
145
146
# File 'lib/seam/resources/connected_account.rb', line 144

def ical_feed_origin
  @ical_feed_origin
end

#ical_urlString?

For iCal connected accounts, the feed URL for the connection. Sourced from the connector configuration.

Returns:

  • (String, nil)


147
148
149
# File 'lib/seam/resources/connected_account.rb', line 147

def ical_url
  @ical_url
end

#image_urlString?

Logo URL for the connected account provider.

Returns:

  • (String, nil)


150
151
152
# File 'lib/seam/resources/connected_account.rb', line 150

def image_url
  @image_url
end

#time_zoneString?

IANA time zone (e.g. America/Los_Angeles) for this connected account. Sourced from the connector configuration.

Returns:

  • (String, nil)


153
154
155
# File 'lib/seam/resources/connected_account.rb', line 153

def time_zone
  @time_zone
end

Instance Method Details

#created_atTime?

Date and time at which the connected account was created.

Returns:

  • (Time, nil)


157
# File 'lib/seam/resources/connected_account.rb', line 157

date_accessor :created_at

#errorsArray<Errors>

Errors associated with the connected account.

Returns:



108
# File 'lib/seam/resources/connected_account.rb', line 108

resource_list_accessor :errors, Errors

#user_identifierUserIdentifier?

User identifier associated with the connected account.

Returns:



105
# File 'lib/seam/resources/connected_account.rb', line 105

resource_accessor :user_identifier, UserIdentifier

#warningsArray<Warnings>

Warnings associated with the connected account.

Returns:



111
# File 'lib/seam/resources/connected_account.rb', line 111

resource_list_accessor :warnings, Warnings