Class: Seam::Resources::ConnectedAccount
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Represents a connected account. A connected account is an external third-party account to which your user has authorized Seam to get access, for example, an August account with a list of door locks.
Defined Under Namespace
Classes: Errors, UserIdentifier, Warnings
Instance Attribute Summary collapse
-
#accepted_capabilities ⇒ Array<String>
List of capabilities that were accepted during the account connection process.
-
#account_type ⇒ String?
Type of connected account.
-
#account_type_display_name ⇒ String
Display name for the connected account type.
-
#automatically_manage_new_devices ⇒ Boolean
Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.
-
#connected_account_id ⇒ String
ID of the connected account.
-
#custom_metadata ⇒ Hash
Set of key:value pairs.
-
#customer_key ⇒ String?
Your unique key for the customer associated with this connected account.
-
#default_checkin_time ⇒ String?
Default reservation check-in time for this connected account, as
HH:mm(24-hour). -
#default_checkout_time ⇒ String?
Default reservation check-out time for this connected account, as
HH:mm(24-hour). -
#display_name ⇒ String
Display name for the connected account.
-
#ical_feed_origin ⇒ String?
For iCal connected accounts, the platform that produced the feed (for example,
airbnb,vrbo, orbooking), orunknownwhen it could not be determined. -
#ical_url ⇒ String?
For iCal connected accounts, the feed URL for the connection.
-
#image_url ⇒ String?
Logo URL for the connected account provider.
-
#time_zone ⇒ String?
IANA time zone (e.g. America/Los_Angeles) for this connected account.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which the connected account was created.
-
#errors ⇒ Array<Errors>
Errors associated with the connected account.
-
#user_identifier ⇒ UserIdentifier?
User identifier associated with the connected account.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the connected account.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#accepted_capabilities ⇒ Array<String>
List of capabilities that were accepted during the account connection process.
114 115 116 |
# File 'lib/seam/resources/connected_account.rb', line 114 def accepted_capabilities @accepted_capabilities end |
#account_type ⇒ String?
Type of connected account.
117 118 119 |
# File 'lib/seam/resources/connected_account.rb', line 117 def account_type @account_type end |
#account_type_display_name ⇒ String
Display name for the connected account type.
120 121 122 |
# File 'lib/seam/resources/connected_account.rb', line 120 def account_type_display_name @account_type_display_name end |
#automatically_manage_new_devices ⇒ Boolean
Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.
123 124 125 |
# File 'lib/seam/resources/connected_account.rb', line 123 def automatically_manage_new_devices @automatically_manage_new_devices end |
#connected_account_id ⇒ String
ID of the connected account.
126 127 128 |
# File 'lib/seam/resources/connected_account.rb', line 126 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Hash
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.
129 130 131 |
# File 'lib/seam/resources/connected_account.rb', line 129 def @custom_metadata end |
#customer_key ⇒ String?
Your unique key for the customer associated with this connected account.
132 133 134 |
# File 'lib/seam/resources/connected_account.rb', line 132 def customer_key @customer_key end |
#default_checkin_time ⇒ String?
Default reservation check-in time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration — set during the connect_webview for providers like Lodgify whose API does not expose check-in times.
135 136 137 |
# File 'lib/seam/resources/connected_account.rb', line 135 def default_checkin_time @default_checkin_time end |
#default_checkout_time ⇒ String?
Default reservation check-out time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration.
138 139 140 |
# File 'lib/seam/resources/connected_account.rb', line 138 def default_checkout_time @default_checkout_time end |
#display_name ⇒ String
Display name for the connected account.
141 142 143 |
# File 'lib/seam/resources/connected_account.rb', line 141 def display_name @display_name end |
#ical_feed_origin ⇒ String?
For iCal connected accounts, the platform that produced the feed (for example, airbnb, vrbo, or booking), or unknown when it could not be determined. Intended for rendering the source platform's logo.
144 145 146 |
# File 'lib/seam/resources/connected_account.rb', line 144 def ical_feed_origin @ical_feed_origin end |
#ical_url ⇒ String?
For iCal connected accounts, the feed URL for the connection. Sourced from the connector configuration.
147 148 149 |
# File 'lib/seam/resources/connected_account.rb', line 147 def ical_url @ical_url end |
#image_url ⇒ String?
Logo URL for the connected account provider.
150 151 152 |
# File 'lib/seam/resources/connected_account.rb', line 150 def image_url @image_url end |
#time_zone ⇒ String?
IANA time zone (e.g. America/Los_Angeles) for this connected account. Sourced from the connector configuration.
153 154 155 |
# File 'lib/seam/resources/connected_account.rb', line 153 def time_zone @time_zone end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which the connected account was created.
157 |
# File 'lib/seam/resources/connected_account.rb', line 157 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the connected account.
108 |
# File 'lib/seam/resources/connected_account.rb', line 108 resource_list_accessor :errors, Errors |
#user_identifier ⇒ UserIdentifier?
User identifier associated with the connected account.
105 |
# File 'lib/seam/resources/connected_account.rb', line 105 resource_accessor :user_identifier, UserIdentifier |