Class: Seam::Resources::ConnectedAccount
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Represents a connected account. A connected account is an external third-party account to which your user has authorized Seam to get access, for example, an August account with a list of door locks.
Defined Under Namespace
Classes: Errors, UserIdentifier, Warnings
Instance Attribute Summary collapse
-
#accepted_capabilities ⇒ Object
List of capabilities that were accepted during the account connection process.
-
#account_type ⇒ Object
Type of connected account.
-
#account_type_display_name ⇒ Object
Display name for the connected account type.
-
#automatically_manage_new_devices ⇒ Object
Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.
-
#connected_account_id ⇒ Object
ID of the connected account.
-
#custom_metadata ⇒ Object
Set of key:value pairs.
-
#customer_key ⇒ Object
Your unique key for the customer associated with this connected account.
-
#default_checkin_time ⇒ Object
Default reservation check-in time for this connected account, as
HH:mm(24-hour). -
#default_checkout_time ⇒ Object
Default reservation check-out time for this connected account, as
HH:mm(24-hour). -
#display_name ⇒ Object
Display name for the connected account.
-
#ical_feed_origin ⇒ Object
For iCal connected accounts, the platform that produced the feed (for example,
airbnb,vrbo, orbooking), orunknownwhen it could not be determined. -
#ical_url ⇒ Object
For iCal connected accounts, the feed URL for the connection.
-
#image_url ⇒ Object
Logo URL for the connected account provider.
-
#time_zone ⇒ Object
IANA time zone (e.g. America/Los_Angeles) for this connected account.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#accepted_capabilities ⇒ Object
List of capabilities that were accepted during the account connection process.
78 79 80 |
# File 'lib/seam/resources/connected_account.rb', line 78 def accepted_capabilities @accepted_capabilities end |
#account_type ⇒ Object
Type of connected account.
80 81 82 |
# File 'lib/seam/resources/connected_account.rb', line 80 def account_type @account_type end |
#account_type_display_name ⇒ Object
Display name for the connected account type.
82 83 84 |
# File 'lib/seam/resources/connected_account.rb', line 82 def account_type_display_name @account_type_display_name end |
#automatically_manage_new_devices ⇒ Object
Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.
84 85 86 |
# File 'lib/seam/resources/connected_account.rb', line 84 def automatically_manage_new_devices @automatically_manage_new_devices end |
#connected_account_id ⇒ Object
ID of the connected account.
86 87 88 |
# File 'lib/seam/resources/connected_account.rb', line 86 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Object
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.
88 89 90 |
# File 'lib/seam/resources/connected_account.rb', line 88 def @custom_metadata end |
#customer_key ⇒ Object
Your unique key for the customer associated with this connected account.
90 91 92 |
# File 'lib/seam/resources/connected_account.rb', line 90 def customer_key @customer_key end |
#default_checkin_time ⇒ Object
Default reservation check-in time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration — set during the connect_webview for providers like Lodgify whose API does not expose check-in times.
92 93 94 |
# File 'lib/seam/resources/connected_account.rb', line 92 def default_checkin_time @default_checkin_time end |
#default_checkout_time ⇒ Object
Default reservation check-out time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration.
94 95 96 |
# File 'lib/seam/resources/connected_account.rb', line 94 def default_checkout_time @default_checkout_time end |
#display_name ⇒ Object
Display name for the connected account.
96 97 98 |
# File 'lib/seam/resources/connected_account.rb', line 96 def display_name @display_name end |
#ical_feed_origin ⇒ Object
For iCal connected accounts, the platform that produced the feed (for example, airbnb, vrbo, or booking), or unknown when it could not be determined. Intended for rendering the source platform's logo.
98 99 100 |
# File 'lib/seam/resources/connected_account.rb', line 98 def ical_feed_origin @ical_feed_origin end |
#ical_url ⇒ Object
For iCal connected accounts, the feed URL for the connection. Sourced from the connector configuration.
100 101 102 |
# File 'lib/seam/resources/connected_account.rb', line 100 def ical_url @ical_url end |
#image_url ⇒ Object
Logo URL for the connected account provider.
102 103 104 |
# File 'lib/seam/resources/connected_account.rb', line 102 def image_url @image_url end |
#time_zone ⇒ Object
IANA time zone (e.g. America/Los_Angeles) for this connected account. Sourced from the connector configuration.
104 105 106 |
# File 'lib/seam/resources/connected_account.rb', line 104 def time_zone @time_zone end |