Class: Seam::Resources::ConnectedAccount

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport, ResourceWarningsSupport
Defined in:
lib/seam/resources/connected_account.rb

Overview

Represents a connected account. A connected account is an external third-party account to which your user has authorized Seam to get access, for example, an August account with a list of door locks.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceWarningsSupport

#warnings

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accepted_capabilitiesObject

List of capabilities that were accepted during the account connection process.



8
9
10
# File 'lib/seam/resources/connected_account.rb', line 8

def accepted_capabilities
  @accepted_capabilities
end

#account_typeObject

Type of connected account.



10
11
12
# File 'lib/seam/resources/connected_account.rb', line 10

def 
  @account_type
end

#account_type_display_nameObject

Display name for the connected account type.



12
13
14
# File 'lib/seam/resources/connected_account.rb', line 12

def 
  @account_type_display_name
end

#automatically_manage_new_devicesObject

Indicates whether Seam should import all new devices for the connected account to make these devices available for management by the Seam API.



14
15
16
# File 'lib/seam/resources/connected_account.rb', line 14

def automatically_manage_new_devices
  @automatically_manage_new_devices
end

#connected_account_idObject

ID of the connected account.



16
17
18
# File 'lib/seam/resources/connected_account.rb', line 16

def 
  @connected_account_id
end

#custom_metadataObject

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.



18
19
20
# File 'lib/seam/resources/connected_account.rb', line 18

def 
  @custom_metadata
end

#customer_keyObject

Your unique key for the customer associated with this connected account.



20
21
22
# File 'lib/seam/resources/connected_account.rb', line 20

def customer_key
  @customer_key
end

#default_checkin_timeObject

Default reservation check-in time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration — set during the connect_webview for providers like Lodgify whose API does not expose check-in times.



22
23
24
# File 'lib/seam/resources/connected_account.rb', line 22

def default_checkin_time
  @default_checkin_time
end

#default_checkout_timeObject

Default reservation check-out time for this connected account, as HH:mm (24-hour). Sourced from the connector configuration.



24
25
26
# File 'lib/seam/resources/connected_account.rb', line 24

def default_checkout_time
  @default_checkout_time
end

#display_nameObject

Display name for the connected account.



26
27
28
# File 'lib/seam/resources/connected_account.rb', line 26

def display_name
  @display_name
end

#ical_feed_originObject

For iCal connected accounts, the platform that produced the feed (for example, airbnb, vrbo, or booking), or unknown when it could not be determined. Intended for rendering the source platform's logo.



28
29
30
# File 'lib/seam/resources/connected_account.rb', line 28

def ical_feed_origin
  @ical_feed_origin
end

#ical_urlObject

For iCal connected accounts, the feed URL for the connection. Sourced from the connector configuration.



30
31
32
# File 'lib/seam/resources/connected_account.rb', line 30

def ical_url
  @ical_url
end

#image_urlObject

Logo URL for the connected account provider.



32
33
34
# File 'lib/seam/resources/connected_account.rb', line 32

def image_url
  @image_url
end

#time_zoneObject

IANA time zone (e.g. America/Los_Angeles) for this connected account. Sourced from the connector configuration.



34
35
36
# File 'lib/seam/resources/connected_account.rb', line 34

def time_zone
  @time_zone
end

#user_identifierObject

Deprecated.

Use display_name instead.

User identifier associated with the connected account.



37
38
39
# File 'lib/seam/resources/connected_account.rb', line 37

def user_identifier
  @user_identifier
end