Class: Seam::Resources::ConnectedAccount::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Defined Under Namespace

Classes: SaltoKsMetadata

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


34
35
36
# File 'lib/seam/resources/connected_account.rb', line 34

def error_code
  @error_code
end

#is_bridge_errorBoolean?

Indicates whether the error is related to Seam Bridge.

Returns:

  • (Boolean, nil)


37
38
39
# File 'lib/seam/resources/connected_account.rb', line 37

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorBoolean?

Indicates whether the error is related specifically to the connected account.

Returns:

  • (Boolean, nil)


40
41
42
# File 'lib/seam/resources/connected_account.rb', line 40

def 
  @is_connected_account_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


43
44
45
# File 'lib/seam/resources/connected_account.rb', line 43

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


46
# File 'lib/seam/resources/connected_account.rb', line 46

date_accessor :created_at

#salto_ks_metadataSaltoKsMetadata

Salto KS metadata associated with the connected account that has an error.

Returns:



31
# File 'lib/seam/resources/connected_account.rb', line 31

resource_accessor :salto_ks_metadata, SaltoKsMetadata