Class: Seam::Resources::ConnectedAccount::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount::Errors
- Defined in:
- lib/seam/resources/connected_account.rb
Defined Under Namespace
Classes: SaltoKsMetadata
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
-
#salto_ks_metadata ⇒ SaltoKsMetadata
Salto KS metadata associated with the connected account that has an error.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
34 35 36 |
# File 'lib/seam/resources/connected_account.rb', line 34 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
37 38 39 |
# File 'lib/seam/resources/connected_account.rb', line 37 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
40 41 42 |
# File 'lib/seam/resources/connected_account.rb', line 40 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
43 44 45 |
# File 'lib/seam/resources/connected_account.rb', line 43 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
46 |
# File 'lib/seam/resources/connected_account.rb', line 46 date_accessor :created_at |
#salto_ks_metadata ⇒ SaltoKsMetadata
Salto KS metadata associated with the connected account that has an error.
31 |
# File 'lib/seam/resources/connected_account.rb', line 31 resource_accessor :salto_ks_metadata, SaltoKsMetadata |