Class: Seam::Resources::ConnectedAccount::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Defined Under Namespace

Classes: SaltoKsMetadata

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeObject

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.



25
26
27
# File 'lib/seam/resources/connected_account.rb', line 25

def error_code
  @error_code
end

#is_bridge_errorObject

Indicates whether the error is related to Seam Bridge.



27
28
29
# File 'lib/seam/resources/connected_account.rb', line 27

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorObject

Indicates whether the error is related specifically to the connected account.



29
30
31
# File 'lib/seam/resources/connected_account.rb', line 29

def 
  @is_connected_account_error
end

#messageObject

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.



31
32
33
# File 'lib/seam/resources/connected_account.rb', line 31

def message
  @message
end