Class: Seam::Resources::ConnectedAccount::Errors::AccountDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::ConnectedAccount::Errors::AccountDisconnected
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the account is disconnected.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
account_disconnected
15 16 17 |
# File 'lib/seam/resources/connected_account.rb', line 15 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
18 19 20 |
# File 'lib/seam/resources/connected_account.rb', line 18 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
21 22 23 |
# File 'lib/seam/resources/connected_account.rb', line 21 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
24 25 26 |
# File 'lib/seam/resources/connected_account.rb', line 24 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
27 |
# File 'lib/seam/resources/connected_account.rb', line 27 date_accessor :created_at |