Class: Seam::Resources::ConnectedAccount::Errors::BridgeDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::ConnectedAccount::Errors::BridgeDisconnected
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the Seam API cannot communicate with Seam Bridge, for example, if the Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
bridge_disconnected
36 37 38 |
# File 'lib/seam/resources/connected_account.rb', line 36 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
39 40 41 |
# File 'lib/seam/resources/connected_account.rb', line 39 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
42 43 44 |
# File 'lib/seam/resources/connected_account.rb', line 42 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
45 46 47 |
# File 'lib/seam/resources/connected_account.rb', line 45 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
48 |
# File 'lib/seam/resources/connected_account.rb', line 48 date_accessor :created_at |