Class: Seam::Resources::ConnectedAccount::Errors::DormakabaSitesDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::ConnectedAccount::Errors::DormakabaSitesDisconnected
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that one or more dormakaba sites associated with the connected account could not be connected. Contact dormakaba support.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
dormakaba_sites_disconnected
102 103 104 |
# File 'lib/seam/resources/connected_account.rb', line 102 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
105 106 107 |
# File 'lib/seam/resources/connected_account.rb', line 105 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
108 109 110 |
# File 'lib/seam/resources/connected_account.rb', line 108 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
111 112 113 |
# File 'lib/seam/resources/connected_account.rb', line 111 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
114 |
# File 'lib/seam/resources/connected_account.rb', line 114 date_accessor :created_at |