Class: Seam::Resources::ConnectedAccount::Errors::SaltoKsMetadata::Sites
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount::Errors::SaltoKsMetadata::Sites
- Defined in:
- lib/seam/resources/connected_account.rb
Instance Attribute Summary collapse
-
#site_id ⇒ String?
ID of a Salto site associated with the connected account that has an error.
-
#site_name ⇒ String?
Name of a Salto site associated with the connected account that has an error.
-
#site_user_subscription_limit ⇒ Integer?
Subscription limit of site users for a Salto site associated with the connected account that has an error.
-
#subscribed_site_user_count ⇒ Integer?
Count of subscribed site users for a Salto site associated with the connected account that has an error.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#site_id ⇒ String?
ID of a Salto site associated with the connected account that has an error.
12 13 14 |
# File 'lib/seam/resources/connected_account.rb', line 12 def site_id @site_id end |
#site_name ⇒ String?
Name of a Salto site associated with the connected account that has an error.
15 16 17 |
# File 'lib/seam/resources/connected_account.rb', line 15 def site_name @site_name end |
#site_user_subscription_limit ⇒ Integer?
Subscription limit of site users for a Salto site associated with the connected account that has an error.
18 19 20 |
# File 'lib/seam/resources/connected_account.rb', line 18 def site_user_subscription_limit @site_user_subscription_limit end |
#subscribed_site_user_count ⇒ Integer?
Count of subscribed site users for a Salto site associated with the connected account that has an error.
21 22 23 |
# File 'lib/seam/resources/connected_account.rb', line 21 def subscribed_site_user_count @subscribed_site_user_count end |