Class: Seam::Resources::ConnectedAccount::Errors::SaltoKsMetadata::Sites

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#site_idObject

ID of a Salto site associated with the connected account that has an error.



11
12
13
# File 'lib/seam/resources/connected_account.rb', line 11

def site_id
  @site_id
end

#site_nameObject

Name of a Salto site associated with the connected account that has an error.



13
14
15
# File 'lib/seam/resources/connected_account.rb', line 13

def site_name
  @site_name
end

#site_user_subscription_limitObject

Subscription limit of site users for a Salto site associated with the connected account that has an error.



15
16
17
# File 'lib/seam/resources/connected_account.rb', line 15

def site_user_subscription_limit
  @site_user_subscription_limit
end

#subscribed_site_user_countObject

Count of subscribed site users for a Salto site associated with the connected account that has an error.



17
18
19
# File 'lib/seam/resources/connected_account.rb', line 17

def subscribed_site_user_count
  @subscribed_site_user_count
end