Class: Seam::Resources::ConnectedAccount::Errors::SaltoKsSubscriptionLimitExceeded
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::ConnectedAccount::Errors::SaltoKsSubscriptionLimitExceeded
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the maximum number of users allowed for the site has been reached. This means that new access codes cannot be created. Contact Salto support to increase the user limit.
Defined Under Namespace
Classes: SaltoKsMetadata
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
-
#salto_ks_metadata ⇒ SaltoKsMetadata
Salto KS metadata associated with the connected account that has an error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
salto_ks_subscription_limit_exceeded
81 82 83 |
# File 'lib/seam/resources/connected_account.rb', line 81 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
84 85 86 |
# File 'lib/seam/resources/connected_account.rb', line 84 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
87 88 89 |
# File 'lib/seam/resources/connected_account.rb', line 87 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
90 91 92 |
# File 'lib/seam/resources/connected_account.rb', line 90 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
93 |
# File 'lib/seam/resources/connected_account.rb', line 93 date_accessor :created_at |
#salto_ks_metadata ⇒ SaltoKsMetadata
Salto KS metadata associated with the connected account that has an error.
76 |
# File 'lib/seam/resources/connected_account.rb', line 76 resource_accessor :salto_ks_metadata, SaltoKsMetadata |