Class: Seam::Resources::ConnectedAccount::UserIdentifier
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount::UserIdentifier
- Defined in:
- lib/seam/resources/connected_account.rb
Instance Attribute Summary collapse
-
#api_url ⇒ String?
API URL for the user identifier associated with the connected account.
-
#email ⇒ String?
Email address of the user identifier associated with the connected account.
-
#exclusive ⇒ Boolean?
Indicates whether the user identifier associated with the connected account is exclusive.
-
#phone ⇒ String?
Phone number of the user identifier associated with the connected account.
-
#username ⇒ String?
Username of the user identifier associated with the connected account.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#api_url ⇒ String?
API URL for the user identifier associated with the connected account.
149 150 151 |
# File 'lib/seam/resources/connected_account.rb', line 149 def api_url @api_url end |
#email ⇒ String?
Email address of the user identifier associated with the connected account.
152 153 154 |
# File 'lib/seam/resources/connected_account.rb', line 152 def email @email end |
#exclusive ⇒ Boolean?
Indicates whether the user identifier associated with the connected account is exclusive.
155 156 157 |
# File 'lib/seam/resources/connected_account.rb', line 155 def exclusive @exclusive end |
#phone ⇒ String?
Phone number of the user identifier associated with the connected account.
158 159 160 |
# File 'lib/seam/resources/connected_account.rb', line 158 def phone @phone end |
#username ⇒ String?
Username of the user identifier associated with the connected account.
161 162 163 |
# File 'lib/seam/resources/connected_account.rb', line 161 def username @username end |