Class: Seam::Resources::ConnectedAccount::UserIdentifier

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#api_urlString?

API URL for the user identifier associated with the connected account.

Returns:

  • (String, nil)


52
53
54
# File 'lib/seam/resources/connected_account.rb', line 52

def api_url
  @api_url
end

#emailString?

Email address of the user identifier associated with the connected account.

Returns:

  • (String, nil)


55
56
57
# File 'lib/seam/resources/connected_account.rb', line 55

def email
  @email
end

#exclusiveBoolean?

Indicates whether the user identifier associated with the connected account is exclusive.

Returns:

  • (Boolean, nil)


58
59
60
# File 'lib/seam/resources/connected_account.rb', line 58

def exclusive
  @exclusive
end

#phoneString?

Phone number of the user identifier associated with the connected account.

Returns:

  • (String, nil)


61
62
63
# File 'lib/seam/resources/connected_account.rb', line 61

def phone
  @phone
end

#usernameString?

Username of the user identifier associated with the connected account.

Returns:

  • (String, nil)


64
65
66
# File 'lib/seam/resources/connected_account.rb', line 64

def username
  @username
end