Class: Seam::Resources::ConnectedAccount::UserIdentifier
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount::UserIdentifier
- Defined in:
- lib/seam/resources/connected_account.rb
Instance Attribute Summary collapse
-
#api_url ⇒ String?
API URL for the user identifier associated with the connected account.
-
#email ⇒ String?
Email address of the user identifier associated with the connected account.
-
#exclusive ⇒ Boolean?
Indicates whether the user identifier associated with the connected account is exclusive.
-
#phone ⇒ String?
Phone number of the user identifier associated with the connected account.
-
#username ⇒ String?
Username of the user identifier associated with the connected account.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#api_url ⇒ String?
API URL for the user identifier associated with the connected account.
52 53 54 |
# File 'lib/seam/resources/connected_account.rb', line 52 def api_url @api_url end |
#email ⇒ String?
Email address of the user identifier associated with the connected account.
55 56 57 |
# File 'lib/seam/resources/connected_account.rb', line 55 def email @email end |
#exclusive ⇒ Boolean?
Indicates whether the user identifier associated with the connected account is exclusive.
58 59 60 |
# File 'lib/seam/resources/connected_account.rb', line 58 def exclusive @exclusive end |
#phone ⇒ String?
Phone number of the user identifier associated with the connected account.
61 62 63 |
# File 'lib/seam/resources/connected_account.rb', line 61 def phone @phone end |
#username ⇒ String?
Username of the user identifier associated with the connected account.
64 65 66 |
# File 'lib/seam/resources/connected_account.rb', line 64 def username @username end |