Class: Seam::Resources::ConnectedAccount::UserIdentifier

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#api_urlObject

API URL for the user identifier associated with the connected account.



38
39
40
# File 'lib/seam/resources/connected_account.rb', line 38

def api_url
  @api_url
end

#emailObject

Email address of the user identifier associated with the connected account.



40
41
42
# File 'lib/seam/resources/connected_account.rb', line 40

def email
  @email
end

#exclusiveObject

Indicates whether the user identifier associated with the connected account is exclusive.



42
43
44
# File 'lib/seam/resources/connected_account.rb', line 42

def exclusive
  @exclusive
end

#phoneObject

Phone number of the user identifier associated with the connected account.



44
45
46
# File 'lib/seam/resources/connected_account.rb', line 44

def phone
  @phone
end

#usernameObject

Username of the user identifier associated with the connected account.



46
47
48
# File 'lib/seam/resources/connected_account.rb', line 46

def username
  @username
end