Class: Seam::Resources::ConnectedAccount::Warnings::AccountReauthorizationRequested
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::AccountReauthorizationRequested
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the Connected Account requires reauthorization using a new Connect Webview. The account is still connected, but cannot access new features. Delaying reauthorization too long will eventually cause the Connected Account to become disconnected.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
239 240 241 |
# File 'lib/seam/resources/connected_account.rb', line 239 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
account_reauthorization_requested
244 245 246 |
# File 'lib/seam/resources/connected_account.rb', line 244 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
247 |
# File 'lib/seam/resources/connected_account.rb', line 247 date_accessor :created_at |