Class: Seam::Resources::ConnectedAccount::Warnings::BeingDeleted
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::BeingDeleted
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the connected account is currently being deleted. All devices, access codes, and other resources associated with this account are in the process of being removed from Seam.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
254 255 256 |
# File 'lib/seam/resources/connected_account.rb', line 254 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
being_deleted
259 260 261 |
# File 'lib/seam/resources/connected_account.rb', line 259 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
262 |
# File 'lib/seam/resources/connected_account.rb', line 262 date_accessor :created_at |