Class: Seam::Resources::ConnectedAccount::Warnings::DormakabaSitesUnapproved
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::DormakabaSitesUnapproved
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that one or more dormakaba sites associated with the connected account are not approved. Contact support@getseam.com to finish setting up your account.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
299 300 301 |
# File 'lib/seam/resources/connected_account.rb', line 299 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
dormakaba_sites_unapproved
304 305 306 |
# File 'lib/seam/resources/connected_account.rb', line 304 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
307 |
# File 'lib/seam/resources/connected_account.rb', line 307 date_accessor :created_at |