Class: Seam::Resources::ConnectedAccount::Warnings::ProviderServiceUnavailable
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::ProviderServiceUnavailable
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the connected account's provider service is temporarily unavailable. Seam will automatically retry and reconnect when the service becomes available again.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
269 270 271 |
# File 'lib/seam/resources/connected_account.rb', line 269 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
provider_service_unavailable
274 275 276 |
# File 'lib/seam/resources/connected_account.rb', line 274 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
277 |
# File 'lib/seam/resources/connected_account.rb', line 277 date_accessor :created_at |