Class: Seam::Resources::ConnectedAccount::Warnings::SaltoKsMetadata::Sites
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ConnectedAccount::Warnings::SaltoKsMetadata::Sites
- Defined in:
- lib/seam/resources/connected_account.rb
Instance Attribute Summary collapse
-
#site_id ⇒ String?
ID of a Salto site associated with the connected account that has a warning.
-
#site_name ⇒ String?
Name of a Salto site associated with the connected account that has a warning.
-
#site_user_subscription_limit ⇒ Integer?
Subscription limit of site users for a Salto site associated with the connected account that has a warning.
-
#subscribed_site_user_count ⇒ Integer?
Count of subscribed site users for a Salto site associated with the connected account that has a warning.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#site_id ⇒ String?
ID of a Salto site associated with the connected account that has a warning.
72 73 74 |
# File 'lib/seam/resources/connected_account.rb', line 72 def site_id @site_id end |
#site_name ⇒ String?
Name of a Salto site associated with the connected account that has a warning.
75 76 77 |
# File 'lib/seam/resources/connected_account.rb', line 75 def site_name @site_name end |
#site_user_subscription_limit ⇒ Integer?
Subscription limit of site users for a Salto site associated with the connected account that has a warning.
78 79 80 |
# File 'lib/seam/resources/connected_account.rb', line 78 def site_user_subscription_limit @site_user_subscription_limit end |
#subscribed_site_user_count ⇒ Integer?
Count of subscribed site users for a Salto site associated with the connected account that has a warning.
81 82 83 |
# File 'lib/seam/resources/connected_account.rb', line 81 def subscribed_site_user_count @subscribed_site_user_count end |