Class: Seam::Resources::ConnectedAccount::Warnings::SaltoKsMetadata::Sites

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/connected_account.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#site_idObject

ID of a Salto site associated with the connected account that has a warning.



53
54
55
# File 'lib/seam/resources/connected_account.rb', line 53

def site_id
  @site_id
end

#site_nameObject

Name of a Salto site associated with the connected account that has a warning.



55
56
57
# File 'lib/seam/resources/connected_account.rb', line 55

def site_name
  @site_name
end

#site_user_subscription_limitObject

Subscription limit of site users for a Salto site associated with the connected account that has a warning.



57
58
59
# File 'lib/seam/resources/connected_account.rb', line 57

def site_user_subscription_limit
  @site_user_subscription_limit
end

#subscribed_site_user_countObject

Count of subscribed site users for a Salto site associated with the connected account that has a warning.



59
60
61
# File 'lib/seam/resources/connected_account.rb', line 59

def subscribed_site_user_count
  @subscribed_site_user_count
end