Class: Seam::Resources::ConnectedAccount::Warnings::ScheduledMaintenanceWindow
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::ScheduledMaintenanceWindow
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that scheduled downtime is planned for the connected account.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
170 171 172 |
# File 'lib/seam/resources/connected_account.rb', line 170 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
scheduled_maintenance_window
175 176 177 |
# File 'lib/seam/resources/connected_account.rb', line 175 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
178 |
# File 'lib/seam/resources/connected_account.rb', line 178 date_accessor :created_at |