Class: Seam::Resources::ConnectedAccount::Warnings::SetupRequired
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::SetupRequired
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that the connected account requires additional setup before it can be fully operational. Follow the instructions in the warning message to complete the setup.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
284 285 286 |
# File 'lib/seam/resources/connected_account.rb', line 284 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
setup_required
289 290 291 |
# File 'lib/seam/resources/connected_account.rb', line 289 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
292 |
# File 'lib/seam/resources/connected_account.rb', line 292 date_accessor :created_at |