Class: Seam::Resources::ConnectedAccount::Warnings::UnknownIssueWithConnectedAccount
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::ConnectedAccount::Warnings::UnknownIssueWithConnectedAccount
- Defined in:
- lib/seam/resources/connected_account.rb
Overview
Indicates that an unknown issue occurred while syncing the state of the connected account with the provider. This issue may affect the proper functioning of one or more resources in the account.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
185 186 187 |
# File 'lib/seam/resources/connected_account.rb', line 185 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
unknown_issue_with_connected_account
190 191 192 |
# File 'lib/seam/resources/connected_account.rb', line 190 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
193 |
# File 'lib/seam/resources/connected_account.rb', line 193 date_accessor :created_at |