Class: Seam::Resources::CustomerPortal
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::CustomerPortal
- Defined in:
- lib/seam/resources/customer_portal.rb
Overview
Represents a Customer Portal. Customer Portal is a hosted, customizable interface for managing device access. It enables you to embed secure, pre-authenticated access flows into your product—either by sharing a link with users or embedding a view in an iframe.
With Customer Portal, you no longer need to build out frontend experiences for physical access, thermostats, and sensors. Instead, you can ship enterprise-grade access control experiences in a fraction of the time, while maintaining your product's branding and user experience.
Seam hosts these flows, handling everything from account connection and device mapping to full-featured device control.
Instance Attribute Summary collapse
-
#customer_key ⇒ Object
Customer key for the customer portal.
-
#url ⇒ Object
URL for the customer portal.
-
#workspace_id ⇒ Object
ID of the workspace associated with the customer portal.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#customer_key ⇒ Object
Customer key for the customer portal.
12 13 14 |
# File 'lib/seam/resources/customer_portal.rb', line 12 def customer_key @customer_key end |
#url ⇒ Object
URL for the customer portal.
14 15 16 |
# File 'lib/seam/resources/customer_portal.rb', line 14 def url @url end |
#workspace_id ⇒ Object
ID of the workspace associated with the customer portal.
16 17 18 |
# File 'lib/seam/resources/customer_portal.rb', line 16 def workspace_id @workspace_id end |