Class: Seam::Resources::Device
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device
- Defined in:
- lib/seam/resources/device.rb
Overview
Represents a device that has been connected to Seam.
Defined Under Namespace
Classes: DeviceManufacturer, DeviceProvider, Errors, Location, Properties, Warnings
Instance Attribute Summary collapse
-
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
-
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
-
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
-
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
-
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
-
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
-
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
-
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
-
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
-
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
-
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
-
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
-
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
-
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
-
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
-
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
-
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
-
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
-
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
-
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
-
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam.
-
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
-
#custom_metadata ⇒ Hash{String => String, Boolean}
Set of key:value pairs.
-
#device_id ⇒ String
ID of the device.
-
#device_type ⇒ String
Type of the device.
-
#display_name ⇒ String
Display name of the device, defaults to nickname (if it is set) or
properties.appearance.name, otherwise. -
#is_managed ⇒ TrueClass
Indicates whether Seam manages the device.
-
#nickname ⇒ String?
Optional nickname to describe the device, settable through Seam.
-
#space_ids ⇒ Array<String>
IDs of the spaces the device is in.
-
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the device object was created.
-
#device_manufacturer ⇒ DeviceManufacturer?
Manufacturer of the device.
-
#device_provider ⇒ DeviceProvider?
Provider of the device.
-
#errors ⇒ Array<Errors>
Array of errors associated with the device.
-
#location ⇒ Location?
Location information for the device.
-
#properties ⇒ Properties
Properties of the device.
-
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
2600 2601 2602 |
# File 'lib/seam/resources/device.rb', line 2600 def can_configure_auto_lock @can_configure_auto_lock end |
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
2603 2604 2605 |
# File 'lib/seam/resources/device.rb', line 2603 def can_hvac_cool @can_hvac_cool end |
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
2606 2607 2608 |
# File 'lib/seam/resources/device.rb', line 2606 def can_hvac_heat @can_hvac_heat end |
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
2609 2610 2611 |
# File 'lib/seam/resources/device.rb', line 2609 def can_hvac_heat_cool @can_hvac_heat_cool end |
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
2612 2613 2614 |
# File 'lib/seam/resources/device.rb', line 2612 def can_program_offline_access_codes @can_program_offline_access_codes end |
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
2615 2616 2617 |
# File 'lib/seam/resources/device.rb', line 2615 def can_program_online_access_codes @can_program_online_access_codes end |
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
2618 2619 2620 |
# File 'lib/seam/resources/device.rb', line 2618 def can_program_thermostat_programs_as_different_each_day @can_program_thermostat_programs_as_different_each_day end |
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
2621 2622 2623 |
# File 'lib/seam/resources/device.rb', line 2621 def can_program_thermostat_programs_as_same_each_day @can_program_thermostat_programs_as_same_each_day end |
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
2624 2625 2626 |
# File 'lib/seam/resources/device.rb', line 2624 def can_program_thermostat_programs_as_weekday_weekend @can_program_thermostat_programs_as_weekday_weekend end |
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
2627 2628 2629 |
# File 'lib/seam/resources/device.rb', line 2627 def can_remotely_lock @can_remotely_lock end |
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
2630 2631 2632 |
# File 'lib/seam/resources/device.rb', line 2630 def can_remotely_unlock @can_remotely_unlock end |
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
2633 2634 2635 |
# File 'lib/seam/resources/device.rb', line 2633 def can_run_thermostat_programs @can_run_thermostat_programs end |
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
2636 2637 2638 |
# File 'lib/seam/resources/device.rb', line 2636 def can_simulate_connection @can_simulate_connection end |
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
2639 2640 2641 |
# File 'lib/seam/resources/device.rb', line 2639 def can_simulate_disconnection @can_simulate_disconnection end |
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
2642 2643 2644 |
# File 'lib/seam/resources/device.rb', line 2642 def can_simulate_hub_connection @can_simulate_hub_connection end |
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
2645 2646 2647 |
# File 'lib/seam/resources/device.rb', line 2645 def can_simulate_hub_disconnection @can_simulate_hub_disconnection end |
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
2648 2649 2650 |
# File 'lib/seam/resources/device.rb', line 2648 def can_simulate_paid_subscription @can_simulate_paid_subscription end |
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
2651 2652 2653 |
# File 'lib/seam/resources/device.rb', line 2651 def can_simulate_removal @can_simulate_removal end |
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
2654 2655 2656 |
# File 'lib/seam/resources/device.rb', line 2654 def can_turn_off_hvac @can_turn_off_hvac end |
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
2657 2658 2659 |
# File 'lib/seam/resources/device.rb', line 2657 def can_unlock_with_code @can_unlock_with_code end |
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.
Known values:
access_codelocknoise_detectionthermostatbatteryphone
2667 2668 2669 |
# File 'lib/seam/resources/device.rb', line 2667 def capabilities_supported @capabilities_supported end |
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
2670 2671 2672 |
# File 'lib/seam/resources/device.rb', line 2670 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Hash{String => String, Boolean}
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application. Keys set to null or to an empty string are omitted.
2673 2674 2675 |
# File 'lib/seam/resources/device.rb', line 2673 def @custom_metadata end |
#device_id ⇒ String
ID of the device.
2676 2677 2678 |
# File 'lib/seam/resources/device.rb', line 2676 def device_id @device_id end |
#device_type ⇒ String
Type of the device. Known values:
akuvox_lockaugust_lockbrivo_access_pointbutterflymx_panelavigilon_alta_entrydoorking_lockgenie_doorigloo_locklinear_locklockly_lockkwikset_locknuki_locksalto_lockschlage_locksmartthings_lockwyze_lockyale_locktwo_n_intercomcontrolbyweb_devicettlock_lockigloohome_lockfour_suites_doordormakaba_oracode_doortedee_lockakiles_lockultraloq_lockyacan_lockkeyincode_lockomnitec_lockkisi_lockaqara_lockkeynest_keynoiseaware_activity_zoneminut_sensorecobee_thermostatnest_thermostathoneywell_resideo_thermostattado_thermostatsensi_thermostatsmartthings_thermostatios_phoneandroid_phonering_camera
2723 2724 2725 |
# File 'lib/seam/resources/device.rb', line 2723 def device_type @device_type end |
#display_name ⇒ String
Display name of the device, defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the device easily, especially when there are numerous devices.
2726 2727 2728 |
# File 'lib/seam/resources/device.rb', line 2726 def display_name @display_name end |
#is_managed ⇒ TrueClass
Indicates whether Seam manages the device. See also Managed and Unmanaged Devices.
2729 2730 2731 |
# File 'lib/seam/resources/device.rb', line 2729 def is_managed @is_managed end |
#nickname ⇒ String?
Optional nickname to describe the device, settable through Seam.
2732 2733 2734 |
# File 'lib/seam/resources/device.rb', line 2732 def nickname @nickname end |
#space_ids ⇒ Array<String>
IDs of the spaces the device is in.
2735 2736 2737 |
# File 'lib/seam/resources/device.rb', line 2735 def space_ids @space_ids end |
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
2738 2739 2740 |
# File 'lib/seam/resources/device.rb', line 2738 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the device object was created.
2742 |
# File 'lib/seam/resources/device.rb', line 2742 date_accessor :created_at |
#device_manufacturer ⇒ DeviceManufacturer?
Manufacturer of the device. Represents the hardware brand, which may differ from the provider.
2582 |
# File 'lib/seam/resources/device.rb', line 2582 resource_accessor :device_manufacturer, DeviceManufacturer |
#device_provider ⇒ DeviceProvider?
Provider of the device. Represents the third-party service through which the device is controlled.
2585 |
# File 'lib/seam/resources/device.rb', line 2585 resource_accessor :device_provider, DeviceProvider |
#errors ⇒ Array<Errors>
Array of errors associated with the device. Each error object within the array contains two fields: error_code and message. error_code is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. message provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.
2594 |
# File 'lib/seam/resources/device.rb', line 2594 resource_list_accessor :errors, Errors |
#location ⇒ Location?
Location information for the device.
2588 |
# File 'lib/seam/resources/device.rb', line 2588 resource_accessor :location, Location |
#properties ⇒ Properties
Properties of the device.
2591 |
# File 'lib/seam/resources/device.rb', line 2591 resource_accessor :properties, Properties |
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device. Each warning object within the array contains two fields: warning_code and message. warning_code is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. message provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.
2597 |
# File 'lib/seam/resources/device.rb', line 2597 resource_list_accessor :warnings, Warnings |