Class: Seam::Resources::Device
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device
- Defined in:
- lib/seam/resources/device.rb
Overview
Represents a device that has been connected to Seam.
Defined Under Namespace
Classes: DeviceManufacturer, DeviceProvider, Errors, Location, Properties, Warnings
Instance Attribute Summary collapse
-
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
-
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
-
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
-
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
-
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
-
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
-
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
-
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
-
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
-
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
-
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
-
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
-
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
-
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
-
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
-
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
-
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
-
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
-
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
-
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
-
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam.
-
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
-
#custom_metadata ⇒ Hash{String => String, Boolean}
Set of key:value pairs.
-
#device_id ⇒ String
ID of the device.
-
#device_type ⇒ String
Type of the device.
-
#display_name ⇒ String
Display name of the device, defaults to nickname (if it is set) or
properties.appearance.name, otherwise. -
#is_managed ⇒ TrueClass
Indicates whether Seam manages the device.
-
#nickname ⇒ String?
Optional nickname to describe the device, settable through Seam.
-
#space_ids ⇒ Array<String>
IDs of the spaces the device is in.
-
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the device object was created.
-
#device_manufacturer ⇒ DeviceManufacturer?
Manufacturer of the device.
-
#device_provider ⇒ DeviceProvider?
Provider of the device.
-
#errors ⇒ Array<Errors>
Array of errors associated with the device.
-
#location ⇒ Location?
Location information for the device.
-
#properties ⇒ Properties
Properties of the device.
-
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
2586 2587 2588 |
# File 'lib/seam/resources/device.rb', line 2586 def can_configure_auto_lock @can_configure_auto_lock end |
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
2589 2590 2591 |
# File 'lib/seam/resources/device.rb', line 2589 def can_hvac_cool @can_hvac_cool end |
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
2592 2593 2594 |
# File 'lib/seam/resources/device.rb', line 2592 def can_hvac_heat @can_hvac_heat end |
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
2595 2596 2597 |
# File 'lib/seam/resources/device.rb', line 2595 def can_hvac_heat_cool @can_hvac_heat_cool end |
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
2598 2599 2600 |
# File 'lib/seam/resources/device.rb', line 2598 def can_program_offline_access_codes @can_program_offline_access_codes end |
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
2601 2602 2603 |
# File 'lib/seam/resources/device.rb', line 2601 def can_program_online_access_codes @can_program_online_access_codes end |
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
2604 2605 2606 |
# File 'lib/seam/resources/device.rb', line 2604 def can_program_thermostat_programs_as_different_each_day @can_program_thermostat_programs_as_different_each_day end |
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
2607 2608 2609 |
# File 'lib/seam/resources/device.rb', line 2607 def can_program_thermostat_programs_as_same_each_day @can_program_thermostat_programs_as_same_each_day end |
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
2610 2611 2612 |
# File 'lib/seam/resources/device.rb', line 2610 def can_program_thermostat_programs_as_weekday_weekend @can_program_thermostat_programs_as_weekday_weekend end |
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
2613 2614 2615 |
# File 'lib/seam/resources/device.rb', line 2613 def can_remotely_lock @can_remotely_lock end |
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
2616 2617 2618 |
# File 'lib/seam/resources/device.rb', line 2616 def can_remotely_unlock @can_remotely_unlock end |
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
2619 2620 2621 |
# File 'lib/seam/resources/device.rb', line 2619 def can_run_thermostat_programs @can_run_thermostat_programs end |
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
2622 2623 2624 |
# File 'lib/seam/resources/device.rb', line 2622 def can_simulate_connection @can_simulate_connection end |
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
2625 2626 2627 |
# File 'lib/seam/resources/device.rb', line 2625 def can_simulate_disconnection @can_simulate_disconnection end |
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
2628 2629 2630 |
# File 'lib/seam/resources/device.rb', line 2628 def can_simulate_hub_connection @can_simulate_hub_connection end |
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
2631 2632 2633 |
# File 'lib/seam/resources/device.rb', line 2631 def can_simulate_hub_disconnection @can_simulate_hub_disconnection end |
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
2634 2635 2636 |
# File 'lib/seam/resources/device.rb', line 2634 def can_simulate_paid_subscription @can_simulate_paid_subscription end |
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
2637 2638 2639 |
# File 'lib/seam/resources/device.rb', line 2637 def can_simulate_removal @can_simulate_removal end |
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
2640 2641 2642 |
# File 'lib/seam/resources/device.rb', line 2640 def can_turn_off_hvac @can_turn_off_hvac end |
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
2643 2644 2645 |
# File 'lib/seam/resources/device.rb', line 2643 def can_unlock_with_code @can_unlock_with_code end |
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.
Known values:
access_codelocknoise_detectionthermostatbatteryphone
2653 2654 2655 |
# File 'lib/seam/resources/device.rb', line 2653 def capabilities_supported @capabilities_supported end |
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
2656 2657 2658 |
# File 'lib/seam/resources/device.rb', line 2656 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Hash{String => String, Boolean}
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.
2659 2660 2661 |
# File 'lib/seam/resources/device.rb', line 2659 def @custom_metadata end |
#device_id ⇒ String
ID of the device.
2662 2663 2664 |
# File 'lib/seam/resources/device.rb', line 2662 def device_id @device_id end |
#device_type ⇒ String
Type of the device. Known values:
akuvox_lockaugust_lockbrivo_access_pointbutterflymx_panelavigilon_alta_entrydoorking_lockgenie_doorigloo_locklinear_locklockly_lockkwikset_locknuki_locksalto_lockschlage_locksmartthings_lockwyze_lockyale_locktwo_n_intercomcontrolbyweb_devicettlock_lockigloohome_lockfour_suites_doordormakaba_oracode_doortedee_lockakiles_lockultraloq_lockyacan_lockkeyincode_lockomnitec_lockkisi_lockaqara_lockkeynest_keynoiseaware_activity_zoneminut_sensorecobee_thermostatnest_thermostathoneywell_resideo_thermostattado_thermostatsensi_thermostatsmartthings_thermostatios_phoneandroid_phonering_camera
2709 2710 2711 |
# File 'lib/seam/resources/device.rb', line 2709 def device_type @device_type end |
#display_name ⇒ String
Display name of the device, defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the device easily, especially when there are numerous devices.
2712 2713 2714 |
# File 'lib/seam/resources/device.rb', line 2712 def display_name @display_name end |
#is_managed ⇒ TrueClass
Indicates whether Seam manages the device. See also Managed and Unmanaged Devices.
2715 2716 2717 |
# File 'lib/seam/resources/device.rb', line 2715 def is_managed @is_managed end |
#nickname ⇒ String?
Optional nickname to describe the device, settable through Seam.
2718 2719 2720 |
# File 'lib/seam/resources/device.rb', line 2718 def nickname @nickname end |
#space_ids ⇒ Array<String>
IDs of the spaces the device is in.
2721 2722 2723 |
# File 'lib/seam/resources/device.rb', line 2721 def space_ids @space_ids end |
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
2724 2725 2726 |
# File 'lib/seam/resources/device.rb', line 2724 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the device object was created.
2728 |
# File 'lib/seam/resources/device.rb', line 2728 date_accessor :created_at |
#device_manufacturer ⇒ DeviceManufacturer?
Manufacturer of the device. Represents the hardware brand, which may differ from the provider.
2568 |
# File 'lib/seam/resources/device.rb', line 2568 resource_accessor :device_manufacturer, DeviceManufacturer |
#device_provider ⇒ DeviceProvider?
Provider of the device. Represents the third-party service through which the device is controlled.
2571 |
# File 'lib/seam/resources/device.rb', line 2571 resource_accessor :device_provider, DeviceProvider |
#errors ⇒ Array<Errors>
Array of errors associated with the device. Each error object within the array contains two fields: error_code and message. error_code is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. message provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.
2580 |
# File 'lib/seam/resources/device.rb', line 2580 resource_list_accessor :errors, Errors |
#location ⇒ Location?
Location information for the device.
2574 |
# File 'lib/seam/resources/device.rb', line 2574 resource_accessor :location, Location |
#properties ⇒ Properties
Properties of the device.
2577 |
# File 'lib/seam/resources/device.rb', line 2577 resource_accessor :properties, Properties |
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device. Each warning object within the array contains two fields: warning_code and message. warning_code is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. message provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.
2583 |
# File 'lib/seam/resources/device.rb', line 2583 resource_list_accessor :warnings, Warnings |