Class: Seam::Resources::Device
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device
- Defined in:
- lib/seam/resources/device.rb
Overview
Represents a device that has been connected to Seam.
Defined Under Namespace
Classes: DeviceManufacturer, DeviceProvider, Errors, Location, Properties, Warnings
Instance Attribute Summary collapse
-
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
-
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
-
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
-
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
-
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
-
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
-
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
-
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
-
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
-
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
-
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
-
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
-
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
-
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
-
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
-
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
-
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
-
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
-
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
-
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
-
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam.
-
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
-
#custom_metadata ⇒ Hash
Set of key:value pairs.
-
#device_id ⇒ String
ID of the device.
-
#device_type ⇒ String
Type of the device.
-
#display_name ⇒ String
Display name of the device, defaults to nickname (if it is set) or
properties.appearance.name, otherwise. -
#is_managed ⇒ Boolean
Indicates whether Seam manages the device.
-
#nickname ⇒ String?
Optional nickname to describe the device, settable through Seam.
-
#space_ids ⇒ Array<String>
IDs of the spaces the device is in.
-
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the device object was created.
-
#device_manufacturer ⇒ DeviceManufacturer?
Manufacturer of the device.
-
#device_provider ⇒ DeviceProvider?
Provider of the device.
-
#errors ⇒ Array<Errors>
Array of errors associated with the device.
-
#location ⇒ Location?
Location information for the device.
-
#properties ⇒ Properties
Properties of the device.
-
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
1722 1723 1724 |
# File 'lib/seam/resources/device.rb', line 1722 def can_configure_auto_lock @can_configure_auto_lock end |
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
1725 1726 1727 |
# File 'lib/seam/resources/device.rb', line 1725 def can_hvac_cool @can_hvac_cool end |
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
1728 1729 1730 |
# File 'lib/seam/resources/device.rb', line 1728 def can_hvac_heat @can_hvac_heat end |
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
1731 1732 1733 |
# File 'lib/seam/resources/device.rb', line 1731 def can_hvac_heat_cool @can_hvac_heat_cool end |
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
1734 1735 1736 |
# File 'lib/seam/resources/device.rb', line 1734 def can_program_offline_access_codes @can_program_offline_access_codes end |
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
1737 1738 1739 |
# File 'lib/seam/resources/device.rb', line 1737 def can_program_online_access_codes @can_program_online_access_codes end |
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
1740 1741 1742 |
# File 'lib/seam/resources/device.rb', line 1740 def can_program_thermostat_programs_as_different_each_day @can_program_thermostat_programs_as_different_each_day end |
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
1743 1744 1745 |
# File 'lib/seam/resources/device.rb', line 1743 def can_program_thermostat_programs_as_same_each_day @can_program_thermostat_programs_as_same_each_day end |
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
1746 1747 1748 |
# File 'lib/seam/resources/device.rb', line 1746 def can_program_thermostat_programs_as_weekday_weekend @can_program_thermostat_programs_as_weekday_weekend end |
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
1749 1750 1751 |
# File 'lib/seam/resources/device.rb', line 1749 def can_remotely_lock @can_remotely_lock end |
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
1752 1753 1754 |
# File 'lib/seam/resources/device.rb', line 1752 def can_remotely_unlock @can_remotely_unlock end |
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
1755 1756 1757 |
# File 'lib/seam/resources/device.rb', line 1755 def can_run_thermostat_programs @can_run_thermostat_programs end |
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
1758 1759 1760 |
# File 'lib/seam/resources/device.rb', line 1758 def can_simulate_connection @can_simulate_connection end |
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
1761 1762 1763 |
# File 'lib/seam/resources/device.rb', line 1761 def can_simulate_disconnection @can_simulate_disconnection end |
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
1764 1765 1766 |
# File 'lib/seam/resources/device.rb', line 1764 def can_simulate_hub_connection @can_simulate_hub_connection end |
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
1767 1768 1769 |
# File 'lib/seam/resources/device.rb', line 1767 def can_simulate_hub_disconnection @can_simulate_hub_disconnection end |
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
1770 1771 1772 |
# File 'lib/seam/resources/device.rb', line 1770 def can_simulate_paid_subscription @can_simulate_paid_subscription end |
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
1773 1774 1775 |
# File 'lib/seam/resources/device.rb', line 1773 def can_simulate_removal @can_simulate_removal end |
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
1776 1777 1778 |
# File 'lib/seam/resources/device.rb', line 1776 def can_turn_off_hvac @can_turn_off_hvac end |
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
1779 1780 1781 |
# File 'lib/seam/resources/device.rb', line 1779 def can_unlock_with_code @can_unlock_with_code end |
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.
1782 1783 1784 |
# File 'lib/seam/resources/device.rb', line 1782 def capabilities_supported @capabilities_supported end |
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
1785 1786 1787 |
# File 'lib/seam/resources/device.rb', line 1785 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Hash
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.
1788 1789 1790 |
# File 'lib/seam/resources/device.rb', line 1788 def @custom_metadata end |
#device_id ⇒ String
ID of the device.
1791 1792 1793 |
# File 'lib/seam/resources/device.rb', line 1791 def device_id @device_id end |
#device_type ⇒ String
Type of the device.
1794 1795 1796 |
# File 'lib/seam/resources/device.rb', line 1794 def device_type @device_type end |
#display_name ⇒ String
Display name of the device, defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the device easily, especially when there are numerous devices.
1797 1798 1799 |
# File 'lib/seam/resources/device.rb', line 1797 def display_name @display_name end |
#is_managed ⇒ Boolean
Indicates whether Seam manages the device. See also Managed and Unmanaged Devices.
1800 1801 1802 |
# File 'lib/seam/resources/device.rb', line 1800 def is_managed @is_managed end |
#nickname ⇒ String?
Optional nickname to describe the device, settable through Seam.
1803 1804 1805 |
# File 'lib/seam/resources/device.rb', line 1803 def nickname @nickname end |
#space_ids ⇒ Array<String>
IDs of the spaces the device is in.
1806 1807 1808 |
# File 'lib/seam/resources/device.rb', line 1806 def space_ids @space_ids end |
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
1809 1810 1811 |
# File 'lib/seam/resources/device.rb', line 1809 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the device object was created.
1813 |
# File 'lib/seam/resources/device.rb', line 1813 date_accessor :created_at |
#device_manufacturer ⇒ DeviceManufacturer?
Manufacturer of the device. Represents the hardware brand, which may differ from the provider.
1704 |
# File 'lib/seam/resources/device.rb', line 1704 resource_accessor :device_manufacturer, DeviceManufacturer |
#device_provider ⇒ DeviceProvider?
Provider of the device. Represents the third-party service through which the device is controlled.
1707 |
# File 'lib/seam/resources/device.rb', line 1707 resource_accessor :device_provider, DeviceProvider |
#errors ⇒ Array<Errors>
Array of errors associated with the device. Each error object within the array contains two fields: error_code and message. error_code is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. message provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.
1716 |
# File 'lib/seam/resources/device.rb', line 1716 resource_list_accessor :errors, Errors |
#location ⇒ Location?
Location information for the device.
1710 |
# File 'lib/seam/resources/device.rb', line 1710 resource_accessor :location, Location |
#properties ⇒ Properties
Properties of the device.
1713 |
# File 'lib/seam/resources/device.rb', line 1713 resource_accessor :properties, Properties |
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device. Each warning object within the array contains two fields: warning_code and message. warning_code is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. message provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.
1719 |
# File 'lib/seam/resources/device.rb', line 1719 resource_list_accessor :warnings, Warnings |