Class: Seam::Resources::Device

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/device.rb

Overview

Represents a device that has been connected to Seam.

Defined Under Namespace

Classes: DeviceManufacturer, DeviceProvider, Errors, Location, Properties, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_configure_auto_lockObject

Indicates whether the lock supports configuring automatic locking.



1134
1135
1136
# File 'lib/seam/resources/device.rb', line 1134

def can_configure_auto_lock
  @can_configure_auto_lock
end

#can_hvac_coolObject

Indicates whether the thermostat supports cooling.



1136
1137
1138
# File 'lib/seam/resources/device.rb', line 1136

def can_hvac_cool
  @can_hvac_cool
end

#can_hvac_heatObject

Indicates whether the thermostat supports heating.



1138
1139
1140
# File 'lib/seam/resources/device.rb', line 1138

def can_hvac_heat
  @can_hvac_heat
end

#can_hvac_heat_coolObject

Indicates whether the thermostat supports simultaneous heating and cooling.



1140
1141
1142
# File 'lib/seam/resources/device.rb', line 1140

def can_hvac_heat_cool
  @can_hvac_heat_cool
end

#can_program_offline_access_codesObject

Indicates whether the device supports programming offline access codes.



1142
1143
1144
# File 'lib/seam/resources/device.rb', line 1142

def can_program_offline_access_codes
  @can_program_offline_access_codes
end

#can_program_online_access_codesObject

Indicates whether the device supports programming online access codes.



1144
1145
1146
# File 'lib/seam/resources/device.rb', line 1144

def can_program_online_access_codes
  @can_program_online_access_codes
end

#can_program_thermostat_programs_as_different_each_dayObject

Indicates whether the thermostat supports different climate programs for each day of the week.



1146
1147
1148
# File 'lib/seam/resources/device.rb', line 1146

def can_program_thermostat_programs_as_different_each_day
  @can_program_thermostat_programs_as_different_each_day
end

#can_program_thermostat_programs_as_same_each_dayObject

Indicates whether the thermostat supports a single climate program applied to every day.



1148
1149
1150
# File 'lib/seam/resources/device.rb', line 1148

def can_program_thermostat_programs_as_same_each_day
  @can_program_thermostat_programs_as_same_each_day
end

#can_program_thermostat_programs_as_weekday_weekendObject

Indicates whether the thermostat supports weekday/weekend climate programs.



1150
1151
1152
# File 'lib/seam/resources/device.rb', line 1150

def can_program_thermostat_programs_as_weekday_weekend
  @can_program_thermostat_programs_as_weekday_weekend
end

#can_remotely_lockObject

Indicates whether the device supports remote locking.



1152
1153
1154
# File 'lib/seam/resources/device.rb', line 1152

def can_remotely_lock
  @can_remotely_lock
end

#can_remotely_unlockObject

Indicates whether the device supports remote unlocking.



1154
1155
1156
# File 'lib/seam/resources/device.rb', line 1154

def can_remotely_unlock
  @can_remotely_unlock
end

#can_run_thermostat_programsObject

Indicates whether the thermostat supports running climate programs.



1156
1157
1158
# File 'lib/seam/resources/device.rb', line 1156

def can_run_thermostat_programs
  @can_run_thermostat_programs
end

#can_simulate_connectionObject

Indicates whether the device supports simulating connection in a sandbox.



1158
1159
1160
# File 'lib/seam/resources/device.rb', line 1158

def can_simulate_connection
  @can_simulate_connection
end

#can_simulate_disconnectionObject

Indicates whether the device supports simulating disconnection in a sandbox.



1160
1161
1162
# File 'lib/seam/resources/device.rb', line 1160

def can_simulate_disconnection
  @can_simulate_disconnection
end

#can_simulate_hub_connectionObject

Indicates whether the hub supports simulating connection in a sandbox.



1162
1163
1164
# File 'lib/seam/resources/device.rb', line 1162

def can_simulate_hub_connection
  @can_simulate_hub_connection
end

#can_simulate_hub_disconnectionObject

Indicates whether the hub supports simulating disconnection in a sandbox.



1164
1165
1166
# File 'lib/seam/resources/device.rb', line 1164

def can_simulate_hub_disconnection
  @can_simulate_hub_disconnection
end

#can_simulate_paid_subscriptionObject

Indicates whether the device supports simulating a paid subscription in a sandbox.



1166
1167
1168
# File 'lib/seam/resources/device.rb', line 1166

def can_simulate_paid_subscription
  @can_simulate_paid_subscription
end

#can_simulate_removalObject

Indicates whether the device supports simulating removal in a sandbox.



1168
1169
1170
# File 'lib/seam/resources/device.rb', line 1168

def can_simulate_removal
  @can_simulate_removal
end

#can_turn_off_hvacObject

Indicates whether the thermostat can be turned off.



1170
1171
1172
# File 'lib/seam/resources/device.rb', line 1170

def can_turn_off_hvac
  @can_turn_off_hvac
end

#can_unlock_with_codeObject

Indicates whether the lock supports unlocking with an access code.



1172
1173
1174
# File 'lib/seam/resources/device.rb', line 1172

def can_unlock_with_code
  @can_unlock_with_code
end

#capabilities_supportedObject

Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.



1174
1175
1176
# File 'lib/seam/resources/device.rb', line 1174

def capabilities_supported
  @capabilities_supported
end

#connected_account_idObject

Unique identifier for the account associated with the device.



1176
1177
1178
# File 'lib/seam/resources/device.rb', line 1176

def 
  @connected_account_id
end

#custom_metadataObject

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.



1178
1179
1180
# File 'lib/seam/resources/device.rb', line 1178

def 
  @custom_metadata
end

#device_idObject

ID of the device.



1180
1181
1182
# File 'lib/seam/resources/device.rb', line 1180

def device_id
  @device_id
end

#device_typeObject

Type of the device.



1182
1183
1184
# File 'lib/seam/resources/device.rb', line 1182

def device_type
  @device_type
end

#display_nameObject

Display name of the device, defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the device easily, especially when there are numerous devices.



1184
1185
1186
# File 'lib/seam/resources/device.rb', line 1184

def display_name
  @display_name
end

#is_managedObject

Indicates whether Seam manages the device. See also Managed and Unmanaged Devices.



1186
1187
1188
# File 'lib/seam/resources/device.rb', line 1186

def is_managed
  @is_managed
end

#nicknameObject

Optional nickname to describe the device, settable through Seam.



1188
1189
1190
# File 'lib/seam/resources/device.rb', line 1188

def nickname
  @nickname
end

#space_idsObject

IDs of the spaces the device is in.



1190
1191
1192
# File 'lib/seam/resources/device.rb', line 1190

def space_ids
  @space_ids
end

#workspace_idObject

Unique identifier for the Seam workspace associated with the device.



1192
1193
1194
# File 'lib/seam/resources/device.rb', line 1192

def workspace_id
  @workspace_id
end