Class: Seam::Resources::Device
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/device.rb
Overview
Represents a device that has been connected to Seam.
Instance Attribute Summary collapse
-
#can_configure_auto_lock ⇒ Object
Indicates whether the lock supports configuring automatic locking.
-
#can_hvac_cool ⇒ Object
Indicates whether the thermostat supports cooling.
-
#can_hvac_heat ⇒ Object
Indicates whether the thermostat supports heating.
-
#can_hvac_heat_cool ⇒ Object
Indicates whether the thermostat supports simultaneous heating and cooling.
-
#can_program_offline_access_codes ⇒ Object
Indicates whether the device supports programming offline access codes.
-
#can_program_online_access_codes ⇒ Object
Indicates whether the device supports programming online access codes.
-
#can_program_thermostat_programs_as_different_each_day ⇒ Object
Indicates whether the thermostat supports different climate programs for each day of the week.
-
#can_program_thermostat_programs_as_same_each_day ⇒ Object
Indicates whether the thermostat supports a single climate program applied to every day.
-
#can_program_thermostat_programs_as_weekday_weekend ⇒ Object
Indicates whether the thermostat supports weekday/weekend climate programs.
-
#can_remotely_lock ⇒ Object
Indicates whether the device supports remote locking.
-
#can_remotely_unlock ⇒ Object
Indicates whether the device supports remote unlocking.
-
#can_run_thermostat_programs ⇒ Object
Indicates whether the thermostat supports running climate programs.
-
#can_simulate_connection ⇒ Object
Indicates whether the device supports simulating connection in a sandbox.
-
#can_simulate_disconnection ⇒ Object
Indicates whether the device supports simulating disconnection in a sandbox.
-
#can_simulate_hub_connection ⇒ Object
Indicates whether the hub supports simulating connection in a sandbox.
-
#can_simulate_hub_disconnection ⇒ Object
Indicates whether the hub supports simulating disconnection in a sandbox.
-
#can_simulate_paid_subscription ⇒ Object
Indicates whether the device supports simulating a paid subscription in a sandbox.
-
#can_simulate_removal ⇒ Object
Indicates whether the device supports simulating removal in a sandbox.
-
#can_turn_off_hvac ⇒ Object
Indicates whether the thermostat can be turned off.
-
#can_unlock_with_code ⇒ Object
Indicates whether the lock supports unlocking with an access code.
-
#capabilities_supported ⇒ Object
Collection of capabilities that the device supports when connected to Seam.
-
#connected_account_id ⇒ Object
Unique identifier for the account associated with the device.
-
#custom_metadata ⇒ Object
Set of key:value pairs.
-
#device_id ⇒ Object
ID of the device.
-
#device_manufacturer ⇒ Object
Manufacturer of the device.
-
#device_provider ⇒ Object
Provider of the device.
-
#device_type ⇒ Object
Type of the device.
-
#display_name ⇒ Object
Display name of the device, defaults to nickname (if it is set) or
properties.appearance.name, otherwise. -
#is_managed ⇒ Object
Indicates whether Seam manages the device.
-
#location ⇒ Object
Location information for the device.
-
#nickname ⇒ Object
Optional nickname to describe the device, settable through Seam.
-
#properties ⇒ Object
Properties of the device.
-
#space_ids ⇒ Object
IDs of the spaces the device is in.
-
#workspace_id ⇒ Object
Unique identifier for the Seam workspace associated with the device.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_configure_auto_lock ⇒ Object
Indicates whether the lock supports configuring automatic locking.
8 9 10 |
# File 'lib/seam/resources/device.rb', line 8 def can_configure_auto_lock @can_configure_auto_lock end |
#can_hvac_cool ⇒ Object
Indicates whether the thermostat supports cooling.
10 11 12 |
# File 'lib/seam/resources/device.rb', line 10 def can_hvac_cool @can_hvac_cool end |
#can_hvac_heat ⇒ Object
Indicates whether the thermostat supports heating.
12 13 14 |
# File 'lib/seam/resources/device.rb', line 12 def can_hvac_heat @can_hvac_heat end |
#can_hvac_heat_cool ⇒ Object
Indicates whether the thermostat supports simultaneous heating and cooling.
14 15 16 |
# File 'lib/seam/resources/device.rb', line 14 def can_hvac_heat_cool @can_hvac_heat_cool end |
#can_program_offline_access_codes ⇒ Object
Indicates whether the device supports programming offline access codes.
16 17 18 |
# File 'lib/seam/resources/device.rb', line 16 def can_program_offline_access_codes @can_program_offline_access_codes end |
#can_program_online_access_codes ⇒ Object
Indicates whether the device supports programming online access codes.
18 19 20 |
# File 'lib/seam/resources/device.rb', line 18 def can_program_online_access_codes @can_program_online_access_codes end |
#can_program_thermostat_programs_as_different_each_day ⇒ Object
Indicates whether the thermostat supports different climate programs for each day of the week.
20 21 22 |
# File 'lib/seam/resources/device.rb', line 20 def can_program_thermostat_programs_as_different_each_day @can_program_thermostat_programs_as_different_each_day end |
#can_program_thermostat_programs_as_same_each_day ⇒ Object
Indicates whether the thermostat supports a single climate program applied to every day.
22 23 24 |
# File 'lib/seam/resources/device.rb', line 22 def can_program_thermostat_programs_as_same_each_day @can_program_thermostat_programs_as_same_each_day end |
#can_program_thermostat_programs_as_weekday_weekend ⇒ Object
Indicates whether the thermostat supports weekday/weekend climate programs.
24 25 26 |
# File 'lib/seam/resources/device.rb', line 24 def can_program_thermostat_programs_as_weekday_weekend @can_program_thermostat_programs_as_weekday_weekend end |
#can_remotely_lock ⇒ Object
Indicates whether the device supports remote locking.
26 27 28 |
# File 'lib/seam/resources/device.rb', line 26 def can_remotely_lock @can_remotely_lock end |
#can_remotely_unlock ⇒ Object
Indicates whether the device supports remote unlocking.
28 29 30 |
# File 'lib/seam/resources/device.rb', line 28 def can_remotely_unlock @can_remotely_unlock end |
#can_run_thermostat_programs ⇒ Object
Indicates whether the thermostat supports running climate programs.
30 31 32 |
# File 'lib/seam/resources/device.rb', line 30 def can_run_thermostat_programs @can_run_thermostat_programs end |
#can_simulate_connection ⇒ Object
Indicates whether the device supports simulating connection in a sandbox.
32 33 34 |
# File 'lib/seam/resources/device.rb', line 32 def can_simulate_connection @can_simulate_connection end |
#can_simulate_disconnection ⇒ Object
Indicates whether the device supports simulating disconnection in a sandbox.
34 35 36 |
# File 'lib/seam/resources/device.rb', line 34 def can_simulate_disconnection @can_simulate_disconnection end |
#can_simulate_hub_connection ⇒ Object
Indicates whether the hub supports simulating connection in a sandbox.
36 37 38 |
# File 'lib/seam/resources/device.rb', line 36 def can_simulate_hub_connection @can_simulate_hub_connection end |
#can_simulate_hub_disconnection ⇒ Object
Indicates whether the hub supports simulating disconnection in a sandbox.
38 39 40 |
# File 'lib/seam/resources/device.rb', line 38 def can_simulate_hub_disconnection @can_simulate_hub_disconnection end |
#can_simulate_paid_subscription ⇒ Object
Indicates whether the device supports simulating a paid subscription in a sandbox.
40 41 42 |
# File 'lib/seam/resources/device.rb', line 40 def can_simulate_paid_subscription @can_simulate_paid_subscription end |
#can_simulate_removal ⇒ Object
Indicates whether the device supports simulating removal in a sandbox.
42 43 44 |
# File 'lib/seam/resources/device.rb', line 42 def can_simulate_removal @can_simulate_removal end |
#can_turn_off_hvac ⇒ Object
Indicates whether the thermostat can be turned off.
44 45 46 |
# File 'lib/seam/resources/device.rb', line 44 def can_turn_off_hvac @can_turn_off_hvac end |
#can_unlock_with_code ⇒ Object
Indicates whether the lock supports unlocking with an access code.
46 47 48 |
# File 'lib/seam/resources/device.rb', line 46 def can_unlock_with_code @can_unlock_with_code end |
#capabilities_supported ⇒ Object
Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.
48 49 50 |
# File 'lib/seam/resources/device.rb', line 48 def capabilities_supported @capabilities_supported end |
#connected_account_id ⇒ Object
Unique identifier for the account associated with the device.
50 51 52 |
# File 'lib/seam/resources/device.rb', line 50 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Object
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.
52 53 54 |
# File 'lib/seam/resources/device.rb', line 52 def @custom_metadata end |
#device_id ⇒ Object
ID of the device.
54 55 56 |
# File 'lib/seam/resources/device.rb', line 54 def device_id @device_id end |
#device_manufacturer ⇒ Object
Manufacturer of the device. Represents the hardware brand, which may differ from the provider.
56 57 58 |
# File 'lib/seam/resources/device.rb', line 56 def device_manufacturer @device_manufacturer end |
#device_provider ⇒ Object
Provider of the device. Represents the third-party service through which the device is controlled.
58 59 60 |
# File 'lib/seam/resources/device.rb', line 58 def device_provider @device_provider end |
#device_type ⇒ Object
Type of the device.
60 61 62 |
# File 'lib/seam/resources/device.rb', line 60 def device_type @device_type end |
#display_name ⇒ Object
Display name of the device, defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the device easily, especially when there are numerous devices.
62 63 64 |
# File 'lib/seam/resources/device.rb', line 62 def display_name @display_name end |
#is_managed ⇒ Object
Indicates whether Seam manages the device. See also Managed and Unmanaged Devices.
64 65 66 |
# File 'lib/seam/resources/device.rb', line 64 def is_managed @is_managed end |
#location ⇒ Object
Location information for the device.
66 67 68 |
# File 'lib/seam/resources/device.rb', line 66 def location @location end |
#nickname ⇒ Object
Optional nickname to describe the device, settable through Seam.
68 69 70 |
# File 'lib/seam/resources/device.rb', line 68 def nickname @nickname end |
#properties ⇒ Object
Properties of the device.
70 71 72 |
# File 'lib/seam/resources/device.rb', line 70 def properties @properties end |
#space_ids ⇒ Object
IDs of the spaces the device is in.
72 73 74 |
# File 'lib/seam/resources/device.rb', line 72 def space_ids @space_ids end |
#workspace_id ⇒ Object
Unique identifier for the Seam workspace associated with the device.
74 75 76 |
# File 'lib/seam/resources/device.rb', line 74 def workspace_id @workspace_id end |