Class: Seam::Resources::Device::DeviceManufacturer
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::DeviceManufacturer
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#display_name ⇒ String
Display name for the manufacturer, such as
August,Yale,Salto, and so on. -
#image_url ⇒ String?
Image URL for the manufacturer logo.
-
#manufacturer ⇒ String
Manufacturer identifier, such as
august,yale,salto, and so on.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#display_name ⇒ String
Display name for the manufacturer, such as August, Yale, Salto, and so on.
10 11 12 |
# File 'lib/seam/resources/device.rb', line 10 def display_name @display_name end |
#image_url ⇒ String?
Image URL for the manufacturer logo.
13 14 15 |
# File 'lib/seam/resources/device.rb', line 13 def image_url @image_url end |
#manufacturer ⇒ String
Manufacturer identifier, such as august, yale, salto, and so on.
16 17 18 |
# File 'lib/seam/resources/device.rb', line 16 def manufacturer @manufacturer end |