Class: Seam::Resources::Device::DeviceManufacturer

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#display_nameObject

Display name for the manufacturer, such as August, Yale, Salto, and so on.



9
10
11
# File 'lib/seam/resources/device.rb', line 9

def display_name
  @display_name
end

#image_urlObject

Image URL for the manufacturer logo.



11
12
13
# File 'lib/seam/resources/device.rb', line 11

def image_url
  @image_url
end

#manufacturerObject

Manufacturer identifier, such as august, yale, salto, and so on.



13
14
15
# File 'lib/seam/resources/device.rb', line 13

def manufacturer
  @manufacturer
end