Class: Seam::Resources::Device::DeviceProvider

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_provider_nameObject

Device provider name. Corresponds to the integration type, such as august, schlage, yale_access, and so on.



18
19
20
# File 'lib/seam/resources/device.rb', line 18

def device_provider_name
  @device_provider_name
end

#display_nameObject

Display name for the device provider type.



20
21
22
# File 'lib/seam/resources/device.rb', line 20

def display_name
  @display_name
end

#image_urlObject

Image URL for the device provider.



22
23
24
# File 'lib/seam/resources/device.rb', line 22

def image_url
  @image_url
end

#provider_categoryObject

Provider category. Indicates the third-party provider type, such as stable, for stable integrations, or internal, for internal integrations.



24
25
26
# File 'lib/seam/resources/device.rb', line 24

def provider_category
  @provider_category
end