Class: Seam::Resources::Device::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Errors
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#error_code ⇒ Object
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Object
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Object
Returns the value of attribute is_connected_account_error.
-
#is_device_error ⇒ Object
Returns the value of attribute is_device_error.
-
#message ⇒ Object
Detailed description of the error.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ Object
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
29 30 31 |
# File 'lib/seam/resources/device.rb', line 29 def error_code @error_code end |
#is_bridge_error ⇒ Object
Indicates whether the error is related to Seam Bridge.
31 32 33 |
# File 'lib/seam/resources/device.rb', line 31 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Object
Returns the value of attribute is_connected_account_error.
32 33 34 |
# File 'lib/seam/resources/device.rb', line 32 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ Object
Returns the value of attribute is_device_error.
33 34 35 |
# File 'lib/seam/resources/device.rb', line 33 def is_device_error @is_device_error end |
#message ⇒ Object
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
35 36 37 |
# File 'lib/seam/resources/device.rb', line 35 def @message end |