Class: Seam::Resources::Device::Errors::AugustLockNotAuthorized
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::Device::Errors::AugustLockNotAuthorized
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the user is not authorized to use the August lock.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
august_lock_not_authorized
216 217 218 |
# File 'lib/seam/resources/device.rb', line 216 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
219 220 221 |
# File 'lib/seam/resources/device.rb', line 219 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
222 223 224 |
# File 'lib/seam/resources/device.rb', line 222 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
225 |
# File 'lib/seam/resources/device.rb', line 225 date_accessor :created_at |