Class: Seam::Resources::Device::Errors::DormakabaSitesDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::Device::Errors::DormakabaSitesDisconnected
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that one or more dormakaba sites associated with the connected account could not be connected. Contact dormakaba support.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
-
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
dormakaba_sites_disconnected
105 106 107 |
# File 'lib/seam/resources/device.rb', line 105 def error_code @error_code end |
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
108 109 110 |
# File 'lib/seam/resources/device.rb', line 108 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
111 112 113 |
# File 'lib/seam/resources/device.rb', line 111 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
114 115 116 |
# File 'lib/seam/resources/device.rb', line 114 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
117 |
# File 'lib/seam/resources/device.rb', line 117 date_accessor :created_at |