Class: Seam::Resources::Device::Errors::SubscriptionRequired
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::Device::Errors::SubscriptionRequired
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that a subscription is required to connect.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
subscription_required
270 271 272 |
# File 'lib/seam/resources/device.rb', line 270 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
273 274 275 |
# File 'lib/seam/resources/device.rb', line 273 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
276 277 278 |
# File 'lib/seam/resources/device.rb', line 276 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
279 |
# File 'lib/seam/resources/device.rb', line 279 date_accessor :created_at |