Class: Seam::Resources::Device::Properties
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: AccessoryKeypad, ActiveThermostatSchedule, AkilesMetadata, Appearance, AqaraMetadata, AssaAbloyCredentialServiceMetadata, AssaAbloyVostioMetadata, AugustMetadata, AvailableClimatePresets, AvigilonAltaMetadata, Battery, BrivoMetadata, CodeConstraints, ControlbywebMetadata, CurrentClimateSetting, DefaultClimateSetting, DormakabaOracodeMetadata, EcobeeMetadata, FourSuitesMetadata, GenieMetadata, HoneywellResideoMetadata, IglooMetadata, IgloohomeMetadata, KeynestMetadata, KeypadBattery, KisiMetadata, KorelockMetadata, KwiksetMetadata, LocklyMetadata, MinutMetadata, Model, NestMetadata, NoiseawareMetadata, NukiMetadata, OfflineTimeFrameOptions, OmnitecMetadata, OnlineTimeFrameOptions, RingMetadata, SaltoKsMetadata, SaltoMetadata, SaltoSpaceCredentialServiceMetadata, SchlageMetadata, SeamBridgeMetadata, SensiMetadata, SmartthingsMetadata, TadoMetadata, TedeeMetadata, TemperatureThreshold, ThermostatDailyPrograms, ThermostatWeeklyProgram, TtlockMetadata, TwoNMetadata, UltraloqMetadata, VisionlineMetadata, WyzeMetadata, YacanMetadata
Instance Attribute Summary collapse
-
#active_thermostat_schedule_id ⇒ String?
ID of the active thermostat schedule.
-
#auto_lock_delay_seconds ⇒ Float?
The delay in seconds before the lock automatically locks after being unlocked.
-
#auto_lock_enabled ⇒ Boolean?
Indicates whether automatic locking is enabled.
-
#available_climate_preset_modes ⇒ Array<String>
Climate preset modes that the thermostat supports, such as "home", "away", "wake", "sleep", "occupied", and "unoccupied".
-
#available_fan_mode_settings ⇒ Array<String>
Fan mode settings that the thermostat supports.
-
#available_hvac_mode_settings ⇒ Array<String>
HVAC mode settings that the thermostat supports.
-
#backup_access_code_pool_enabled ⇒ Boolean?
Indicates whether the backup access code pool is currently enabled for the device.
-
#battery_level ⇒ Float?
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
-
#currently_triggering_noise_threshold_ids ⇒ Array<String>
Array of noise threshold IDs that are currently triggering.
-
#door_open ⇒ Boolean?
Indicates whether the door is open.
-
#fallback_climate_preset_key ⇒ String?
Key of the fallback climate preset for the thermostat.
-
#fan_mode_setting ⇒ String?
deprecated
Deprecated.
Use
current_climate_setting.fan_mode_settinginstead. -
#has_direct_power ⇒ Boolean?
Indicates whether the device has direct power.
-
#has_native_entry_events ⇒ Boolean?
Indicates whether the device supports native entry events.
-
#image_alt_text ⇒ String?
Alt text for the device image.
-
#image_url ⇒ String?
Image URL for the device.
-
#is_cooling ⇒ Boolean?
Indicates whether the connected HVAC system is currently cooling, as reported by the thermostat.
-
#is_fan_running ⇒ Boolean?
Indicates whether the fan in the connected HVAC system is currently running, as reported by the thermostat.
-
#is_heating ⇒ Boolean?
Indicates whether the connected HVAC system is currently heating, as reported by the thermostat.
-
#is_temporary_manual_override_active ⇒ Boolean?
Indicates whether the current thermostat settings differ from the most recent active program or schedule that Seam activated.
-
#locked ⇒ Boolean?
Indicates whether the lock is locked.
-
#manufacturer ⇒ String?
Manufacturer of the device.
-
#max_active_codes_supported ⇒ Float?
Maximum number of active access codes that the device supports.
-
#max_cooling_set_point_celsius ⇒ Float?
Maximum cooling set point in °C.
-
#max_cooling_set_point_fahrenheit ⇒ Float?
Maximum cooling set point in °F.
-
#max_heating_set_point_celsius ⇒ Float?
Maximum heating set point in °C.
-
#max_heating_set_point_fahrenheit ⇒ Float?
Maximum heating set point in °F.
-
#max_thermostat_daily_program_periods_per_day ⇒ Float?
Maximum number of periods that the thermostat can support per day.
-
#max_unique_climate_presets_per_thermostat_weekly_program ⇒ Float?
Maximum number of climate presets that the thermostat can support for weekly programming.
-
#min_cooling_set_point_celsius ⇒ Float?
Minimum cooling set point in °C.
-
#min_cooling_set_point_fahrenheit ⇒ Float?
Minimum cooling set point in °F.
-
#min_heating_cooling_delta_celsius ⇒ Float?
Minimum temperature difference in °C between the cooling and heating set points when in heat-cool (auto) mode.
-
#min_heating_cooling_delta_fahrenheit ⇒ Float?
Minimum temperature difference in °F between the cooling and heating set points when in heat-cool (auto) mode.
-
#min_heating_set_point_celsius ⇒ Float?
Minimum heating set point in °C.
-
#min_heating_set_point_fahrenheit ⇒ Float?
Minimum heating set point in °F.
-
#name ⇒ String
deprecated
Deprecated.
use device.display_name instead
-
#noise_level_decibels ⇒ Float?
Indicates current noise level in decibels, if the device supports noise detection.
-
#offline_access_codes_enabled ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_offline_access_codes
-
#online ⇒ Boolean
Indicates whether the device is online.
-
#online_access_codes_enabled ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_online_access_codes
-
#relative_humidity ⇒ Float?
Reported relative humidity, as a value between 0 and 1, inclusive.
-
#serial_number ⇒ String?
Serial number of the device.
-
#supported_code_lengths ⇒ Array<Float>
Supported code lengths for access codes.
-
#supports_accessory_keypad ⇒ Boolean?
deprecated
Deprecated.
use device.properties.model.can_connect_accessory_keypad
-
#supports_backup_access_code_pool ⇒ Boolean?
Indicates whether the device supports a backup access code pool.
-
#supports_offline_access_codes ⇒ Boolean?
deprecated
Deprecated.
use offline_access_codes_enabled
-
#temperature_celsius ⇒ Float?
Reported temperature in °C.
-
#temperature_fahrenheit ⇒ Float?
Reported temperature in °F.
-
#thermostat_daily_program_period_precision_minutes ⇒ Float?
Precision of the thermostat's period in minutes.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#accessory_keypad ⇒ AccessoryKeypad?
Accessory keypad properties and state.
-
#active_thermostat_schedule ⇒ ActiveThermostatSchedule?
Active thermostat schedule.
-
#akiles_metadata ⇒ AkilesMetadata?
Metadata for an Akiles device.
-
#appearance ⇒ Appearance
Appearance-related properties, as reported by the device.
-
#aqara_metadata ⇒ AqaraMetadata?
Metadata for an Aqara device.
-
#assa_abloy_credential_service_metadata ⇒ AssaAbloyCredentialServiceMetadata?
ASSA ABLOY Credential Service metadata for the phone.
-
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Metadata for an ASSA ABLOY Vostio system.
-
#august_metadata ⇒ AugustMetadata?
Metadata for an August device.
-
#available_climate_presets ⇒ Array<AvailableClimatePresets>
Available climate presets for the thermostat.
-
#avigilon_alta_metadata ⇒ AvigilonAltaMetadata?
Metadata for an Avigilon Alta system.
-
#battery ⇒ Battery?
Represents the current status of the battery charge level.
-
#brivo_metadata ⇒ BrivoMetadata?
Metadata for a Brivo device.
-
#code_constraints ⇒ Array<CodeConstraints>
Constraints on access codes for the device.
-
#controlbyweb_metadata ⇒ ControlbywebMetadata?
Metadata for a ControlByWeb device.
-
#current_climate_setting ⇒ CurrentClimateSetting?
Current climate setting.
- #default_climate_setting ⇒ DefaultClimateSetting?
-
#dormakaba_oracode_metadata ⇒ DormakabaOracodeMetadata?
Metadata for a dormakaba Oracode device.
-
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata for an ecobee device.
-
#four_suites_metadata ⇒ FourSuitesMetadata?
Metadata for a 4SUITES device.
-
#genie_metadata ⇒ GenieMetadata?
Metadata for a Genie device.
-
#honeywell_resideo_metadata ⇒ HoneywellResideoMetadata?
Metadata for a Honeywell Resideo device.
-
#igloo_metadata ⇒ IglooMetadata?
Metadata for an igloo device.
-
#igloohome_metadata ⇒ IgloohomeMetadata?
Metadata for an igloohome device.
-
#keynest_metadata ⇒ KeynestMetadata?
Metadata for a KeyNest device.
-
#keypad_battery ⇒ KeypadBattery?
Keypad battery status.
-
#kisi_metadata ⇒ KisiMetadata?
Metadata for a Kisi device.
-
#korelock_metadata ⇒ KorelockMetadata?
Metadata for a Korelock device.
-
#kwikset_metadata ⇒ KwiksetMetadata?
Metadata for a Kwikset device.
-
#lockly_metadata ⇒ LocklyMetadata?
Metadata for a Lockly device.
-
#minut_metadata ⇒ MinutMetadata?
Metadata for a Minut device.
-
#model ⇒ Model
Device model-related properties.
-
#nest_metadata ⇒ NestMetadata?
Metadata for a Google Nest device.
-
#noiseaware_metadata ⇒ NoiseawareMetadata?
Metadata for a NoiseAware device.
-
#nuki_metadata ⇒ NukiMetadata?
Metadata for a Nuki device.
-
#offline_time_frame_options ⇒ Array<OfflineTimeFrameOptions>
Time frames that may be requested when creating an offline access code, expressed as a list of options.
-
#omnitec_metadata ⇒ OmnitecMetadata?
Metadata for an Omnitec device.
-
#online_time_frame_options ⇒ Array<OnlineTimeFrameOptions>
Time frames that may be requested when creating an online access code, expressed as a list of options.
-
#ring_metadata ⇒ RingMetadata?
Metadata for a Ring device.
-
#salto_ks_metadata ⇒ SaltoKsMetadata?
Metadata for a Salto KS device.
-
#salto_metadata ⇒ SaltoMetadata?
Metada for a Salto device.
-
#salto_space_credential_service_metadata ⇒ SaltoSpaceCredentialServiceMetadata?
Salto Space credential service metadata for the phone.
-
#schlage_metadata ⇒ SchlageMetadata?
Metadata for a Schlage device.
-
#seam_bridge_metadata ⇒ SeamBridgeMetadata?
Metadata for Seam Bridge.
-
#sensi_metadata ⇒ SensiMetadata?
Metadata for a Sensi device.
-
#smartthings_metadata ⇒ SmartthingsMetadata?
Metadata for a SmartThings device.
-
#tado_metadata ⇒ TadoMetadata?
Metadata for a tado° device.
-
#tedee_metadata ⇒ TedeeMetadata?
Metadata for a Tedee device.
-
#temperature_threshold ⇒ TemperatureThreshold?
Current temperature threshold set for the thermostat.
-
#thermostat_daily_programs ⇒ Array<ThermostatDailyPrograms>
Configured daily programs for the thermostat.
-
#thermostat_weekly_program ⇒ ThermostatWeeklyProgram?
Current weekly program for the thermostat.
-
#ttlock_metadata ⇒ TtlockMetadata?
Metadata for a TTLock device.
-
#two_n_metadata ⇒ TwoNMetadata?
Metadata for a 2N device.
-
#ultraloq_metadata ⇒ UltraloqMetadata?
Metadata for an Ultraloq device.
-
#visionline_metadata ⇒ VisionlineMetadata?
Metadata for an ASSA ABLOY Visionline system.
-
#wyze_metadata ⇒ WyzeMetadata?
Metadata for a Wyze device.
-
#yacan_metadata ⇒ YacanMetadata?
Metadata for a Yacan device.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#active_thermostat_schedule_id ⇒ String?
ID of the active thermostat schedule.
1606 1607 1608 |
# File 'lib/seam/resources/device.rb', line 1606 def active_thermostat_schedule_id @active_thermostat_schedule_id end |
#auto_lock_delay_seconds ⇒ Float?
The delay in seconds before the lock automatically locks after being unlocked.
1579 1580 1581 |
# File 'lib/seam/resources/device.rb', line 1579 def auto_lock_delay_seconds @auto_lock_delay_seconds end |
#auto_lock_enabled ⇒ Boolean?
Indicates whether automatic locking is enabled.
1582 1583 1584 |
# File 'lib/seam/resources/device.rb', line 1582 def auto_lock_enabled @auto_lock_enabled end |
#available_climate_preset_modes ⇒ Array<String>
Climate preset modes that the thermostat supports, such as "home", "away", "wake", "sleep", "occupied", and "unoccupied".
1609 1610 1611 |
# File 'lib/seam/resources/device.rb', line 1609 def available_climate_preset_modes @available_climate_preset_modes end |
#available_fan_mode_settings ⇒ Array<String>
Fan mode settings that the thermostat supports.
1612 1613 1614 |
# File 'lib/seam/resources/device.rb', line 1612 def available_fan_mode_settings @available_fan_mode_settings end |
#available_hvac_mode_settings ⇒ Array<String>
HVAC mode settings that the thermostat supports.
1615 1616 1617 |
# File 'lib/seam/resources/device.rb', line 1615 def available_hvac_mode_settings @available_hvac_mode_settings end |
#backup_access_code_pool_enabled ⇒ Boolean?
Indicates whether the backup access code pool is currently enabled for the device. To disable it, set this to false using /devices/update.
1585 1586 1587 |
# File 'lib/seam/resources/device.rb', line 1585 def backup_access_code_pool_enabled @backup_access_code_pool_enabled end |
#battery_level ⇒ Float?
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
1534 1535 1536 |
# File 'lib/seam/resources/device.rb', line 1534 def battery_level @battery_level end |
#currently_triggering_noise_threshold_ids ⇒ Array<String>
Array of noise threshold IDs that are currently triggering.
1537 1538 1539 |
# File 'lib/seam/resources/device.rb', line 1537 def currently_triggering_noise_threshold_ids @currently_triggering_noise_threshold_ids end |
#door_open ⇒ Boolean?
Indicates whether the door is open.
1588 1589 1590 |
# File 'lib/seam/resources/device.rb', line 1588 def door_open @door_open end |
#fallback_climate_preset_key ⇒ String?
Key of the fallback climate preset for the thermostat.
1618 1619 1620 |
# File 'lib/seam/resources/device.rb', line 1618 def fallback_climate_preset_key @fallback_climate_preset_key end |
#fan_mode_setting ⇒ String?
Use current_climate_setting.fan_mode_setting instead.
1621 1622 1623 |
# File 'lib/seam/resources/device.rb', line 1621 def fan_mode_setting @fan_mode_setting end |
#has_direct_power ⇒ Boolean?
Indicates whether the device has direct power.
1540 1541 1542 |
# File 'lib/seam/resources/device.rb', line 1540 def has_direct_power @has_direct_power end |
#has_native_entry_events ⇒ Boolean?
Indicates whether the device supports native entry events.
1591 1592 1593 |
# File 'lib/seam/resources/device.rb', line 1591 def has_native_entry_events @has_native_entry_events end |
#image_alt_text ⇒ String?
Alt text for the device image.
1543 1544 1545 |
# File 'lib/seam/resources/device.rb', line 1543 def image_alt_text @image_alt_text end |
#image_url ⇒ String?
Image URL for the device.
1546 1547 1548 |
# File 'lib/seam/resources/device.rb', line 1546 def image_url @image_url end |
#is_cooling ⇒ Boolean?
Indicates whether the connected HVAC system is currently cooling, as reported by the thermostat.
1624 1625 1626 |
# File 'lib/seam/resources/device.rb', line 1624 def is_cooling @is_cooling end |
#is_fan_running ⇒ Boolean?
Indicates whether the fan in the connected HVAC system is currently running, as reported by the thermostat.
1627 1628 1629 |
# File 'lib/seam/resources/device.rb', line 1627 def is_fan_running @is_fan_running end |
#is_heating ⇒ Boolean?
Indicates whether the connected HVAC system is currently heating, as reported by the thermostat.
1630 1631 1632 |
# File 'lib/seam/resources/device.rb', line 1630 def is_heating @is_heating end |
#is_temporary_manual_override_active ⇒ Boolean?
Indicates whether the current thermostat settings differ from the most recent active program or schedule that Seam activated. For this condition to occur, current_climate_setting.manual_override_allowed must also be true.
1633 1634 1635 |
# File 'lib/seam/resources/device.rb', line 1633 def is_temporary_manual_override_active @is_temporary_manual_override_active end |
#locked ⇒ Boolean?
Indicates whether the lock is locked.
1594 1595 1596 |
# File 'lib/seam/resources/device.rb', line 1594 def locked @locked end |
#manufacturer ⇒ String?
Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.
1549 1550 1551 |
# File 'lib/seam/resources/device.rb', line 1549 def manufacturer @manufacturer end |
#max_active_codes_supported ⇒ Float?
Maximum number of active access codes that the device supports.
1597 1598 1599 |
# File 'lib/seam/resources/device.rb', line 1597 def max_active_codes_supported @max_active_codes_supported end |
#max_cooling_set_point_celsius ⇒ Float?
Maximum cooling set point in °C.
1636 1637 1638 |
# File 'lib/seam/resources/device.rb', line 1636 def max_cooling_set_point_celsius @max_cooling_set_point_celsius end |
#max_cooling_set_point_fahrenheit ⇒ Float?
Maximum cooling set point in °F.
1639 1640 1641 |
# File 'lib/seam/resources/device.rb', line 1639 def max_cooling_set_point_fahrenheit @max_cooling_set_point_fahrenheit end |
#max_heating_set_point_celsius ⇒ Float?
Maximum heating set point in °C.
1642 1643 1644 |
# File 'lib/seam/resources/device.rb', line 1642 def max_heating_set_point_celsius @max_heating_set_point_celsius end |
#max_heating_set_point_fahrenheit ⇒ Float?
Maximum heating set point in °F.
1645 1646 1647 |
# File 'lib/seam/resources/device.rb', line 1645 def max_heating_set_point_fahrenheit @max_heating_set_point_fahrenheit end |
#max_thermostat_daily_program_periods_per_day ⇒ Float?
Maximum number of periods that the thermostat can support per day. For example, if the thermostat supports 4 periods per day, this value is 4.
1648 1649 1650 |
# File 'lib/seam/resources/device.rb', line 1648 def max_thermostat_daily_program_periods_per_day @max_thermostat_daily_program_periods_per_day end |
#max_unique_climate_presets_per_thermostat_weekly_program ⇒ Float?
Maximum number of climate presets that the thermostat can support for weekly programming.
1651 1652 1653 |
# File 'lib/seam/resources/device.rb', line 1651 def max_unique_climate_presets_per_thermostat_weekly_program @max_unique_climate_presets_per_thermostat_weekly_program end |
#min_cooling_set_point_celsius ⇒ Float?
Minimum cooling set point in °C.
1654 1655 1656 |
# File 'lib/seam/resources/device.rb', line 1654 def min_cooling_set_point_celsius @min_cooling_set_point_celsius end |
#min_cooling_set_point_fahrenheit ⇒ Float?
Minimum cooling set point in °F.
1657 1658 1659 |
# File 'lib/seam/resources/device.rb', line 1657 def min_cooling_set_point_fahrenheit @min_cooling_set_point_fahrenheit end |
#min_heating_cooling_delta_celsius ⇒ Float?
Minimum temperature difference in °C between the cooling and heating set points when in heat-cool (auto) mode.
1660 1661 1662 |
# File 'lib/seam/resources/device.rb', line 1660 def min_heating_cooling_delta_celsius @min_heating_cooling_delta_celsius end |
#min_heating_cooling_delta_fahrenheit ⇒ Float?
Minimum temperature difference in °F between the cooling and heating set points when in heat-cool (auto) mode.
1663 1664 1665 |
# File 'lib/seam/resources/device.rb', line 1663 def min_heating_cooling_delta_fahrenheit @min_heating_cooling_delta_fahrenheit end |
#min_heating_set_point_celsius ⇒ Float?
Minimum heating set point in °C.
1666 1667 1668 |
# File 'lib/seam/resources/device.rb', line 1666 def min_heating_set_point_celsius @min_heating_set_point_celsius end |
#min_heating_set_point_fahrenheit ⇒ Float?
Minimum heating set point in °F.
1669 1670 1671 |
# File 'lib/seam/resources/device.rb', line 1669 def min_heating_set_point_fahrenheit @min_heating_set_point_fahrenheit end |
#name ⇒ String
use device.display_name instead
Name of the device.
1553 1554 1555 |
# File 'lib/seam/resources/device.rb', line 1553 def name @name end |
#noise_level_decibels ⇒ Float?
Indicates current noise level in decibels, if the device supports noise detection.
1556 1557 1558 |
# File 'lib/seam/resources/device.rb', line 1556 def noise_level_decibels @noise_level_decibels end |
#offline_access_codes_enabled ⇒ Boolean?
use device.can_program_offline_access_codes
Indicates whether it is currently possible to use offline access codes for the device.
1560 1561 1562 |
# File 'lib/seam/resources/device.rb', line 1560 def offline_access_codes_enabled @offline_access_codes_enabled end |
#online ⇒ Boolean
Indicates whether the device is online.
1563 1564 1565 |
# File 'lib/seam/resources/device.rb', line 1563 def online @online end |
#online_access_codes_enabled ⇒ Boolean?
use device.can_program_online_access_codes
Indicates whether it is currently possible to use online access codes for the device.
1567 1568 1569 |
# File 'lib/seam/resources/device.rb', line 1567 def online_access_codes_enabled @online_access_codes_enabled end |
#relative_humidity ⇒ Float?
Reported relative humidity, as a value between 0 and 1, inclusive.
1672 1673 1674 |
# File 'lib/seam/resources/device.rb', line 1672 def relative_humidity @relative_humidity end |
#serial_number ⇒ String?
Serial number of the device.
1570 1571 1572 |
# File 'lib/seam/resources/device.rb', line 1570 def serial_number @serial_number end |
#supported_code_lengths ⇒ Array<Float>
Supported code lengths for access codes.
1600 1601 1602 |
# File 'lib/seam/resources/device.rb', line 1600 def supported_code_lengths @supported_code_lengths end |
#supports_accessory_keypad ⇒ Boolean?
use device.properties.model.can_connect_accessory_keypad
1573 1574 1575 |
# File 'lib/seam/resources/device.rb', line 1573 def supports_accessory_keypad @supports_accessory_keypad end |
#supports_backup_access_code_pool ⇒ Boolean?
Indicates whether the device supports a backup access code pool.
1603 1604 1605 |
# File 'lib/seam/resources/device.rb', line 1603 def supports_backup_access_code_pool @supports_backup_access_code_pool end |
#supports_offline_access_codes ⇒ Boolean?
use offline_access_codes_enabled
1576 1577 1578 |
# File 'lib/seam/resources/device.rb', line 1576 def supports_offline_access_codes @supports_offline_access_codes end |
#temperature_celsius ⇒ Float?
Reported temperature in °C.
1675 1676 1677 |
# File 'lib/seam/resources/device.rb', line 1675 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float?
Reported temperature in °F.
1678 1679 1680 |
# File 'lib/seam/resources/device.rb', line 1678 def temperature_fahrenheit @temperature_fahrenheit end |
#thermostat_daily_program_period_precision_minutes ⇒ Float?
Precision of the thermostat's period in minutes. For example, if the thermostat supports 15-minute periods, this value is 15. All values are relative to the top of the hour, so for 15 minutes, the periods would be 0, 15, 30, and 45 minutes past the hour.
1681 1682 1683 |
# File 'lib/seam/resources/device.rb', line 1681 def thermostat_daily_program_period_precision_minutes @thermostat_daily_program_period_precision_minutes end |
Instance Method Details
#accessory_keypad ⇒ AccessoryKeypad?
Accessory keypad properties and state.
1367 |
# File 'lib/seam/resources/device.rb', line 1367 resource_accessor :accessory_keypad, AccessoryKeypad |
#active_thermostat_schedule ⇒ ActiveThermostatSchedule?
Active thermostat schedule.
1505 |
# File 'lib/seam/resources/device.rb', line 1505 resource_accessor :active_thermostat_schedule, ActiveThermostatSchedule |
#akiles_metadata ⇒ AkilesMetadata?
Metadata for an Akiles device.
1385 |
# File 'lib/seam/resources/device.rb', line 1385 resource_accessor :akiles_metadata, AkilesMetadata |
#appearance ⇒ Appearance
Appearance-related properties, as reported by the device.
1370 |
# File 'lib/seam/resources/device.rb', line 1370 resource_accessor :appearance, Appearance |
#aqara_metadata ⇒ AqaraMetadata?
Metadata for an Aqara device.
1388 |
# File 'lib/seam/resources/device.rb', line 1388 resource_accessor :aqara_metadata, AqaraMetadata |
#assa_abloy_credential_service_metadata ⇒ AssaAbloyCredentialServiceMetadata?
ASSA ABLOY Credential Service metadata for the phone.
1379 |
# File 'lib/seam/resources/device.rb', line 1379 resource_accessor :assa_abloy_credential_service_metadata, AssaAbloyCredentialServiceMetadata |
#assa_abloy_vostio_metadata ⇒ AssaAbloyVostioMetadata?
Metadata for an ASSA ABLOY Vostio system.
1391 |
# File 'lib/seam/resources/device.rb', line 1391 resource_accessor :assa_abloy_vostio_metadata, AssaAbloyVostioMetadata |
#august_metadata ⇒ AugustMetadata?
Metadata for an August device.
1394 |
# File 'lib/seam/resources/device.rb', line 1394 resource_accessor :august_metadata, AugustMetadata |
#available_climate_presets ⇒ Array<AvailableClimatePresets>
Available climate presets for the thermostat.
1528 |
# File 'lib/seam/resources/device.rb', line 1528 resource_list_accessor :available_climate_presets, AvailableClimatePresets |
#avigilon_alta_metadata ⇒ AvigilonAltaMetadata?
Metadata for an Avigilon Alta system.
1397 |
# File 'lib/seam/resources/device.rb', line 1397 resource_accessor :avigilon_alta_metadata, AvigilonAltaMetadata |
#battery ⇒ Battery?
Represents the current status of the battery charge level.
1373 |
# File 'lib/seam/resources/device.rb', line 1373 resource_accessor :battery, Battery |
#brivo_metadata ⇒ BrivoMetadata?
Metadata for a Brivo device.
1400 |
# File 'lib/seam/resources/device.rb', line 1400 resource_accessor :brivo_metadata, BrivoMetadata |
#code_constraints ⇒ Array<CodeConstraints>
Constraints on access codes for the device. Seam represents each constraint as an object with a constraint_type property. Depending on the constraint type, there may also be additional properties. Note that some constraints are manufacturer- or device-specific.
1519 |
# File 'lib/seam/resources/device.rb', line 1519 resource_list_accessor :code_constraints, CodeConstraints |
#controlbyweb_metadata ⇒ ControlbywebMetadata?
Metadata for a ControlByWeb device.
1403 |
# File 'lib/seam/resources/device.rb', line 1403 resource_accessor :controlbyweb_metadata, ControlbywebMetadata |
#current_climate_setting ⇒ CurrentClimateSetting?
Current climate setting.
1508 |
# File 'lib/seam/resources/device.rb', line 1508 resource_accessor :current_climate_setting, CurrentClimateSetting |
#default_climate_setting ⇒ DefaultClimateSetting?
1510 |
# File 'lib/seam/resources/device.rb', line 1510 resource_accessor :default_climate_setting, DefaultClimateSetting |
#dormakaba_oracode_metadata ⇒ DormakabaOracodeMetadata?
Metadata for a dormakaba Oracode device.
1406 |
# File 'lib/seam/resources/device.rb', line 1406 resource_accessor :dormakaba_oracode_metadata, DormakabaOracodeMetadata |
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata for an ecobee device.
1409 |
# File 'lib/seam/resources/device.rb', line 1409 resource_accessor :ecobee_metadata, EcobeeMetadata |
#four_suites_metadata ⇒ FourSuitesMetadata?
Metadata for a 4SUITES device.
1412 |
# File 'lib/seam/resources/device.rb', line 1412 resource_accessor :four_suites_metadata, FourSuitesMetadata |
#genie_metadata ⇒ GenieMetadata?
Metadata for a Genie device.
1415 |
# File 'lib/seam/resources/device.rb', line 1415 resource_accessor :genie_metadata, GenieMetadata |
#honeywell_resideo_metadata ⇒ HoneywellResideoMetadata?
Metadata for a Honeywell Resideo device.
1418 |
# File 'lib/seam/resources/device.rb', line 1418 resource_accessor :honeywell_resideo_metadata, HoneywellResideoMetadata |
#igloo_metadata ⇒ IglooMetadata?
Metadata for an igloo device.
1421 |
# File 'lib/seam/resources/device.rb', line 1421 resource_accessor :igloo_metadata, IglooMetadata |
#igloohome_metadata ⇒ IgloohomeMetadata?
Metadata for an igloohome device.
1424 |
# File 'lib/seam/resources/device.rb', line 1424 resource_accessor :igloohome_metadata, IgloohomeMetadata |
#keynest_metadata ⇒ KeynestMetadata?
Metadata for a KeyNest device.
1427 |
# File 'lib/seam/resources/device.rb', line 1427 resource_accessor :keynest_metadata, KeynestMetadata |
#keypad_battery ⇒ KeypadBattery?
Keypad battery status.
1502 |
# File 'lib/seam/resources/device.rb', line 1502 resource_accessor :keypad_battery, KeypadBattery |
#kisi_metadata ⇒ KisiMetadata?
Metadata for a Kisi device.
1430 |
# File 'lib/seam/resources/device.rb', line 1430 resource_accessor :kisi_metadata, KisiMetadata |
#korelock_metadata ⇒ KorelockMetadata?
Metadata for a Korelock device.
1433 |
# File 'lib/seam/resources/device.rb', line 1433 resource_accessor :korelock_metadata, KorelockMetadata |
#kwikset_metadata ⇒ KwiksetMetadata?
Metadata for a Kwikset device.
1436 |
# File 'lib/seam/resources/device.rb', line 1436 resource_accessor :kwikset_metadata, KwiksetMetadata |
#lockly_metadata ⇒ LocklyMetadata?
Metadata for a Lockly device.
1439 |
# File 'lib/seam/resources/device.rb', line 1439 resource_accessor :lockly_metadata, LocklyMetadata |
#minut_metadata ⇒ MinutMetadata?
Metadata for a Minut device.
1442 |
# File 'lib/seam/resources/device.rb', line 1442 resource_accessor :minut_metadata, MinutMetadata |
#model ⇒ Model
Device model-related properties.
1376 |
# File 'lib/seam/resources/device.rb', line 1376 resource_accessor :model, Model |
#nest_metadata ⇒ NestMetadata?
Metadata for a Google Nest device.
1445 |
# File 'lib/seam/resources/device.rb', line 1445 resource_accessor :nest_metadata, NestMetadata |
#noiseaware_metadata ⇒ NoiseawareMetadata?
Metadata for a NoiseAware device.
1448 |
# File 'lib/seam/resources/device.rb', line 1448 resource_accessor :noiseaware_metadata, NoiseawareMetadata |
#nuki_metadata ⇒ NukiMetadata?
Metadata for a Nuki device.
1451 |
# File 'lib/seam/resources/device.rb', line 1451 resource_accessor :nuki_metadata, NukiMetadata |
#offline_time_frame_options ⇒ Array<OfflineTimeFrameOptions>
Time frames that may be requested when creating an offline access code, expressed as a list of options. The caller picks one option (by matching the requested duration when the options' duration ranges do not overlap, or by display_name when they do) and satisfies that one option's rules. When undefined, any time frame works.
1522 |
# File 'lib/seam/resources/device.rb', line 1522 resource_list_accessor :offline_time_frame_options, OfflineTimeFrameOptions |
#omnitec_metadata ⇒ OmnitecMetadata?
Metadata for an Omnitec device.
1454 |
# File 'lib/seam/resources/device.rb', line 1454 resource_accessor :omnitec_metadata, OmnitecMetadata |
#online_time_frame_options ⇒ Array<OnlineTimeFrameOptions>
Time frames that may be requested when creating an online access code, expressed as a list of options. The caller picks one option (by matching the requested duration when the options' duration ranges do not overlap, or by display_name when they do) and satisfies that one option's rules. When undefined, any time frame works.
1525 |
# File 'lib/seam/resources/device.rb', line 1525 resource_list_accessor :online_time_frame_options, OnlineTimeFrameOptions |
#ring_metadata ⇒ RingMetadata?
Metadata for a Ring device.
1457 |
# File 'lib/seam/resources/device.rb', line 1457 resource_accessor :ring_metadata, RingMetadata |
#salto_ks_metadata ⇒ SaltoKsMetadata?
Metadata for a Salto KS device.
1460 |
# File 'lib/seam/resources/device.rb', line 1460 resource_accessor :salto_ks_metadata, SaltoKsMetadata |
#salto_metadata ⇒ SaltoMetadata?
Metada for a Salto device.
1463 |
# File 'lib/seam/resources/device.rb', line 1463 resource_accessor :salto_metadata, SaltoMetadata |
#salto_space_credential_service_metadata ⇒ SaltoSpaceCredentialServiceMetadata?
Salto Space credential service metadata for the phone.
1382 |
# File 'lib/seam/resources/device.rb', line 1382 resource_accessor :salto_space_credential_service_metadata, SaltoSpaceCredentialServiceMetadata |
#schlage_metadata ⇒ SchlageMetadata?
Metadata for a Schlage device.
1466 |
# File 'lib/seam/resources/device.rb', line 1466 resource_accessor :schlage_metadata, SchlageMetadata |
#seam_bridge_metadata ⇒ SeamBridgeMetadata?
Metadata for Seam Bridge.
1469 |
# File 'lib/seam/resources/device.rb', line 1469 resource_accessor :seam_bridge_metadata, SeamBridgeMetadata |
#sensi_metadata ⇒ SensiMetadata?
Metadata for a Sensi device.
1472 |
# File 'lib/seam/resources/device.rb', line 1472 resource_accessor :sensi_metadata, SensiMetadata |
#smartthings_metadata ⇒ SmartthingsMetadata?
Metadata for a SmartThings device.
1475 |
# File 'lib/seam/resources/device.rb', line 1475 resource_accessor :smartthings_metadata, SmartthingsMetadata |
#tado_metadata ⇒ TadoMetadata?
Metadata for a tado° device.
1478 |
# File 'lib/seam/resources/device.rb', line 1478 resource_accessor :tado_metadata, TadoMetadata |
#tedee_metadata ⇒ TedeeMetadata?
Metadata for a Tedee device.
1481 |
# File 'lib/seam/resources/device.rb', line 1481 resource_accessor :tedee_metadata, TedeeMetadata |
#temperature_threshold ⇒ TemperatureThreshold?
Current temperature threshold set for the thermostat.
1513 |
# File 'lib/seam/resources/device.rb', line 1513 resource_accessor :temperature_threshold, TemperatureThreshold |
#thermostat_daily_programs ⇒ Array<ThermostatDailyPrograms>
Configured daily programs for the thermostat.
1531 |
# File 'lib/seam/resources/device.rb', line 1531 resource_list_accessor :thermostat_daily_programs, ThermostatDailyPrograms |
#thermostat_weekly_program ⇒ ThermostatWeeklyProgram?
Current weekly program for the thermostat.
1516 |
# File 'lib/seam/resources/device.rb', line 1516 resource_accessor :thermostat_weekly_program, ThermostatWeeklyProgram |
#ttlock_metadata ⇒ TtlockMetadata?
Metadata for a TTLock device.
1484 |
# File 'lib/seam/resources/device.rb', line 1484 resource_accessor :ttlock_metadata, TtlockMetadata |
#two_n_metadata ⇒ TwoNMetadata?
Metadata for a 2N device.
1487 |
# File 'lib/seam/resources/device.rb', line 1487 resource_accessor :two_n_metadata, TwoNMetadata |
#ultraloq_metadata ⇒ UltraloqMetadata?
Metadata for an Ultraloq device.
1490 |
# File 'lib/seam/resources/device.rb', line 1490 resource_accessor :ultraloq_metadata, UltraloqMetadata |
#visionline_metadata ⇒ VisionlineMetadata?
Metadata for an ASSA ABLOY Visionline system.
1493 |
# File 'lib/seam/resources/device.rb', line 1493 resource_accessor :visionline_metadata, VisionlineMetadata |
#wyze_metadata ⇒ WyzeMetadata?
Metadata for a Wyze device.
1496 |
# File 'lib/seam/resources/device.rb', line 1496 resource_accessor :wyze_metadata, WyzeMetadata |
#yacan_metadata ⇒ YacanMetadata?
Metadata for a Yacan device.
1499 |
# File 'lib/seam/resources/device.rb', line 1499 resource_accessor :yacan_metadata, YacanMetadata |