Class: Seam::Resources::Device::Properties
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: AccessoryKeypad, ActiveThermostatSchedule, AkilesMetadata, Appearance, AqaraMetadata, AssaAbloyCredentialServiceMetadata, AssaAbloyVostioMetadata, AugustMetadata, AvailableClimatePresets, AvigilonAltaMetadata, Battery, BrivoMetadata, CodeConstraints, ControlbywebMetadata, CurrentClimateSetting, DefaultClimateSetting, DormakabaOracodeMetadata, EcobeeMetadata, FourSuitesMetadata, GenieMetadata, HoneywellResideoMetadata, IglooMetadata, IgloohomeMetadata, KeynestMetadata, KeypadBattery, KisiMetadata, KorelockMetadata, KwiksetMetadata, LocklyMetadata, MinutMetadata, Model, NestMetadata, NoiseawareMetadata, NukiMetadata, OfflineTimeFrameOptions, OmnitecMetadata, OnlineTimeFrameOptions, RingMetadata, SaltoKsMetadata, SaltoMetadata, SaltoSpaceCredentialServiceMetadata, SchlageMetadata, SeamBridgeMetadata, SensiMetadata, SmartthingsMetadata, TadoMetadata, TedeeMetadata, TemperatureThreshold, ThermostatDailyPrograms, ThermostatWeeklyProgram, TtlockMetadata, TwoNMetadata, UltraloqMetadata, VisionlineMetadata, WyzeMetadata
Instance Attribute Summary collapse
-
#active_thermostat_schedule_id ⇒ Object
ID of the active thermostat schedule.
-
#auto_lock_delay_seconds ⇒ Object
The delay in seconds before the lock automatically locks after being unlocked.
-
#auto_lock_enabled ⇒ Object
Indicates whether automatic locking is enabled.
-
#available_climate_preset_modes ⇒ Object
Climate preset modes that the thermostat supports, such as "home", "away", "wake", "sleep", "occupied", and "unoccupied".
-
#available_fan_mode_settings ⇒ Object
Fan mode settings that the thermostat supports.
-
#available_hvac_mode_settings ⇒ Object
HVAC mode settings that the thermostat supports.
-
#backup_access_code_pool_enabled ⇒ Object
Indicates whether the backup access code pool is currently enabled for the device.
-
#battery_level ⇒ Object
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
-
#currently_triggering_noise_threshold_ids ⇒ Object
Array of noise threshold IDs that are currently triggering.
-
#door_open ⇒ Object
Indicates whether the door is open.
-
#fallback_climate_preset_key ⇒ Object
Key of the fallback climate preset for the thermostat.
-
#fan_mode_setting ⇒ Object
deprecated
Deprecated.
Use
current_climate_setting.fan_mode_settinginstead. -
#has_direct_power ⇒ Object
Indicates whether the device has direct power.
-
#has_native_entry_events ⇒ Object
Indicates whether the device supports native entry events.
-
#image_alt_text ⇒ Object
Alt text for the device image.
-
#image_url ⇒ Object
Image URL for the device.
-
#is_cooling ⇒ Object
Indicates whether the connected HVAC system is currently cooling, as reported by the thermostat.
-
#is_fan_running ⇒ Object
Indicates whether the fan in the connected HVAC system is currently running, as reported by the thermostat.
-
#is_heating ⇒ Object
Indicates whether the connected HVAC system is currently heating, as reported by the thermostat.
-
#is_temporary_manual_override_active ⇒ Object
Indicates whether the current thermostat settings differ from the most recent active program or schedule that Seam activated.
-
#locked ⇒ Object
Indicates whether the lock is locked.
-
#manufacturer ⇒ Object
Manufacturer of the device.
-
#max_active_codes_supported ⇒ Object
Maximum number of active access codes that the device supports.
-
#max_cooling_set_point_celsius ⇒ Object
Maximum cooling set point in °C.
-
#max_cooling_set_point_fahrenheit ⇒ Object
Maximum cooling set point in °F.
-
#max_heating_set_point_celsius ⇒ Object
Maximum heating set point in °C.
-
#max_heating_set_point_fahrenheit ⇒ Object
Maximum heating set point in °F.
-
#max_thermostat_daily_program_periods_per_day ⇒ Object
Maximum number of periods that the thermostat can support per day.
-
#max_unique_climate_presets_per_thermostat_weekly_program ⇒ Object
Maximum number of climate presets that the thermostat can support for weekly programming.
-
#min_cooling_set_point_celsius ⇒ Object
Minimum cooling set point in °C.
-
#min_cooling_set_point_fahrenheit ⇒ Object
Minimum cooling set point in °F.
-
#min_heating_cooling_delta_celsius ⇒ Object
Minimum temperature difference in °C between the cooling and heating set points when in heat-cool (auto) mode.
-
#min_heating_cooling_delta_fahrenheit ⇒ Object
Minimum temperature difference in °F between the cooling and heating set points when in heat-cool (auto) mode.
-
#min_heating_set_point_celsius ⇒ Object
Minimum heating set point in °C.
-
#min_heating_set_point_fahrenheit ⇒ Object
Minimum heating set point in °F.
-
#name ⇒ Object
deprecated
Deprecated.
use device.display_name instead
-
#noise_level_decibels ⇒ Object
Indicates current noise level in decibels, if the device supports noise detection.
-
#offline_access_codes_enabled ⇒ Object
deprecated
Deprecated.
use device.can_program_offline_access_codes
-
#online ⇒ Object
Indicates whether the device is online.
-
#online_access_codes_enabled ⇒ Object
deprecated
Deprecated.
use device.can_program_online_access_codes
-
#relative_humidity ⇒ Object
Reported relative humidity, as a value between 0 and 1, inclusive.
-
#serial_number ⇒ Object
Serial number of the device.
-
#supported_code_lengths ⇒ Object
Supported code lengths for access codes.
-
#supports_accessory_keypad ⇒ Object
deprecated
Deprecated.
use device.properties.model.can_connect_accessory_keypad
-
#supports_backup_access_code_pool ⇒ Object
Indicates whether the device supports a backup access code pool.
-
#supports_offline_access_codes ⇒ Object
deprecated
Deprecated.
use offline_access_codes_enabled
-
#temperature_celsius ⇒ Object
Reported temperature in °C.
-
#temperature_fahrenheit ⇒ Object
Reported temperature in °F.
-
#thermostat_daily_program_period_precision_minutes ⇒ Object
Precision of the thermostat's period in minutes.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#active_thermostat_schedule_id ⇒ Object
ID of the active thermostat schedule.
1061 1062 1063 |
# File 'lib/seam/resources/device.rb', line 1061 def active_thermostat_schedule_id @active_thermostat_schedule_id end |
#auto_lock_delay_seconds ⇒ Object
The delay in seconds before the lock automatically locks after being unlocked.
1043 1044 1045 |
# File 'lib/seam/resources/device.rb', line 1043 def auto_lock_delay_seconds @auto_lock_delay_seconds end |
#auto_lock_enabled ⇒ Object
Indicates whether automatic locking is enabled.
1045 1046 1047 |
# File 'lib/seam/resources/device.rb', line 1045 def auto_lock_enabled @auto_lock_enabled end |
#available_climate_preset_modes ⇒ Object
Climate preset modes that the thermostat supports, such as "home", "away", "wake", "sleep", "occupied", and "unoccupied".
1063 1064 1065 |
# File 'lib/seam/resources/device.rb', line 1063 def available_climate_preset_modes @available_climate_preset_modes end |
#available_fan_mode_settings ⇒ Object
Fan mode settings that the thermostat supports.
1065 1066 1067 |
# File 'lib/seam/resources/device.rb', line 1065 def available_fan_mode_settings @available_fan_mode_settings end |
#available_hvac_mode_settings ⇒ Object
HVAC mode settings that the thermostat supports.
1067 1068 1069 |
# File 'lib/seam/resources/device.rb', line 1067 def available_hvac_mode_settings @available_hvac_mode_settings end |
#backup_access_code_pool_enabled ⇒ Object
Indicates whether the backup access code pool is currently enabled for the device. To disable it, set this to false using /devices/update.
1047 1048 1049 |
# File 'lib/seam/resources/device.rb', line 1047 def backup_access_code_pool_enabled @backup_access_code_pool_enabled end |
#battery_level ⇒ Object
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
1012 1013 1014 |
# File 'lib/seam/resources/device.rb', line 1012 def battery_level @battery_level end |
#currently_triggering_noise_threshold_ids ⇒ Object
Array of noise threshold IDs that are currently triggering.
1014 1015 1016 |
# File 'lib/seam/resources/device.rb', line 1014 def currently_triggering_noise_threshold_ids @currently_triggering_noise_threshold_ids end |
#door_open ⇒ Object
Indicates whether the door is open.
1049 1050 1051 |
# File 'lib/seam/resources/device.rb', line 1049 def door_open @door_open end |
#fallback_climate_preset_key ⇒ Object
Key of the fallback climate preset for the thermostat.
1069 1070 1071 |
# File 'lib/seam/resources/device.rb', line 1069 def fallback_climate_preset_key @fallback_climate_preset_key end |
#fan_mode_setting ⇒ Object
Use current_climate_setting.fan_mode_setting instead.
1071 1072 1073 |
# File 'lib/seam/resources/device.rb', line 1071 def fan_mode_setting @fan_mode_setting end |
#has_direct_power ⇒ Object
Indicates whether the device has direct power.
1016 1017 1018 |
# File 'lib/seam/resources/device.rb', line 1016 def has_direct_power @has_direct_power end |
#has_native_entry_events ⇒ Object
Indicates whether the device supports native entry events.
1051 1052 1053 |
# File 'lib/seam/resources/device.rb', line 1051 def has_native_entry_events @has_native_entry_events end |
#image_alt_text ⇒ Object
Alt text for the device image.
1018 1019 1020 |
# File 'lib/seam/resources/device.rb', line 1018 def image_alt_text @image_alt_text end |
#image_url ⇒ Object
Image URL for the device.
1020 1021 1022 |
# File 'lib/seam/resources/device.rb', line 1020 def image_url @image_url end |
#is_cooling ⇒ Object
Indicates whether the connected HVAC system is currently cooling, as reported by the thermostat.
1073 1074 1075 |
# File 'lib/seam/resources/device.rb', line 1073 def is_cooling @is_cooling end |
#is_fan_running ⇒ Object
Indicates whether the fan in the connected HVAC system is currently running, as reported by the thermostat.
1075 1076 1077 |
# File 'lib/seam/resources/device.rb', line 1075 def is_fan_running @is_fan_running end |
#is_heating ⇒ Object
Indicates whether the connected HVAC system is currently heating, as reported by the thermostat.
1077 1078 1079 |
# File 'lib/seam/resources/device.rb', line 1077 def is_heating @is_heating end |
#is_temporary_manual_override_active ⇒ Object
Indicates whether the current thermostat settings differ from the most recent active program or schedule that Seam activated. For this condition to occur, current_climate_setting.manual_override_allowed must also be true.
1079 1080 1081 |
# File 'lib/seam/resources/device.rb', line 1079 def is_temporary_manual_override_active @is_temporary_manual_override_active end |
#locked ⇒ Object
Indicates whether the lock is locked.
1053 1054 1055 |
# File 'lib/seam/resources/device.rb', line 1053 def locked @locked end |
#manufacturer ⇒ Object
Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.
1022 1023 1024 |
# File 'lib/seam/resources/device.rb', line 1022 def manufacturer @manufacturer end |
#max_active_codes_supported ⇒ Object
Maximum number of active access codes that the device supports.
1055 1056 1057 |
# File 'lib/seam/resources/device.rb', line 1055 def max_active_codes_supported @max_active_codes_supported end |
#max_cooling_set_point_celsius ⇒ Object
Maximum cooling set point in °C.
1081 1082 1083 |
# File 'lib/seam/resources/device.rb', line 1081 def max_cooling_set_point_celsius @max_cooling_set_point_celsius end |
#max_cooling_set_point_fahrenheit ⇒ Object
Maximum cooling set point in °F.
1083 1084 1085 |
# File 'lib/seam/resources/device.rb', line 1083 def max_cooling_set_point_fahrenheit @max_cooling_set_point_fahrenheit end |
#max_heating_set_point_celsius ⇒ Object
Maximum heating set point in °C.
1085 1086 1087 |
# File 'lib/seam/resources/device.rb', line 1085 def max_heating_set_point_celsius @max_heating_set_point_celsius end |
#max_heating_set_point_fahrenheit ⇒ Object
Maximum heating set point in °F.
1087 1088 1089 |
# File 'lib/seam/resources/device.rb', line 1087 def max_heating_set_point_fahrenheit @max_heating_set_point_fahrenheit end |
#max_thermostat_daily_program_periods_per_day ⇒ Object
Maximum number of periods that the thermostat can support per day. For example, if the thermostat supports 4 periods per day, this value is 4.
1089 1090 1091 |
# File 'lib/seam/resources/device.rb', line 1089 def max_thermostat_daily_program_periods_per_day @max_thermostat_daily_program_periods_per_day end |
#max_unique_climate_presets_per_thermostat_weekly_program ⇒ Object
Maximum number of climate presets that the thermostat can support for weekly programming.
1091 1092 1093 |
# File 'lib/seam/resources/device.rb', line 1091 def max_unique_climate_presets_per_thermostat_weekly_program @max_unique_climate_presets_per_thermostat_weekly_program end |
#min_cooling_set_point_celsius ⇒ Object
Minimum cooling set point in °C.
1093 1094 1095 |
# File 'lib/seam/resources/device.rb', line 1093 def min_cooling_set_point_celsius @min_cooling_set_point_celsius end |
#min_cooling_set_point_fahrenheit ⇒ Object
Minimum cooling set point in °F.
1095 1096 1097 |
# File 'lib/seam/resources/device.rb', line 1095 def min_cooling_set_point_fahrenheit @min_cooling_set_point_fahrenheit end |
#min_heating_cooling_delta_celsius ⇒ Object
Minimum temperature difference in °C between the cooling and heating set points when in heat-cool (auto) mode.
1097 1098 1099 |
# File 'lib/seam/resources/device.rb', line 1097 def min_heating_cooling_delta_celsius @min_heating_cooling_delta_celsius end |
#min_heating_cooling_delta_fahrenheit ⇒ Object
Minimum temperature difference in °F between the cooling and heating set points when in heat-cool (auto) mode.
1099 1100 1101 |
# File 'lib/seam/resources/device.rb', line 1099 def min_heating_cooling_delta_fahrenheit @min_heating_cooling_delta_fahrenheit end |
#min_heating_set_point_celsius ⇒ Object
Minimum heating set point in °C.
1101 1102 1103 |
# File 'lib/seam/resources/device.rb', line 1101 def min_heating_set_point_celsius @min_heating_set_point_celsius end |
#min_heating_set_point_fahrenheit ⇒ Object
Minimum heating set point in °F.
1103 1104 1105 |
# File 'lib/seam/resources/device.rb', line 1103 def min_heating_set_point_fahrenheit @min_heating_set_point_fahrenheit end |
#name ⇒ Object
use device.display_name instead
Name of the device.
1025 1026 1027 |
# File 'lib/seam/resources/device.rb', line 1025 def name @name end |
#noise_level_decibels ⇒ Object
Indicates current noise level in decibels, if the device supports noise detection.
1027 1028 1029 |
# File 'lib/seam/resources/device.rb', line 1027 def noise_level_decibels @noise_level_decibels end |
#offline_access_codes_enabled ⇒ Object
use device.can_program_offline_access_codes
Indicates whether it is currently possible to use offline access codes for the device.
1030 1031 1032 |
# File 'lib/seam/resources/device.rb', line 1030 def offline_access_codes_enabled @offline_access_codes_enabled end |
#online ⇒ Object
Indicates whether the device is online.
1032 1033 1034 |
# File 'lib/seam/resources/device.rb', line 1032 def online @online end |
#online_access_codes_enabled ⇒ Object
use device.can_program_online_access_codes
Indicates whether it is currently possible to use online access codes for the device.
1035 1036 1037 |
# File 'lib/seam/resources/device.rb', line 1035 def online_access_codes_enabled @online_access_codes_enabled end |
#relative_humidity ⇒ Object
Reported relative humidity, as a value between 0 and 1, inclusive.
1105 1106 1107 |
# File 'lib/seam/resources/device.rb', line 1105 def relative_humidity @relative_humidity end |
#serial_number ⇒ Object
Serial number of the device.
1037 1038 1039 |
# File 'lib/seam/resources/device.rb', line 1037 def serial_number @serial_number end |
#supported_code_lengths ⇒ Object
Supported code lengths for access codes.
1057 1058 1059 |
# File 'lib/seam/resources/device.rb', line 1057 def supported_code_lengths @supported_code_lengths end |
#supports_accessory_keypad ⇒ Object
use device.properties.model.can_connect_accessory_keypad
1039 1040 1041 |
# File 'lib/seam/resources/device.rb', line 1039 def supports_accessory_keypad @supports_accessory_keypad end |
#supports_backup_access_code_pool ⇒ Object
Indicates whether the device supports a backup access code pool.
1059 1060 1061 |
# File 'lib/seam/resources/device.rb', line 1059 def supports_backup_access_code_pool @supports_backup_access_code_pool end |
#supports_offline_access_codes ⇒ Object
use offline_access_codes_enabled
1041 1042 1043 |
# File 'lib/seam/resources/device.rb', line 1041 def supports_offline_access_codes @supports_offline_access_codes end |
#temperature_celsius ⇒ Object
Reported temperature in °C.
1107 1108 1109 |
# File 'lib/seam/resources/device.rb', line 1107 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Object
Reported temperature in °F.
1109 1110 1111 |
# File 'lib/seam/resources/device.rb', line 1109 def temperature_fahrenheit @temperature_fahrenheit end |
#thermostat_daily_program_period_precision_minutes ⇒ Object
Precision of the thermostat's period in minutes. For example, if the thermostat supports 15-minute periods, this value is 15. All values are relative to the top of the hour, so for 15 minutes, the periods would be 0, 15, 30, and 45 minutes past the hour.
1111 1112 1113 |
# File 'lib/seam/resources/device.rb', line 1111 def thermostat_daily_program_period_precision_minutes @thermostat_daily_program_period_precision_minutes end |