Class: Seam::Resources::Device::Properties::ActiveThermostatSchedule

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: Errors

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_preset_keyString

Key of the climate preset to use for the thermostat schedule.

Returns:

  • (String)


1080
1081
1082
# File 'lib/seam/resources/device.rb', line 1080

def climate_preset_key
  @climate_preset_key
end

#device_idString

ID of the desired thermostat device.

Returns:

  • (String)


1083
1084
1085
# File 'lib/seam/resources/device.rb', line 1083

def device_id
  @device_id
end

#is_override_allowedBoolean?

Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.

Returns:

  • (Boolean, nil)


1086
1087
1088
# File 'lib/seam/resources/device.rb', line 1086

def is_override_allowed
  @is_override_allowed
end

#max_override_period_minutesInteger?

Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.

Returns:

  • (Integer, nil)


1089
1090
1091
# File 'lib/seam/resources/device.rb', line 1089

def max_override_period_minutes
  @max_override_period_minutes
end

#nameString?

User-friendly name to identify the thermostat schedule.

Returns:

  • (String, nil)


1092
1093
1094
# File 'lib/seam/resources/device.rb', line 1092

def name
  @name
end

#thermostat_schedule_idString

ID of the thermostat schedule.

Returns:

  • (String)


1095
1096
1097
# File 'lib/seam/resources/device.rb', line 1095

def thermostat_schedule_id
  @thermostat_schedule_id
end

#workspace_idString

ID of the workspace that contains the thermostat schedule.

Returns:

  • (String)


1098
1099
1100
# File 'lib/seam/resources/device.rb', line 1098

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the thermostat schedule was created.

Returns:

  • (Time)


1101
# File 'lib/seam/resources/device.rb', line 1101

date_accessor :created_at

#ends_atTime

Date and time at which the thermostat schedule ends, in ISO 8601 format.

Returns:

  • (Time)


1104
# File 'lib/seam/resources/device.rb', line 1104

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the thermostat schedule.

Returns:



1077
# File 'lib/seam/resources/device.rb', line 1077

resource_list_accessor :errors, Errors

#starts_atTime

Date and time at which the thermostat schedule starts, in ISO 8601 format.

Returns:

  • (Time)


1107
# File 'lib/seam/resources/device.rb', line 1107

date_accessor :starts_at