Class: Seam::Resources::Device::Properties::ActiveThermostatSchedule
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::ActiveThermostatSchedule
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: Errors
Instance Attribute Summary collapse
-
#climate_preset_key ⇒ String
Key of the climate preset to use for the thermostat schedule.
-
#device_id ⇒ String
ID of the desired thermostat device.
-
#is_override_allowed ⇒ Boolean?
Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.
-
#max_override_period_minutes ⇒ Integer?
Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset.
-
#name ⇒ String?
User-friendly name to identify the thermostat schedule.
-
#thermostat_schedule_id ⇒ String
ID of the thermostat schedule.
-
#workspace_id ⇒ String
ID of the workspace that contains the thermostat schedule.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the thermostat schedule was created.
-
#ends_at ⇒ Time
Date and time at which the thermostat schedule ends, in ISO 8601 format.
-
#errors ⇒ Array<Errors>
Errors associated with the thermostat schedule.
-
#starts_at ⇒ Time
Date and time at which the thermostat schedule starts, in ISO 8601 format.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#climate_preset_key ⇒ String
Key of the climate preset to use for the thermostat schedule.
1080 1081 1082 |
# File 'lib/seam/resources/device.rb', line 1080 def climate_preset_key @climate_preset_key end |
#device_id ⇒ String
ID of the desired thermostat device.
1083 1084 1085 |
# File 'lib/seam/resources/device.rb', line 1083 def device_id @device_id end |
#is_override_allowed ⇒ Boolean?
Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.
1086 1087 1088 |
# File 'lib/seam/resources/device.rb', line 1086 def is_override_allowed @is_override_allowed end |
#max_override_period_minutes ⇒ Integer?
Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.
1089 1090 1091 |
# File 'lib/seam/resources/device.rb', line 1089 def max_override_period_minutes @max_override_period_minutes end |
#name ⇒ String?
User-friendly name to identify the thermostat schedule.
1092 1093 1094 |
# File 'lib/seam/resources/device.rb', line 1092 def name @name end |
#thermostat_schedule_id ⇒ String
ID of the thermostat schedule.
1095 1096 1097 |
# File 'lib/seam/resources/device.rb', line 1095 def thermostat_schedule_id @thermostat_schedule_id end |
#workspace_id ⇒ String
ID of the workspace that contains the thermostat schedule.
1098 1099 1100 |
# File 'lib/seam/resources/device.rb', line 1098 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the thermostat schedule was created.
1101 |
# File 'lib/seam/resources/device.rb', line 1101 date_accessor :created_at |
#ends_at ⇒ Time
Date and time at which the thermostat schedule ends, in ISO 8601 format.
1104 |
# File 'lib/seam/resources/device.rb', line 1104 date_accessor :ends_at |
#errors ⇒ Array<Errors>
Errors associated with the thermostat schedule.
1077 |
# File 'lib/seam/resources/device.rb', line 1077 resource_list_accessor :errors, Errors |
#starts_at ⇒ Time
Date and time at which the thermostat schedule starts, in ISO 8601 format.
1107 |
# File 'lib/seam/resources/device.rb', line 1107 date_accessor :starts_at |