Class: Seam::Resources::Device::Properties::ActiveThermostatSchedule

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: Errors

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_preset_keyObject

Key of the climate preset to use for the thermostat schedule.



758
759
760
# File 'lib/seam/resources/device.rb', line 758

def climate_preset_key
  @climate_preset_key
end

#device_idObject

ID of the desired thermostat device.



760
761
762
# File 'lib/seam/resources/device.rb', line 760

def device_id
  @device_id
end

#is_override_allowedObject

Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.



762
763
764
# File 'lib/seam/resources/device.rb', line 762

def is_override_allowed
  @is_override_allowed
end

#max_override_period_minutesObject

Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.



764
765
766
# File 'lib/seam/resources/device.rb', line 764

def max_override_period_minutes
  @max_override_period_minutes
end

#nameObject

User-friendly name to identify the thermostat schedule.



766
767
768
# File 'lib/seam/resources/device.rb', line 766

def name
  @name
end

#thermostat_schedule_idObject

ID of the thermostat schedule.



768
769
770
# File 'lib/seam/resources/device.rb', line 768

def thermostat_schedule_id
  @thermostat_schedule_id
end

#workspace_idObject

ID of the workspace that contains the thermostat schedule.



770
771
772
# File 'lib/seam/resources/device.rb', line 770

def workspace_id
  @workspace_id
end