Class: Seam::Resources::Device::Properties::AvailableClimatePresets
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::AvailableClimatePresets
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: EcobeeMetadata
Instance Attribute Summary collapse
-
#can_delete ⇒ Boolean
Indicates whether the climate preset key can be deleted.
-
#can_edit ⇒ Boolean
Indicates whether the climate preset key can be edited.
-
#can_use_with_thermostat_daily_programs ⇒ Boolean
Indicates whether the climate preset key can be programmed in a thermostat daily program.
-
#climate_preset_key ⇒ String
Unique key to identify the climate preset.
-
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
-
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F).
-
#display_name ⇒ String
Display name for the climate preset.
-
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#manual_override_allowed ⇒ Boolean
deprecated
Deprecated.
Use 'thermostat_schedule.is_override_allowed'
-
#name ⇒ String?
User-friendly name to identify the climate preset.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_delete ⇒ Boolean
Indicates whether the climate preset key can be deleted.
1450 1451 1452 |
# File 'lib/seam/resources/device.rb', line 1450 def can_delete @can_delete end |
#can_edit ⇒ Boolean
Indicates whether the climate preset key can be edited.
1453 1454 1455 |
# File 'lib/seam/resources/device.rb', line 1453 def can_edit @can_edit end |
#can_use_with_thermostat_daily_programs ⇒ Boolean
Indicates whether the climate preset key can be programmed in a thermostat daily program.
1456 1457 1458 |
# File 'lib/seam/resources/device.rb', line 1456 def can_use_with_thermostat_daily_programs @can_use_with_thermostat_daily_programs end |
#climate_preset_key ⇒ String
Unique key to identify the climate preset.
1459 1460 1461 |
# File 'lib/seam/resources/device.rb', line 1459 def climate_preset_key @climate_preset_key end |
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device. Known values:
homeawaywakesleepoccupiedunoccupied
1469 1470 1471 |
# File 'lib/seam/resources/device.rb', line 1469 def climate_preset_mode @climate_preset_mode end |
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C). See also Set Points.
1472 1473 1474 |
# File 'lib/seam/resources/device.rb', line 1472 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F). See also Set Points.
1475 1476 1477 |
# File 'lib/seam/resources/device.rb', line 1475 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#display_name ⇒ String
Display name for the climate preset.
1478 1479 1480 |
# File 'lib/seam/resources/device.rb', line 1478 def display_name @display_name end |
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as on, auto, or circulate.
Known values:
autooncirculate
1485 1486 1487 |
# File 'lib/seam/resources/device.rb', line 1485 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C). See also Set Points.
1488 1489 1490 |
# File 'lib/seam/resources/device.rb', line 1488 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F). See also Set Points.
1491 1492 1493 |
# File 'lib/seam/resources/device.rb', line 1491 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
Known values:
offheatcoolheat_cooleco
1500 1501 1502 |
# File 'lib/seam/resources/device.rb', line 1500 def hvac_mode_setting @hvac_mode_setting end |
#manual_override_allowed ⇒ Boolean
Use 'thermostat_schedule.is_override_allowed'
Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.
1504 1505 1506 |
# File 'lib/seam/resources/device.rb', line 1504 def manual_override_allowed @manual_override_allowed end |
#name ⇒ String?
User-friendly name to identify the climate preset.
1507 1508 1509 |
# File 'lib/seam/resources/device.rb', line 1507 def name @name end |
Instance Method Details
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
1447 |
# File 'lib/seam/resources/device.rb', line 1447 resource_accessor :ecobee_metadata, EcobeeMetadata |