Class: Seam::Resources::Device::Properties::AvailableClimatePresets
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::AvailableClimatePresets
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: EcobeeMetadata
Instance Attribute Summary collapse
-
#can_delete ⇒ Boolean
Indicates whether the climate preset key can be deleted.
-
#can_edit ⇒ Boolean
Indicates whether the climate preset key can be edited.
-
#can_use_with_thermostat_daily_programs ⇒ Boolean
Indicates whether the climate preset key can be programmed in a thermostat daily program.
-
#climate_preset_key ⇒ String
Unique key to identify the climate preset.
-
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
-
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F).
-
#display_name ⇒ String
Display name for the climate preset.
-
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#manual_override_allowed ⇒ Boolean
deprecated
Deprecated.
Use 'thermostat_schedule.is_override_allowed'
-
#name ⇒ String?
User-friendly name to identify the climate preset.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_delete ⇒ Boolean
Indicates whether the climate preset key can be deleted.
1128 1129 1130 |
# File 'lib/seam/resources/device.rb', line 1128 def can_delete @can_delete end |
#can_edit ⇒ Boolean
Indicates whether the climate preset key can be edited.
1131 1132 1133 |
# File 'lib/seam/resources/device.rb', line 1131 def can_edit @can_edit end |
#can_use_with_thermostat_daily_programs ⇒ Boolean
Indicates whether the climate preset key can be programmed in a thermostat daily program.
1134 1135 1136 |
# File 'lib/seam/resources/device.rb', line 1134 def can_use_with_thermostat_daily_programs @can_use_with_thermostat_daily_programs end |
#climate_preset_key ⇒ String
Unique key to identify the climate preset.
1137 1138 1139 |
# File 'lib/seam/resources/device.rb', line 1137 def climate_preset_key @climate_preset_key end |
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
1140 1141 1142 |
# File 'lib/seam/resources/device.rb', line 1140 def climate_preset_mode @climate_preset_mode end |
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C). See also Set Points.
1143 1144 1145 |
# File 'lib/seam/resources/device.rb', line 1143 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F). See also Set Points.
1146 1147 1148 |
# File 'lib/seam/resources/device.rb', line 1146 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#display_name ⇒ String
Display name for the climate preset.
1149 1150 1151 |
# File 'lib/seam/resources/device.rb', line 1149 def display_name @display_name end |
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as on, auto, or circulate.
1152 1153 1154 |
# File 'lib/seam/resources/device.rb', line 1152 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C). See also Set Points.
1155 1156 1157 |
# File 'lib/seam/resources/device.rb', line 1155 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F). See also Set Points.
1158 1159 1160 |
# File 'lib/seam/resources/device.rb', line 1158 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
1161 1162 1163 |
# File 'lib/seam/resources/device.rb', line 1161 def hvac_mode_setting @hvac_mode_setting end |
#manual_override_allowed ⇒ Boolean
Use 'thermostat_schedule.is_override_allowed'
Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.
1165 1166 1167 |
# File 'lib/seam/resources/device.rb', line 1165 def manual_override_allowed @manual_override_allowed end |
#name ⇒ String?
User-friendly name to identify the climate preset.
1168 1169 1170 |
# File 'lib/seam/resources/device.rb', line 1168 def name @name end |
Instance Method Details
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
1125 |
# File 'lib/seam/resources/device.rb', line 1125 resource_accessor :ecobee_metadata, EcobeeMetadata |