Class: Seam::Resources::Device::Properties::AvailableClimatePresets
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::AvailableClimatePresets
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: EcobeeMetadata
Instance Attribute Summary collapse
-
#can_delete ⇒ Object
Indicates whether the climate preset key can be deleted.
-
#can_edit ⇒ Object
Indicates whether the climate preset key can be edited.
-
#can_use_with_thermostat_daily_programs ⇒ Object
Indicates whether the climate preset key can be programmed in a thermostat daily program.
-
#climate_preset_key ⇒ Object
Unique key to identify the climate preset.
-
#climate_preset_mode ⇒ Object
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
-
#cooling_set_point_celsius ⇒ Object
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should cool (in °F).
-
#display_name ⇒ Object
Display name for the climate preset.
-
#fan_mode_setting ⇒ Object
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Object
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ Object
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#manual_override_allowed ⇒ Object
deprecated
Deprecated.
Use 'thermostat_schedule.is_override_allowed'
-
#name ⇒ Object
User-friendly name to identify the climate preset.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_delete ⇒ Object
Indicates whether the climate preset key can be deleted.
791 792 793 |
# File 'lib/seam/resources/device.rb', line 791 def can_delete @can_delete end |
#can_edit ⇒ Object
Indicates whether the climate preset key can be edited.
793 794 795 |
# File 'lib/seam/resources/device.rb', line 793 def can_edit @can_edit end |
#can_use_with_thermostat_daily_programs ⇒ Object
Indicates whether the climate preset key can be programmed in a thermostat daily program.
795 796 797 |
# File 'lib/seam/resources/device.rb', line 795 def can_use_with_thermostat_daily_programs @can_use_with_thermostat_daily_programs end |
#climate_preset_key ⇒ Object
Unique key to identify the climate preset.
797 798 799 |
# File 'lib/seam/resources/device.rb', line 797 def climate_preset_key @climate_preset_key end |
#climate_preset_mode ⇒ Object
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
799 800 801 |
# File 'lib/seam/resources/device.rb', line 799 def climate_preset_mode @climate_preset_mode end |
#cooling_set_point_celsius ⇒ Object
Temperature to which the thermostat should cool (in °C). See also Set Points.
801 802 803 |
# File 'lib/seam/resources/device.rb', line 801 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should cool (in °F). See also Set Points.
803 804 805 |
# File 'lib/seam/resources/device.rb', line 803 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#display_name ⇒ Object
Display name for the climate preset.
805 806 807 |
# File 'lib/seam/resources/device.rb', line 805 def display_name @display_name end |
#fan_mode_setting ⇒ Object
Desired fan mode setting, such as on, auto, or circulate.
807 808 809 |
# File 'lib/seam/resources/device.rb', line 807 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Object
Temperature to which the thermostat should heat (in °C). See also Set Points.
809 810 811 |
# File 'lib/seam/resources/device.rb', line 809 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should heat (in °F). See also Set Points.
811 812 813 |
# File 'lib/seam/resources/device.rb', line 811 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ Object
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
813 814 815 |
# File 'lib/seam/resources/device.rb', line 813 def hvac_mode_setting @hvac_mode_setting end |
#manual_override_allowed ⇒ Object
Use 'thermostat_schedule.is_override_allowed'
Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.
816 817 818 |
# File 'lib/seam/resources/device.rb', line 816 def manual_override_allowed @manual_override_allowed end |
#name ⇒ Object
User-friendly name to identify the climate preset.
818 819 820 |
# File 'lib/seam/resources/device.rb', line 818 def name @name end |