Class: Seam::Resources::Device::Properties::AvailableClimatePresets::EcobeeMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_refObject

Reference to the Ecobee climate, if applicable.



782
783
784
# File 'lib/seam/resources/device.rb', line 782

def climate_ref
  @climate_ref
end

#is_optimizedObject

Indicates if the climate preset is optimized by Ecobee.



784
785
786
# File 'lib/seam/resources/device.rb', line 784

def is_optimized
  @is_optimized
end

#ownerObject

Indicates whether the climate preset is owned by the user or the system.



786
787
788
# File 'lib/seam/resources/device.rb', line 786

def owner
  @owner
end