Class: Seam::Resources::Device::Properties::BrivoMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::BrivoMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#activation_enabled ⇒ Object
Indicates whether the Brivo access point has activation (remote unlock) enabled.
-
#device_name ⇒ Object
Device name for a Brivo device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#activation_enabled ⇒ Object
Indicates whether the Brivo access point has activation (remote unlock) enabled.
179 180 181 |
# File 'lib/seam/resources/device.rb', line 179 def activation_enabled @activation_enabled end |
#device_name ⇒ Object
Device name for a Brivo device.
181 182 183 |
# File 'lib/seam/resources/device.rb', line 181 def device_name @device_name end |