Class: Seam::Resources::Device::Properties::CurrentClimateSetting
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::CurrentClimateSetting
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: EcobeeMetadata
Instance Attribute Summary collapse
-
#can_delete ⇒ Boolean?
Indicates whether the climate preset key can be deleted.
-
#can_edit ⇒ Boolean?
Indicates whether the climate preset key can be edited.
-
#can_use_with_thermostat_daily_programs ⇒ Boolean?
Indicates whether the climate preset key can be programmed in a thermostat daily program.
-
#climate_preset_key ⇒ String?
Unique key to identify the climate preset.
-
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
-
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F).
-
#display_name ⇒ String?
Display name for the climate preset.
-
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#manual_override_allowed ⇒ Boolean?
deprecated
Deprecated.
Use 'thermostat_schedule.is_override_allowed'
-
#name ⇒ String?
User-friendly name to identify the climate preset.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_delete ⇒ Boolean?
Indicates whether the climate preset key can be deleted.
1189 1190 1191 |
# File 'lib/seam/resources/device.rb', line 1189 def can_delete @can_delete end |
#can_edit ⇒ Boolean?
Indicates whether the climate preset key can be edited.
1192 1193 1194 |
# File 'lib/seam/resources/device.rb', line 1192 def can_edit @can_edit end |
#can_use_with_thermostat_daily_programs ⇒ Boolean?
Indicates whether the climate preset key can be programmed in a thermostat daily program.
1195 1196 1197 |
# File 'lib/seam/resources/device.rb', line 1195 def can_use_with_thermostat_daily_programs @can_use_with_thermostat_daily_programs end |
#climate_preset_key ⇒ String?
Unique key to identify the climate preset.
1198 1199 1200 |
# File 'lib/seam/resources/device.rb', line 1198 def climate_preset_key @climate_preset_key end |
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
1201 1202 1203 |
# File 'lib/seam/resources/device.rb', line 1201 def climate_preset_mode @climate_preset_mode end |
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C). See also Set Points.
1204 1205 1206 |
# File 'lib/seam/resources/device.rb', line 1204 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F). See also Set Points.
1207 1208 1209 |
# File 'lib/seam/resources/device.rb', line 1207 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#display_name ⇒ String?
Display name for the climate preset.
1210 1211 1212 |
# File 'lib/seam/resources/device.rb', line 1210 def display_name @display_name end |
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as on, auto, or circulate.
1213 1214 1215 |
# File 'lib/seam/resources/device.rb', line 1213 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C). See also Set Points.
1216 1217 1218 |
# File 'lib/seam/resources/device.rb', line 1216 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F). See also Set Points.
1219 1220 1221 |
# File 'lib/seam/resources/device.rb', line 1219 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
1222 1223 1224 |
# File 'lib/seam/resources/device.rb', line 1222 def hvac_mode_setting @hvac_mode_setting end |
#manual_override_allowed ⇒ Boolean?
Use 'thermostat_schedule.is_override_allowed'
Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.
1226 1227 1228 |
# File 'lib/seam/resources/device.rb', line 1226 def manual_override_allowed @manual_override_allowed end |
#name ⇒ String?
User-friendly name to identify the climate preset.
1229 1230 1231 |
# File 'lib/seam/resources/device.rb', line 1229 def name @name end |
Instance Method Details
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
1186 |
# File 'lib/seam/resources/device.rb', line 1186 resource_accessor :ecobee_metadata, EcobeeMetadata |