Class: Seam::Resources::Device::Properties::CurrentClimateSetting::EcobeeMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::CurrentClimateSetting::EcobeeMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#climate_ref ⇒ Object
Reference to the Ecobee climate, if applicable.
-
#is_optimized ⇒ Object
Indicates if the climate preset is optimized by Ecobee.
-
#owner ⇒ Object
Indicates whether the climate preset is owned by the user or the system.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#climate_ref ⇒ Object
Reference to the Ecobee climate, if applicable.
824 825 826 |
# File 'lib/seam/resources/device.rb', line 824 def climate_ref @climate_ref end |
#is_optimized ⇒ Object
Indicates if the climate preset is optimized by Ecobee.
826 827 828 |
# File 'lib/seam/resources/device.rb', line 826 def is_optimized @is_optimized end |
#owner ⇒ Object
Indicates whether the climate preset is owned by the user or the system.
828 829 830 |
# File 'lib/seam/resources/device.rb', line 828 def owner @owner end |