Class: Seam::Resources::Device::Properties::DefaultClimateSetting
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::DefaultClimateSetting
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: EcobeeMetadata
Instance Attribute Summary collapse
-
#can_delete ⇒ Boolean?
Indicates whether the climate preset key can be deleted.
-
#can_edit ⇒ Boolean?
Indicates whether the climate preset key can be edited.
-
#can_use_with_thermostat_daily_programs ⇒ Boolean?
Indicates whether the climate preset key can be programmed in a thermostat daily program.
-
#climate_preset_key ⇒ String?
Unique key to identify the climate preset.
-
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
-
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F).
-
#display_name ⇒ String?
Display name for the climate preset.
-
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#manual_override_allowed ⇒ Boolean?
deprecated
Deprecated.
Use 'thermostat_schedule.is_override_allowed'
-
#name ⇒ String?
User-friendly name to identify the climate preset.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_delete ⇒ Boolean?
Indicates whether the climate preset key can be deleted.
1250 1251 1252 |
# File 'lib/seam/resources/device.rb', line 1250 def can_delete @can_delete end |
#can_edit ⇒ Boolean?
Indicates whether the climate preset key can be edited.
1253 1254 1255 |
# File 'lib/seam/resources/device.rb', line 1253 def can_edit @can_edit end |
#can_use_with_thermostat_daily_programs ⇒ Boolean?
Indicates whether the climate preset key can be programmed in a thermostat daily program.
1256 1257 1258 |
# File 'lib/seam/resources/device.rb', line 1256 def can_use_with_thermostat_daily_programs @can_use_with_thermostat_daily_programs end |
#climate_preset_key ⇒ String?
Unique key to identify the climate preset.
1259 1260 1261 |
# File 'lib/seam/resources/device.rb', line 1259 def climate_preset_key @climate_preset_key end |
#climate_preset_mode ⇒ String?
The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.
1262 1263 1264 |
# File 'lib/seam/resources/device.rb', line 1262 def climate_preset_mode @climate_preset_mode end |
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C). See also Set Points.
1265 1266 1267 |
# File 'lib/seam/resources/device.rb', line 1265 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F). See also Set Points.
1268 1269 1270 |
# File 'lib/seam/resources/device.rb', line 1268 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#display_name ⇒ String?
Display name for the climate preset.
1271 1272 1273 |
# File 'lib/seam/resources/device.rb', line 1271 def display_name @display_name end |
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as on, auto, or circulate.
1274 1275 1276 |
# File 'lib/seam/resources/device.rb', line 1274 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C). See also Set Points.
1277 1278 1279 |
# File 'lib/seam/resources/device.rb', line 1277 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F). See also Set Points.
1280 1281 1282 |
# File 'lib/seam/resources/device.rb', line 1280 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
1283 1284 1285 |
# File 'lib/seam/resources/device.rb', line 1283 def hvac_mode_setting @hvac_mode_setting end |
#manual_override_allowed ⇒ Boolean?
Use 'thermostat_schedule.is_override_allowed'
Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.
1287 1288 1289 |
# File 'lib/seam/resources/device.rb', line 1287 def manual_override_allowed @manual_override_allowed end |
#name ⇒ String?
User-friendly name to identify the climate preset.
1290 1291 1292 |
# File 'lib/seam/resources/device.rb', line 1290 def name @name end |
Instance Method Details
#ecobee_metadata ⇒ EcobeeMetadata?
Metadata specific to the Ecobee climate, if applicable.
1247 |
# File 'lib/seam/resources/device.rb', line 1247 resource_accessor :ecobee_metadata, EcobeeMetadata |