Class: Seam::Resources::Device::Properties::DefaultClimateSetting

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: EcobeeMetadata

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_deleteObject

Indicates whether the climate preset key can be deleted.



875
876
877
# File 'lib/seam/resources/device.rb', line 875

def can_delete
  @can_delete
end

#can_editObject

Indicates whether the climate preset key can be edited.



877
878
879
# File 'lib/seam/resources/device.rb', line 877

def can_edit
  @can_edit
end

#can_use_with_thermostat_daily_programsObject

Indicates whether the climate preset key can be programmed in a thermostat daily program.



879
880
881
# File 'lib/seam/resources/device.rb', line 879

def can_use_with_thermostat_daily_programs
  @can_use_with_thermostat_daily_programs
end

#climate_preset_keyObject

Unique key to identify the climate preset.



881
882
883
# File 'lib/seam/resources/device.rb', line 881

def climate_preset_key
  @climate_preset_key
end

#climate_preset_modeObject

The climate preset mode for the thermostat, based on the available climate preset modes reported by the device.



883
884
885
# File 'lib/seam/resources/device.rb', line 883

def climate_preset_mode
  @climate_preset_mode
end

#cooling_set_point_celsiusObject

Temperature to which the thermostat should cool (in °C). See also Set Points.



885
886
887
# File 'lib/seam/resources/device.rb', line 885

def cooling_set_point_celsius
  @cooling_set_point_celsius
end

#cooling_set_point_fahrenheitObject

Temperature to which the thermostat should cool (in °F). See also Set Points.



887
888
889
# File 'lib/seam/resources/device.rb', line 887

def cooling_set_point_fahrenheit
  @cooling_set_point_fahrenheit
end

#display_nameObject

Display name for the climate preset.



889
890
891
# File 'lib/seam/resources/device.rb', line 889

def display_name
  @display_name
end

#fan_mode_settingObject

Desired fan mode setting, such as on, auto, or circulate.



891
892
893
# File 'lib/seam/resources/device.rb', line 891

def fan_mode_setting
  @fan_mode_setting
end

#heating_set_point_celsiusObject

Temperature to which the thermostat should heat (in °C). See also Set Points.



893
894
895
# File 'lib/seam/resources/device.rb', line 893

def heating_set_point_celsius
  @heating_set_point_celsius
end

#heating_set_point_fahrenheitObject

Temperature to which the thermostat should heat (in °F). See also Set Points.



895
896
897
# File 'lib/seam/resources/device.rb', line 895

def heating_set_point_fahrenheit
  @heating_set_point_fahrenheit
end

#hvac_mode_settingObject

Desired HVAC mode setting, such as heat, cool, heat_cool, or off.



897
898
899
# File 'lib/seam/resources/device.rb', line 897

def hvac_mode_setting
  @hvac_mode_setting
end

#manual_override_allowedObject

Deprecated.

Use 'thermostat_schedule.is_override_allowed'

Indicates whether a person at the thermostat can change the thermostat's settings. See Specifying Manual Override Permissions.



900
901
902
# File 'lib/seam/resources/device.rb', line 900

def manual_override_allowed
  @manual_override_allowed
end

#nameObject

User-friendly name to identify the climate preset.



902
903
904
# File 'lib/seam/resources/device.rb', line 902

def name
  @name
end