Class: Seam::Resources::Device::Properties::DefaultClimateSetting::EcobeeMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_refString?

Reference to the Ecobee climate, if applicable.

Returns:

  • (String, nil)


1236
1237
1238
# File 'lib/seam/resources/device.rb', line 1236

def climate_ref
  @climate_ref
end

#is_optimizedBoolean?

Indicates if the climate preset is optimized by Ecobee.

Returns:

  • (Boolean, nil)


1239
1240
1241
# File 'lib/seam/resources/device.rb', line 1239

def is_optimized
  @is_optimized
end

#ownerString?

Indicates whether the climate preset is owned by the user or the system.

Returns:

  • (String, nil)


1242
1243
1244
# File 'lib/seam/resources/device.rb', line 1242

def owner
  @owner
end