Class: Seam::Resources::Device::Properties::DefaultClimateSetting::EcobeeMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_refObject

Reference to the Ecobee climate, if applicable.



866
867
868
# File 'lib/seam/resources/device.rb', line 866

def climate_ref
  @climate_ref
end

#is_optimizedObject

Indicates if the climate preset is optimized by Ecobee.



868
869
870
# File 'lib/seam/resources/device.rb', line 868

def is_optimized
  @is_optimized
end

#ownerObject

Indicates whether the climate preset is owned by the user or the system.



870
871
872
# File 'lib/seam/resources/device.rb', line 870

def owner
  @owner
end