Class: Seam::Resources::Device::Properties::DormakabaOracodeMetadata::PredefinedTimeSlots

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#check_in_timeObject

Check in time for a time slot for a dormakaba Oracode device.



199
200
201
# File 'lib/seam/resources/device.rb', line 199

def check_in_time
  @check_in_time
end

#check_out_timeObject

Checkout time for a time slot for a dormakaba Oracode device.



201
202
203
# File 'lib/seam/resources/device.rb', line 201

def check_out_time
  @check_out_time
end

#dormakaba_oracode_user_level_idObject

ID of a user level for a dormakaba Oracode device.



203
204
205
# File 'lib/seam/resources/device.rb', line 203

def dormakaba_oracode_user_level_id
  @dormakaba_oracode_user_level_id
end

#dormakaba_oracode_user_level_prefixObject

Prefix for a user level for a dormakaba Oracode device.



205
206
207
# File 'lib/seam/resources/device.rb', line 205

def dormakaba_oracode_user_level_prefix
  @dormakaba_oracode_user_level_prefix
end

#is_24_hourObject

Indicates whether a time slot for a dormakaba Oracode device is a 24-hour time slot.



207
208
209
# File 'lib/seam/resources/device.rb', line 207

def is_24_hour
  @is_24_hour
end

#is_biweekly_modeObject

Indicates whether a time slot for a dormakaba Oracode device is in biweekly mode.



209
210
211
# File 'lib/seam/resources/device.rb', line 209

def is_biweekly_mode
  @is_biweekly_mode
end

#is_masterObject

Indicates whether a time slot for a dormakaba Oracode device is a master time slot.



211
212
213
# File 'lib/seam/resources/device.rb', line 211

def is_master
  @is_master
end

#is_one_shotObject

Indicates whether a time slot for a dormakaba Oracode device is a one-shot time slot.



213
214
215
# File 'lib/seam/resources/device.rb', line 213

def is_one_shot
  @is_one_shot
end

#nameObject

Name of a time slot for a dormakaba Oracode device.



215
216
217
# File 'lib/seam/resources/device.rb', line 215

def name
  @name
end

#prefixObject

Prefix for a time slot for a dormakaba Oracode device.



217
218
219
# File 'lib/seam/resources/device.rb', line 217

def prefix
  @prefix
end