Class: Seam::Resources::Device::Properties::IgloohomeMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::IgloohomeMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#bridge_id ⇒ Object
Bridge ID for an igloohome device.
-
#bridge_name ⇒ Object
Bridge name for an igloohome device.
-
#device_id ⇒ Object
Device ID for an igloohome device.
-
#device_name ⇒ Object
Device name for an igloohome device.
-
#is_accessory_keypad_linked_to_bridge ⇒ Object
Indicates whether a keypad is linked to a bridge for an igloohome device.
-
#keypad_id ⇒ Object
Keypad ID for an igloohome device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#bridge_id ⇒ Object
Bridge ID for an igloohome device.
278 279 280 |
# File 'lib/seam/resources/device.rb', line 278 def bridge_id @bridge_id end |
#bridge_name ⇒ Object
Bridge name for an igloohome device.
280 281 282 |
# File 'lib/seam/resources/device.rb', line 280 def bridge_name @bridge_name end |
#device_id ⇒ Object
Device ID for an igloohome device.
282 283 284 |
# File 'lib/seam/resources/device.rb', line 282 def device_id @device_id end |
#device_name ⇒ Object
Device name for an igloohome device.
284 285 286 |
# File 'lib/seam/resources/device.rb', line 284 def device_name @device_name end |
#is_accessory_keypad_linked_to_bridge ⇒ Object
Indicates whether a keypad is linked to a bridge for an igloohome device.
286 287 288 |
# File 'lib/seam/resources/device.rb', line 286 def is_accessory_keypad_linked_to_bridge @is_accessory_keypad_linked_to_bridge end |
#keypad_id ⇒ Object
Keypad ID for an igloohome device.
288 289 290 |
# File 'lib/seam/resources/device.rb', line 288 def keypad_id @keypad_id end |