Class: Seam::Resources::Device::Properties::KeynestMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::KeynestMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Address for a KeyNest device.
-
#current_or_last_store_id ⇒ Float?
Current or last store ID for a KeyNest device.
-
#current_status ⇒ String?
Current status for a KeyNest device.
-
#current_user_company ⇒ String?
Current user company for a KeyNest device.
-
#current_user_email ⇒ String?
Current user email for a KeyNest device.
-
#current_user_name ⇒ String?
Current user name for a KeyNest device.
-
#current_user_phone_number ⇒ String?
Current user phone number for a KeyNest device.
-
#default_office_id ⇒ Float?
Default office ID for a KeyNest device.
-
#device_name ⇒ String?
Device name for a KeyNest device.
-
#fob_id ⇒ Float?
Fob ID for a KeyNest device.
-
#handover_method ⇒ String?
Handover method for a KeyNest device.
-
#has_photo ⇒ Boolean?
Whether the KeyNest device has a photo.
-
#is_quadient_locker ⇒ Boolean?
Whether the key is in a locker that does not support the access codes API.
-
#key_id ⇒ String?
Key ID for a KeyNest device.
-
#key_notes ⇒ String?
Key notes for a KeyNest device.
-
#keynest_app_user ⇒ String?
KeyNest app user for a KeyNest device.
-
#last_movement ⇒ String?
Last movement timestamp for a KeyNest device.
-
#property_id ⇒ String?
Property ID for a KeyNest device.
-
#property_postcode ⇒ String?
Property postcode for a KeyNest device.
-
#status_type ⇒ String?
Status type for a KeyNest device.
-
#subscription_plan ⇒ String?
Subscription plan for a KeyNest device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#address ⇒ String?
Address for a KeyNest device.
400 401 402 |
# File 'lib/seam/resources/device.rb', line 400 def address @address end |
#current_or_last_store_id ⇒ Float?
Current or last store ID for a KeyNest device.
403 404 405 |
# File 'lib/seam/resources/device.rb', line 403 def current_or_last_store_id @current_or_last_store_id end |
#current_status ⇒ String?
Current status for a KeyNest device.
406 407 408 |
# File 'lib/seam/resources/device.rb', line 406 def current_status @current_status end |
#current_user_company ⇒ String?
Current user company for a KeyNest device.
409 410 411 |
# File 'lib/seam/resources/device.rb', line 409 def current_user_company @current_user_company end |
#current_user_email ⇒ String?
Current user email for a KeyNest device.
412 413 414 |
# File 'lib/seam/resources/device.rb', line 412 def current_user_email @current_user_email end |
#current_user_name ⇒ String?
Current user name for a KeyNest device.
415 416 417 |
# File 'lib/seam/resources/device.rb', line 415 def current_user_name @current_user_name end |
#current_user_phone_number ⇒ String?
Current user phone number for a KeyNest device.
418 419 420 |
# File 'lib/seam/resources/device.rb', line 418 def current_user_phone_number @current_user_phone_number end |
#default_office_id ⇒ Float?
Default office ID for a KeyNest device.
421 422 423 |
# File 'lib/seam/resources/device.rb', line 421 def default_office_id @default_office_id end |
#device_name ⇒ String?
Device name for a KeyNest device.
424 425 426 |
# File 'lib/seam/resources/device.rb', line 424 def device_name @device_name end |
#fob_id ⇒ Float?
Fob ID for a KeyNest device.
427 428 429 |
# File 'lib/seam/resources/device.rb', line 427 def fob_id @fob_id end |
#handover_method ⇒ String?
Handover method for a KeyNest device.
430 431 432 |
# File 'lib/seam/resources/device.rb', line 430 def handover_method @handover_method end |
#has_photo ⇒ Boolean?
Whether the KeyNest device has a photo.
433 434 435 |
# File 'lib/seam/resources/device.rb', line 433 def has_photo @has_photo end |
#is_quadient_locker ⇒ Boolean?
Whether the key is in a locker that does not support the access codes API.
436 437 438 |
# File 'lib/seam/resources/device.rb', line 436 def is_quadient_locker @is_quadient_locker end |
#key_id ⇒ String?
Key ID for a KeyNest device.
439 440 441 |
# File 'lib/seam/resources/device.rb', line 439 def key_id @key_id end |
#key_notes ⇒ String?
Key notes for a KeyNest device.
442 443 444 |
# File 'lib/seam/resources/device.rb', line 442 def key_notes @key_notes end |
#keynest_app_user ⇒ String?
KeyNest app user for a KeyNest device.
445 446 447 |
# File 'lib/seam/resources/device.rb', line 445 def keynest_app_user @keynest_app_user end |
#last_movement ⇒ String?
Last movement timestamp for a KeyNest device.
448 449 450 |
# File 'lib/seam/resources/device.rb', line 448 def last_movement @last_movement end |
#property_id ⇒ String?
Property ID for a KeyNest device.
451 452 453 |
# File 'lib/seam/resources/device.rb', line 451 def property_id @property_id end |
#property_postcode ⇒ String?
Property postcode for a KeyNest device.
454 455 456 |
# File 'lib/seam/resources/device.rb', line 454 def property_postcode @property_postcode end |
#status_type ⇒ String?
Status type for a KeyNest device.
457 458 459 |
# File 'lib/seam/resources/device.rb', line 457 def status_type @status_type end |
#subscription_plan ⇒ String?
Subscription plan for a KeyNest device.
460 461 462 |
# File 'lib/seam/resources/device.rb', line 460 def subscription_plan @subscription_plan end |