Class: Seam::Resources::Device::Properties::KeynestMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::KeynestMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Address for a KeyNest device.
-
#current_or_last_store_id ⇒ Object
Current or last store ID for a KeyNest device.
-
#current_status ⇒ Object
Current status for a KeyNest device.
-
#current_user_company ⇒ Object
Current user company for a KeyNest device.
-
#current_user_email ⇒ Object
Current user email for a KeyNest device.
-
#current_user_name ⇒ Object
Current user name for a KeyNest device.
-
#current_user_phone_number ⇒ Object
Current user phone number for a KeyNest device.
-
#default_office_id ⇒ Object
Default office ID for a KeyNest device.
-
#device_name ⇒ Object
Device name for a KeyNest device.
-
#fob_id ⇒ Object
Fob ID for a KeyNest device.
-
#handover_method ⇒ Object
Handover method for a KeyNest device.
-
#has_photo ⇒ Object
Whether the KeyNest device has a photo.
-
#is_quadient_locker ⇒ Object
Whether the key is in a locker that does not support the access codes API.
-
#key_id ⇒ Object
Key ID for a KeyNest device.
-
#key_notes ⇒ Object
Key notes for a KeyNest device.
-
#keynest_app_user ⇒ Object
KeyNest app user for a KeyNest device.
-
#last_movement ⇒ Object
Last movement timestamp for a KeyNest device.
-
#property_id ⇒ Object
Property ID for a KeyNest device.
-
#property_postcode ⇒ Object
Property postcode for a KeyNest device.
-
#status_type ⇒ Object
Status type for a KeyNest device.
-
#subscription_plan ⇒ Object
Subscription plan for a KeyNest device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#address ⇒ Object
Address for a KeyNest device.
293 294 295 |
# File 'lib/seam/resources/device.rb', line 293 def address @address end |
#current_or_last_store_id ⇒ Object
Current or last store ID for a KeyNest device.
295 296 297 |
# File 'lib/seam/resources/device.rb', line 295 def current_or_last_store_id @current_or_last_store_id end |
#current_status ⇒ Object
Current status for a KeyNest device.
297 298 299 |
# File 'lib/seam/resources/device.rb', line 297 def current_status @current_status end |
#current_user_company ⇒ Object
Current user company for a KeyNest device.
299 300 301 |
# File 'lib/seam/resources/device.rb', line 299 def current_user_company @current_user_company end |
#current_user_email ⇒ Object
Current user email for a KeyNest device.
301 302 303 |
# File 'lib/seam/resources/device.rb', line 301 def current_user_email @current_user_email end |
#current_user_name ⇒ Object
Current user name for a KeyNest device.
303 304 305 |
# File 'lib/seam/resources/device.rb', line 303 def current_user_name @current_user_name end |
#current_user_phone_number ⇒ Object
Current user phone number for a KeyNest device.
305 306 307 |
# File 'lib/seam/resources/device.rb', line 305 def current_user_phone_number @current_user_phone_number end |
#default_office_id ⇒ Object
Default office ID for a KeyNest device.
307 308 309 |
# File 'lib/seam/resources/device.rb', line 307 def default_office_id @default_office_id end |
#device_name ⇒ Object
Device name for a KeyNest device.
309 310 311 |
# File 'lib/seam/resources/device.rb', line 309 def device_name @device_name end |
#fob_id ⇒ Object
Fob ID for a KeyNest device.
311 312 313 |
# File 'lib/seam/resources/device.rb', line 311 def fob_id @fob_id end |
#handover_method ⇒ Object
Handover method for a KeyNest device.
313 314 315 |
# File 'lib/seam/resources/device.rb', line 313 def handover_method @handover_method end |
#has_photo ⇒ Object
Whether the KeyNest device has a photo.
315 316 317 |
# File 'lib/seam/resources/device.rb', line 315 def has_photo @has_photo end |
#is_quadient_locker ⇒ Object
Whether the key is in a locker that does not support the access codes API.
317 318 319 |
# File 'lib/seam/resources/device.rb', line 317 def is_quadient_locker @is_quadient_locker end |
#key_id ⇒ Object
Key ID for a KeyNest device.
319 320 321 |
# File 'lib/seam/resources/device.rb', line 319 def key_id @key_id end |
#key_notes ⇒ Object
Key notes for a KeyNest device.
321 322 323 |
# File 'lib/seam/resources/device.rb', line 321 def key_notes @key_notes end |
#keynest_app_user ⇒ Object
KeyNest app user for a KeyNest device.
323 324 325 |
# File 'lib/seam/resources/device.rb', line 323 def keynest_app_user @keynest_app_user end |
#last_movement ⇒ Object
Last movement timestamp for a KeyNest device.
325 326 327 |
# File 'lib/seam/resources/device.rb', line 325 def last_movement @last_movement end |
#property_id ⇒ Object
Property ID for a KeyNest device.
327 328 329 |
# File 'lib/seam/resources/device.rb', line 327 def property_id @property_id end |
#property_postcode ⇒ Object
Property postcode for a KeyNest device.
329 330 331 |
# File 'lib/seam/resources/device.rb', line 329 def property_postcode @property_postcode end |
#status_type ⇒ Object
Status type for a KeyNest device.
331 332 333 |
# File 'lib/seam/resources/device.rb', line 331 def status_type @status_type end |
#subscription_plan ⇒ Object
Subscription plan for a KeyNest device.
333 334 335 |
# File 'lib/seam/resources/device.rb', line 333 def subscription_plan @subscription_plan end |