Class: Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Humidity

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#timeObject

Time of latest humidity reading for a Minut device.



393
394
395
# File 'lib/seam/resources/device.rb', line 393

def time
  @time
end

#valueObject

Value of latest humidity reading for a Minut device.



395
396
397
# File 'lib/seam/resources/device.rb', line 395

def value
  @value
end