Class: Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Sound
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Sound
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#time ⇒ Object
Time of latest sound reading for a Minut device.
-
#value ⇒ Object
Value of latest sound reading for a Minut device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#time ⇒ Object
Time of latest sound reading for a Minut device.
407 408 409 |
# File 'lib/seam/resources/device.rb', line 407 def time @time end |
#value ⇒ Object
Value of latest sound reading for a Minut device.
409 410 411 |
# File 'lib/seam/resources/device.rb', line 409 def value @value end |