Class: Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Temperature
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::MinutMetadata::LatestSensorValues::Temperature
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#time ⇒ Object
Time of latest temperature reading for a Minut device.
-
#value ⇒ Object
Value of latest temperature reading for a Minut device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#time ⇒ Object
Time of latest temperature reading for a Minut device.
414 415 416 |
# File 'lib/seam/resources/device.rb', line 414 def time @time end |
#value ⇒ Object
Value of latest temperature reading for a Minut device.
416 417 418 |
# File 'lib/seam/resources/device.rb', line 416 def value @value end |