Class: Seam::Resources::Device::Properties::Model

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accessory_keypad_supportedObject

Deprecated.

use device.properties.model.can_connect_accessory_keypad



75
76
77
# File 'lib/seam/resources/device.rb', line 75

def accessory_keypad_supported
  @accessory_keypad_supported
end

#can_connect_accessory_keypadObject

Indicates whether the device can connect a accessory keypad.



77
78
79
# File 'lib/seam/resources/device.rb', line 77

def can_connect_accessory_keypad
  @can_connect_accessory_keypad
end

#display_nameObject

Display name of the device model.



79
80
81
# File 'lib/seam/resources/device.rb', line 79

def display_name
  @display_name
end

#has_built_in_keypadObject

Indicates whether the device has a built in accessory keypad.



81
82
83
# File 'lib/seam/resources/device.rb', line 81

def has_built_in_keypad
  @has_built_in_keypad
end

#manufacturer_display_nameObject

Display name that corresponds to the manufacturer-specific terminology for the device.



83
84
85
# File 'lib/seam/resources/device.rb', line 83

def manufacturer_display_name
  @manufacturer_display_name
end

#offline_access_codes_supportedObject

Deprecated.

use device.can_program_offline_access_codes.



85
86
87
# File 'lib/seam/resources/device.rb', line 85

def offline_access_codes_supported
  @offline_access_codes_supported
end

#online_access_codes_supportedObject

Deprecated.

use device.can_program_online_access_codes.



87
88
89
# File 'lib/seam/resources/device.rb', line 87

def online_access_codes_supported
  @online_access_codes_supported
end