Class: Seam::Resources::Device::Properties::NukiMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idString?

Device ID for a Nuki device.

Returns:

  • (String, nil)


643
644
645
# File 'lib/seam/resources/device.rb', line 643

def device_id
  @device_id
end

#device_nameString?

Device name for a Nuki device.

Returns:

  • (String, nil)


646
647
648
# File 'lib/seam/resources/device.rb', line 646

def device_name
  @device_name
end

#keypad_2_pairedBoolean?

Indicates whether keypad 2 is paired for a Nuki device.

Returns:

  • (Boolean, nil)


649
650
651
# File 'lib/seam/resources/device.rb', line 649

def keypad_2_paired
  @keypad_2_paired
end

#keypad_battery_criticalBoolean?

Indicates whether the keypad battery is in a critical state for a Nuki device.

Returns:

  • (Boolean, nil)


652
653
654
# File 'lib/seam/resources/device.rb', line 652

def keypad_battery_critical
  @keypad_battery_critical
end

#keypad_pairedBoolean?

Indicates whether the keypad is paired for a Nuki device.

Returns:

  • (Boolean, nil)


655
656
657
# File 'lib/seam/resources/device.rb', line 655

def keypad_paired
  @keypad_paired
end