Class: Seam::Resources::Device::Properties::NukiMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idObject

Device ID for a Nuki device.



459
460
461
# File 'lib/seam/resources/device.rb', line 459

def device_id
  @device_id
end

#device_nameObject

Device name for a Nuki device.



461
462
463
# File 'lib/seam/resources/device.rb', line 461

def device_name
  @device_name
end

#keypad_2_pairedObject

Indicates whether keypad 2 is paired for a Nuki device.



463
464
465
# File 'lib/seam/resources/device.rb', line 463

def keypad_2_paired
  @keypad_2_paired
end

#keypad_battery_criticalObject

Indicates whether the keypad battery is in a critical state for a Nuki device.



465
466
467
# File 'lib/seam/resources/device.rb', line 465

def keypad_battery_critical
  @keypad_battery_critical
end

#keypad_pairedObject

Indicates whether the keypad is paired for a Nuki device.



467
468
469
# File 'lib/seam/resources/device.rb', line 467

def keypad_paired
  @keypad_paired
end