Class: Seam::Resources::Device::Properties::OmnitecMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::OmnitecMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#has_gateway ⇒ Boolean?
Whether the Omnitec lock has a connected gateway for remote operations.
-
#lock_alias ⇒ String?
Operator-assigned alias for an Omnitec device.
-
#lock_id ⇒ Float?
Lock ID for an Omnitec device.
-
#lock_mac ⇒ String?
Bluetooth MAC address for an Omnitec device.
-
#lock_name ⇒ String?
Lock name for an Omnitec device.
-
#time_zone ⇒ String?
IANA time zone for the Omnitec device, used to schedule time-bound access codes at the correct local time (accounting for DST).
-
#timezone_raw_offset_ms ⇒ Float?
Static UTC offset of the Omnitec lock in milliseconds.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#has_gateway ⇒ Boolean?
Whether the Omnitec lock has a connected gateway for remote operations.
962 963 964 |
# File 'lib/seam/resources/device.rb', line 962 def has_gateway @has_gateway end |
#lock_alias ⇒ String?
Operator-assigned alias for an Omnitec device.
965 966 967 |
# File 'lib/seam/resources/device.rb', line 965 def lock_alias @lock_alias end |
#lock_id ⇒ Float?
Lock ID for an Omnitec device.
968 969 970 |
# File 'lib/seam/resources/device.rb', line 968 def lock_id @lock_id end |
#lock_mac ⇒ String?
Bluetooth MAC address for an Omnitec device.
971 972 973 |
# File 'lib/seam/resources/device.rb', line 971 def lock_mac @lock_mac end |
#lock_name ⇒ String?
Lock name for an Omnitec device.
974 975 976 |
# File 'lib/seam/resources/device.rb', line 974 def lock_name @lock_name end |
#time_zone ⇒ String?
IANA time zone for the Omnitec device, used to schedule time-bound access codes at the correct local time (accounting for DST).
977 978 979 |
# File 'lib/seam/resources/device.rb', line 977 def time_zone @time_zone end |
#timezone_raw_offset_ms ⇒ Float?
Static UTC offset of the Omnitec lock in milliseconds. Does not account for DST.
980 981 982 |
# File 'lib/seam/resources/device.rb', line 980 def timezone_raw_offset_ms @timezone_raw_offset_ms end |