Class: Seam::Resources::Device::Properties::OmnitecMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#has_gatewayBoolean?

Whether the Omnitec lock has a connected gateway for remote operations.

Returns:

  • (Boolean, nil)


661
662
663
# File 'lib/seam/resources/device.rb', line 661

def has_gateway
  @has_gateway
end

#lock_aliasString?

Operator-assigned alias for an Omnitec device.

Returns:

  • (String, nil)


664
665
666
# File 'lib/seam/resources/device.rb', line 664

def lock_alias
  @lock_alias
end

#lock_idFloat?

Lock ID for an Omnitec device.

Returns:

  • (Float, nil)


667
668
669
# File 'lib/seam/resources/device.rb', line 667

def lock_id
  @lock_id
end

#lock_macString?

Bluetooth MAC address for an Omnitec device.

Returns:

  • (String, nil)


670
671
672
# File 'lib/seam/resources/device.rb', line 670

def lock_mac
  @lock_mac
end

#lock_nameString?

Lock name for an Omnitec device.

Returns:

  • (String, nil)


673
674
675
# File 'lib/seam/resources/device.rb', line 673

def lock_name
  @lock_name
end

#time_zoneString?

IANA time zone for the Omnitec device, used to schedule time-bound access codes at the correct local time (accounting for DST).

Returns:

  • (String, nil)


676
677
678
# File 'lib/seam/resources/device.rb', line 676

def time_zone
  @time_zone
end

#timezone_raw_offset_msFloat?

Static UTC offset of the Omnitec lock in milliseconds. Does not account for DST.

Returns:

  • (Float, nil)


679
680
681
# File 'lib/seam/resources/device.rb', line 679

def timezone_raw_offset_ms
  @timezone_raw_offset_ms
end