Class: Seam::Resources::Device::Properties::OmnitecMetadata

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#has_gatewayObject

Whether the Omnitec lock has a connected gateway for remote operations.



472
473
474
# File 'lib/seam/resources/device.rb', line 472

def has_gateway
  @has_gateway
end

#lock_aliasObject

Operator-assigned alias for an Omnitec device.



474
475
476
# File 'lib/seam/resources/device.rb', line 474

def lock_alias
  @lock_alias
end

#lock_idObject

Lock ID for an Omnitec device.



476
477
478
# File 'lib/seam/resources/device.rb', line 476

def lock_id
  @lock_id
end

#lock_macObject

Bluetooth MAC address for an Omnitec device.



478
479
480
# File 'lib/seam/resources/device.rb', line 478

def lock_mac
  @lock_mac
end

#lock_nameObject

Lock name for an Omnitec device.



480
481
482
# File 'lib/seam/resources/device.rb', line 480

def lock_name
  @lock_name
end

#time_zoneObject

IANA time zone for the Omnitec device, used to schedule time-bound access codes at the correct local time (accounting for DST).



482
483
484
# File 'lib/seam/resources/device.rb', line 482

def time_zone
  @time_zone
end

#timezone_raw_offset_msObject

Static UTC offset of the Omnitec lock in milliseconds. Does not account for DST.



484
485
486
# File 'lib/seam/resources/device.rb', line 484

def timezone_raw_offset_ms
  @timezone_raw_offset_ms
end