Class: Seam::Resources::Device::Properties::SensiMetadata
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::SensiMetadata
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#device_id ⇒ String?
Device ID for a Sensi device.
-
#device_name ⇒ String?
Device name for a Sensi device.
-
#dual_setpoints_not_supported ⇒ Boolean?
Set to true when the device does not support the /dual-setpoints API endpoint.
-
#enforced_setpoint_range_celsius ⇒ Array<Float>
Enforced setpoint range in Celsius for a Sensi device, derived from an OutOfRange API error.
-
#product_type ⇒ String?
Product type for a Sensi device.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ String?
Device ID for a Sensi device.
775 776 777 |
# File 'lib/seam/resources/device.rb', line 775 def device_id @device_id end |
#device_name ⇒ String?
Device name for a Sensi device.
778 779 780 |
# File 'lib/seam/resources/device.rb', line 778 def device_name @device_name end |
#dual_setpoints_not_supported ⇒ Boolean?
Set to true when the device does not support the /dual-setpoints API endpoint.
781 782 783 |
# File 'lib/seam/resources/device.rb', line 781 def dual_setpoints_not_supported @dual_setpoints_not_supported end |
#enforced_setpoint_range_celsius ⇒ Array<Float>
Enforced setpoint range in Celsius for a Sensi device, derived from an OutOfRange API error.
784 785 786 |
# File 'lib/seam/resources/device.rb', line 784 def enforced_setpoint_range_celsius @enforced_setpoint_range_celsius end |
#product_type ⇒ String?
Product type for a Sensi device.
787 788 789 |
# File 'lib/seam/resources/device.rb', line 787 def product_type @product_type end |