Class: Seam::Resources::Device::Properties::TemperatureThreshold
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::TemperatureThreshold
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#lower_limit_celsius ⇒ Float?
Lower limit in °C within the current temperature threshold set for the thermostat.
-
#lower_limit_fahrenheit ⇒ Float?
Lower limit in °F within the current temperature threshold set for the thermostat.
-
#upper_limit_celsius ⇒ Float?
Upper limit in °C within the current temperature threshold set for the thermostat.
-
#upper_limit_fahrenheit ⇒ Float?
Upper limit in °F within the current temperature threshold set for the thermostat.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#lower_limit_celsius ⇒ Float?
Lower limit in °C within the current temperature threshold set for the thermostat.
1296 1297 1298 |
# File 'lib/seam/resources/device.rb', line 1296 def lower_limit_celsius @lower_limit_celsius end |
#lower_limit_fahrenheit ⇒ Float?
Lower limit in °F within the current temperature threshold set for the thermostat.
1299 1300 1301 |
# File 'lib/seam/resources/device.rb', line 1299 def lower_limit_fahrenheit @lower_limit_fahrenheit end |
#upper_limit_celsius ⇒ Float?
Upper limit in °C within the current temperature threshold set for the thermostat.
1302 1303 1304 |
# File 'lib/seam/resources/device.rb', line 1302 def upper_limit_celsius @upper_limit_celsius end |
#upper_limit_fahrenheit ⇒ Float?
Upper limit in °F within the current temperature threshold set for the thermostat.
1305 1306 1307 |
# File 'lib/seam/resources/device.rb', line 1305 def upper_limit_fahrenheit @upper_limit_fahrenheit end |