Class: Seam::Resources::Device::Properties::TemperatureThreshold

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#lower_limit_celsiusObject

Lower limit in °C within the current temperature threshold set for the thermostat.



907
908
909
# File 'lib/seam/resources/device.rb', line 907

def lower_limit_celsius
  @lower_limit_celsius
end

#lower_limit_fahrenheitObject

Lower limit in °F within the current temperature threshold set for the thermostat.



909
910
911
# File 'lib/seam/resources/device.rb', line 909

def lower_limit_fahrenheit
  @lower_limit_fahrenheit
end

#upper_limit_celsiusObject

Upper limit in °C within the current temperature threshold set for the thermostat.



911
912
913
# File 'lib/seam/resources/device.rb', line 911

def upper_limit_celsius
  @upper_limit_celsius
end

#upper_limit_fahrenheitObject

Upper limit in °F within the current temperature threshold set for the thermostat.



913
914
915
# File 'lib/seam/resources/device.rb', line 913

def upper_limit_fahrenheit
  @upper_limit_fahrenheit
end