Class: Seam::Resources::Device::Properties::ThermostatDailyPrograms

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: Periods

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idString

ID of the thermostat device on which the thermostat daily program is configured.

Returns:

  • (String)


1323
1324
1325
# File 'lib/seam/resources/device.rb', line 1323

def device_id
  @device_id
end

#nameString?

User-friendly name to identify the thermostat daily program.

Returns:

  • (String, nil)


1326
1327
1328
# File 'lib/seam/resources/device.rb', line 1326

def name
  @name
end

#thermostat_daily_program_idString

ID of the thermostat daily program.

Returns:

  • (String)


1329
1330
1331
# File 'lib/seam/resources/device.rb', line 1329

def thermostat_daily_program_id
  @thermostat_daily_program_id
end

#workspace_idString

ID of the workspace that contains the thermostat daily program.

Returns:

  • (String)


1332
1333
1334
# File 'lib/seam/resources/device.rb', line 1332

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the thermostat daily program was created.

Returns:

  • (Time)


1335
# File 'lib/seam/resources/device.rb', line 1335

date_accessor :created_at

#periodsArray<Periods>

Array of thermostat daily program periods.

Returns:



1320
# File 'lib/seam/resources/device.rb', line 1320

resource_list_accessor :periods, Periods