Class: Seam::Resources::Device::Properties::ThermostatDailyPrograms
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::ThermostatDailyPrograms
- Defined in:
- lib/seam/resources/device.rb
Defined Under Namespace
Classes: Periods
Instance Attribute Summary collapse
-
#device_id ⇒ String
ID of the thermostat device on which the thermostat daily program is configured.
-
#name ⇒ String?
User-friendly name to identify the thermostat daily program.
-
#thermostat_daily_program_id ⇒ String
ID of the thermostat daily program.
-
#workspace_id ⇒ String
ID of the workspace that contains the thermostat daily program.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the thermostat daily program was created.
-
#periods ⇒ Array<Periods>
Array of thermostat daily program periods.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ String
ID of the thermostat device on which the thermostat daily program is configured.
1323 1324 1325 |
# File 'lib/seam/resources/device.rb', line 1323 def device_id @device_id end |
#name ⇒ String?
User-friendly name to identify the thermostat daily program.
1326 1327 1328 |
# File 'lib/seam/resources/device.rb', line 1326 def name @name end |
#thermostat_daily_program_id ⇒ String
ID of the thermostat daily program.
1329 1330 1331 |
# File 'lib/seam/resources/device.rb', line 1329 def thermostat_daily_program_id @thermostat_daily_program_id end |
#workspace_id ⇒ String
ID of the workspace that contains the thermostat daily program.
1332 1333 1334 |
# File 'lib/seam/resources/device.rb', line 1332 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the thermostat daily program was created.
1335 |
# File 'lib/seam/resources/device.rb', line 1335 date_accessor :created_at |