Class: Seam::Resources::Device::Properties::ThermostatDailyPrograms

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Defined Under Namespace

Classes: Periods

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idObject

ID of the thermostat device on which the thermostat daily program is configured.



926
927
928
# File 'lib/seam/resources/device.rb', line 926

def device_id
  @device_id
end

#nameObject

User-friendly name to identify the thermostat daily program.



928
929
930
# File 'lib/seam/resources/device.rb', line 928

def name
  @name
end

#thermostat_daily_program_idObject

ID of the thermostat daily program.



930
931
932
# File 'lib/seam/resources/device.rb', line 930

def thermostat_daily_program_id
  @thermostat_daily_program_id
end

#workspace_idObject

ID of the workspace that contains the thermostat daily program.



932
933
934
# File 'lib/seam/resources/device.rb', line 932

def workspace_id
  @workspace_id
end