Class: Seam::Resources::Device::Properties::ThermostatWeeklyProgram
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Properties::ThermostatWeeklyProgram
- Defined in:
- lib/seam/resources/device.rb
Instance Attribute Summary collapse
-
#friday_program_id ⇒ String?
ID of the thermostat daily program to run on Fridays.
-
#monday_program_id ⇒ String?
ID of the thermostat daily program to run on Mondays.
-
#saturday_program_id ⇒ String?
ID of the thermostat daily program to run on Saturdays.
-
#sunday_program_id ⇒ String?
ID of the thermostat daily program to run on Sundays.
-
#thursday_program_id ⇒ String?
ID of the thermostat daily program to run on Thursdays.
-
#tuesday_program_id ⇒ String?
ID of the thermostat daily program to run on Tuesdays.
-
#wednesday_program_id ⇒ String?
ID of the thermostat daily program to run on Wednesdays.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the thermostat weekly program was created.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#friday_program_id ⇒ String?
ID of the thermostat daily program to run on Fridays.
1341 1342 1343 |
# File 'lib/seam/resources/device.rb', line 1341 def friday_program_id @friday_program_id end |
#monday_program_id ⇒ String?
ID of the thermostat daily program to run on Mondays.
1344 1345 1346 |
# File 'lib/seam/resources/device.rb', line 1344 def monday_program_id @monday_program_id end |
#saturday_program_id ⇒ String?
ID of the thermostat daily program to run on Saturdays.
1347 1348 1349 |
# File 'lib/seam/resources/device.rb', line 1347 def saturday_program_id @saturday_program_id end |
#sunday_program_id ⇒ String?
ID of the thermostat daily program to run on Sundays.
1350 1351 1352 |
# File 'lib/seam/resources/device.rb', line 1350 def sunday_program_id @sunday_program_id end |
#thursday_program_id ⇒ String?
ID of the thermostat daily program to run on Thursdays.
1353 1354 1355 |
# File 'lib/seam/resources/device.rb', line 1353 def thursday_program_id @thursday_program_id end |
#tuesday_program_id ⇒ String?
ID of the thermostat daily program to run on Tuesdays.
1356 1357 1358 |
# File 'lib/seam/resources/device.rb', line 1356 def tuesday_program_id @tuesday_program_id end |
#wednesday_program_id ⇒ String?
ID of the thermostat daily program to run on Wednesdays.
1359 1360 1361 |
# File 'lib/seam/resources/device.rb', line 1359 def wednesday_program_id @wednesday_program_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the thermostat weekly program was created.
1362 |
# File 'lib/seam/resources/device.rb', line 1362 date_accessor :created_at |