Class: Seam::Resources::Device::Properties::ThermostatWeeklyProgram

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#friday_program_idObject

ID of the thermostat daily program to run on Fridays.



939
940
941
# File 'lib/seam/resources/device.rb', line 939

def friday_program_id
  @friday_program_id
end

#monday_program_idObject

ID of the thermostat daily program to run on Mondays.



941
942
943
# File 'lib/seam/resources/device.rb', line 941

def monday_program_id
  @monday_program_id
end

#saturday_program_idObject

ID of the thermostat daily program to run on Saturdays.



943
944
945
# File 'lib/seam/resources/device.rb', line 943

def saturday_program_id
  @saturday_program_id
end

#sunday_program_idObject

ID of the thermostat daily program to run on Sundays.



945
946
947
# File 'lib/seam/resources/device.rb', line 945

def sunday_program_id
  @sunday_program_id
end

#thursday_program_idObject

ID of the thermostat daily program to run on Thursdays.



947
948
949
# File 'lib/seam/resources/device.rb', line 947

def thursday_program_id
  @thursday_program_id
end

#tuesday_program_idObject

ID of the thermostat daily program to run on Tuesdays.



949
950
951
# File 'lib/seam/resources/device.rb', line 949

def tuesday_program_id
  @tuesday_program_id
end

#wednesday_program_idObject

ID of the thermostat daily program to run on Wednesdays.



951
952
953
# File 'lib/seam/resources/device.rb', line 951

def wednesday_program_id
  @wednesday_program_id
end