Class: Seam::Resources::Device::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Device::Warnings
- Defined in:
- lib/seam/resources/device.rb
Overview
Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.
Defined Under Namespace
Classes: AccessoryKeypadSetupRequired, DeviceCommunicationDegraded, DeviceHasFlakyConnection, HubRequiredForAdditionalCapabilities, KeynestUnsupportedLocker, LocklyTimeZoneNotConfigured, ManyActiveBackupCodes, MaxAccessCodesReached, PartialBackupAccessCodePool, PowerSavingMode, PrivacyMode, ProviderIssue, SaltoKsLockAccessCodeSupportRemoved, SaltoKsOfficeMode, SaltoKsPrivacyMode, SaltoKsSubscriptionLimitAlmostReached, ScheduledMaintenanceWindow, TemperatureThresholdExceeded, ThirdPartyIntegrationDetected, TimeZoneMismatch, TimeZoneUnknown, TtlockLockGatewayUnlockingNotEnabled, TtlockWeakGatewaySignal, TwoNDeviceMissingTimezone, UltraloqTimeZoneUnknown, UnknownIssueWithPhone, UnreliableOnlineStatus
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2499 2500 2501 |
# File 'lib/seam/resources/device.rb', line 2499 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
partial_backup_access_code_poolmany_active_backup_codesthird_party_integration_detectedttlock_lock_gateway_unlocking_not_enabledttlock_weak_gateway_signalpower_saving_modetemperature_threshold_exceededdevice_communication_degradedscheduled_maintenance_windowdevice_has_flaky_connectionsalto_ks_office_modesalto_ks_privacy_modeprivacy_modesalto_ks_subscription_limit_almost_reachedsalto_ks_lock_access_code_support_removedunknown_issue_with_phonelockly_time_zone_not_configuredultraloq_time_zone_unknowntime_zone_unknowntime_zone_mismatchtwo_n_device_missing_timezonehub_required_for_additional_capabilitiesprovider_issuekeynest_unsupported_lockeraccessory_keypad_setup_requiredunreliable_online_statusmax_access_codes_reached
2530 2531 2532 |
# File 'lib/seam/resources/device.rb', line 2530 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2533 |
# File 'lib/seam/resources/device.rb', line 2533 date_accessor :created_at |