Class: Seam::Resources::Device::Warnings

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#active_access_code_countInteger

Number of active access codes on the device when the warning was set.

Returns:

  • (Integer)


1687
1688
1689
# File 'lib/seam/resources/device.rb', line 1687

def active_access_code_count
  @active_access_code_count
end

#max_active_access_code_countInteger

Maximum number of active access codes supported by the device.

Returns:

  • (Integer)


1690
1691
1692
# File 'lib/seam/resources/device.rb', line 1690

def max_active_access_code_count
  @max_active_access_code_count
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


1693
1694
1695
# File 'lib/seam/resources/device.rb', line 1693

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


1696
1697
1698
# File 'lib/seam/resources/device.rb', line 1696

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


1699
# File 'lib/seam/resources/device.rb', line 1699

date_accessor :created_at