Class: Seam::Resources::Device::Warnings

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#active_access_code_countObject

Number of active access codes on the device when the warning was set.



1116
1117
1118
# File 'lib/seam/resources/device.rb', line 1116

def active_access_code_count
  @active_access_code_count
end

#max_active_access_code_countObject

Maximum number of active access codes supported by the device.



1118
1119
1120
# File 'lib/seam/resources/device.rb', line 1118

def max_active_access_code_count
  @max_active_access_code_count
end

#messageObject

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.



1120
1121
1122
# File 'lib/seam/resources/device.rb', line 1120

def message
  @message
end

#warning_codeObject

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.



1122
1123
1124
# File 'lib/seam/resources/device.rb', line 1122

def warning_code
  @warning_code
end