Class: Seam::Resources::Device::Warnings::DeviceCommunicationDegraded
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::DeviceCommunicationDegraded
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the device appears to be unresponsive.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2195 2196 2197 |
# File 'lib/seam/resources/device.rb', line 2195 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
device_communication_degraded
2200 2201 2202 |
# File 'lib/seam/resources/device.rb', line 2200 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2203 |
# File 'lib/seam/resources/device.rb', line 2203 date_accessor :created_at |