Class: Seam::Resources::Device::Warnings::LocklyTimeZoneNotConfigured
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::LocklyTimeZoneNotConfigured
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that Seam detected that the Lockly device does not have a time zone configured. Time-bound codes may not work as expected.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2327 2328 2329 |
# File 'lib/seam/resources/device.rb', line 2327 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
lockly_time_zone_not_configured
2332 2333 2334 |
# File 'lib/seam/resources/device.rb', line 2332 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2335 |
# File 'lib/seam/resources/device.rb', line 2335 date_accessor :created_at |