Class: Seam::Resources::Device::Warnings::PartialBackupAccessCodePool
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::PartialBackupAccessCodePool
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the backup access code is unhealthy.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2087 2088 2089 |
# File 'lib/seam/resources/device.rb', line 2087 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
partial_backup_access_code_pool
2092 2093 2094 |
# File 'lib/seam/resources/device.rb', line 2092 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2095 |
# File 'lib/seam/resources/device.rb', line 2095 date_accessor :created_at |