Class: Seam::Resources::Device::Warnings::PartialBackupAccessCodePool

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the backup access code is unhealthy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2090
2091
2092
# File 'lib/seam/resources/device.rb', line 2090

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • partial_backup_access_code_pool

Returns:

  • (String)


2095
2096
2097
# File 'lib/seam/resources/device.rb', line 2095

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2098
# File 'lib/seam/resources/device.rb', line 2098

date_accessor :created_at