Class: Seam::Resources::Device::Warnings::PowerSavingMode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::PowerSavingMode
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the device is in power saving mode and may have limited functionality.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2165 2166 2167 |
# File 'lib/seam/resources/device.rb', line 2165 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
power_saving_mode
2170 2171 2172 |
# File 'lib/seam/resources/device.rb', line 2170 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2173 |
# File 'lib/seam/resources/device.rb', line 2173 date_accessor :created_at |