Class: Seam::Resources::Device::Warnings::SaltoKsSubscriptionLimitAlmostReached
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::SaltoKsSubscriptionLimitAlmostReached
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the Salto KS site has exceeded 80% of the maximum number of allowed users. Increase your subscription limit or delete some users from your site.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2285 2286 2287 |
# File 'lib/seam/resources/device.rb', line 2285 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
salto_ks_subscription_limit_almost_reached
2290 2291 2292 |
# File 'lib/seam/resources/device.rb', line 2290 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2293 |
# File 'lib/seam/resources/device.rb', line 2293 date_accessor :created_at |