Class: Seam::Resources::Device::Warnings::TemperatureThresholdExceeded

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that the temperature threshold has been exceeded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2180
2181
2182
# File 'lib/seam/resources/device.rb', line 2180

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • temperature_threshold_exceeded

Returns:

  • (String)


2185
2186
2187
# File 'lib/seam/resources/device.rb', line 2185

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2188
# File 'lib/seam/resources/device.rb', line 2188

date_accessor :created_at