Class: Seam::Resources::Device::Warnings::TemperatureThresholdExceeded
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::TemperatureThresholdExceeded
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the temperature threshold has been exceeded.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2180 2181 2182 |
# File 'lib/seam/resources/device.rb', line 2180 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
temperature_threshold_exceeded
2185 2186 2187 |
# File 'lib/seam/resources/device.rb', line 2185 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2188 |
# File 'lib/seam/resources/device.rb', line 2188 date_accessor :created_at |