Class: Seam::Resources::Device::Warnings::TimeZoneMismatch
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::TimeZoneMismatch
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the device's configured time zone does not match its hardware UTC offset. Time-bound access codes may activate at the wrong local time.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2375 2376 2377 |
# File 'lib/seam/resources/device.rb', line 2375 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
time_zone_mismatch
2380 2381 2382 |
# File 'lib/seam/resources/device.rb', line 2380 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2383 |
# File 'lib/seam/resources/device.rb', line 2383 date_accessor :created_at |