Class: Seam::Resources::Device::Warnings::TtlockWeakGatewaySignal
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::TtlockWeakGatewaySignal
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the gateway signal is weak.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2150 2151 2152 |
# File 'lib/seam/resources/device.rb', line 2150 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
ttlock_weak_gateway_signal
2155 2156 2157 |
# File 'lib/seam/resources/device.rb', line 2155 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2158 |
# File 'lib/seam/resources/device.rb', line 2158 date_accessor :created_at |