Class: Seam::Resources::Device::Warnings::TwoNDeviceMissingTimezone
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::TwoNDeviceMissingTimezone
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that the 2N device does not have a time zone configured. Configure a time zone on the device to enable access codes.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2390 2391 2392 |
# File 'lib/seam/resources/device.rb', line 2390 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
two_n_device_missing_timezone
2395 2396 2397 |
# File 'lib/seam/resources/device.rb', line 2395 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2398 |
# File 'lib/seam/resources/device.rb', line 2398 date_accessor :created_at |