Class: Seam::Resources::Device::Warnings::UltraloqTimeZoneUnknown
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::UltraloqTimeZoneUnknown
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that Seam does not know the time zone of the Ultraloq device. Set a time zone to enable time-bound access codes.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2345 2346 2347 |
# File 'lib/seam/resources/device.rb', line 2345 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
ultraloq_time_zone_unknown
2350 2351 2352 |
# File 'lib/seam/resources/device.rb', line 2350 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2353 |
# File 'lib/seam/resources/device.rb', line 2353 date_accessor :created_at |