Class: Seam::Resources::Device::Warnings::UnknownIssueWithPhone
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::Device::Warnings::UnknownIssueWithPhone
- Defined in:
- lib/seam/resources/device.rb
Overview
Indicates that an unknown issue occurred while syncing the state of the phone with the provider. This issue may affect the proper functioning of the phone.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
2312 2313 2314 |
# File 'lib/seam/resources/device.rb', line 2312 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
unknown_issue_with_phone
2317 2318 2319 |
# File 'lib/seam/resources/device.rb', line 2317 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
2320 |
# File 'lib/seam/resources/device.rb', line 2320 date_accessor :created_at |