Class: Seam::Resources::Device::Warnings::UnknownIssueWithPhone

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/device.rb

Overview

Indicates that an unknown issue occurred while syncing the state of the phone with the provider. This issue may affect the proper functioning of the phone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


2315
2316
2317
# File 'lib/seam/resources/device.rb', line 2315

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • unknown_issue_with_phone

Returns:

  • (String)


2320
2321
2322
# File 'lib/seam/resources/device.rb', line 2320

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


2323
# File 'lib/seam/resources/device.rb', line 2323

date_accessor :created_at