Class: Seam::Resources::DeviceProvider

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/device_provider.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_configure_auto_lockBoolean?

Indicates whether the lock supports configuring automatic locking.

Returns:

  • (Boolean, nil)


8
9
10
# File 'lib/seam/resources/device_provider.rb', line 8

def can_configure_auto_lock
  @can_configure_auto_lock
end

#can_hvac_coolBoolean?

Indicates whether the thermostat supports cooling.

Returns:

  • (Boolean, nil)


11
12
13
# File 'lib/seam/resources/device_provider.rb', line 11

def can_hvac_cool
  @can_hvac_cool
end

#can_hvac_heatBoolean?

Indicates whether the thermostat supports heating.

Returns:

  • (Boolean, nil)


14
15
16
# File 'lib/seam/resources/device_provider.rb', line 14

def can_hvac_heat
  @can_hvac_heat
end

#can_hvac_heat_coolBoolean?

Indicates whether the thermostat supports simultaneous heating and cooling.

Returns:

  • (Boolean, nil)


17
18
19
# File 'lib/seam/resources/device_provider.rb', line 17

def can_hvac_heat_cool
  @can_hvac_heat_cool
end

#can_program_offline_access_codesBoolean?

Indicates whether the device supports programming offline access codes.

Returns:

  • (Boolean, nil)


20
21
22
# File 'lib/seam/resources/device_provider.rb', line 20

def can_program_offline_access_codes
  @can_program_offline_access_codes
end

#can_program_online_access_codesBoolean?

Indicates whether the device supports programming online access codes.

Returns:

  • (Boolean, nil)


23
24
25
# File 'lib/seam/resources/device_provider.rb', line 23

def can_program_online_access_codes
  @can_program_online_access_codes
end

#can_program_thermostat_programs_as_different_each_dayBoolean?

Indicates whether the thermostat supports different climate programs for each day of the week.

Returns:

  • (Boolean, nil)


26
27
28
# File 'lib/seam/resources/device_provider.rb', line 26

def can_program_thermostat_programs_as_different_each_day
  @can_program_thermostat_programs_as_different_each_day
end

#can_program_thermostat_programs_as_same_each_dayBoolean?

Indicates whether the thermostat supports a single climate program applied to every day.

Returns:

  • (Boolean, nil)


29
30
31
# File 'lib/seam/resources/device_provider.rb', line 29

def can_program_thermostat_programs_as_same_each_day
  @can_program_thermostat_programs_as_same_each_day
end

#can_program_thermostat_programs_as_weekday_weekendBoolean?

Indicates whether the thermostat supports weekday/weekend climate programs.

Returns:

  • (Boolean, nil)


32
33
34
# File 'lib/seam/resources/device_provider.rb', line 32

def can_program_thermostat_programs_as_weekday_weekend
  @can_program_thermostat_programs_as_weekday_weekend
end

#can_remotely_lockBoolean?

Indicates whether the device supports remote locking.

Returns:

  • (Boolean, nil)


35
36
37
# File 'lib/seam/resources/device_provider.rb', line 35

def can_remotely_lock
  @can_remotely_lock
end

#can_remotely_unlockBoolean?

Indicates whether the device supports remote unlocking.

Returns:

  • (Boolean, nil)


38
39
40
# File 'lib/seam/resources/device_provider.rb', line 38

def can_remotely_unlock
  @can_remotely_unlock
end

#can_run_thermostat_programsBoolean?

Indicates whether the thermostat supports running climate programs.

Returns:

  • (Boolean, nil)


41
42
43
# File 'lib/seam/resources/device_provider.rb', line 41

def can_run_thermostat_programs
  @can_run_thermostat_programs
end

#can_simulate_connectionBoolean?

Indicates whether the device supports simulating connection in a sandbox.

Returns:

  • (Boolean, nil)


44
45
46
# File 'lib/seam/resources/device_provider.rb', line 44

def can_simulate_connection
  @can_simulate_connection
end

#can_simulate_disconnectionBoolean?

Indicates whether the device supports simulating disconnection in a sandbox.

Returns:

  • (Boolean, nil)


47
48
49
# File 'lib/seam/resources/device_provider.rb', line 47

def can_simulate_disconnection
  @can_simulate_disconnection
end

#can_simulate_hub_connectionBoolean?

Indicates whether the hub supports simulating connection in a sandbox.

Returns:

  • (Boolean, nil)


50
51
52
# File 'lib/seam/resources/device_provider.rb', line 50

def can_simulate_hub_connection
  @can_simulate_hub_connection
end

#can_simulate_hub_disconnectionBoolean?

Indicates whether the hub supports simulating disconnection in a sandbox.

Returns:

  • (Boolean, nil)


53
54
55
# File 'lib/seam/resources/device_provider.rb', line 53

def can_simulate_hub_disconnection
  @can_simulate_hub_disconnection
end

#can_simulate_paid_subscriptionBoolean?

Indicates whether the device supports simulating a paid subscription in a sandbox.

Returns:

  • (Boolean, nil)


56
57
58
# File 'lib/seam/resources/device_provider.rb', line 56

def can_simulate_paid_subscription
  @can_simulate_paid_subscription
end

#can_simulate_removalBoolean?

Indicates whether the device supports simulating removal in a sandbox.

Returns:

  • (Boolean, nil)


59
60
61
# File 'lib/seam/resources/device_provider.rb', line 59

def can_simulate_removal
  @can_simulate_removal
end

#can_turn_off_hvacBoolean?

Indicates whether the thermostat can be turned off.

Returns:

  • (Boolean, nil)


62
63
64
# File 'lib/seam/resources/device_provider.rb', line 62

def can_turn_off_hvac
  @can_turn_off_hvac
end

#can_unlock_with_codeBoolean?

Indicates whether the lock supports unlocking with an access code.

Returns:

  • (Boolean, nil)


65
66
67
# File 'lib/seam/resources/device_provider.rb', line 65

def can_unlock_with_code
  @can_unlock_with_code
end

#device_provider_nameString

Name of the device provider.

Returns:

  • (String)


68
69
70
# File 'lib/seam/resources/device_provider.rb', line 68

def device_provider_name
  @device_provider_name
end

#display_nameString

Display name for the device provider.

Returns:

  • (String)


71
72
73
# File 'lib/seam/resources/device_provider.rb', line 71

def display_name
  @display_name
end

#image_urlString

Image URL for the device provider.

Returns:

  • (String)


74
75
76
# File 'lib/seam/resources/device_provider.rb', line 74

def image_url
  @image_url
end

#provider_categoriesArray<String>

List of provider categories to which the device provider belongs, such as stable, consumer_smartlocks, thermostats, and so on.

Returns:

  • (Array<String>)


77
78
79
# File 'lib/seam/resources/device_provider.rb', line 77

def provider_categories
  @provider_categories
end