Class: Seam::Resources::DeviceProvider

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/device_provider.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_configure_auto_lockObject

Indicates whether the lock supports configuring automatic locking.



7
8
9
# File 'lib/seam/resources/device_provider.rb', line 7

def can_configure_auto_lock
  @can_configure_auto_lock
end

#can_hvac_coolObject

Indicates whether the thermostat supports cooling.



9
10
11
# File 'lib/seam/resources/device_provider.rb', line 9

def can_hvac_cool
  @can_hvac_cool
end

#can_hvac_heatObject

Indicates whether the thermostat supports heating.



11
12
13
# File 'lib/seam/resources/device_provider.rb', line 11

def can_hvac_heat
  @can_hvac_heat
end

#can_hvac_heat_coolObject

Indicates whether the thermostat supports simultaneous heating and cooling.



13
14
15
# File 'lib/seam/resources/device_provider.rb', line 13

def can_hvac_heat_cool
  @can_hvac_heat_cool
end

#can_program_offline_access_codesObject

Indicates whether the device supports programming offline access codes.



15
16
17
# File 'lib/seam/resources/device_provider.rb', line 15

def can_program_offline_access_codes
  @can_program_offline_access_codes
end

#can_program_online_access_codesObject

Indicates whether the device supports programming online access codes.



17
18
19
# File 'lib/seam/resources/device_provider.rb', line 17

def can_program_online_access_codes
  @can_program_online_access_codes
end

#can_program_thermostat_programs_as_different_each_dayObject

Indicates whether the thermostat supports different climate programs for each day of the week.



19
20
21
# File 'lib/seam/resources/device_provider.rb', line 19

def can_program_thermostat_programs_as_different_each_day
  @can_program_thermostat_programs_as_different_each_day
end

#can_program_thermostat_programs_as_same_each_dayObject

Indicates whether the thermostat supports a single climate program applied to every day.



21
22
23
# File 'lib/seam/resources/device_provider.rb', line 21

def can_program_thermostat_programs_as_same_each_day
  @can_program_thermostat_programs_as_same_each_day
end

#can_program_thermostat_programs_as_weekday_weekendObject

Indicates whether the thermostat supports weekday/weekend climate programs.



23
24
25
# File 'lib/seam/resources/device_provider.rb', line 23

def can_program_thermostat_programs_as_weekday_weekend
  @can_program_thermostat_programs_as_weekday_weekend
end

#can_remotely_lockObject

Indicates whether the device supports remote locking.



25
26
27
# File 'lib/seam/resources/device_provider.rb', line 25

def can_remotely_lock
  @can_remotely_lock
end

#can_remotely_unlockObject

Indicates whether the device supports remote unlocking.



27
28
29
# File 'lib/seam/resources/device_provider.rb', line 27

def can_remotely_unlock
  @can_remotely_unlock
end

#can_run_thermostat_programsObject

Indicates whether the thermostat supports running climate programs.



29
30
31
# File 'lib/seam/resources/device_provider.rb', line 29

def can_run_thermostat_programs
  @can_run_thermostat_programs
end

#can_simulate_connectionObject

Indicates whether the device supports simulating connection in a sandbox.



31
32
33
# File 'lib/seam/resources/device_provider.rb', line 31

def can_simulate_connection
  @can_simulate_connection
end

#can_simulate_disconnectionObject

Indicates whether the device supports simulating disconnection in a sandbox.



33
34
35
# File 'lib/seam/resources/device_provider.rb', line 33

def can_simulate_disconnection
  @can_simulate_disconnection
end

#can_simulate_hub_connectionObject

Indicates whether the hub supports simulating connection in a sandbox.



35
36
37
# File 'lib/seam/resources/device_provider.rb', line 35

def can_simulate_hub_connection
  @can_simulate_hub_connection
end

#can_simulate_hub_disconnectionObject

Indicates whether the hub supports simulating disconnection in a sandbox.



37
38
39
# File 'lib/seam/resources/device_provider.rb', line 37

def can_simulate_hub_disconnection
  @can_simulate_hub_disconnection
end

#can_simulate_paid_subscriptionObject

Indicates whether the device supports simulating a paid subscription in a sandbox.



39
40
41
# File 'lib/seam/resources/device_provider.rb', line 39

def can_simulate_paid_subscription
  @can_simulate_paid_subscription
end

#can_simulate_removalObject

Indicates whether the device supports simulating removal in a sandbox.



41
42
43
# File 'lib/seam/resources/device_provider.rb', line 41

def can_simulate_removal
  @can_simulate_removal
end

#can_turn_off_hvacObject

Indicates whether the thermostat can be turned off.



43
44
45
# File 'lib/seam/resources/device_provider.rb', line 43

def can_turn_off_hvac
  @can_turn_off_hvac
end

#can_unlock_with_codeObject

Indicates whether the lock supports unlocking with an access code.



45
46
47
# File 'lib/seam/resources/device_provider.rb', line 45

def can_unlock_with_code
  @can_unlock_with_code
end

#device_provider_nameObject

Name of the device provider.



47
48
49
# File 'lib/seam/resources/device_provider.rb', line 47

def device_provider_name
  @device_provider_name
end

#display_nameObject

Display name for the device provider.



49
50
51
# File 'lib/seam/resources/device_provider.rb', line 49

def display_name
  @display_name
end

#image_urlObject

Image URL for the device provider.



51
52
53
# File 'lib/seam/resources/device_provider.rb', line 51

def image_url
  @image_url
end

#provider_categoriesObject

List of provider categories to which the device provider belongs, such as stable, consumer_smartlocks, thermostats, and so on.



53
54
55
# File 'lib/seam/resources/device_provider.rb', line 53

def provider_categories
  @provider_categories
end