Class: Seam::Resources::DeviceProvider
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::DeviceProvider
- Defined in:
- lib/seam/resources/device_provider.rb
Instance Attribute Summary collapse
-
#can_configure_auto_lock ⇒ Object
Indicates whether the lock supports configuring automatic locking.
-
#can_hvac_cool ⇒ Object
Indicates whether the thermostat supports cooling.
-
#can_hvac_heat ⇒ Object
Indicates whether the thermostat supports heating.
-
#can_hvac_heat_cool ⇒ Object
Indicates whether the thermostat supports simultaneous heating and cooling.
-
#can_program_offline_access_codes ⇒ Object
Indicates whether the device supports programming offline access codes.
-
#can_program_online_access_codes ⇒ Object
Indicates whether the device supports programming online access codes.
-
#can_program_thermostat_programs_as_different_each_day ⇒ Object
Indicates whether the thermostat supports different climate programs for each day of the week.
-
#can_program_thermostat_programs_as_same_each_day ⇒ Object
Indicates whether the thermostat supports a single climate program applied to every day.
-
#can_program_thermostat_programs_as_weekday_weekend ⇒ Object
Indicates whether the thermostat supports weekday/weekend climate programs.
-
#can_remotely_lock ⇒ Object
Indicates whether the device supports remote locking.
-
#can_remotely_unlock ⇒ Object
Indicates whether the device supports remote unlocking.
-
#can_run_thermostat_programs ⇒ Object
Indicates whether the thermostat supports running climate programs.
-
#can_simulate_connection ⇒ Object
Indicates whether the device supports simulating connection in a sandbox.
-
#can_simulate_disconnection ⇒ Object
Indicates whether the device supports simulating disconnection in a sandbox.
-
#can_simulate_hub_connection ⇒ Object
Indicates whether the hub supports simulating connection in a sandbox.
-
#can_simulate_hub_disconnection ⇒ Object
Indicates whether the hub supports simulating disconnection in a sandbox.
-
#can_simulate_paid_subscription ⇒ Object
Indicates whether the device supports simulating a paid subscription in a sandbox.
-
#can_simulate_removal ⇒ Object
Indicates whether the device supports simulating removal in a sandbox.
-
#can_turn_off_hvac ⇒ Object
Indicates whether the thermostat can be turned off.
-
#can_unlock_with_code ⇒ Object
Indicates whether the lock supports unlocking with an access code.
-
#device_provider_name ⇒ Object
Name of the device provider.
-
#display_name ⇒ Object
Display name for the device provider.
-
#image_url ⇒ Object
Image URL for the device provider.
-
#provider_categories ⇒ Object
List of provider categories to which the device provider belongs, such as
stable,consumer_smartlocks,thermostats, and so on.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_configure_auto_lock ⇒ Object
Indicates whether the lock supports configuring automatic locking.
7 8 9 |
# File 'lib/seam/resources/device_provider.rb', line 7 def can_configure_auto_lock @can_configure_auto_lock end |
#can_hvac_cool ⇒ Object
Indicates whether the thermostat supports cooling.
9 10 11 |
# File 'lib/seam/resources/device_provider.rb', line 9 def can_hvac_cool @can_hvac_cool end |
#can_hvac_heat ⇒ Object
Indicates whether the thermostat supports heating.
11 12 13 |
# File 'lib/seam/resources/device_provider.rb', line 11 def can_hvac_heat @can_hvac_heat end |
#can_hvac_heat_cool ⇒ Object
Indicates whether the thermostat supports simultaneous heating and cooling.
13 14 15 |
# File 'lib/seam/resources/device_provider.rb', line 13 def can_hvac_heat_cool @can_hvac_heat_cool end |
#can_program_offline_access_codes ⇒ Object
Indicates whether the device supports programming offline access codes.
15 16 17 |
# File 'lib/seam/resources/device_provider.rb', line 15 def can_program_offline_access_codes @can_program_offline_access_codes end |
#can_program_online_access_codes ⇒ Object
Indicates whether the device supports programming online access codes.
17 18 19 |
# File 'lib/seam/resources/device_provider.rb', line 17 def can_program_online_access_codes @can_program_online_access_codes end |
#can_program_thermostat_programs_as_different_each_day ⇒ Object
Indicates whether the thermostat supports different climate programs for each day of the week.
19 20 21 |
# File 'lib/seam/resources/device_provider.rb', line 19 def can_program_thermostat_programs_as_different_each_day @can_program_thermostat_programs_as_different_each_day end |
#can_program_thermostat_programs_as_same_each_day ⇒ Object
Indicates whether the thermostat supports a single climate program applied to every day.
21 22 23 |
# File 'lib/seam/resources/device_provider.rb', line 21 def can_program_thermostat_programs_as_same_each_day @can_program_thermostat_programs_as_same_each_day end |
#can_program_thermostat_programs_as_weekday_weekend ⇒ Object
Indicates whether the thermostat supports weekday/weekend climate programs.
23 24 25 |
# File 'lib/seam/resources/device_provider.rb', line 23 def can_program_thermostat_programs_as_weekday_weekend @can_program_thermostat_programs_as_weekday_weekend end |
#can_remotely_lock ⇒ Object
Indicates whether the device supports remote locking.
25 26 27 |
# File 'lib/seam/resources/device_provider.rb', line 25 def can_remotely_lock @can_remotely_lock end |
#can_remotely_unlock ⇒ Object
Indicates whether the device supports remote unlocking.
27 28 29 |
# File 'lib/seam/resources/device_provider.rb', line 27 def can_remotely_unlock @can_remotely_unlock end |
#can_run_thermostat_programs ⇒ Object
Indicates whether the thermostat supports running climate programs.
29 30 31 |
# File 'lib/seam/resources/device_provider.rb', line 29 def can_run_thermostat_programs @can_run_thermostat_programs end |
#can_simulate_connection ⇒ Object
Indicates whether the device supports simulating connection in a sandbox.
31 32 33 |
# File 'lib/seam/resources/device_provider.rb', line 31 def can_simulate_connection @can_simulate_connection end |
#can_simulate_disconnection ⇒ Object
Indicates whether the device supports simulating disconnection in a sandbox.
33 34 35 |
# File 'lib/seam/resources/device_provider.rb', line 33 def can_simulate_disconnection @can_simulate_disconnection end |
#can_simulate_hub_connection ⇒ Object
Indicates whether the hub supports simulating connection in a sandbox.
35 36 37 |
# File 'lib/seam/resources/device_provider.rb', line 35 def can_simulate_hub_connection @can_simulate_hub_connection end |
#can_simulate_hub_disconnection ⇒ Object
Indicates whether the hub supports simulating disconnection in a sandbox.
37 38 39 |
# File 'lib/seam/resources/device_provider.rb', line 37 def can_simulate_hub_disconnection @can_simulate_hub_disconnection end |
#can_simulate_paid_subscription ⇒ Object
Indicates whether the device supports simulating a paid subscription in a sandbox.
39 40 41 |
# File 'lib/seam/resources/device_provider.rb', line 39 def can_simulate_paid_subscription @can_simulate_paid_subscription end |
#can_simulate_removal ⇒ Object
Indicates whether the device supports simulating removal in a sandbox.
41 42 43 |
# File 'lib/seam/resources/device_provider.rb', line 41 def can_simulate_removal @can_simulate_removal end |
#can_turn_off_hvac ⇒ Object
Indicates whether the thermostat can be turned off.
43 44 45 |
# File 'lib/seam/resources/device_provider.rb', line 43 def can_turn_off_hvac @can_turn_off_hvac end |
#can_unlock_with_code ⇒ Object
Indicates whether the lock supports unlocking with an access code.
45 46 47 |
# File 'lib/seam/resources/device_provider.rb', line 45 def can_unlock_with_code @can_unlock_with_code end |
#device_provider_name ⇒ Object
Name of the device provider.
47 48 49 |
# File 'lib/seam/resources/device_provider.rb', line 47 def device_provider_name @device_provider_name end |
#display_name ⇒ Object
Display name for the device provider.
49 50 51 |
# File 'lib/seam/resources/device_provider.rb', line 49 def display_name @display_name end |
#image_url ⇒ Object
Image URL for the device provider.
51 52 53 |
# File 'lib/seam/resources/device_provider.rb', line 51 def image_url @image_url end |
#provider_categories ⇒ Object
List of provider categories to which the device provider belongs, such as stable, consumer_smartlocks, thermostats, and so on.
53 54 55 |
# File 'lib/seam/resources/device_provider.rb', line 53 def provider_categories @provider_categories end |