Class: Seam::Resources::InstantKey
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::InstantKey
- Defined in:
- lib/seam/resources/instant_key.rb
Overview
Represents a Seam Instant Key. For issuing Bluetooth mobile keys, Instant Keys are the fastest way to share access. With a single API call, you can create a mobile key and send it through text or email or embed it in your own app.
There’s no app to install, nor account to create. Your user just taps a link and gets a lightweight, native-feeling experience using iOS App Clip or Instant Apps on Android. Further, Instant Keys work offline, so even in areas with poor cellular or Wi-Fi, like elevator banks or concrete-walled hallways, the Instant Keys still work.
Defined Under Namespace
Classes: Customization
Instance Attribute Summary collapse
-
#client_session_id ⇒ String
ID of the client session associated with the Instant Key.
-
#customization_profile_id ⇒ String?
ID of the customization profile associated with the Instant Key.
-
#instant_key_id ⇒ String
ID of the Instant Key.
-
#instant_key_url ⇒ String
Shareable URL for the Instant Key.
-
#user_identity_id ⇒ String
ID of the user identity associated with the Instant Key.
-
#workspace_id ⇒ String
ID of the workspace that contains the Instant Key.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the Instant Key was created.
-
#customization ⇒ Customization?
Customization applied to the Instant Key UI.
-
#expires_at ⇒ Time
Date and time at which the Instant Key expires.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#client_session_id ⇒ String
ID of the client session associated with the Instant Key.
26 27 28 |
# File 'lib/seam/resources/instant_key.rb', line 26 def client_session_id @client_session_id end |
#customization_profile_id ⇒ String?
ID of the customization profile associated with the Instant Key.
29 30 31 |
# File 'lib/seam/resources/instant_key.rb', line 29 def customization_profile_id @customization_profile_id end |
#instant_key_id ⇒ String
ID of the Instant Key.
32 33 34 |
# File 'lib/seam/resources/instant_key.rb', line 32 def instant_key_id @instant_key_id end |
#instant_key_url ⇒ String
Shareable URL for the Instant Key. Use the URL to deliver the Instant Key to your user through a link in a text message or email or by embedding it in your web app.
35 36 37 |
# File 'lib/seam/resources/instant_key.rb', line 35 def instant_key_url @instant_key_url end |
#user_identity_id ⇒ String
ID of the user identity associated with the Instant Key.
38 39 40 |
# File 'lib/seam/resources/instant_key.rb', line 38 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the Instant Key.
41 42 43 |
# File 'lib/seam/resources/instant_key.rb', line 41 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the Instant Key was created.
45 |
# File 'lib/seam/resources/instant_key.rb', line 45 date_accessor :created_at |
#customization ⇒ Customization?
Customization applied to the Instant Key UI.
23 |
# File 'lib/seam/resources/instant_key.rb', line 23 resource_accessor :customization, Customization |
#expires_at ⇒ Time
Date and time at which the Instant Key expires.
49 |
# File 'lib/seam/resources/instant_key.rb', line 49 date_accessor :expires_at |