Class: Seam::Resources::InstantKey
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::InstantKey
- Defined in:
- lib/seam/resources/instant_key.rb
Overview
Represents a Seam Instant Key. For issuing Bluetooth mobile keys, Instant Keys are the fastest way to share access. With a single API call, you can create a mobile key and send it through text or email or embed it in your own app.
There’s no app to install, nor account to create. Your user just taps a link and gets a lightweight, native-feeling experience using iOS App Clip or Instant Apps on Android. Further, Instant Keys work offline, so even in areas with poor cellular or Wi-Fi, like elevator banks or concrete-walled hallways, the Instant Keys still work.
Instance Attribute Summary collapse
-
#client_session_id ⇒ Object
ID of the client session associated with the Instant Key.
-
#customization ⇒ Object
Customization applied to the Instant Key UI.
-
#customization_profile_id ⇒ Object
ID of the customization profile associated with the Instant Key.
-
#instant_key_id ⇒ Object
ID of the Instant Key.
-
#instant_key_url ⇒ Object
Shareable URL for the Instant Key.
-
#user_identity_id ⇒ Object
ID of the user identity associated with the Instant Key.
-
#workspace_id ⇒ Object
ID of the workspace that contains the Instant Key.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#client_session_id ⇒ Object
ID of the client session associated with the Instant Key.
10 11 12 |
# File 'lib/seam/resources/instant_key.rb', line 10 def client_session_id @client_session_id end |
#customization ⇒ Object
Customization applied to the Instant Key UI.
12 13 14 |
# File 'lib/seam/resources/instant_key.rb', line 12 def customization @customization end |
#customization_profile_id ⇒ Object
ID of the customization profile associated with the Instant Key.
14 15 16 |
# File 'lib/seam/resources/instant_key.rb', line 14 def customization_profile_id @customization_profile_id end |
#instant_key_id ⇒ Object
ID of the Instant Key.
16 17 18 |
# File 'lib/seam/resources/instant_key.rb', line 16 def instant_key_id @instant_key_id end |
#instant_key_url ⇒ Object
Shareable URL for the Instant Key. Use the URL to deliver the Instant Key to your user through a link in a text message or email or by embedding it in your web app.
18 19 20 |
# File 'lib/seam/resources/instant_key.rb', line 18 def instant_key_url @instant_key_url end |
#user_identity_id ⇒ Object
ID of the user identity associated with the Instant Key.
20 21 22 |
# File 'lib/seam/resources/instant_key.rb', line 20 def user_identity_id @user_identity_id end |
#workspace_id ⇒ Object
ID of the workspace that contains the Instant Key.
22 23 24 |
# File 'lib/seam/resources/instant_key.rb', line 22 def workspace_id @workspace_id end |