Class: Seam::Resources::InstantKey::Customization
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::InstantKey::Customization
- Defined in:
- lib/seam/resources/instant_key.rb
Instance Attribute Summary collapse
-
#logo_url ⇒ Object
URL of the logo displayed on the Instant Key.
-
#primary_color ⇒ Object
Primary color used in the Instant Key UI.
-
#secondary_color ⇒ Object
Secondary color used in the Instant Key UI.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#logo_url ⇒ Object
URL of the logo displayed on the Instant Key.
11 12 13 |
# File 'lib/seam/resources/instant_key.rb', line 11 def logo_url @logo_url end |
#primary_color ⇒ Object
Primary color used in the Instant Key UI.
13 14 15 |
# File 'lib/seam/resources/instant_key.rb', line 13 def primary_color @primary_color end |
#secondary_color ⇒ Object
Secondary color used in the Instant Key UI.
15 16 17 |
# File 'lib/seam/resources/instant_key.rb', line 15 def secondary_color @secondary_color end |