Class: Seam::Resources::NoiseThreshold
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::NoiseThreshold
- Defined in:
- lib/seam/resources/noise_threshold.rb
Overview
Represents a noise threshold for a noise sensor. Thresholds represent the limits of noise tolerated at a property, which can be customized for each hour of the day. Each device has its own default thresholds, but you can use the Seam API to modify them.
Instance Attribute Summary collapse
-
#device_id ⇒ String
Unique identifier for the device that contains the noise threshold.
-
#ends_daily_at ⇒ String
Time at which the noise threshold should become inactive daily.
-
#name ⇒ String
Name of the noise threshold.
-
#noise_threshold_decibels ⇒ Float
Noise level in decibels for the noise threshold.
-
#noise_threshold_id ⇒ String
Unique identifier for the noise threshold.
-
#noise_threshold_nrs ⇒ Float?
Noise level in Noiseaware Noise Risk Score (NRS) for the noise threshold.
-
#starts_daily_at ⇒ String
Time at which the noise threshold should become active daily.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ String
Unique identifier for the device that contains the noise threshold.
9 10 11 |
# File 'lib/seam/resources/noise_threshold.rb', line 9 def device_id @device_id end |
#ends_daily_at ⇒ String
Time at which the noise threshold should become inactive daily.
12 13 14 |
# File 'lib/seam/resources/noise_threshold.rb', line 12 def ends_daily_at @ends_daily_at end |
#name ⇒ String
Name of the noise threshold.
15 16 17 |
# File 'lib/seam/resources/noise_threshold.rb', line 15 def name @name end |
#noise_threshold_decibels ⇒ Float
Noise level in decibels for the noise threshold.
18 19 20 |
# File 'lib/seam/resources/noise_threshold.rb', line 18 def noise_threshold_decibels @noise_threshold_decibels end |
#noise_threshold_id ⇒ String
Unique identifier for the noise threshold.
21 22 23 |
# File 'lib/seam/resources/noise_threshold.rb', line 21 def noise_threshold_id @noise_threshold_id end |
#noise_threshold_nrs ⇒ Float?
Noise level in Noiseaware Noise Risk Score (NRS) for the noise threshold. This parameter is only relevant for Noiseaware sensors.
24 25 26 |
# File 'lib/seam/resources/noise_threshold.rb', line 24 def noise_threshold_nrs @noise_threshold_nrs end |
#starts_daily_at ⇒ String
Time at which the noise threshold should become active daily.
27 28 29 |
# File 'lib/seam/resources/noise_threshold.rb', line 27 def starts_daily_at @starts_daily_at end |