Class: Seam::Resources::NoiseThreshold

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/noise_threshold.rb

Overview

Represents a noise threshold for a noise sensor. Thresholds represent the limits of noise tolerated at a property, which can be customized for each hour of the day. Each device has its own default thresholds, but you can use the Seam API to modify them.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idObject

Unique identifier for the device that contains the noise threshold.



8
9
10
# File 'lib/seam/resources/noise_threshold.rb', line 8

def device_id
  @device_id
end

#ends_daily_atObject

Time at which the noise threshold should become inactive daily.



10
11
12
# File 'lib/seam/resources/noise_threshold.rb', line 10

def ends_daily_at
  @ends_daily_at
end

#nameObject

Name of the noise threshold.



12
13
14
# File 'lib/seam/resources/noise_threshold.rb', line 12

def name
  @name
end

#noise_threshold_decibelsObject

Noise level in decibels for the noise threshold.



14
15
16
# File 'lib/seam/resources/noise_threshold.rb', line 14

def noise_threshold_decibels
  @noise_threshold_decibels
end

#noise_threshold_idObject

Unique identifier for the noise threshold.



16
17
18
# File 'lib/seam/resources/noise_threshold.rb', line 16

def noise_threshold_id
  @noise_threshold_id
end

#noise_threshold_nrsObject

Noise level in Noiseaware Noise Risk Score (NRS) for the noise threshold. This parameter is only relevant for Noiseaware sensors.



18
19
20
# File 'lib/seam/resources/noise_threshold.rb', line 18

def noise_threshold_nrs
  @noise_threshold_nrs
end

#starts_daily_atObject

Time at which the noise threshold should become active daily.



20
21
22
# File 'lib/seam/resources/noise_threshold.rb', line 20

def starts_daily_at
  @starts_daily_at
end