Class: Seam::Resources::Pagination

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/pagination.rb

Overview

Information about the current page of results.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#has_next_pageObject

Indicates whether there is another page of results after this one.



8
9
10
# File 'lib/seam/resources/pagination.rb', line 8

def has_next_page
  @has_next_page
end

#next_page_cursorObject

Opaque value that can be used to select the next page of results via the page_cursor parameter.



10
11
12
# File 'lib/seam/resources/pagination.rb', line 10

def next_page_cursor
  @next_page_cursor
end

#next_page_urlObject

URL to get the next page of results.



12
13
14
# File 'lib/seam/resources/pagination.rb', line 12

def next_page_url
  @next_page_url
end