Class: Seam::Resources::Pagination
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Pagination
- Defined in:
- lib/seam/resources/pagination.rb
Overview
Information about the current page of results.
Instance Attribute Summary collapse
-
#has_next_page ⇒ Object
Indicates whether there is another page of results after this one.
-
#next_page_cursor ⇒ Object
Opaque value that can be used to select the next page of results via the
page_cursorparameter. -
#next_page_url ⇒ Object
URL to get the next page of results.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#has_next_page ⇒ Object
Indicates whether there is another page of results after this one.
8 9 10 |
# File 'lib/seam/resources/pagination.rb', line 8 def has_next_page @has_next_page end |
#next_page_cursor ⇒ Object
Opaque value that can be used to select the next page of results via the page_cursor parameter.
10 11 12 |
# File 'lib/seam/resources/pagination.rb', line 10 def next_page_cursor @next_page_cursor end |
#next_page_url ⇒ Object
URL to get the next page of results.
12 13 14 |
# File 'lib/seam/resources/pagination.rb', line 12 def next_page_url @next_page_url end |