Class: Seam::Resources::Phone
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Phone
- Defined in:
- lib/seam/resources/phone.rb
Overview
Represents an app user's mobile phone.
Defined Under Namespace
Classes: Errors, Properties, Warnings
Instance Attribute Summary collapse
-
#custom_metadata ⇒ Hash
Optional custom metadata for the phone.
-
#device_id ⇒ String
ID of the phone.
-
#device_type ⇒ String
Type of the phone device, such as
ios_phoneorandroid_phone. -
#display_name ⇒ String
Display name of the phone.
-
#nickname ⇒ String?
Optional nickname to describe the phone, settable through Seam.
-
#workspace_id ⇒ String
ID of the workspace that contains the phone.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the phone was created.
-
#errors ⇒ Array<Errors>
Errors associated with the phone.
-
#properties ⇒ Properties
Properties of the phone.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the phone.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#custom_metadata ⇒ Hash
Optional custom metadata for the phone.
75 76 77 |
# File 'lib/seam/resources/phone.rb', line 75 def @custom_metadata end |
#device_id ⇒ String
ID of the phone.
78 79 80 |
# File 'lib/seam/resources/phone.rb', line 78 def device_id @device_id end |
#device_type ⇒ String
Type of the phone device, such as ios_phone or android_phone.
81 82 83 |
# File 'lib/seam/resources/phone.rb', line 81 def device_type @device_type end |
#display_name ⇒ String
Display name of the phone. Defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the phone easily, especially when there are numerous phones.
84 85 86 |
# File 'lib/seam/resources/phone.rb', line 84 def display_name @display_name end |
#nickname ⇒ String?
Optional nickname to describe the phone, settable through Seam.
87 88 89 |
# File 'lib/seam/resources/phone.rb', line 87 def nickname @nickname end |
#workspace_id ⇒ String
ID of the workspace that contains the phone.
90 91 92 |
# File 'lib/seam/resources/phone.rb', line 90 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the phone was created.
94 |
# File 'lib/seam/resources/phone.rb', line 94 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the phone.
69 |
# File 'lib/seam/resources/phone.rb', line 69 resource_list_accessor :errors, Errors |
#properties ⇒ Properties
Properties of the phone.
66 |
# File 'lib/seam/resources/phone.rb', line 66 resource_accessor :properties, Properties |