Class: Seam::Resources::Phone
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Phone
- Defined in:
- lib/seam/resources/phone.rb
Overview
Represents an app user's mobile phone.
Defined Under Namespace
Classes: Errors, Properties, Warnings
Instance Attribute Summary collapse
-
#custom_metadata ⇒ Object
Optional custom metadata for the phone.
-
#device_id ⇒ Object
ID of the phone.
-
#device_type ⇒ Object
Type of the phone device, such as
ios_phoneorandroid_phone. -
#display_name ⇒ Object
Display name of the phone.
-
#nickname ⇒ Object
Optional nickname to describe the phone, settable through Seam.
-
#workspace_id ⇒ Object
ID of the workspace that contains the phone.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#custom_metadata ⇒ Object
Optional custom metadata for the phone.
52 53 54 |
# File 'lib/seam/resources/phone.rb', line 52 def @custom_metadata end |
#device_id ⇒ Object
ID of the phone.
54 55 56 |
# File 'lib/seam/resources/phone.rb', line 54 def device_id @device_id end |
#device_type ⇒ Object
Type of the phone device, such as ios_phone or android_phone.
56 57 58 |
# File 'lib/seam/resources/phone.rb', line 56 def device_type @device_type end |
#display_name ⇒ Object
Display name of the phone. Defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the phone easily, especially when there are numerous phones.
58 59 60 |
# File 'lib/seam/resources/phone.rb', line 58 def display_name @display_name end |
#nickname ⇒ Object
Optional nickname to describe the phone, settable through Seam.
60 61 62 |
# File 'lib/seam/resources/phone.rb', line 60 def nickname @nickname end |
#workspace_id ⇒ Object
ID of the workspace that contains the phone.
62 63 64 |
# File 'lib/seam/resources/phone.rb', line 62 def workspace_id @workspace_id end |