Class: Seam::Resources::Phone

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport, ResourceWarningsSupport
Defined in:
lib/seam/resources/phone.rb

Overview

Represents an app user's mobile phone.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceWarningsSupport

#warnings

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#custom_metadataObject

Optional custom metadata for the phone.



8
9
10
# File 'lib/seam/resources/phone.rb', line 8

def 
  @custom_metadata
end

#device_idObject

ID of the phone.



10
11
12
# File 'lib/seam/resources/phone.rb', line 10

def device_id
  @device_id
end

#device_typeObject

Type of the phone device, such as ios_phone or android_phone.



12
13
14
# File 'lib/seam/resources/phone.rb', line 12

def device_type
  @device_type
end

#display_nameObject

Display name of the phone. Defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the phone easily, especially when there are numerous phones.



14
15
16
# File 'lib/seam/resources/phone.rb', line 14

def display_name
  @display_name
end

#nicknameObject

Optional nickname to describe the phone, settable through Seam.



16
17
18
# File 'lib/seam/resources/phone.rb', line 16

def nickname
  @nickname
end

#propertiesObject

Properties of the phone.



18
19
20
# File 'lib/seam/resources/phone.rb', line 18

def properties
  @properties
end

#workspace_idObject

ID of the workspace that contains the phone.



20
21
22
# File 'lib/seam/resources/phone.rb', line 20

def workspace_id
  @workspace_id
end