Class: Seam::Resources::Phone
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Phone
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/phone.rb
Overview
Represents an app user's mobile phone.
Instance Attribute Summary collapse
-
#custom_metadata ⇒ Object
Optional custom metadata for the phone.
-
#device_id ⇒ Object
ID of the phone.
-
#device_type ⇒ Object
Type of the phone device, such as
ios_phoneorandroid_phone. -
#display_name ⇒ Object
Display name of the phone.
-
#nickname ⇒ Object
Optional nickname to describe the phone, settable through Seam.
-
#properties ⇒ Object
Properties of the phone.
-
#workspace_id ⇒ Object
ID of the workspace that contains the phone.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#custom_metadata ⇒ Object
Optional custom metadata for the phone.
8 9 10 |
# File 'lib/seam/resources/phone.rb', line 8 def @custom_metadata end |
#device_id ⇒ Object
ID of the phone.
10 11 12 |
# File 'lib/seam/resources/phone.rb', line 10 def device_id @device_id end |
#device_type ⇒ Object
Type of the phone device, such as ios_phone or android_phone.
12 13 14 |
# File 'lib/seam/resources/phone.rb', line 12 def device_type @device_type end |
#display_name ⇒ Object
Display name of the phone. Defaults to nickname (if it is set) or properties.appearance.name, otherwise. Enables administrators and users to identify the phone easily, especially when there are numerous phones.
14 15 16 |
# File 'lib/seam/resources/phone.rb', line 14 def display_name @display_name end |
#nickname ⇒ Object
Optional nickname to describe the phone, settable through Seam.
16 17 18 |
# File 'lib/seam/resources/phone.rb', line 16 def nickname @nickname end |
#properties ⇒ Object
Properties of the phone.
18 19 20 |
# File 'lib/seam/resources/phone.rb', line 18 def properties @properties end |
#workspace_id ⇒ Object
ID of the workspace that contains the phone.
20 21 22 |
# File 'lib/seam/resources/phone.rb', line 20 def workspace_id @workspace_id end |