Class: Seam::Resources::SeamEvent
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::SeamEvent
- Defined in:
- lib/seam/resources/event.rb
Defined Under Namespace
Classes: AccessCodeErrors, AccessCodeWarnings, AcsSystemErrors, AcsSystemWarnings, ChangedProperties, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings, From, Reason, RequestedMutations, To
Instance Attribute Summary collapse
- #access_code_id ⇒ String?
-
#access_code_is_managed ⇒ Boolean?
Whether the access code is managed by Seam (true) or unmanaged (false).
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
-
#access_grant_key ⇒ String?
Key of the affected Access Grant (if present).
-
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ String
ID of the affected access method.
-
#acs_access_group_id ⇒ String
ID of the affected access group.
-
#acs_credential_id ⇒ String
ID of the affected credential.
-
#acs_encoder_id ⇒ String
ID of the affected encoder.
- #acs_entrance_id ⇒ String
- #acs_entrance_ids ⇒ Array<String>
-
#acs_system_id ⇒ String
ID of the access system.
-
#acs_user_id ⇒ String
ID of the affected access system user.
- #action_attempt_id ⇒ String?
-
#action_type ⇒ String
Type of the action.
-
#activation_reason ⇒ String
The reason the camera was activated.
-
#backup_access_code_id ⇒ String
ID of the backup access code that was pulled from the pool.
-
#battery_level ⇒ Float
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
-
#battery_status ⇒ String
Battery status of the affected device, calculated from the numeric
battery_levelvalue. -
#change_reason ⇒ String?
Human-readable reason for the change (e.g.
ongoing code auto-renewed). -
#client_session_id ⇒ String
ID of the affected client session.
-
#climate_preset_key ⇒ String
Key of the climate preset that was activated.
- #code ⇒ String?
- #connect_webview_id ⇒ String?
- #connected_account_custom_metadata ⇒ Hash?
- #connected_account_id ⇒ String?
-
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F).
- #customer_key ⇒ String?
-
#description ⇒ String
Human-readable description of the change and its source.
-
#desired_temperature_celsius ⇒ Float?
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
-
#desired_temperature_fahrenheit ⇒ Float?
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
- #device_custom_metadata ⇒ Hash?
- #device_id ⇒ String?
- #device_ids ⇒ Array<String>
- #device_name ⇒ String?
-
#ends_at ⇒ String?
The new end time for the access grant.
-
#error_code ⇒ String
Error code associated with the disconnection event, if any.
-
#error_message ⇒ String
Description of why the access methods could not be created.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String?
ID of the event.
-
#event_type ⇒ String?
Type of the event.
-
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. - #image_url ⇒ String?
-
#is_backup_code ⇒ Boolean?
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
-
#is_fallback_climate_preset ⇒ Boolean
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
- #is_via_bluetooth ⇒ Boolean?
- #is_via_nfc ⇒ Boolean?
-
#lower_limit_celsius ⇒ Float?
Lower temperature limit, in °C, defined by the set threshold.
-
#lower_limit_fahrenheit ⇒ Float?
Lower temperature limit, in °F, defined by the set threshold.
- #method ⇒ String
-
#minut_metadata ⇒ Hash?
Metadata from Minut.
-
#missing_device_ids ⇒ Array<String>
IDs of the devices that did not receive a requested access method.
-
#motion_sub_type ⇒ String?
Sub-type of motion detected, if available.
-
#noise_level_decibels ⇒ Float?
Detected noise level in decibels.
-
#noise_level_nrs ⇒ Float?
Detected noise level in Noiseaware Noise Risk Score (NRS).
-
#noise_threshold_id ⇒ String?
ID of the noise threshold that was triggered.
-
#noise_threshold_name ⇒ String?
Name of the noise threshold that was triggered.
-
#noiseaware_metadata ⇒ Hash?
Metadata from Noiseaware.
-
#space_id ⇒ String
ID of the affected space.
-
#space_key ⇒ String?
Unique key for the space within the workspace.
-
#starts_at ⇒ String?
The new start time for the access grant.
-
#status ⇒ String
Status of the action.
-
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
-
#thermostat_schedule_id ⇒ String?
ID of the thermostat schedule that prompted the affected climate preset to be activated.
-
#upper_limit_celsius ⇒ Float?
Upper temperature limit, in °C, defined by the set threshold.
-
#upper_limit_fahrenheit ⇒ Float?
Upper temperature limit, in °F, defined by the set threshold.
- #video_url ⇒ String?
-
#workspace_id ⇒ String?
ID of the workspace associated with the event.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
-
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
-
#acs_system_errors ⇒ Array<AcsSystemErrors>
Errors associated with the access control system.
-
#acs_system_warnings ⇒ Array<AcsSystemWarnings>
Warnings associated with the access control system.
-
#changed_properties ⇒ Array<ChangedProperties>
List of properties that changed on the access code.
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time?
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
- #from ⇒ From
-
#occurred_at ⇒ Time?
Date and time at which the event occurred.
-
#reason ⇒ Reason?
Why access was denied, when the provider reports a determinable cause.
-
#requested_mutations ⇒ Array<RequestedMutations>
Array of mutations requested on the access code, each containing the mutation type and from/to values.
- #to ⇒ To
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_code_id ⇒ String?
203 204 205 |
# File 'lib/seam/resources/event.rb', line 203 def access_code_id @access_code_id end |
#access_code_is_managed ⇒ Boolean?
Whether the access code is managed by Seam (true) or unmanaged (false). Only present when access_code_id is set.
206 207 208 |
# File 'lib/seam/resources/event.rb', line 206 def access_code_is_managed @access_code_is_managed end |
#access_grant_id ⇒ String
ID of the affected Access Grant.
209 210 211 |
# File 'lib/seam/resources/event.rb', line 209 def access_grant_id @access_grant_id end |
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
212 213 214 |
# File 'lib/seam/resources/event.rb', line 212 def access_grant_ids @access_grant_ids end |
#access_grant_key ⇒ String?
Key of the affected Access Grant (if present).
215 216 217 |
# File 'lib/seam/resources/event.rb', line 215 def access_grant_key @access_grant_key end |
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
218 219 220 |
# File 'lib/seam/resources/event.rb', line 218 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ String
ID of the affected access method.
221 222 223 |
# File 'lib/seam/resources/event.rb', line 221 def access_method_id @access_method_id end |
#acs_access_group_id ⇒ String
ID of the affected access group.
224 225 226 |
# File 'lib/seam/resources/event.rb', line 224 def acs_access_group_id @acs_access_group_id end |
#acs_credential_id ⇒ String
ID of the affected credential.
227 228 229 |
# File 'lib/seam/resources/event.rb', line 227 def acs_credential_id @acs_credential_id end |
#acs_encoder_id ⇒ String
ID of the affected encoder.
230 231 232 |
# File 'lib/seam/resources/event.rb', line 230 def acs_encoder_id @acs_encoder_id end |
#acs_entrance_id ⇒ String
232 233 234 |
# File 'lib/seam/resources/event.rb', line 232 def acs_entrance_id @acs_entrance_id end |
#acs_entrance_ids ⇒ Array<String>
234 235 236 |
# File 'lib/seam/resources/event.rb', line 234 def acs_entrance_ids @acs_entrance_ids end |
#acs_system_id ⇒ String
ID of the access system.
237 238 239 |
# File 'lib/seam/resources/event.rb', line 237 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the affected access system user.
240 241 242 |
# File 'lib/seam/resources/event.rb', line 240 def acs_user_id @acs_user_id end |
#action_attempt_id ⇒ String?
242 243 244 |
# File 'lib/seam/resources/event.rb', line 242 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Type of the action.
245 246 247 |
# File 'lib/seam/resources/event.rb', line 245 def action_type @action_type end |
#activation_reason ⇒ String
The reason the camera was activated.
248 249 250 |
# File 'lib/seam/resources/event.rb', line 248 def activation_reason @activation_reason end |
#backup_access_code_id ⇒ String
ID of the backup access code that was pulled from the pool.
251 252 253 |
# File 'lib/seam/resources/event.rb', line 251 def backup_access_code_id @backup_access_code_id end |
#battery_level ⇒ Float
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
254 255 256 |
# File 'lib/seam/resources/event.rb', line 254 def battery_level @battery_level end |
#battery_status ⇒ String
Battery status of the affected device, calculated from the numeric battery_level value.
257 258 259 |
# File 'lib/seam/resources/event.rb', line 257 def battery_status @battery_status end |
#change_reason ⇒ String?
Human-readable reason for the change (e.g. ongoing code auto-renewed).
260 261 262 |
# File 'lib/seam/resources/event.rb', line 260 def change_reason @change_reason end |
#client_session_id ⇒ String
ID of the affected client session.
263 264 265 |
# File 'lib/seam/resources/event.rb', line 263 def client_session_id @client_session_id end |
#climate_preset_key ⇒ String
Key of the climate preset that was activated.
266 267 268 |
# File 'lib/seam/resources/event.rb', line 266 def climate_preset_key @climate_preset_key end |
#code ⇒ String?
268 269 270 |
# File 'lib/seam/resources/event.rb', line 268 def code @code end |
#connect_webview_id ⇒ String?
270 271 272 |
# File 'lib/seam/resources/event.rb', line 270 def connect_webview_id @connect_webview_id end |
#connected_account_custom_metadata ⇒ Hash?
272 273 274 |
# File 'lib/seam/resources/event.rb', line 272 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String?
274 275 276 |
# File 'lib/seam/resources/event.rb', line 274 def connected_account_id @connected_account_id end |
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C). See also Set Points.
277 278 279 |
# File 'lib/seam/resources/event.rb', line 277 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F). See also Set Points.
280 281 282 |
# File 'lib/seam/resources/event.rb', line 280 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#customer_key ⇒ String?
282 283 284 |
# File 'lib/seam/resources/event.rb', line 282 def customer_key @customer_key end |
#description ⇒ String
Human-readable description of the change and its source.
285 286 287 |
# File 'lib/seam/resources/event.rb', line 285 def description @description end |
#desired_temperature_celsius ⇒ Float?
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
288 289 290 |
# File 'lib/seam/resources/event.rb', line 288 def desired_temperature_celsius @desired_temperature_celsius end |
#desired_temperature_fahrenheit ⇒ Float?
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
291 292 293 |
# File 'lib/seam/resources/event.rb', line 291 def desired_temperature_fahrenheit @desired_temperature_fahrenheit end |
#device_custom_metadata ⇒ Hash?
293 294 295 |
# File 'lib/seam/resources/event.rb', line 293 def @device_custom_metadata end |
#device_id ⇒ String?
295 296 297 |
# File 'lib/seam/resources/event.rb', line 295 def device_id @device_id end |
#device_ids ⇒ Array<String>
297 298 299 |
# File 'lib/seam/resources/event.rb', line 297 def device_ids @device_ids end |
#device_name ⇒ String?
299 300 301 |
# File 'lib/seam/resources/event.rb', line 299 def device_name @device_name end |
#ends_at ⇒ String?
The new end time for the access grant.
302 303 304 |
# File 'lib/seam/resources/event.rb', line 302 def ends_at @ends_at end |
#error_code ⇒ String
Error code associated with the disconnection event, if any.
305 306 307 |
# File 'lib/seam/resources/event.rb', line 305 def error_code @error_code end |
#error_message ⇒ String
Description of why the access methods could not be created.
308 309 310 |
# File 'lib/seam/resources/event.rb', line 308 def @error_message end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
311 312 313 |
# File 'lib/seam/resources/event.rb', line 311 def event_description @event_description end |
#event_id ⇒ String?
ID of the event.
314 315 316 |
# File 'lib/seam/resources/event.rb', line 314 def event_id @event_id end |
#event_type ⇒ String?
Type of the event.
317 318 319 |
# File 'lib/seam/resources/event.rb', line 317 def event_type @event_type end |
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as on, auto, or circulate.
320 321 322 |
# File 'lib/seam/resources/event.rb', line 320 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C). See also Set Points.
323 324 325 |
# File 'lib/seam/resources/event.rb', line 323 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F). See also Set Points.
326 327 328 |
# File 'lib/seam/resources/event.rb', line 326 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
329 330 331 |
# File 'lib/seam/resources/event.rb', line 329 def hvac_mode_setting @hvac_mode_setting end |
#image_url ⇒ String?
331 332 333 |
# File 'lib/seam/resources/event.rb', line 331 def image_url @image_url end |
#is_backup_code ⇒ Boolean?
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
334 335 336 |
# File 'lib/seam/resources/event.rb', line 334 def is_backup_code @is_backup_code end |
#is_fallback_climate_preset ⇒ Boolean
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
337 338 339 |
# File 'lib/seam/resources/event.rb', line 337 def is_fallback_climate_preset @is_fallback_climate_preset end |
#is_via_bluetooth ⇒ Boolean?
339 340 341 |
# File 'lib/seam/resources/event.rb', line 339 def is_via_bluetooth @is_via_bluetooth end |
#is_via_nfc ⇒ Boolean?
341 342 343 |
# File 'lib/seam/resources/event.rb', line 341 def is_via_nfc @is_via_nfc end |
#lower_limit_celsius ⇒ Float?
Lower temperature limit, in °C, defined by the set threshold.
344 345 346 |
# File 'lib/seam/resources/event.rb', line 344 def lower_limit_celsius @lower_limit_celsius end |
#lower_limit_fahrenheit ⇒ Float?
Lower temperature limit, in °F, defined by the set threshold.
347 348 349 |
# File 'lib/seam/resources/event.rb', line 347 def lower_limit_fahrenheit @lower_limit_fahrenheit end |
#method ⇒ String
349 350 351 |
# File 'lib/seam/resources/event.rb', line 349 def method @method end |
#minut_metadata ⇒ Hash?
Metadata from Minut.
352 353 354 |
# File 'lib/seam/resources/event.rb', line 352 def @minut_metadata end |
#missing_device_ids ⇒ Array<String>
IDs of the devices that did not receive a requested access method. Use these to identify which specific devices failed without having to fetch the Access Grant.
355 356 357 |
# File 'lib/seam/resources/event.rb', line 355 def missing_device_ids @missing_device_ids end |
#motion_sub_type ⇒ String?
Sub-type of motion detected, if available.
358 359 360 |
# File 'lib/seam/resources/event.rb', line 358 def motion_sub_type @motion_sub_type end |
#noise_level_decibels ⇒ Float?
Detected noise level in decibels.
361 362 363 |
# File 'lib/seam/resources/event.rb', line 361 def noise_level_decibels @noise_level_decibels end |
#noise_level_nrs ⇒ Float?
Detected noise level in Noiseaware Noise Risk Score (NRS).
364 365 366 |
# File 'lib/seam/resources/event.rb', line 364 def noise_level_nrs @noise_level_nrs end |
#noise_threshold_id ⇒ String?
ID of the noise threshold that was triggered.
367 368 369 |
# File 'lib/seam/resources/event.rb', line 367 def noise_threshold_id @noise_threshold_id end |
#noise_threshold_name ⇒ String?
Name of the noise threshold that was triggered.
370 371 372 |
# File 'lib/seam/resources/event.rb', line 370 def noise_threshold_name @noise_threshold_name end |
#noiseaware_metadata ⇒ Hash?
Metadata from Noiseaware.
373 374 375 |
# File 'lib/seam/resources/event.rb', line 373 def @noiseaware_metadata end |
#space_id ⇒ String
ID of the affected space.
376 377 378 |
# File 'lib/seam/resources/event.rb', line 376 def space_id @space_id end |
#space_key ⇒ String?
Unique key for the space within the workspace.
379 380 381 |
# File 'lib/seam/resources/event.rb', line 379 def space_key @space_key end |
#starts_at ⇒ String?
The new start time for the access grant.
382 383 384 |
# File 'lib/seam/resources/event.rb', line 382 def starts_at @starts_at end |
#status ⇒ String
Status of the action.
385 386 387 |
# File 'lib/seam/resources/event.rb', line 385 def status @status end |
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
388 389 390 |
# File 'lib/seam/resources/event.rb', line 388 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
391 392 393 |
# File 'lib/seam/resources/event.rb', line 391 def temperature_fahrenheit @temperature_fahrenheit end |
#thermostat_schedule_id ⇒ String?
ID of the thermostat schedule that prompted the affected climate preset to be activated.
394 395 396 |
# File 'lib/seam/resources/event.rb', line 394 def thermostat_schedule_id @thermostat_schedule_id end |
#upper_limit_celsius ⇒ Float?
Upper temperature limit, in °C, defined by the set threshold.
397 398 399 |
# File 'lib/seam/resources/event.rb', line 397 def upper_limit_celsius @upper_limit_celsius end |
#upper_limit_fahrenheit ⇒ Float?
Upper temperature limit, in °F, defined by the set threshold.
400 401 402 |
# File 'lib/seam/resources/event.rb', line 400 def upper_limit_fahrenheit @upper_limit_fahrenheit end |
#video_url ⇒ String?
402 403 404 |
# File 'lib/seam/resources/event.rb', line 402 def video_url @video_url end |
#workspace_id ⇒ String?
ID of the workspace associated with the event.
405 406 407 |
# File 'lib/seam/resources/event.rb', line 405 def workspace_id @workspace_id end |
Instance Method Details
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
174 |
# File 'lib/seam/resources/event.rb', line 174 resource_list_accessor :access_code_errors, AccessCodeErrors |
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
177 |
# File 'lib/seam/resources/event.rb', line 177 resource_list_accessor :access_code_warnings, AccessCodeWarnings |
#acs_system_errors ⇒ Array<AcsSystemErrors>
Errors associated with the access control system.
180 |
# File 'lib/seam/resources/event.rb', line 180 resource_list_accessor :acs_system_errors, AcsSystemErrors |
#acs_system_warnings ⇒ Array<AcsSystemWarnings>
Warnings associated with the access control system.
183 |
# File 'lib/seam/resources/event.rb', line 183 resource_list_accessor :acs_system_warnings, AcsSystemWarnings |
#changed_properties ⇒ Array<ChangedProperties>
List of properties that changed on the access code.
186 |
# File 'lib/seam/resources/event.rb', line 186 resource_list_accessor :changed_properties, ChangedProperties |
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
189 |
# File 'lib/seam/resources/event.rb', line 189 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
192 |
# File 'lib/seam/resources/event.rb', line 192 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time?
Date and time at which the event was created.
409 |
# File 'lib/seam/resources/event.rb', line 409 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
195 |
# File 'lib/seam/resources/event.rb', line 195 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
198 |
# File 'lib/seam/resources/event.rb', line 198 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time?
Date and time at which the event occurred.
413 |
# File 'lib/seam/resources/event.rb', line 413 date_accessor :occurred_at |
#reason ⇒ Reason?
Why access was denied, when the provider reports a determinable cause. Omitted when unknown.
169 |
# File 'lib/seam/resources/event.rb', line 169 resource_accessor :reason, Reason |
#requested_mutations ⇒ Array<RequestedMutations>
Array of mutations requested on the access code, each containing the mutation type and from/to values.
201 |
# File 'lib/seam/resources/event.rb', line 201 resource_list_accessor :requested_mutations, RequestedMutations |