Class: Seam::Resources::SeamEvent
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::SeamEvent
- Defined in:
- lib/seam/resources/event.rb
Defined Under Namespace
Classes: AccessCodeErrors, AccessCodeWarnings, AcsSystemErrors, AcsSystemWarnings, ChangedProperties, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings, From, Reason, RequestedMutations, To
Instance Attribute Summary collapse
-
#access_code_id ⇒ Object
Returns the value of attribute access_code_id.
-
#access_code_is_managed ⇒ Object
Whether the access code is managed by Seam (true) or unmanaged (false).
-
#access_grant_id ⇒ Object
ID of the affected Access Grant.
-
#access_grant_ids ⇒ Object
IDs of the access grants associated with this access method.
-
#access_grant_key ⇒ Object
Key of the affected Access Grant (if present).
-
#access_grant_keys ⇒ Object
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ Object
ID of the affected access method.
-
#acs_access_group_id ⇒ Object
ID of the affected access group.
-
#acs_credential_id ⇒ Object
ID of the affected credential.
-
#acs_encoder_id ⇒ Object
ID of the affected encoder.
-
#acs_entrance_id ⇒ Object
Returns the value of attribute acs_entrance_id.
-
#acs_entrance_ids ⇒ Object
Returns the value of attribute acs_entrance_ids.
-
#acs_system_id ⇒ Object
Returns the value of attribute acs_system_id.
-
#acs_user_id ⇒ Object
Returns the value of attribute acs_user_id.
-
#action_attempt_id ⇒ Object
Returns the value of attribute action_attempt_id.
-
#action_type ⇒ Object
Type of the action.
-
#activation_reason ⇒ Object
The reason the camera was activated.
-
#backup_access_code_id ⇒ Object
ID of the backup access code that was pulled from the pool.
-
#battery_level ⇒ Object
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
-
#battery_status ⇒ Object
Battery status of the affected device, calculated from the numeric
battery_levelvalue. -
#change_reason ⇒ Object
Human-readable reason for the change (e.g.
ongoing code auto-renewed). -
#client_session_id ⇒ Object
ID of the affected client session.
-
#climate_preset_key ⇒ Object
Key of the climate preset that was activated.
-
#code ⇒ Object
Returns the value of attribute code.
-
#connect_webview_id ⇒ Object
Returns the value of attribute connect_webview_id.
-
#connected_account_custom_metadata ⇒ Object
Returns the value of attribute connected_account_custom_metadata.
-
#connected_account_id ⇒ Object
Returns the value of attribute connected_account_id.
-
#connected_account_type ⇒ Object
undocumented: Unreleased.
-
#cooling_set_point_celsius ⇒ Object
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should cool (in °F).
-
#customer_key ⇒ Object
Returns the value of attribute customer_key.
-
#description ⇒ Object
Human-readable description of the change and its source.
-
#desired_temperature_celsius ⇒ Object
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
-
#desired_temperature_fahrenheit ⇒ Object
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
-
#device_custom_metadata ⇒ Object
Returns the value of attribute device_custom_metadata.
-
#device_id ⇒ Object
Returns the value of attribute device_id.
-
#device_ids ⇒ Object
Returns the value of attribute device_ids.
-
#device_name ⇒ Object
Returns the value of attribute device_name.
-
#ends_at ⇒ Object
The new end time for the access grant.
-
#error_code ⇒ Object
Error code associated with the disconnection event, if any.
-
#error_message ⇒ Object
Description of why the access methods could not be created.
-
#event_description ⇒ Object
Human-readable description of the event.
-
#event_id ⇒ Object
ID of the event.
-
#event_type ⇒ Object
Type of the event.
-
#fan_mode_setting ⇒ Object
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Object
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ Object
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#image_url ⇒ Object
Returns the value of attribute image_url.
-
#is_backup_code ⇒ Object
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
-
#is_fallback_climate_preset ⇒ Object
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
-
#is_via_bluetooth ⇒ Object
Returns the value of attribute is_via_bluetooth.
-
#is_via_nfc ⇒ Object
Returns the value of attribute is_via_nfc.
-
#lower_limit_celsius ⇒ Object
Lower temperature limit, in °C, defined by the set threshold.
-
#lower_limit_fahrenheit ⇒ Object
Lower temperature limit, in °F, defined by the set threshold.
-
#method ⇒ Object
Returns the value of attribute method.
-
#minut_metadata ⇒ Object
Metadata from Minut.
-
#missing_device_ids ⇒ Object
IDs of the devices that did not receive a requested access method.
-
#motion_sub_type ⇒ Object
Sub-type of motion detected, if available.
-
#noise_level_decibels ⇒ Object
Detected noise level in decibels.
-
#noise_level_nrs ⇒ Object
Detected noise level in Noiseaware Noise Risk Score (NRS).
-
#noise_threshold_id ⇒ Object
ID of the noise threshold that was triggered.
-
#noise_threshold_name ⇒ Object
Name of the noise threshold that was triggered.
-
#noiseaware_metadata ⇒ Object
Metadata from Noiseaware.
-
#space_id ⇒ Object
ID of the affected space.
-
#space_key ⇒ Object
Unique key for the space within the workspace.
-
#starts_at ⇒ Object
The new start time for the access grant.
-
#status ⇒ Object
Status of the action.
-
#temperature_celsius ⇒ Object
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Object
Temperature, in °F, reported by the affected thermostat.
-
#thermostat_schedule_id ⇒ Object
ID of the thermostat schedule that prompted the affected climate preset to be activated.
-
#upper_limit_celsius ⇒ Object
Upper temperature limit, in °C, defined by the set threshold.
-
#upper_limit_fahrenheit ⇒ Object
Upper temperature limit, in °F, defined by the set threshold.
-
#user_identity_id ⇒ Object
Returns the value of attribute user_identity_id.
-
#video_url ⇒ Object
Returns the value of attribute video_url.
-
#workspace_id ⇒ Object
ID of the workspace associated with the event.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_code_id ⇒ Object
Returns the value of attribute access_code_id.
138 139 140 |
# File 'lib/seam/resources/event.rb', line 138 def access_code_id @access_code_id end |
#access_code_is_managed ⇒ Object
Whether the access code is managed by Seam (true) or unmanaged (false). Only present when access_code_id is set.
140 141 142 |
# File 'lib/seam/resources/event.rb', line 140 def access_code_is_managed @access_code_is_managed end |
#access_grant_id ⇒ Object
ID of the affected Access Grant.
142 143 144 |
# File 'lib/seam/resources/event.rb', line 142 def access_grant_id @access_grant_id end |
#access_grant_ids ⇒ Object
IDs of the access grants associated with this access method.
144 145 146 |
# File 'lib/seam/resources/event.rb', line 144 def access_grant_ids @access_grant_ids end |
#access_grant_key ⇒ Object
Key of the affected Access Grant (if present).
146 147 148 |
# File 'lib/seam/resources/event.rb', line 146 def access_grant_key @access_grant_key end |
#access_grant_keys ⇒ Object
Keys of the access grants associated with this access method (if present).
148 149 150 |
# File 'lib/seam/resources/event.rb', line 148 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ Object
ID of the affected access method.
150 151 152 |
# File 'lib/seam/resources/event.rb', line 150 def access_method_id @access_method_id end |
#acs_access_group_id ⇒ Object
ID of the affected access group.
152 153 154 |
# File 'lib/seam/resources/event.rb', line 152 def acs_access_group_id @acs_access_group_id end |
#acs_credential_id ⇒ Object
ID of the affected credential.
154 155 156 |
# File 'lib/seam/resources/event.rb', line 154 def acs_credential_id @acs_credential_id end |
#acs_encoder_id ⇒ Object
ID of the affected encoder.
156 157 158 |
# File 'lib/seam/resources/event.rb', line 156 def acs_encoder_id @acs_encoder_id end |
#acs_entrance_id ⇒ Object
Returns the value of attribute acs_entrance_id.
157 158 159 |
# File 'lib/seam/resources/event.rb', line 157 def acs_entrance_id @acs_entrance_id end |
#acs_entrance_ids ⇒ Object
Returns the value of attribute acs_entrance_ids.
158 159 160 |
# File 'lib/seam/resources/event.rb', line 158 def acs_entrance_ids @acs_entrance_ids end |
#acs_system_id ⇒ Object
Returns the value of attribute acs_system_id.
159 160 161 |
# File 'lib/seam/resources/event.rb', line 159 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ Object
Returns the value of attribute acs_user_id.
160 161 162 |
# File 'lib/seam/resources/event.rb', line 160 def acs_user_id @acs_user_id end |
#action_attempt_id ⇒ Object
Returns the value of attribute action_attempt_id.
161 162 163 |
# File 'lib/seam/resources/event.rb', line 161 def action_attempt_id @action_attempt_id end |
#action_type ⇒ Object
Type of the action.
163 164 165 |
# File 'lib/seam/resources/event.rb', line 163 def action_type @action_type end |
#activation_reason ⇒ Object
The reason the camera was activated.
165 166 167 |
# File 'lib/seam/resources/event.rb', line 165 def activation_reason @activation_reason end |
#backup_access_code_id ⇒ Object
ID of the backup access code that was pulled from the pool.
167 168 169 |
# File 'lib/seam/resources/event.rb', line 167 def backup_access_code_id @backup_access_code_id end |
#battery_level ⇒ Object
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
169 170 171 |
# File 'lib/seam/resources/event.rb', line 169 def battery_level @battery_level end |
#battery_status ⇒ Object
Battery status of the affected device, calculated from the numeric battery_level value.
171 172 173 |
# File 'lib/seam/resources/event.rb', line 171 def battery_status @battery_status end |
#change_reason ⇒ Object
Human-readable reason for the change (e.g. ongoing code auto-renewed).
173 174 175 |
# File 'lib/seam/resources/event.rb', line 173 def change_reason @change_reason end |
#client_session_id ⇒ Object
ID of the affected client session.
175 176 177 |
# File 'lib/seam/resources/event.rb', line 175 def client_session_id @client_session_id end |
#climate_preset_key ⇒ Object
Key of the climate preset that was activated.
177 178 179 |
# File 'lib/seam/resources/event.rb', line 177 def climate_preset_key @climate_preset_key end |
#code ⇒ Object
Returns the value of attribute code.
178 179 180 |
# File 'lib/seam/resources/event.rb', line 178 def code @code end |
#connect_webview_id ⇒ Object
Returns the value of attribute connect_webview_id.
179 180 181 |
# File 'lib/seam/resources/event.rb', line 179 def connect_webview_id @connect_webview_id end |
#connected_account_custom_metadata ⇒ Object
Returns the value of attribute connected_account_custom_metadata.
180 181 182 |
# File 'lib/seam/resources/event.rb', line 180 def @connected_account_custom_metadata end |
#connected_account_id ⇒ Object
Returns the value of attribute connected_account_id.
181 182 183 |
# File 'lib/seam/resources/event.rb', line 181 def connected_account_id @connected_account_id end |
#connected_account_type ⇒ Object
undocumented: Unreleased.
183 184 185 |
# File 'lib/seam/resources/event.rb', line 183 def connected_account_type @connected_account_type end |
#cooling_set_point_celsius ⇒ Object
Temperature to which the thermostat should cool (in °C). See also Set Points.
185 186 187 |
# File 'lib/seam/resources/event.rb', line 185 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should cool (in °F). See also Set Points.
187 188 189 |
# File 'lib/seam/resources/event.rb', line 187 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#customer_key ⇒ Object
Returns the value of attribute customer_key.
188 189 190 |
# File 'lib/seam/resources/event.rb', line 188 def customer_key @customer_key end |
#description ⇒ Object
Human-readable description of the change and its source.
190 191 192 |
# File 'lib/seam/resources/event.rb', line 190 def description @description end |
#desired_temperature_celsius ⇒ Object
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
192 193 194 |
# File 'lib/seam/resources/event.rb', line 192 def desired_temperature_celsius @desired_temperature_celsius end |
#desired_temperature_fahrenheit ⇒ Object
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
194 195 196 |
# File 'lib/seam/resources/event.rb', line 194 def desired_temperature_fahrenheit @desired_temperature_fahrenheit end |
#device_custom_metadata ⇒ Object
Returns the value of attribute device_custom_metadata.
195 196 197 |
# File 'lib/seam/resources/event.rb', line 195 def @device_custom_metadata end |
#device_id ⇒ Object
Returns the value of attribute device_id.
196 197 198 |
# File 'lib/seam/resources/event.rb', line 196 def device_id @device_id end |
#device_ids ⇒ Object
Returns the value of attribute device_ids.
197 198 199 |
# File 'lib/seam/resources/event.rb', line 197 def device_ids @device_ids end |
#device_name ⇒ Object
Returns the value of attribute device_name.
198 199 200 |
# File 'lib/seam/resources/event.rb', line 198 def device_name @device_name end |
#ends_at ⇒ Object
The new end time for the access grant.
200 201 202 |
# File 'lib/seam/resources/event.rb', line 200 def ends_at @ends_at end |
#error_code ⇒ Object
Error code associated with the disconnection event, if any.
202 203 204 |
# File 'lib/seam/resources/event.rb', line 202 def error_code @error_code end |
#error_message ⇒ Object
Description of why the access methods could not be created.
204 205 206 |
# File 'lib/seam/resources/event.rb', line 204 def @error_message end |
#event_description ⇒ Object
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
206 207 208 |
# File 'lib/seam/resources/event.rb', line 206 def event_description @event_description end |
#event_id ⇒ Object
ID of the event.
208 209 210 |
# File 'lib/seam/resources/event.rb', line 208 def event_id @event_id end |
#event_type ⇒ Object
Type of the event.
210 211 212 |
# File 'lib/seam/resources/event.rb', line 210 def event_type @event_type end |
#fan_mode_setting ⇒ Object
Desired fan mode setting, such as on, auto, or circulate.
212 213 214 |
# File 'lib/seam/resources/event.rb', line 212 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Object
Temperature to which the thermostat should heat (in °C). See also Set Points.
214 215 216 |
# File 'lib/seam/resources/event.rb', line 214 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should heat (in °F). See also Set Points.
216 217 218 |
# File 'lib/seam/resources/event.rb', line 216 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ Object
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
218 219 220 |
# File 'lib/seam/resources/event.rb', line 218 def hvac_mode_setting @hvac_mode_setting end |
#image_url ⇒ Object
Returns the value of attribute image_url.
219 220 221 |
# File 'lib/seam/resources/event.rb', line 219 def image_url @image_url end |
#is_backup_code ⇒ Object
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
221 222 223 |
# File 'lib/seam/resources/event.rb', line 221 def is_backup_code @is_backup_code end |
#is_fallback_climate_preset ⇒ Object
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
223 224 225 |
# File 'lib/seam/resources/event.rb', line 223 def is_fallback_climate_preset @is_fallback_climate_preset end |
#is_via_bluetooth ⇒ Object
Returns the value of attribute is_via_bluetooth.
224 225 226 |
# File 'lib/seam/resources/event.rb', line 224 def is_via_bluetooth @is_via_bluetooth end |
#is_via_nfc ⇒ Object
Returns the value of attribute is_via_nfc.
225 226 227 |
# File 'lib/seam/resources/event.rb', line 225 def is_via_nfc @is_via_nfc end |
#lower_limit_celsius ⇒ Object
Lower temperature limit, in °C, defined by the set threshold.
227 228 229 |
# File 'lib/seam/resources/event.rb', line 227 def lower_limit_celsius @lower_limit_celsius end |
#lower_limit_fahrenheit ⇒ Object
Lower temperature limit, in °F, defined by the set threshold.
229 230 231 |
# File 'lib/seam/resources/event.rb', line 229 def lower_limit_fahrenheit @lower_limit_fahrenheit end |
#method ⇒ Object
Returns the value of attribute method.
230 231 232 |
# File 'lib/seam/resources/event.rb', line 230 def method @method end |
#minut_metadata ⇒ Object
Metadata from Minut.
232 233 234 |
# File 'lib/seam/resources/event.rb', line 232 def @minut_metadata end |
#missing_device_ids ⇒ Object
IDs of the devices that did not receive a requested access method. Use these to identify which specific devices failed without having to fetch the Access Grant.
234 235 236 |
# File 'lib/seam/resources/event.rb', line 234 def missing_device_ids @missing_device_ids end |
#motion_sub_type ⇒ Object
Sub-type of motion detected, if available.
236 237 238 |
# File 'lib/seam/resources/event.rb', line 236 def motion_sub_type @motion_sub_type end |
#noise_level_decibels ⇒ Object
Detected noise level in decibels.
238 239 240 |
# File 'lib/seam/resources/event.rb', line 238 def noise_level_decibels @noise_level_decibels end |
#noise_level_nrs ⇒ Object
Detected noise level in Noiseaware Noise Risk Score (NRS).
240 241 242 |
# File 'lib/seam/resources/event.rb', line 240 def noise_level_nrs @noise_level_nrs end |
#noise_threshold_id ⇒ Object
ID of the noise threshold that was triggered.
242 243 244 |
# File 'lib/seam/resources/event.rb', line 242 def noise_threshold_id @noise_threshold_id end |
#noise_threshold_name ⇒ Object
Name of the noise threshold that was triggered.
244 245 246 |
# File 'lib/seam/resources/event.rb', line 244 def noise_threshold_name @noise_threshold_name end |
#noiseaware_metadata ⇒ Object
Metadata from Noiseaware.
246 247 248 |
# File 'lib/seam/resources/event.rb', line 246 def @noiseaware_metadata end |
#space_id ⇒ Object
ID of the affected space.
248 249 250 |
# File 'lib/seam/resources/event.rb', line 248 def space_id @space_id end |
#space_key ⇒ Object
Unique key for the space within the workspace.
250 251 252 |
# File 'lib/seam/resources/event.rb', line 250 def space_key @space_key end |
#starts_at ⇒ Object
The new start time for the access grant.
252 253 254 |
# File 'lib/seam/resources/event.rb', line 252 def starts_at @starts_at end |
#status ⇒ Object
Status of the action.
254 255 256 |
# File 'lib/seam/resources/event.rb', line 254 def status @status end |
#temperature_celsius ⇒ Object
Temperature, in °C, reported by the affected thermostat.
256 257 258 |
# File 'lib/seam/resources/event.rb', line 256 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Object
Temperature, in °F, reported by the affected thermostat.
258 259 260 |
# File 'lib/seam/resources/event.rb', line 258 def temperature_fahrenheit @temperature_fahrenheit end |
#thermostat_schedule_id ⇒ Object
ID of the thermostat schedule that prompted the affected climate preset to be activated.
260 261 262 |
# File 'lib/seam/resources/event.rb', line 260 def thermostat_schedule_id @thermostat_schedule_id end |
#upper_limit_celsius ⇒ Object
Upper temperature limit, in °C, defined by the set threshold.
262 263 264 |
# File 'lib/seam/resources/event.rb', line 262 def upper_limit_celsius @upper_limit_celsius end |
#upper_limit_fahrenheit ⇒ Object
Upper temperature limit, in °F, defined by the set threshold.
264 265 266 |
# File 'lib/seam/resources/event.rb', line 264 def upper_limit_fahrenheit @upper_limit_fahrenheit end |
#user_identity_id ⇒ Object
Returns the value of attribute user_identity_id.
265 266 267 |
# File 'lib/seam/resources/event.rb', line 265 def user_identity_id @user_identity_id end |
#video_url ⇒ Object
Returns the value of attribute video_url.
266 267 268 |
# File 'lib/seam/resources/event.rb', line 266 def video_url @video_url end |
#workspace_id ⇒ Object
ID of the workspace associated with the event.
268 269 270 |
# File 'lib/seam/resources/event.rb', line 268 def workspace_id @workspace_id end |