Class: Seam::Resources::SeamEvent
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::SeamEvent
- Defined in:
- lib/seam/resources/event.rb
Instance Attribute Summary collapse
-
#access_code_errors ⇒ Object
Errors associated with the access code.
-
#access_code_id ⇒ Object
ID of the affected access code.
-
#access_code_is_managed ⇒ Object
Whether the access code is managed by Seam (true) or unmanaged (false).
-
#access_code_warnings ⇒ Object
Warnings associated with the access code.
-
#access_grant_id ⇒ Object
ID of the affected Access Grant.
-
#access_grant_ids ⇒ Object
IDs of the access grants associated with this access method.
-
#access_grant_key ⇒ Object
Key of the affected Access Grant (if present).
-
#access_grant_keys ⇒ Object
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ Object
ID of the affected access method.
-
#acs_access_group_id ⇒ Object
ID of the affected access group.
-
#acs_credential_id ⇒ Object
ID of the affected credential.
-
#acs_encoder_id ⇒ Object
ID of the affected encoder.
-
#acs_entrance_id ⇒ Object
ID of the affected entrance.
-
#acs_entrance_ids ⇒ Object
IDs of all ACS entrances currently attached to the space.
-
#acs_system_errors ⇒ Object
Errors associated with the access control system.
-
#acs_system_id ⇒ Object
ID of the access system.
-
#acs_system_warnings ⇒ Object
Warnings associated with the access control system.
-
#acs_user_id ⇒ Object
ID of the affected access system user.
-
#action_attempt_id ⇒ Object
ID of the affected action attempt.
-
#action_type ⇒ Object
Type of the action.
-
#activation_reason ⇒ Object
The reason the camera was activated.
-
#backup_access_code_id ⇒ Object
ID of the backup access code that was pulled from the pool.
-
#battery_level ⇒ Object
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
-
#battery_status ⇒ Object
Battery status of the affected device, calculated from the numeric
battery_levelvalue. -
#change_reason ⇒ Object
Human-readable reason for the change (e.g.
ongoing code auto-renewed). -
#changed_properties ⇒ Object
List of properties that changed on the access code.
-
#client_session_id ⇒ Object
ID of the affected client session.
-
#climate_preset_key ⇒ Object
Key of the climate preset that was activated.
-
#code ⇒ Object
Code for the affected access code.
-
#connect_webview_id ⇒ Object
ID of the Connect Webview associated with the event.
-
#connected_account_custom_metadata ⇒ Object
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_errors ⇒ Object
Errors associated with the connected account.
-
#connected_account_id ⇒ Object
ID of the connected account associated with the affected access code.
-
#connected_account_type ⇒ Object
undocumented: Unreleased.
-
#connected_account_warnings ⇒ Object
Warnings associated with the connected account.
-
#cooling_set_point_celsius ⇒ Object
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should cool (in °F).
-
#customer_key ⇒ Object
The customer key associated with this connected account, if any.
-
#description ⇒ Object
Human-readable description of the change and its source.
-
#desired_temperature_celsius ⇒ Object
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
-
#desired_temperature_fahrenheit ⇒ Object
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
-
#device_custom_metadata ⇒ Object
Custom metadata of the device, present when device_id is provided.
-
#device_errors ⇒ Object
Errors associated with the device.
-
#device_id ⇒ Object
ID of the device associated with the affected access code.
-
#device_ids ⇒ Object
IDs of all devices currently attached to the space.
-
#device_name ⇒ Object
Name of the deleted device, captured at deletion time.
-
#device_warnings ⇒ Object
Warnings associated with the device.
-
#ends_at ⇒ Object
The new end time for the access grant.
-
#error_code ⇒ Object
Error code associated with the disconnection event, if any.
-
#error_message ⇒ Object
Description of why the access methods could not be created.
-
#event_description ⇒ Object
Human-readable description of the event.
-
#event_id ⇒ Object
ID of the event.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#fan_mode_setting ⇒ Object
Desired fan mode setting, such as
on,auto, orcirculate. -
#from ⇒ Object
Previous access code name configuration.
-
#heating_set_point_celsius ⇒ Object
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ Object
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#image_url ⇒ Object
URL to a thumbnail image captured at the time of activation.
-
#is_backup_code ⇒ Object
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
-
#is_fallback_climate_preset ⇒ Object
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
-
#is_via_bluetooth ⇒ Object
Whether the lock action was performed over Bluetooth by a remote client (such as the provider's mobile app), rather than a direct physical interaction or a Seam-initiated remote action.
-
#is_via_nfc ⇒ Object
Whether the lock action was performed by an NFC credential tap (such as an Apple Home Key or an NFC key fob) presented to the lock, rather than a direct physical interaction or a Seam-initiated remote action.
-
#lower_limit_celsius ⇒ Object
Lower temperature limit, in °C, defined by the set threshold.
-
#lower_limit_fahrenheit ⇒ Object
Lower temperature limit, in °F, defined by the set threshold.
-
#method ⇒ Object
Method by which the lock was locked.
-
#minut_metadata ⇒ Object
Metadata from Minut.
-
#missing_device_ids ⇒ Object
IDs of the devices that did not receive a requested access method.
-
#motion_sub_type ⇒ Object
Sub-type of motion detected, if available.
-
#noise_level_decibels ⇒ Object
Detected noise level in decibels.
-
#noise_level_nrs ⇒ Object
Detected noise level in Noiseaware Noise Risk Score (NRS).
-
#noise_threshold_id ⇒ Object
ID of the noise threshold that was triggered.
-
#noise_threshold_name ⇒ Object
Name of the noise threshold that was triggered.
-
#noiseaware_metadata ⇒ Object
Metadata from Noiseaware.
-
#reason ⇒ Object
Why access was denied, when the provider reports a determinable cause.
-
#requested_mutations ⇒ Object
Array of mutations requested on the access code, each containing the mutation type and from/to values.
-
#space_id ⇒ Object
ID of the affected space.
-
#space_key ⇒ Object
Unique key for the space within the workspace.
-
#starts_at ⇒ Object
The new start time for the access grant.
-
#status ⇒ Object
Status of the action.
-
#temperature_celsius ⇒ Object
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Object
Temperature, in °F, reported by the affected thermostat.
-
#thermostat_schedule_id ⇒ Object
ID of the thermostat schedule that prompted the affected climate preset to be activated.
-
#to ⇒ Object
New access code name configuration.
-
#upper_limit_celsius ⇒ Object
Upper temperature limit, in °C, defined by the set threshold.
-
#upper_limit_fahrenheit ⇒ Object
Upper temperature limit, in °F, defined by the set threshold.
-
#user_identity_id ⇒ Object
undocumented: Unreleased.
-
#video_url ⇒ Object
URL to a short video clip captured at the time of activation.
-
#workspace_id ⇒ Object
ID of the workspace associated with the event.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_code_errors ⇒ Object
Errors associated with the access code.
7 8 9 |
# File 'lib/seam/resources/event.rb', line 7 def access_code_errors @access_code_errors end |
#access_code_id ⇒ Object
ID of the affected access code.
9 10 11 |
# File 'lib/seam/resources/event.rb', line 9 def access_code_id @access_code_id end |
#access_code_is_managed ⇒ Object
Whether the access code is managed by Seam (true) or unmanaged (false). Only present when access_code_id is set.
11 12 13 |
# File 'lib/seam/resources/event.rb', line 11 def access_code_is_managed @access_code_is_managed end |
#access_code_warnings ⇒ Object
Warnings associated with the access code.
13 14 15 |
# File 'lib/seam/resources/event.rb', line 13 def access_code_warnings @access_code_warnings end |
#access_grant_id ⇒ Object
ID of the affected Access Grant.
15 16 17 |
# File 'lib/seam/resources/event.rb', line 15 def access_grant_id @access_grant_id end |
#access_grant_ids ⇒ Object
IDs of the access grants associated with this access method.
17 18 19 |
# File 'lib/seam/resources/event.rb', line 17 def access_grant_ids @access_grant_ids end |
#access_grant_key ⇒ Object
Key of the affected Access Grant (if present).
19 20 21 |
# File 'lib/seam/resources/event.rb', line 19 def access_grant_key @access_grant_key end |
#access_grant_keys ⇒ Object
Keys of the access grants associated with this access method (if present).
21 22 23 |
# File 'lib/seam/resources/event.rb', line 21 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ Object
ID of the affected access method.
23 24 25 |
# File 'lib/seam/resources/event.rb', line 23 def access_method_id @access_method_id end |
#acs_access_group_id ⇒ Object
ID of the affected access group.
25 26 27 |
# File 'lib/seam/resources/event.rb', line 25 def acs_access_group_id @acs_access_group_id end |
#acs_credential_id ⇒ Object
ID of the affected credential.
27 28 29 |
# File 'lib/seam/resources/event.rb', line 27 def acs_credential_id @acs_credential_id end |
#acs_encoder_id ⇒ Object
ID of the affected encoder.
29 30 31 |
# File 'lib/seam/resources/event.rb', line 29 def acs_encoder_id @acs_encoder_id end |
#acs_entrance_id ⇒ Object
ID of the affected entrance.
31 32 33 |
# File 'lib/seam/resources/event.rb', line 31 def acs_entrance_id @acs_entrance_id end |
#acs_entrance_ids ⇒ Object
IDs of all ACS entrances currently attached to the space.
33 34 35 |
# File 'lib/seam/resources/event.rb', line 33 def acs_entrance_ids @acs_entrance_ids end |
#acs_system_errors ⇒ Object
Errors associated with the access control system.
35 36 37 |
# File 'lib/seam/resources/event.rb', line 35 def acs_system_errors @acs_system_errors end |
#acs_system_id ⇒ Object
ID of the access system.
37 38 39 |
# File 'lib/seam/resources/event.rb', line 37 def acs_system_id @acs_system_id end |
#acs_system_warnings ⇒ Object
Warnings associated with the access control system.
39 40 41 |
# File 'lib/seam/resources/event.rb', line 39 def acs_system_warnings @acs_system_warnings end |
#acs_user_id ⇒ Object
ID of the affected access system user.
41 42 43 |
# File 'lib/seam/resources/event.rb', line 41 def acs_user_id @acs_user_id end |
#action_attempt_id ⇒ Object
ID of the affected action attempt.
43 44 45 |
# File 'lib/seam/resources/event.rb', line 43 def action_attempt_id @action_attempt_id end |
#action_type ⇒ Object
Type of the action.
45 46 47 |
# File 'lib/seam/resources/event.rb', line 45 def action_type @action_type end |
#activation_reason ⇒ Object
The reason the camera was activated.
47 48 49 |
# File 'lib/seam/resources/event.rb', line 47 def activation_reason @activation_reason end |
#backup_access_code_id ⇒ Object
ID of the backup access code that was pulled from the pool.
49 50 51 |
# File 'lib/seam/resources/event.rb', line 49 def backup_access_code_id @backup_access_code_id end |
#battery_level ⇒ Object
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
51 52 53 |
# File 'lib/seam/resources/event.rb', line 51 def battery_level @battery_level end |
#battery_status ⇒ Object
Battery status of the affected device, calculated from the numeric battery_level value.
53 54 55 |
# File 'lib/seam/resources/event.rb', line 53 def battery_status @battery_status end |
#change_reason ⇒ Object
Human-readable reason for the change (e.g. ongoing code auto-renewed).
55 56 57 |
# File 'lib/seam/resources/event.rb', line 55 def change_reason @change_reason end |
#changed_properties ⇒ Object
List of properties that changed on the access code.
57 58 59 |
# File 'lib/seam/resources/event.rb', line 57 def changed_properties @changed_properties end |
#client_session_id ⇒ Object
ID of the affected client session.
59 60 61 |
# File 'lib/seam/resources/event.rb', line 59 def client_session_id @client_session_id end |
#climate_preset_key ⇒ Object
Key of the climate preset that was activated.
61 62 63 |
# File 'lib/seam/resources/event.rb', line 61 def climate_preset_key @climate_preset_key end |
#code ⇒ Object
Code for the affected access code.
63 64 65 |
# File 'lib/seam/resources/event.rb', line 63 def code @code end |
#connect_webview_id ⇒ Object
ID of the Connect Webview associated with the event.
65 66 67 |
# File 'lib/seam/resources/event.rb', line 65 def connect_webview_id @connect_webview_id end |
#connected_account_custom_metadata ⇒ Object
Custom metadata of the connected account, present when connected_account_id is provided.
67 68 69 |
# File 'lib/seam/resources/event.rb', line 67 def @connected_account_custom_metadata end |
#connected_account_errors ⇒ Object
Errors associated with the connected account.
69 70 71 |
# File 'lib/seam/resources/event.rb', line 69 def connected_account_errors @connected_account_errors end |
#connected_account_id ⇒ Object
ID of the connected account associated with the affected access code.
71 72 73 |
# File 'lib/seam/resources/event.rb', line 71 def connected_account_id @connected_account_id end |
#connected_account_type ⇒ Object
undocumented: Unreleased.
73 74 75 |
# File 'lib/seam/resources/event.rb', line 73 def connected_account_type @connected_account_type end |
#connected_account_warnings ⇒ Object
Warnings associated with the connected account.
75 76 77 |
# File 'lib/seam/resources/event.rb', line 75 def connected_account_warnings @connected_account_warnings end |
#cooling_set_point_celsius ⇒ Object
Temperature to which the thermostat should cool (in °C). See also Set Points.
77 78 79 |
# File 'lib/seam/resources/event.rb', line 77 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should cool (in °F). See also Set Points.
79 80 81 |
# File 'lib/seam/resources/event.rb', line 79 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#customer_key ⇒ Object
The customer key associated with this connected account, if any.
81 82 83 |
# File 'lib/seam/resources/event.rb', line 81 def customer_key @customer_key end |
#description ⇒ Object
Human-readable description of the change and its source.
83 84 85 |
# File 'lib/seam/resources/event.rb', line 83 def description @description end |
#desired_temperature_celsius ⇒ Object
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
85 86 87 |
# File 'lib/seam/resources/event.rb', line 85 def desired_temperature_celsius @desired_temperature_celsius end |
#desired_temperature_fahrenheit ⇒ Object
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
87 88 89 |
# File 'lib/seam/resources/event.rb', line 87 def desired_temperature_fahrenheit @desired_temperature_fahrenheit end |
#device_custom_metadata ⇒ Object
Custom metadata of the device, present when device_id is provided.
89 90 91 |
# File 'lib/seam/resources/event.rb', line 89 def @device_custom_metadata end |
#device_errors ⇒ Object
Errors associated with the device.
91 92 93 |
# File 'lib/seam/resources/event.rb', line 91 def device_errors @device_errors end |
#device_id ⇒ Object
ID of the device associated with the affected access code.
93 94 95 |
# File 'lib/seam/resources/event.rb', line 93 def device_id @device_id end |
#device_ids ⇒ Object
IDs of all devices currently attached to the space.
95 96 97 |
# File 'lib/seam/resources/event.rb', line 95 def device_ids @device_ids end |
#device_name ⇒ Object
Name of the deleted device, captured at deletion time. The device record no longer exists when this event fires, so the name is preserved here. Null when the device had no resolvable name.
97 98 99 |
# File 'lib/seam/resources/event.rb', line 97 def device_name @device_name end |
#device_warnings ⇒ Object
Warnings associated with the device.
99 100 101 |
# File 'lib/seam/resources/event.rb', line 99 def device_warnings @device_warnings end |
#ends_at ⇒ Object
The new end time for the access grant.
101 102 103 |
# File 'lib/seam/resources/event.rb', line 101 def ends_at @ends_at end |
#error_code ⇒ Object
Error code associated with the disconnection event, if any.
103 104 105 |
# File 'lib/seam/resources/event.rb', line 103 def error_code @error_code end |
#error_message ⇒ Object
Description of why the access methods could not be created.
105 106 107 |
# File 'lib/seam/resources/event.rb', line 105 def @error_message end |
#event_description ⇒ Object
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
107 108 109 |
# File 'lib/seam/resources/event.rb', line 107 def event_description @event_description end |
#event_id ⇒ Object
ID of the event.
109 110 111 |
# File 'lib/seam/resources/event.rb', line 109 def event_id @event_id end |
#event_type ⇒ Object
Returns the value of attribute event_type.
110 111 112 |
# File 'lib/seam/resources/event.rb', line 110 def event_type @event_type end |
#fan_mode_setting ⇒ Object
Desired fan mode setting, such as on, auto, or circulate.
112 113 114 |
# File 'lib/seam/resources/event.rb', line 112 def fan_mode_setting @fan_mode_setting end |
#from ⇒ Object
Previous access code name configuration.
114 115 116 |
# File 'lib/seam/resources/event.rb', line 114 def from @from end |
#heating_set_point_celsius ⇒ Object
Temperature to which the thermostat should heat (in °C). See also Set Points.
116 117 118 |
# File 'lib/seam/resources/event.rb', line 116 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Object
Temperature to which the thermostat should heat (in °F). See also Set Points.
118 119 120 |
# File 'lib/seam/resources/event.rb', line 118 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ Object
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
120 121 122 |
# File 'lib/seam/resources/event.rb', line 120 def hvac_mode_setting @hvac_mode_setting end |
#image_url ⇒ Object
URL to a thumbnail image captured at the time of activation.
122 123 124 |
# File 'lib/seam/resources/event.rb', line 122 def image_url @image_url end |
#is_backup_code ⇒ Object
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
124 125 126 |
# File 'lib/seam/resources/event.rb', line 124 def is_backup_code @is_backup_code end |
#is_fallback_climate_preset ⇒ Object
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
126 127 128 |
# File 'lib/seam/resources/event.rb', line 126 def is_fallback_climate_preset @is_fallback_climate_preset end |
#is_via_bluetooth ⇒ Object
Whether the lock action was performed over Bluetooth by a remote client (such as the provider's mobile app), rather than a direct physical interaction or a Seam-initiated remote action.
128 129 130 |
# File 'lib/seam/resources/event.rb', line 128 def is_via_bluetooth @is_via_bluetooth end |
#is_via_nfc ⇒ Object
Whether the lock action was performed by an NFC credential tap (such as an Apple Home Key or an NFC key fob) presented to the lock, rather than a direct physical interaction or a Seam-initiated remote action.
130 131 132 |
# File 'lib/seam/resources/event.rb', line 130 def is_via_nfc @is_via_nfc end |
#lower_limit_celsius ⇒ Object
Lower temperature limit, in °C, defined by the set threshold.
132 133 134 |
# File 'lib/seam/resources/event.rb', line 132 def lower_limit_celsius @lower_limit_celsius end |
#lower_limit_fahrenheit ⇒ Object
Lower temperature limit, in °F, defined by the set threshold.
134 135 136 |
# File 'lib/seam/resources/event.rb', line 134 def lower_limit_fahrenheit @lower_limit_fahrenheit end |
#method ⇒ Object
Method by which the lock was locked. keycode: an access code was used (see access_code_id). manual: a physical action such as a thumbturn or button press. remote: a remote action via an app, Bluetooth, or the Seam API (see action_attempt_id if Seam-initiated; see is_via_bluetooth or is_via_nfc for the transport). automatic: triggered automatically, for example by an auto-relock timer. unknown: could not be determined.
136 137 138 |
# File 'lib/seam/resources/event.rb', line 136 def method @method end |
#minut_metadata ⇒ Object
Metadata from Minut.
138 139 140 |
# File 'lib/seam/resources/event.rb', line 138 def @minut_metadata end |
#missing_device_ids ⇒ Object
IDs of the devices that did not receive a requested access method. Use these to identify which specific devices failed without having to fetch the Access Grant.
140 141 142 |
# File 'lib/seam/resources/event.rb', line 140 def missing_device_ids @missing_device_ids end |
#motion_sub_type ⇒ Object
Sub-type of motion detected, if available.
142 143 144 |
# File 'lib/seam/resources/event.rb', line 142 def motion_sub_type @motion_sub_type end |
#noise_level_decibels ⇒ Object
Detected noise level in decibels.
144 145 146 |
# File 'lib/seam/resources/event.rb', line 144 def noise_level_decibels @noise_level_decibels end |
#noise_level_nrs ⇒ Object
Detected noise level in Noiseaware Noise Risk Score (NRS).
146 147 148 |
# File 'lib/seam/resources/event.rb', line 146 def noise_level_nrs @noise_level_nrs end |
#noise_threshold_id ⇒ Object
ID of the noise threshold that was triggered.
148 149 150 |
# File 'lib/seam/resources/event.rb', line 148 def noise_threshold_id @noise_threshold_id end |
#noise_threshold_name ⇒ Object
Name of the noise threshold that was triggered.
150 151 152 |
# File 'lib/seam/resources/event.rb', line 150 def noise_threshold_name @noise_threshold_name end |
#noiseaware_metadata ⇒ Object
Metadata from Noiseaware.
152 153 154 |
# File 'lib/seam/resources/event.rb', line 152 def @noiseaware_metadata end |
#reason ⇒ Object
Why access was denied, when the provider reports a determinable cause. Omitted when unknown.
154 155 156 |
# File 'lib/seam/resources/event.rb', line 154 def reason @reason end |
#requested_mutations ⇒ Object
Array of mutations requested on the access code, each containing the mutation type and from/to values.
156 157 158 |
# File 'lib/seam/resources/event.rb', line 156 def requested_mutations @requested_mutations end |
#space_id ⇒ Object
ID of the affected space.
158 159 160 |
# File 'lib/seam/resources/event.rb', line 158 def space_id @space_id end |
#space_key ⇒ Object
Unique key for the space within the workspace.
160 161 162 |
# File 'lib/seam/resources/event.rb', line 160 def space_key @space_key end |
#starts_at ⇒ Object
The new start time for the access grant.
162 163 164 |
# File 'lib/seam/resources/event.rb', line 162 def starts_at @starts_at end |
#status ⇒ Object
Status of the action.
164 165 166 |
# File 'lib/seam/resources/event.rb', line 164 def status @status end |
#temperature_celsius ⇒ Object
Temperature, in °C, reported by the affected thermostat.
166 167 168 |
# File 'lib/seam/resources/event.rb', line 166 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Object
Temperature, in °F, reported by the affected thermostat.
168 169 170 |
# File 'lib/seam/resources/event.rb', line 168 def temperature_fahrenheit @temperature_fahrenheit end |
#thermostat_schedule_id ⇒ Object
ID of the thermostat schedule that prompted the affected climate preset to be activated.
170 171 172 |
# File 'lib/seam/resources/event.rb', line 170 def thermostat_schedule_id @thermostat_schedule_id end |
#to ⇒ Object
New access code name configuration.
172 173 174 |
# File 'lib/seam/resources/event.rb', line 172 def to @to end |
#upper_limit_celsius ⇒ Object
Upper temperature limit, in °C, defined by the set threshold.
174 175 176 |
# File 'lib/seam/resources/event.rb', line 174 def upper_limit_celsius @upper_limit_celsius end |
#upper_limit_fahrenheit ⇒ Object
Upper temperature limit, in °F, defined by the set threshold.
176 177 178 |
# File 'lib/seam/resources/event.rb', line 176 def upper_limit_fahrenheit @upper_limit_fahrenheit end |
#user_identity_id ⇒ Object
undocumented: Unreleased. --- ID of the user identity associated with the lock event.
180 181 182 |
# File 'lib/seam/resources/event.rb', line 180 def user_identity_id @user_identity_id end |
#video_url ⇒ Object
URL to a short video clip captured at the time of activation.
182 183 184 |
# File 'lib/seam/resources/event.rb', line 182 def video_url @video_url end |
#workspace_id ⇒ Object
ID of the workspace associated with the event.
184 185 186 |
# File 'lib/seam/resources/event.rb', line 184 def workspace_id @workspace_id end |