Class: Seam::Resources::SeamEvent::AccessCodeBackupAccessCodePulled
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeBackupAccessCodePulled
- Defined in:
- lib/seam/resources/event.rb
Overview
A backup access code was pulled from the backup access code pool and set on a device.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#backup_access_code_id ⇒ String
ID of the backup access code that was pulled from the pool.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.backup_access_code_pulled. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
1097 1098 1099 |
# File 'lib/seam/resources/event.rb', line 1097 def access_code_id @access_code_id end |
#backup_access_code_id ⇒ String
ID of the backup access code that was pulled from the pool.
1100 1101 1102 |
# File 'lib/seam/resources/event.rb', line 1100 def backup_access_code_id @backup_access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
1103 1104 1105 |
# File 'lib/seam/resources/event.rb', line 1103 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
1106 1107 1108 |
# File 'lib/seam/resources/event.rb', line 1106 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
1109 1110 1111 |
# File 'lib/seam/resources/event.rb', line 1109 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
1112 1113 1114 |
# File 'lib/seam/resources/event.rb', line 1112 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1115 1116 1117 |
# File 'lib/seam/resources/event.rb', line 1115 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1118 1119 1120 |
# File 'lib/seam/resources/event.rb', line 1118 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.backup_access_code_pulled
1122 1123 1124 |
# File 'lib/seam/resources/event.rb', line 1122 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1125 1126 1127 |
# File 'lib/seam/resources/event.rb', line 1125 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1128 |
# File 'lib/seam/resources/event.rb', line 1128 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1131 |
# File 'lib/seam/resources/event.rb', line 1131 date_accessor :occurred_at |