Class: Seam::Resources::SeamEvent::AccessCodeChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An access code was changed.

Defined Under Namespace

Classes: ChangedProperties

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString

ID of the affected access code.

Returns:

  • (String)


64
65
66
# File 'lib/seam/resources/event.rb', line 64

def access_code_id
  @access_code_id
end

#change_reasonString?

Human-readable reason for the change (e.g. ongoing code auto-renewed).

Returns:

  • (String, nil)


67
68
69
# File 'lib/seam/resources/event.rb', line 67

def change_reason
  @change_reason
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


70
71
72
# File 'lib/seam/resources/event.rb', line 70

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the affected access code.

Returns:

  • (String)


73
74
75
# File 'lib/seam/resources/event.rb', line 73

def 
  @connected_account_id
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


76
77
78
# File 'lib/seam/resources/event.rb', line 76

def 
  @device_custom_metadata
end

#device_idString

ID of the device associated with the affected access code.

Returns:

  • (String)


79
80
81
# File 'lib/seam/resources/event.rb', line 79

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


82
83
84
# File 'lib/seam/resources/event.rb', line 82

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


85
86
87
# File 'lib/seam/resources/event.rb', line 85

def event_id
  @event_id
end

#event_typeString

Known values:

  • access_code.changed

Returns:

  • (String)


89
90
91
# File 'lib/seam/resources/event.rb', line 89

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


92
93
94
# File 'lib/seam/resources/event.rb', line 92

def workspace_id
  @workspace_id
end

Instance Method Details

#changed_propertiesArray<ChangedProperties>

List of properties that changed on the access code.

Returns:



61
# File 'lib/seam/resources/event.rb', line 61

resource_list_accessor :changed_properties, ChangedProperties

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


95
# File 'lib/seam/resources/event.rb', line 95

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


98
# File 'lib/seam/resources/event.rb', line 98

date_accessor :occurred_at