Class: Seam::Resources::SeamEvent::AccessCodeCodeChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeCodeChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
The pin code of an access code was changed on the device.
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#description ⇒ String
Human-readable description of the change and its source.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.code_changed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#from ⇒ From
Previous pin code configuration.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
-
#to ⇒ To
New pin code configuration.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
182 183 184 |
# File 'lib/seam/resources/event.rb', line 182 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
185 186 187 |
# File 'lib/seam/resources/event.rb', line 185 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
188 189 190 |
# File 'lib/seam/resources/event.rb', line 188 def connected_account_id @connected_account_id end |
#description ⇒ String
Human-readable description of the change and its source.
191 192 193 |
# File 'lib/seam/resources/event.rb', line 191 def description @description end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
194 195 196 |
# File 'lib/seam/resources/event.rb', line 194 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
197 198 199 |
# File 'lib/seam/resources/event.rb', line 197 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
200 201 202 |
# File 'lib/seam/resources/event.rb', line 200 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
203 204 205 |
# File 'lib/seam/resources/event.rb', line 203 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.code_changed
207 208 209 |
# File 'lib/seam/resources/event.rb', line 207 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
210 211 212 |
# File 'lib/seam/resources/event.rb', line 210 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
213 |
# File 'lib/seam/resources/event.rb', line 213 date_accessor :created_at |
#from ⇒ From
Previous pin code configuration.
176 |
# File 'lib/seam/resources/event.rb', line 176 resource_accessor :from, From |
#occurred_at ⇒ Time
Date and time at which the event occurred.
216 |
# File 'lib/seam/resources/event.rb', line 216 date_accessor :occurred_at |