Class: Seam::Resources::SeamEvent::AccessCodeCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
An access code was created.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.created. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
11 12 13 |
# File 'lib/seam/resources/event.rb', line 11 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
14 15 16 |
# File 'lib/seam/resources/event.rb', line 14 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
17 18 19 |
# File 'lib/seam/resources/event.rb', line 17 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
20 21 22 |
# File 'lib/seam/resources/event.rb', line 20 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
23 24 25 |
# File 'lib/seam/resources/event.rb', line 23 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
26 27 28 |
# File 'lib/seam/resources/event.rb', line 26 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
29 30 31 |
# File 'lib/seam/resources/event.rb', line 29 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.created
33 34 35 |
# File 'lib/seam/resources/event.rb', line 33 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
36 37 38 |
# File 'lib/seam/resources/event.rb', line 36 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
39 |
# File 'lib/seam/resources/event.rb', line 39 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
42 |
# File 'lib/seam/resources/event.rb', line 42 date_accessor :occurred_at |