Class: Seam::Resources::SeamEvent::AccessCodeDelayInRemovingFromDevice
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeDelayInRemovingFromDevice
- Defined in:
- lib/seam/resources/event.rb
Overview
There was an unusually long delay in removing an access code from a device.
Defined Under Namespace
Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.delay_in_removing_from_device. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
-
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
855 856 857 |
# File 'lib/seam/resources/event.rb', line 855 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
858 859 860 |
# File 'lib/seam/resources/event.rb', line 858 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
861 862 863 |
# File 'lib/seam/resources/event.rb', line 861 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
864 865 866 |
# File 'lib/seam/resources/event.rb', line 864 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
867 868 869 |
# File 'lib/seam/resources/event.rb', line 867 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
870 871 872 |
# File 'lib/seam/resources/event.rb', line 870 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
873 874 875 |
# File 'lib/seam/resources/event.rb', line 873 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.delay_in_removing_from_device
877 878 879 |
# File 'lib/seam/resources/event.rb', line 877 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
880 881 882 |
# File 'lib/seam/resources/event.rb', line 880 def workspace_id @workspace_id end |
Instance Method Details
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
837 |
# File 'lib/seam/resources/event.rb', line 837 resource_list_accessor :access_code_errors, AccessCodeErrors |
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
840 |
# File 'lib/seam/resources/event.rb', line 840 resource_list_accessor :access_code_warnings, AccessCodeWarnings |
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
843 |
# File 'lib/seam/resources/event.rb', line 843 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
846 |
# File 'lib/seam/resources/event.rb', line 846 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
883 |
# File 'lib/seam/resources/event.rb', line 883 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
849 |
# File 'lib/seam/resources/event.rb', line 849 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
852 |
# File 'lib/seam/resources/event.rb', line 852 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
886 |
# File 'lib/seam/resources/event.rb', line 886 date_accessor :occurred_at |