Class: Seam::Resources::SeamEvent::AccessCodeDeletedExternalToSeam
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeDeletedExternalToSeam
- Defined in:
- lib/seam/resources/event.rb
Overview
An access code was deleted outside of Seam.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.deleted_external_to_seam. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
1059 1060 1061 |
# File 'lib/seam/resources/event.rb', line 1059 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
1062 1063 1064 |
# File 'lib/seam/resources/event.rb', line 1062 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
1065 1066 1067 |
# File 'lib/seam/resources/event.rb', line 1065 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
1068 1069 1070 |
# File 'lib/seam/resources/event.rb', line 1068 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
1071 1072 1073 |
# File 'lib/seam/resources/event.rb', line 1071 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1074 1075 1076 |
# File 'lib/seam/resources/event.rb', line 1074 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1077 1078 1079 |
# File 'lib/seam/resources/event.rb', line 1077 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.deleted_external_to_seam
1081 1082 1083 |
# File 'lib/seam/resources/event.rb', line 1081 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1084 1085 1086 |
# File 'lib/seam/resources/event.rb', line 1084 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1087 |
# File 'lib/seam/resources/event.rb', line 1087 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1090 |
# File 'lib/seam/resources/event.rb', line 1090 date_accessor :occurred_at |