Class: Seam::Resources::SeamEvent::AccessCodeFailedToRemoveFromDevice
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeFailedToRemoveFromDevice
- Defined in:
- lib/seam/resources/event.rb
Overview
An access code failed to be removed from a device.
Defined Under Namespace
Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.failed_to_remove_from_device. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
-
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
983 984 985 |
# File 'lib/seam/resources/event.rb', line 983 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
986 987 988 |
# File 'lib/seam/resources/event.rb', line 986 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
989 990 991 |
# File 'lib/seam/resources/event.rb', line 989 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
992 993 994 |
# File 'lib/seam/resources/event.rb', line 992 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
995 996 997 |
# File 'lib/seam/resources/event.rb', line 995 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
998 999 1000 |
# File 'lib/seam/resources/event.rb', line 998 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1001 1002 1003 |
# File 'lib/seam/resources/event.rb', line 1001 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.failed_to_remove_from_device
1005 1006 1007 |
# File 'lib/seam/resources/event.rb', line 1005 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1008 1009 1010 |
# File 'lib/seam/resources/event.rb', line 1008 def workspace_id @workspace_id end |
Instance Method Details
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
965 |
# File 'lib/seam/resources/event.rb', line 965 resource_list_accessor :access_code_errors, AccessCodeErrors |
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
968 |
# File 'lib/seam/resources/event.rb', line 968 resource_list_accessor :access_code_warnings, AccessCodeWarnings |
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
971 |
# File 'lib/seam/resources/event.rb', line 971 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
974 |
# File 'lib/seam/resources/event.rb', line 974 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
1011 |
# File 'lib/seam/resources/event.rb', line 1011 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
977 |
# File 'lib/seam/resources/event.rb', line 977 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
980 |
# File 'lib/seam/resources/event.rb', line 980 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1014 |
# File 'lib/seam/resources/event.rb', line 1014 date_accessor :occurred_at |