Class: Seam::Resources::SeamEvent::AccessCodeModifiedExternalToSeam
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeModifiedExternalToSeam
- Defined in:
- lib/seam/resources/event.rb
Overview
An access code was modified outside of Seam.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.modified_external_to_seam. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
1021 1022 1023 |
# File 'lib/seam/resources/event.rb', line 1021 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
1024 1025 1026 |
# File 'lib/seam/resources/event.rb', line 1024 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
1027 1028 1029 |
# File 'lib/seam/resources/event.rb', line 1027 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
1030 1031 1032 |
# File 'lib/seam/resources/event.rb', line 1030 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
1033 1034 1035 |
# File 'lib/seam/resources/event.rb', line 1033 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1036 1037 1038 |
# File 'lib/seam/resources/event.rb', line 1036 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1039 1040 1041 |
# File 'lib/seam/resources/event.rb', line 1039 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.modified_external_to_seam
1043 1044 1045 |
# File 'lib/seam/resources/event.rb', line 1043 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1046 1047 1048 |
# File 'lib/seam/resources/event.rb', line 1046 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1049 |
# File 'lib/seam/resources/event.rb', line 1049 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1052 |
# File 'lib/seam/resources/event.rb', line 1052 date_accessor :occurred_at |