Class: Seam::Resources::SeamEvent::AccessCodeMutationsRequested
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeMutationsRequested
- Defined in:
- lib/seam/resources/event.rb
Overview
Mutations were requested on an access code. This event fires at request time, before the change is confirmed on the device.
Defined Under Namespace
Classes: RequestedMutations
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.mutations_requested. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
-
#requested_mutations ⇒ Array<RequestedMutations>
Array of mutations requested on the access code, each containing the mutation type and from/to values.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
310 311 312 |
# File 'lib/seam/resources/event.rb', line 310 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
313 314 315 |
# File 'lib/seam/resources/event.rb', line 313 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
316 317 318 |
# File 'lib/seam/resources/event.rb', line 316 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
319 320 321 |
# File 'lib/seam/resources/event.rb', line 319 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
322 323 324 |
# File 'lib/seam/resources/event.rb', line 322 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
325 326 327 |
# File 'lib/seam/resources/event.rb', line 325 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
328 329 330 |
# File 'lib/seam/resources/event.rb', line 328 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.mutations_requested
332 333 334 |
# File 'lib/seam/resources/event.rb', line 332 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
335 336 337 |
# File 'lib/seam/resources/event.rb', line 335 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
338 |
# File 'lib/seam/resources/event.rb', line 338 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
341 |
# File 'lib/seam/resources/event.rb', line 341 date_accessor :occurred_at |
#requested_mutations ⇒ Array<RequestedMutations>
Array of mutations requested on the access code, each containing the mutation type and from/to values.
307 |
# File 'lib/seam/resources/event.rb', line 307 resource_list_accessor :requested_mutations, RequestedMutations |