Class: Seam::Resources::SeamEvent::AccessCodeNameChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeNameChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
The name of an access code was changed on the device.
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#description ⇒ String
Human-readable description of the change and its source.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.name_changed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#from ⇒ From
Previous access code name configuration.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
-
#to ⇒ To
New access code name configuration.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
123 124 125 |
# File 'lib/seam/resources/event.rb', line 123 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
126 127 128 |
# File 'lib/seam/resources/event.rb', line 126 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
129 130 131 |
# File 'lib/seam/resources/event.rb', line 129 def connected_account_id @connected_account_id end |
#description ⇒ String
Human-readable description of the change and its source.
132 133 134 |
# File 'lib/seam/resources/event.rb', line 132 def description @description end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
135 136 137 |
# File 'lib/seam/resources/event.rb', line 135 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
138 139 140 |
# File 'lib/seam/resources/event.rb', line 138 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
141 142 143 |
# File 'lib/seam/resources/event.rb', line 141 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
144 145 146 |
# File 'lib/seam/resources/event.rb', line 144 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.name_changed
148 149 150 |
# File 'lib/seam/resources/event.rb', line 148 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
151 152 153 |
# File 'lib/seam/resources/event.rb', line 151 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
154 |
# File 'lib/seam/resources/event.rb', line 154 date_accessor :created_at |
#from ⇒ From
Previous access code name configuration.
117 |
# File 'lib/seam/resources/event.rb', line 117 resource_accessor :from, From |
#occurred_at ⇒ Time
Date and time at which the event occurred.
157 |
# File 'lib/seam/resources/event.rb', line 157 date_accessor :occurred_at |