Class: Seam::Resources::SeamEvent::AccessCodeRemovedFromDevice
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeRemovedFromDevice
- Defined in:
- lib/seam/resources/event.rb
Overview
An access code was removed from a device.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.removed_from_device. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
430 431 432 |
# File 'lib/seam/resources/event.rb', line 430 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
433 434 435 |
# File 'lib/seam/resources/event.rb', line 433 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
436 437 438 |
# File 'lib/seam/resources/event.rb', line 436 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
439 440 441 |
# File 'lib/seam/resources/event.rb', line 439 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
442 443 444 |
# File 'lib/seam/resources/event.rb', line 442 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
445 446 447 |
# File 'lib/seam/resources/event.rb', line 445 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
448 449 450 |
# File 'lib/seam/resources/event.rb', line 448 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.removed_from_device
452 453 454 |
# File 'lib/seam/resources/event.rb', line 452 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
455 456 457 |
# File 'lib/seam/resources/event.rb', line 455 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
458 |
# File 'lib/seam/resources/event.rb', line 458 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
461 |
# File 'lib/seam/resources/event.rb', line 461 date_accessor :occurred_at |