Class: Seam::Resources::SeamEvent::AccessCodeTimeFrameChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeTimeFrameChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
The time frame of an access code was changed on the device.
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#description ⇒ String
Human-readable description of the change and its source.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.time_frame_changed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#from ⇒ From
Previous time frame configuration.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
-
#to ⇒ To
New time frame configuration.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
247 248 249 |
# File 'lib/seam/resources/event.rb', line 247 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
250 251 252 |
# File 'lib/seam/resources/event.rb', line 250 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
253 254 255 |
# File 'lib/seam/resources/event.rb', line 253 def connected_account_id @connected_account_id end |
#description ⇒ String
Human-readable description of the change and its source.
256 257 258 |
# File 'lib/seam/resources/event.rb', line 256 def description @description end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
259 260 261 |
# File 'lib/seam/resources/event.rb', line 259 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
262 263 264 |
# File 'lib/seam/resources/event.rb', line 262 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
265 266 267 |
# File 'lib/seam/resources/event.rb', line 265 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
268 269 270 |
# File 'lib/seam/resources/event.rb', line 268 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.time_frame_changed
272 273 274 |
# File 'lib/seam/resources/event.rb', line 272 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
275 276 277 |
# File 'lib/seam/resources/event.rb', line 275 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
278 |
# File 'lib/seam/resources/event.rb', line 278 date_accessor :created_at |
#from ⇒ From
Previous time frame configuration.
241 |
# File 'lib/seam/resources/event.rb', line 241 resource_accessor :from, From |
#occurred_at ⇒ Time
Date and time at which the event occurred.
281 |
# File 'lib/seam/resources/event.rb', line 281 date_accessor :occurred_at |