Class: Seam::Resources::SeamEvent::AccessCodeUnmanagedFailedToConvertToManaged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeUnmanagedFailedToConvertToManaged
- Defined in:
- lib/seam/resources/event.rb
Overview
An unmanaged access code failed to be converted to a managed access code.
Defined Under Namespace
Classes: AccessCodeErrors, AccessCodeWarnings, ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.unmanaged.failed_to_convert_to_managed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
-
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
1266 1267 1268 |
# File 'lib/seam/resources/event.rb', line 1266 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
1269 1270 1271 |
# File 'lib/seam/resources/event.rb', line 1269 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
1272 1273 1274 |
# File 'lib/seam/resources/event.rb', line 1272 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
1275 1276 1277 |
# File 'lib/seam/resources/event.rb', line 1275 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
1278 1279 1280 |
# File 'lib/seam/resources/event.rb', line 1278 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1281 1282 1283 |
# File 'lib/seam/resources/event.rb', line 1281 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1284 1285 1286 |
# File 'lib/seam/resources/event.rb', line 1284 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.unmanaged.failed_to_convert_to_managed
1288 1289 1290 |
# File 'lib/seam/resources/event.rb', line 1288 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1291 1292 1293 |
# File 'lib/seam/resources/event.rb', line 1291 def workspace_id @workspace_id end |
Instance Method Details
#access_code_errors ⇒ Array<AccessCodeErrors>
Errors associated with the access code.
1248 |
# File 'lib/seam/resources/event.rb', line 1248 resource_list_accessor :access_code_errors, AccessCodeErrors |
#access_code_warnings ⇒ Array<AccessCodeWarnings>
Warnings associated with the access code.
1251 |
# File 'lib/seam/resources/event.rb', line 1251 resource_list_accessor :access_code_warnings, AccessCodeWarnings |
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
1254 |
# File 'lib/seam/resources/event.rb', line 1254 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
1257 |
# File 'lib/seam/resources/event.rb', line 1257 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
1294 |
# File 'lib/seam/resources/event.rb', line 1294 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
1260 |
# File 'lib/seam/resources/event.rb', line 1260 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
1263 |
# File 'lib/seam/resources/event.rb', line 1263 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1297 |
# File 'lib/seam/resources/event.rb', line 1297 date_accessor :occurred_at |