Class: Seam::Resources::SeamEvent::AccessCodeUnmanagedRemoved
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessCodeUnmanagedRemoved
- Defined in:
- lib/seam/resources/event.rb
Overview
An unmanaged access code was removed from a device.
Instance Attribute Summary collapse
-
#access_code_id ⇒ String
ID of the affected access code.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the device associated with the affected access code.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_code.unmanaged.removed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_code_id ⇒ String
ID of the affected access code.
1342 1343 1344 |
# File 'lib/seam/resources/event.rb', line 1342 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
1345 1346 1347 |
# File 'lib/seam/resources/event.rb', line 1345 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the affected access code.
1348 1349 1350 |
# File 'lib/seam/resources/event.rb', line 1348 def connected_account_id @connected_account_id end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
1351 1352 1353 |
# File 'lib/seam/resources/event.rb', line 1351 def @device_custom_metadata end |
#device_id ⇒ String
ID of the device associated with the affected access code.
1354 1355 1356 |
# File 'lib/seam/resources/event.rb', line 1354 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1357 1358 1359 |
# File 'lib/seam/resources/event.rb', line 1357 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1360 1361 1362 |
# File 'lib/seam/resources/event.rb', line 1360 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_code.unmanaged.removed
1364 1365 1366 |
# File 'lib/seam/resources/event.rb', line 1364 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1367 1368 1369 |
# File 'lib/seam/resources/event.rb', line 1367 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1370 |
# File 'lib/seam/resources/event.rb', line 1370 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1373 |
# File 'lib/seam/resources/event.rb', line 1373 date_accessor :occurred_at |