Class: Seam::Resources::SeamEvent::AccessGrantAccessGrantedToDoor
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessGrantAccessGrantedToDoor
- Defined in:
- lib/seam/resources/event.rb
Overview
Access requested as part of an Access Grant to a particular door was successfully granted.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#acs_entrance_id ⇒ String
ID of the affected entrance.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_grant.access_granted_to_door. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_id ⇒ String
ID of the affected Access Grant.
1458 1459 1460 |
# File 'lib/seam/resources/event.rb', line 1458 def access_grant_id @access_grant_id end |
#acs_entrance_id ⇒ String
ID of the affected entrance.
1461 1462 1463 |
# File 'lib/seam/resources/event.rb', line 1461 def acs_entrance_id @acs_entrance_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1464 1465 1466 |
# File 'lib/seam/resources/event.rb', line 1464 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1467 1468 1469 |
# File 'lib/seam/resources/event.rb', line 1467 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_grant.access_granted_to_door
1471 1472 1473 |
# File 'lib/seam/resources/event.rb', line 1471 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1474 1475 1476 |
# File 'lib/seam/resources/event.rb', line 1474 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1477 |
# File 'lib/seam/resources/event.rb', line 1477 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1480 |
# File 'lib/seam/resources/event.rb', line 1480 date_accessor :occurred_at |