Class: Seam::Resources::SeamEvent::AccessGrantAccessTimesChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessGrantAccessTimesChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
An Access Grant's start or end time was changed.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#access_grant_key ⇒ String?
Key of the affected Access Grant (if present).
-
#ends_at ⇒ String?
The new end time for the access grant.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_grant.access_times_changed. -
#starts_at ⇒ String?
The new start time for the access grant.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_id ⇒ String
ID of the affected Access Grant.
1516 1517 1518 |
# File 'lib/seam/resources/event.rb', line 1516 def access_grant_id @access_grant_id end |
#access_grant_key ⇒ String?
Key of the affected Access Grant (if present).
1519 1520 1521 |
# File 'lib/seam/resources/event.rb', line 1519 def access_grant_key @access_grant_key end |
#ends_at ⇒ String?
The new end time for the access grant.
1522 1523 1524 |
# File 'lib/seam/resources/event.rb', line 1522 def ends_at @ends_at end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1525 1526 1527 |
# File 'lib/seam/resources/event.rb', line 1525 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1528 1529 1530 |
# File 'lib/seam/resources/event.rb', line 1528 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_grant.access_times_changed
1532 1533 1534 |
# File 'lib/seam/resources/event.rb', line 1532 def event_type @event_type end |
#starts_at ⇒ String?
The new start time for the access grant.
1535 1536 1537 |
# File 'lib/seam/resources/event.rb', line 1535 def starts_at @starts_at end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1538 1539 1540 |
# File 'lib/seam/resources/event.rb', line 1538 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1541 |
# File 'lib/seam/resources/event.rb', line 1541 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1544 |
# File 'lib/seam/resources/event.rb', line 1544 date_accessor :occurred_at |