Class: Seam::Resources::SeamEvent::AccessGrantAccessToDoorLost
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessGrantAccessToDoorLost
- Defined in:
- lib/seam/resources/event.rb
Overview
Access to a particular door that was requested as part of an Access Grant was lost.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#acs_entrance_id ⇒ String
ID of the affected entrance.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_grant.access_to_door_lost. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_id ⇒ String
ID of the affected Access Grant.
1487 1488 1489 |
# File 'lib/seam/resources/event.rb', line 1487 def access_grant_id @access_grant_id end |
#acs_entrance_id ⇒ String
ID of the affected entrance.
1490 1491 1492 |
# File 'lib/seam/resources/event.rb', line 1490 def acs_entrance_id @acs_entrance_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1493 1494 1495 |
# File 'lib/seam/resources/event.rb', line 1493 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1496 1497 1498 |
# File 'lib/seam/resources/event.rb', line 1496 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_grant.access_to_door_lost
1500 1501 1502 |
# File 'lib/seam/resources/event.rb', line 1500 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1503 1504 1505 |
# File 'lib/seam/resources/event.rb', line 1503 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1506 |
# File 'lib/seam/resources/event.rb', line 1506 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1509 |
# File 'lib/seam/resources/event.rb', line 1509 date_accessor :occurred_at |