Class: Seam::Resources::SeamEvent::AccessGrantCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessGrantCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
An Access Grant was created.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_grant.created. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_id ⇒ String
ID of the affected Access Grant.
1380 1381 1382 |
# File 'lib/seam/resources/event.rb', line 1380 def access_grant_id @access_grant_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1383 1384 1385 |
# File 'lib/seam/resources/event.rb', line 1383 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1386 1387 1388 |
# File 'lib/seam/resources/event.rb', line 1386 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_grant.created
1390 1391 1392 |
# File 'lib/seam/resources/event.rb', line 1390 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1393 1394 1395 |
# File 'lib/seam/resources/event.rb', line 1393 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1396 |
# File 'lib/seam/resources/event.rb', line 1396 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1399 |
# File 'lib/seam/resources/event.rb', line 1399 date_accessor :occurred_at |