Class: Seam::Resources::SeamEvent::AccessGrantDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessGrantDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
An Access Grant was deleted.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the affected Access Grant.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_grant.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_id ⇒ String
ID of the affected Access Grant.
1406 1407 1408 |
# File 'lib/seam/resources/event.rb', line 1406 def access_grant_id @access_grant_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1409 1410 1411 |
# File 'lib/seam/resources/event.rb', line 1409 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1412 1413 1414 |
# File 'lib/seam/resources/event.rb', line 1412 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_grant.deleted
1416 1417 1418 |
# File 'lib/seam/resources/event.rb', line 1416 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1419 1420 1421 |
# File 'lib/seam/resources/event.rb', line 1419 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1422 |
# File 'lib/seam/resources/event.rb', line 1422 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1425 |
# File 'lib/seam/resources/event.rb', line 1425 date_accessor :occurred_at |