Class: Seam::Resources::SeamEvent::AccessMethodCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessMethodCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
An access method was created.
Instance Attribute Summary collapse
-
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
-
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ String
ID of the affected access method.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_method.created. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
1755 1756 1757 |
# File 'lib/seam/resources/event.rb', line 1755 def access_grant_ids @access_grant_ids end |
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
1758 1759 1760 |
# File 'lib/seam/resources/event.rb', line 1758 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ String
ID of the affected access method.
1761 1762 1763 |
# File 'lib/seam/resources/event.rb', line 1761 def access_method_id @access_method_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1764 1765 1766 |
# File 'lib/seam/resources/event.rb', line 1764 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1767 1768 1769 |
# File 'lib/seam/resources/event.rb', line 1767 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_method.created
1771 1772 1773 |
# File 'lib/seam/resources/event.rb', line 1771 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1774 1775 1776 |
# File 'lib/seam/resources/event.rb', line 1774 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1777 |
# File 'lib/seam/resources/event.rb', line 1777 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1780 |
# File 'lib/seam/resources/event.rb', line 1780 date_accessor :occurred_at |