Class: Seam::Resources::SeamEvent::AccessMethodReissued
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessMethodReissued
- Defined in:
- lib/seam/resources/event.rb
Overview
An access method was reissued.
Instance Attribute Summary collapse
-
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
-
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ String
ID of the affected access method.
-
#code ⇒ String?
The actual PIN code for code access methods (only present when mode is 'code').
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_method.reissued. -
#is_backup_code ⇒ Boolean?
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
1717 1718 1719 |
# File 'lib/seam/resources/event.rb', line 1717 def access_grant_ids @access_grant_ids end |
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
1720 1721 1722 |
# File 'lib/seam/resources/event.rb', line 1720 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ String
ID of the affected access method.
1723 1724 1725 |
# File 'lib/seam/resources/event.rb', line 1723 def access_method_id @access_method_id end |
#code ⇒ String?
The actual PIN code for code access methods (only present when mode is 'code').
1726 1727 1728 |
# File 'lib/seam/resources/event.rb', line 1726 def code @code end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1729 1730 1731 |
# File 'lib/seam/resources/event.rb', line 1729 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1732 1733 1734 |
# File 'lib/seam/resources/event.rb', line 1732 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_method.reissued
1736 1737 1738 |
# File 'lib/seam/resources/event.rb', line 1736 def event_type @event_type end |
#is_backup_code ⇒ Boolean?
Indicates whether the code is a backup code (only present when mode is 'code' and a backup code was used).
1739 1740 1741 |
# File 'lib/seam/resources/event.rb', line 1739 def is_backup_code @is_backup_code end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1742 1743 1744 |
# File 'lib/seam/resources/event.rb', line 1742 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1745 |
# File 'lib/seam/resources/event.rb', line 1745 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1748 |
# File 'lib/seam/resources/event.rb', line 1748 date_accessor :occurred_at |