Class: Seam::Resources::SeamEvent::AccessMethodRevoked
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AccessMethodRevoked
- Defined in:
- lib/seam/resources/event.rb
Overview
An access method was revoked.
Instance Attribute Summary collapse
-
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
-
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
-
#access_method_id ⇒ String
ID of the affected access method.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
access_method.revoked. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#access_grant_ids ⇒ Array<String>
IDs of the access grants associated with this access method.
1621 1622 1623 |
# File 'lib/seam/resources/event.rb', line 1621 def access_grant_ids @access_grant_ids end |
#access_grant_keys ⇒ Array<String>
Keys of the access grants associated with this access method (if present).
1624 1625 1626 |
# File 'lib/seam/resources/event.rb', line 1624 def access_grant_keys @access_grant_keys end |
#access_method_id ⇒ String
ID of the affected access method.
1627 1628 1629 |
# File 'lib/seam/resources/event.rb', line 1627 def access_method_id @access_method_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1630 1631 1632 |
# File 'lib/seam/resources/event.rb', line 1630 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1633 1634 1635 |
# File 'lib/seam/resources/event.rb', line 1633 def event_id @event_id end |
#event_type ⇒ String
Known values:
access_method.revoked
1637 1638 1639 |
# File 'lib/seam/resources/event.rb', line 1637 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1640 1641 1642 |
# File 'lib/seam/resources/event.rb', line 1640 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1643 |
# File 'lib/seam/resources/event.rb', line 1643 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1646 |
# File 'lib/seam/resources/event.rb', line 1646 date_accessor :occurred_at |