Class: Seam::Resources::SeamEvent::AcsAccessGroupDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsAccessGroupDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
An ACS access group was deleted.
Instance Attribute Summary collapse
-
#acs_access_group_id ⇒ String
ID of the affected access group.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_access_group.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_access_group_id ⇒ String
ID of the affected access group.
2254 2255 2256 |
# File 'lib/seam/resources/event.rb', line 2254 def acs_access_group_id @acs_access_group_id end |
#acs_system_id ⇒ String
ID of the access system.
2257 2258 2259 |
# File 'lib/seam/resources/event.rb', line 2257 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2260 2261 2262 |
# File 'lib/seam/resources/event.rb', line 2260 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2263 2264 2265 |
# File 'lib/seam/resources/event.rb', line 2263 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2266 2267 2268 |
# File 'lib/seam/resources/event.rb', line 2266 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_access_group.deleted
2270 2271 2272 |
# File 'lib/seam/resources/event.rb', line 2270 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2273 2274 2275 |
# File 'lib/seam/resources/event.rb', line 2273 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2276 |
# File 'lib/seam/resources/event.rb', line 2276 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2279 |
# File 'lib/seam/resources/event.rb', line 2279 date_accessor :occurred_at |