Class: Seam::Resources::SeamEvent::AcsCredentialDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsCredentialDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system credential was deleted.
Instance Attribute Summary collapse
-
#acs_credential_id ⇒ String
ID of the affected credential.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_credential.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_credential_id ⇒ String
ID of the affected credential.
1998 1999 2000 |
# File 'lib/seam/resources/event.rb', line 1998 def acs_credential_id @acs_credential_id end |
#acs_system_id ⇒ String
ID of the access system.
2001 2002 2003 |
# File 'lib/seam/resources/event.rb', line 2001 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2004 2005 2006 |
# File 'lib/seam/resources/event.rb', line 2004 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2007 2008 2009 |
# File 'lib/seam/resources/event.rb', line 2007 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2010 2011 2012 |
# File 'lib/seam/resources/event.rb', line 2010 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_credential.deleted
2014 2015 2016 |
# File 'lib/seam/resources/event.rb', line 2014 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2017 2018 2019 |
# File 'lib/seam/resources/event.rb', line 2017 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2020 |
# File 'lib/seam/resources/event.rb', line 2020 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2023 |
# File 'lib/seam/resources/event.rb', line 2023 date_accessor :occurred_at |