Class: Seam::Resources::SeamEvent::AcsCredentialReissued
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsCredentialReissued
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system credential was reissued.
Instance Attribute Summary collapse
-
#acs_credential_id ⇒ String
ID of the affected credential.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_credential.reissued. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_credential_id ⇒ String
ID of the affected credential.
2062 2063 2064 |
# File 'lib/seam/resources/event.rb', line 2062 def acs_credential_id @acs_credential_id end |
#acs_system_id ⇒ String
ID of the access system.
2065 2066 2067 |
# File 'lib/seam/resources/event.rb', line 2065 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2068 2069 2070 |
# File 'lib/seam/resources/event.rb', line 2068 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2071 2072 2073 |
# File 'lib/seam/resources/event.rb', line 2071 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2074 2075 2076 |
# File 'lib/seam/resources/event.rb', line 2074 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_credential.reissued
2078 2079 2080 |
# File 'lib/seam/resources/event.rb', line 2078 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2081 2082 2083 |
# File 'lib/seam/resources/event.rb', line 2081 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2084 |
# File 'lib/seam/resources/event.rb', line 2084 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2087 |
# File 'lib/seam/resources/event.rb', line 2087 date_accessor :occurred_at |