Class: Seam::Resources::SeamEvent::AcsEncoderAdded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsEncoderAdded
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system encoder was added.
Instance Attribute Summary collapse
-
#acs_encoder_id ⇒ String
ID of the affected encoder.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_encoder.added. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_encoder_id ⇒ String
ID of the affected encoder.
2190 2191 2192 |
# File 'lib/seam/resources/event.rb', line 2190 def acs_encoder_id @acs_encoder_id end |
#acs_system_id ⇒ String
ID of the access system.
2193 2194 2195 |
# File 'lib/seam/resources/event.rb', line 2193 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2196 2197 2198 |
# File 'lib/seam/resources/event.rb', line 2196 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2199 2200 2201 |
# File 'lib/seam/resources/event.rb', line 2199 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2202 2203 2204 |
# File 'lib/seam/resources/event.rb', line 2202 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_encoder.added
2206 2207 2208 |
# File 'lib/seam/resources/event.rb', line 2206 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2209 2210 2211 |
# File 'lib/seam/resources/event.rb', line 2209 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2212 |
# File 'lib/seam/resources/event.rb', line 2212 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2215 |
# File 'lib/seam/resources/event.rb', line 2215 date_accessor :occurred_at |