Class: Seam::Resources::SeamEvent::AcsEncoderRemoved
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsEncoderRemoved
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system encoder was removed.
Instance Attribute Summary collapse
-
#acs_encoder_id ⇒ String
ID of the affected encoder.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_encoder.removed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_encoder_id ⇒ String
ID of the affected encoder.
2222 2223 2224 |
# File 'lib/seam/resources/event.rb', line 2222 def acs_encoder_id @acs_encoder_id end |
#acs_system_id ⇒ String
ID of the access system.
2225 2226 2227 |
# File 'lib/seam/resources/event.rb', line 2225 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2228 2229 2230 |
# File 'lib/seam/resources/event.rb', line 2228 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2231 2232 2233 |
# File 'lib/seam/resources/event.rb', line 2231 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2234 2235 2236 |
# File 'lib/seam/resources/event.rb', line 2234 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_encoder.removed
2238 2239 2240 |
# File 'lib/seam/resources/event.rb', line 2238 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2241 2242 2243 |
# File 'lib/seam/resources/event.rb', line 2241 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2244 |
# File 'lib/seam/resources/event.rb', line 2244 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2247 |
# File 'lib/seam/resources/event.rb', line 2247 date_accessor :occurred_at |