Class: Seam::Resources::SeamEvent::AcsEntranceAdded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsEntranceAdded
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system entrance was added.
Instance Attribute Summary collapse
-
#acs_entrance_id ⇒ String
ID of the affected entrance.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_entrance.added. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_entrance_id ⇒ String
ID of the affected entrance.
2286 2287 2288 |
# File 'lib/seam/resources/event.rb', line 2286 def acs_entrance_id @acs_entrance_id end |
#acs_system_id ⇒ String
ID of the access system.
2289 2290 2291 |
# File 'lib/seam/resources/event.rb', line 2289 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2292 2293 2294 |
# File 'lib/seam/resources/event.rb', line 2292 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2295 2296 2297 |
# File 'lib/seam/resources/event.rb', line 2295 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2298 2299 2300 |
# File 'lib/seam/resources/event.rb', line 2298 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_entrance.added
2302 2303 2304 |
# File 'lib/seam/resources/event.rb', line 2302 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2305 2306 2307 |
# File 'lib/seam/resources/event.rb', line 2305 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2308 |
# File 'lib/seam/resources/event.rb', line 2308 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2311 |
# File 'lib/seam/resources/event.rb', line 2311 date_accessor :occurred_at |