Class: Seam::Resources::SeamEvent::AcsEntranceRemoved
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsEntranceRemoved
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system entrance was removed.
Instance Attribute Summary collapse
-
#acs_entrance_id ⇒ String
ID of the affected entrance.
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_entrance.removed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_entrance_id ⇒ String
ID of the affected entrance.
2318 2319 2320 |
# File 'lib/seam/resources/event.rb', line 2318 def acs_entrance_id @acs_entrance_id end |
#acs_system_id ⇒ String
ID of the access system.
2321 2322 2323 |
# File 'lib/seam/resources/event.rb', line 2321 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2324 2325 2326 |
# File 'lib/seam/resources/event.rb', line 2324 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2327 2328 2329 |
# File 'lib/seam/resources/event.rb', line 2327 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2330 2331 2332 |
# File 'lib/seam/resources/event.rb', line 2330 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_entrance.removed
2334 2335 2336 |
# File 'lib/seam/resources/event.rb', line 2334 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2337 2338 2339 |
# File 'lib/seam/resources/event.rb', line 2337 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2340 |
# File 'lib/seam/resources/event.rb', line 2340 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2343 |
# File 'lib/seam/resources/event.rb', line 2343 date_accessor :occurred_at |