Class: Seam::Resources::SeamEvent::AcsSystemConnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsSystemConnected
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system was connected.
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_system.connected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system.
1851 1852 1853 |
# File 'lib/seam/resources/event.rb', line 1851 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
1854 1855 1856 |
# File 'lib/seam/resources/event.rb', line 1854 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1857 1858 1859 |
# File 'lib/seam/resources/event.rb', line 1857 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1860 1861 1862 |
# File 'lib/seam/resources/event.rb', line 1860 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_system.connected
1864 1865 1866 |
# File 'lib/seam/resources/event.rb', line 1864 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1867 1868 1869 |
# File 'lib/seam/resources/event.rb', line 1867 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
1870 |
# File 'lib/seam/resources/event.rb', line 1870 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1873 |
# File 'lib/seam/resources/event.rb', line 1873 date_accessor :occurred_at |