Class: Seam::Resources::SeamEvent::AcsSystemDisconnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsSystemDisconnected
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system was disconnected.
Defined Under Namespace
Classes: AcsSystemErrors, AcsSystemWarnings, ConnectedAccountErrors, ConnectedAccountWarnings
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_system.disconnected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#acs_system_errors ⇒ Array<AcsSystemErrors>
Errors associated with the access control system.
-
#acs_system_warnings ⇒ Array<AcsSystemWarnings>
Warnings associated with the access control system.
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system.
1969 1970 1971 |
# File 'lib/seam/resources/event.rb', line 1969 def acs_system_id @acs_system_id end |
#connected_account_id ⇒ String?
ID of the connected account.
1972 1973 1974 |
# File 'lib/seam/resources/event.rb', line 1972 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
1975 1976 1977 |
# File 'lib/seam/resources/event.rb', line 1975 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
1978 1979 1980 |
# File 'lib/seam/resources/event.rb', line 1978 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_system.disconnected
1982 1983 1984 |
# File 'lib/seam/resources/event.rb', line 1982 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
1985 1986 1987 |
# File 'lib/seam/resources/event.rb', line 1985 def workspace_id @workspace_id end |
Instance Method Details
#acs_system_errors ⇒ Array<AcsSystemErrors>
Errors associated with the access control system.
1957 |
# File 'lib/seam/resources/event.rb', line 1957 resource_list_accessor :acs_system_errors, AcsSystemErrors |
#acs_system_warnings ⇒ Array<AcsSystemWarnings>
Warnings associated with the access control system.
1960 |
# File 'lib/seam/resources/event.rb', line 1960 resource_list_accessor :acs_system_warnings, AcsSystemWarnings |
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
1963 |
# File 'lib/seam/resources/event.rb', line 1963 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
1966 |
# File 'lib/seam/resources/event.rb', line 1966 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
1988 |
# File 'lib/seam/resources/event.rb', line 1988 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
1991 |
# File 'lib/seam/resources/event.rb', line 1991 date_accessor :occurred_at |