Class: Seam::Resources::SeamEvent::AcsUserCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsUserCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system user was created.
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system.
-
#acs_user_id ⇒ String
ID of the affected access system user.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_user.created. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system.
2126 2127 2128 |
# File 'lib/seam/resources/event.rb', line 2126 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the affected access system user.
2129 2130 2131 |
# File 'lib/seam/resources/event.rb', line 2129 def acs_user_id @acs_user_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2132 2133 2134 |
# File 'lib/seam/resources/event.rb', line 2132 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2135 2136 2137 |
# File 'lib/seam/resources/event.rb', line 2135 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2138 2139 2140 |
# File 'lib/seam/resources/event.rb', line 2138 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_user.created
2142 2143 2144 |
# File 'lib/seam/resources/event.rb', line 2142 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2145 2146 2147 |
# File 'lib/seam/resources/event.rb', line 2145 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2148 |
# File 'lib/seam/resources/event.rb', line 2148 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2151 |
# File 'lib/seam/resources/event.rb', line 2151 date_accessor :occurred_at |