Class: Seam::Resources::SeamEvent::AcsUserDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::AcsUserDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
An access system user was deleted.
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system.
-
#acs_user_id ⇒ String
ID of the affected access system user.
-
#connected_account_id ⇒ String?
ID of the connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
acs_user.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system.
2158 2159 2160 |
# File 'lib/seam/resources/event.rb', line 2158 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the affected access system user.
2161 2162 2163 |
# File 'lib/seam/resources/event.rb', line 2161 def acs_user_id @acs_user_id end |
#connected_account_id ⇒ String?
ID of the connected account.
2164 2165 2166 |
# File 'lib/seam/resources/event.rb', line 2164 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2167 2168 2169 |
# File 'lib/seam/resources/event.rb', line 2167 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2170 2171 2172 |
# File 'lib/seam/resources/event.rb', line 2170 def event_id @event_id end |
#event_type ⇒ String
Known values:
acs_user.deleted
2174 2175 2176 |
# File 'lib/seam/resources/event.rb', line 2174 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2177 2178 2179 |
# File 'lib/seam/resources/event.rb', line 2177 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2180 |
# File 'lib/seam/resources/event.rb', line 2180 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2183 |
# File 'lib/seam/resources/event.rb', line 2183 date_accessor :occurred_at |