Class: Seam::Resources::SeamEvent::ActionAttemptSimulateKeypadCodeEntrySucceeded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ActionAttemptSimulateKeypadCodeEntrySucceeded
- Defined in:
- lib/seam/resources/event.rb
Overview
A simulate keypad code entry action attempt succeeded.
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the affected action attempt.
-
#action_type ⇒ String
Type of the action.
-
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
-
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
action_attempt.simulate_keypad_code_entry.succeeded. -
#status ⇒ String
Status of the action.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the affected action attempt.
2835 2836 2837 |
# File 'lib/seam/resources/event.rb', line 2835 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Type of the action.
2838 2839 2840 |
# File 'lib/seam/resources/event.rb', line 2838 def action_type @action_type end |
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
2841 2842 2843 |
# File 'lib/seam/resources/event.rb', line 2841 def connected_account_id @connected_account_id end |
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
2844 2845 2846 |
# File 'lib/seam/resources/event.rb', line 2844 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2847 2848 2849 |
# File 'lib/seam/resources/event.rb', line 2847 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2850 2851 2852 |
# File 'lib/seam/resources/event.rb', line 2850 def event_id @event_id end |
#event_type ⇒ String
Known values:
action_attempt.simulate_keypad_code_entry.succeeded
2854 2855 2856 |
# File 'lib/seam/resources/event.rb', line 2854 def event_type @event_type end |
#status ⇒ String
Status of the action.
2857 2858 2859 |
# File 'lib/seam/resources/event.rb', line 2857 def status @status end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2860 2861 2862 |
# File 'lib/seam/resources/event.rb', line 2860 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2863 |
# File 'lib/seam/resources/event.rb', line 2863 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2866 |
# File 'lib/seam/resources/event.rb', line 2866 date_accessor :occurred_at |