Class: Seam::Resources::SeamEvent::ActionAttemptUnlockDoorFailed
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ActionAttemptUnlockDoorFailed
- Defined in:
- lib/seam/resources/event.rb
Overview
An unlock door action attempt failed.
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the affected action attempt.
-
#action_type ⇒ String
Type of the action.
-
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
-
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
action_attempt.unlock_door.failed. -
#status ⇒ String
Status of the action.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the affected action attempt.
2797 2798 2799 |
# File 'lib/seam/resources/event.rb', line 2797 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Type of the action.
2800 2801 2802 |
# File 'lib/seam/resources/event.rb', line 2800 def action_type @action_type end |
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
2803 2804 2805 |
# File 'lib/seam/resources/event.rb', line 2803 def connected_account_id @connected_account_id end |
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
2806 2807 2808 |
# File 'lib/seam/resources/event.rb', line 2806 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2809 2810 2811 |
# File 'lib/seam/resources/event.rb', line 2809 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2812 2813 2814 |
# File 'lib/seam/resources/event.rb', line 2812 def event_id @event_id end |
#event_type ⇒ String
Known values:
action_attempt.unlock_door.failed
2816 2817 2818 |
# File 'lib/seam/resources/event.rb', line 2816 def event_type @event_type end |
#status ⇒ String
Status of the action.
2819 2820 2821 |
# File 'lib/seam/resources/event.rb', line 2819 def status @status end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2822 2823 2824 |
# File 'lib/seam/resources/event.rb', line 2822 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2825 |
# File 'lib/seam/resources/event.rb', line 2825 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2828 |
# File 'lib/seam/resources/event.rb', line 2828 date_accessor :occurred_at |