Class: Seam::Resources::SeamEvent::ActionAttemptUnlockDoorSucceeded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ActionAttemptUnlockDoorSucceeded
- Defined in:
- lib/seam/resources/event.rb
Overview
An unlock door action attempt succeeded.
Instance Attribute Summary collapse
-
#action_attempt_id ⇒ String
ID of the affected action attempt.
-
#action_type ⇒ String
Type of the action.
-
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
-
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
action_attempt.unlock_door.succeeded. -
#status ⇒ String
Status of the action.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#action_attempt_id ⇒ String
ID of the affected action attempt.
2759 2760 2761 |
# File 'lib/seam/resources/event.rb', line 2759 def action_attempt_id @action_attempt_id end |
#action_type ⇒ String
Type of the action.
2762 2763 2764 |
# File 'lib/seam/resources/event.rb', line 2762 def action_type @action_type end |
#connected_account_id ⇒ String?
ID of the connected account associated with the action attempt, if applicable.
2765 2766 2767 |
# File 'lib/seam/resources/event.rb', line 2765 def connected_account_id @connected_account_id end |
#device_id ⇒ String?
ID of the device associated with the action attempt, if applicable.
2768 2769 2770 |
# File 'lib/seam/resources/event.rb', line 2768 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2771 2772 2773 |
# File 'lib/seam/resources/event.rb', line 2771 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2774 2775 2776 |
# File 'lib/seam/resources/event.rb', line 2774 def event_id @event_id end |
#event_type ⇒ String
Known values:
action_attempt.unlock_door.succeeded
2778 2779 2780 |
# File 'lib/seam/resources/event.rb', line 2778 def event_type @event_type end |
#status ⇒ String
Status of the action.
2781 2782 2783 |
# File 'lib/seam/resources/event.rb', line 2781 def status @status end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2784 2785 2786 |
# File 'lib/seam/resources/event.rb', line 2784 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2787 |
# File 'lib/seam/resources/event.rb', line 2787 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2790 |
# File 'lib/seam/resources/event.rb', line 2790 date_accessor :occurred_at |