Class: Seam::Resources::SeamEvent::CameraActivated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::CameraActivated
- Defined in:
- lib/seam/resources/event.rb
Overview
A camera was activated, for example, by motion detection.
Instance Attribute Summary collapse
-
#activation_reason ⇒ String
The reason the camera was activated.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
camera.activated. -
#image_url ⇒ String?
URL to a thumbnail image captured at the time of activation.
-
#motion_sub_type ⇒ String?
Sub-type of motion detected, if available.
-
#video_url ⇒ String?
URL to a short video clip captured at the time of activation.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#activation_reason ⇒ String
The reason the camera was activated. Known values:
motion_detected
4838 4839 4840 |
# File 'lib/seam/resources/event.rb', line 4838 def activation_reason @activation_reason end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4841 4842 4843 |
# File 'lib/seam/resources/event.rb', line 4841 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4844 4845 4846 |
# File 'lib/seam/resources/event.rb', line 4844 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4847 4848 4849 |
# File 'lib/seam/resources/event.rb', line 4847 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4850 4851 4852 |
# File 'lib/seam/resources/event.rb', line 4850 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4853 4854 4855 |
# File 'lib/seam/resources/event.rb', line 4853 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4856 4857 4858 |
# File 'lib/seam/resources/event.rb', line 4856 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4859 4860 4861 |
# File 'lib/seam/resources/event.rb', line 4859 def event_id @event_id end |
#event_type ⇒ String
Known values:
camera.activated
4863 4864 4865 |
# File 'lib/seam/resources/event.rb', line 4863 def event_type @event_type end |
#image_url ⇒ String?
URL to a thumbnail image captured at the time of activation.
4866 4867 4868 |
# File 'lib/seam/resources/event.rb', line 4866 def image_url @image_url end |
#motion_sub_type ⇒ String?
Sub-type of motion detected, if available. Known values:
humanvehiclepackageother
4874 4875 4876 |
# File 'lib/seam/resources/event.rb', line 4874 def motion_sub_type @motion_sub_type end |
#video_url ⇒ String?
URL to a short video clip captured at the time of activation.
4877 4878 4879 |
# File 'lib/seam/resources/event.rb', line 4877 def video_url @video_url end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4880 4881 4882 |
# File 'lib/seam/resources/event.rb', line 4880 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4883 |
# File 'lib/seam/resources/event.rb', line 4883 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4886 |
# File 'lib/seam/resources/event.rb', line 4886 date_accessor :occurred_at |