Class: Seam::Resources::SeamEvent::ChangedProperties
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::SeamEvent::ChangedProperties
- Defined in:
- lib/seam/resources/event.rb
Instance Attribute Summary collapse
-
#from ⇒ String?
Previous value of the property, or null if not set.
-
#property ⇒ String
Name of the property that changed (e.g.
code). -
#to ⇒ String?
New value of the property, or null if cleared.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#from ⇒ String?
Previous value of the property, or null if not set.
57 58 59 |
# File 'lib/seam/resources/event.rb', line 57 def from @from end |
#property ⇒ String
Name of the property that changed (e.g. code).
60 61 62 |
# File 'lib/seam/resources/event.rb', line 60 def property @property end |
#to ⇒ String?
New value of the property, or null if cleared.
63 64 65 |
# File 'lib/seam/resources/event.rb', line 63 def to @to end |