Class: Seam::Resources::SeamEvent::ChangedProperties

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#fromObject

Previous value of the property, or null if not set.



44
45
46
# File 'lib/seam/resources/event.rb', line 44

def from
  @from
end

#propertyObject

Name of the property that changed (e.g. code).



46
47
48
# File 'lib/seam/resources/event.rb', line 46

def property
  @property
end

#toObject

New value of the property, or null if cleared.



48
49
50
# File 'lib/seam/resources/event.rb', line 48

def to
  @to
end