Class: Seam::Resources::SeamEvent::ClientSessionDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ClientSessionDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
A client session was deleted.
Instance Attribute Summary collapse
-
#client_session_id ⇒ String
ID of the affected client session.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
client_session.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#client_session_id ⇒ String
ID of the affected client session.
2350 2351 2352 |
# File 'lib/seam/resources/event.rb', line 2350 def client_session_id @client_session_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2353 2354 2355 |
# File 'lib/seam/resources/event.rb', line 2353 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2356 2357 2358 |
# File 'lib/seam/resources/event.rb', line 2356 def event_id @event_id end |
#event_type ⇒ String
Known values:
client_session.deleted
2360 2361 2362 |
# File 'lib/seam/resources/event.rb', line 2360 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2363 2364 2365 |
# File 'lib/seam/resources/event.rb', line 2363 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2366 |
# File 'lib/seam/resources/event.rb', line 2366 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2369 |
# File 'lib/seam/resources/event.rb', line 2369 date_accessor :occurred_at |