Class: Seam::Resources::SeamEvent::ConnectedAccountCompletedFirstSync
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountCompletedFirstSync
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account completed the first sync with Seam, and the corresponding devices or systems are now available.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.completed_first_sync. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2534 2535 2536 |
# File 'lib/seam/resources/event.rb', line 2534 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2537 2538 2539 |
# File 'lib/seam/resources/event.rb', line 2537 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2540 2541 2542 |
# File 'lib/seam/resources/event.rb', line 2540 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2543 2544 2545 |
# File 'lib/seam/resources/event.rb', line 2543 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.completed_first_sync
2547 2548 2549 |
# File 'lib/seam/resources/event.rb', line 2547 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2550 2551 2552 |
# File 'lib/seam/resources/event.rb', line 2550 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2553 |
# File 'lib/seam/resources/event.rb', line 2553 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2556 |
# File 'lib/seam/resources/event.rb', line 2556 date_accessor :occurred_at |