Class: Seam::Resources::SeamEvent::ConnectedAccountCompletedFirstSyncAfterReconnection
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountCompletedFirstSyncAfterReconnection
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account completed the first sync after reconnection with Seam, and the corresponding devices or systems are now available.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.completed_first_sync_after_reconnection. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2595 2596 2597 |
# File 'lib/seam/resources/event.rb', line 2595 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2598 2599 2600 |
# File 'lib/seam/resources/event.rb', line 2598 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2601 2602 2603 |
# File 'lib/seam/resources/event.rb', line 2601 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2604 2605 2606 |
# File 'lib/seam/resources/event.rb', line 2604 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.completed_first_sync_after_reconnection
2608 2609 2610 |
# File 'lib/seam/resources/event.rb', line 2608 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2611 2612 2613 |
# File 'lib/seam/resources/event.rb', line 2611 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2614 |
# File 'lib/seam/resources/event.rb', line 2614 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2617 |
# File 'lib/seam/resources/event.rb', line 2617 date_accessor :occurred_at |