Class: Seam::Resources::SeamEvent::ConnectedAccountConnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountConnected
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account was connected for the first time or was reconnected after being disconnected.
Instance Attribute Summary collapse
-
#connect_webview_id ⇒ String?
ID of the Connect Webview associated with the event.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#customer_key ⇒ String?
The customer key associated with this connected account, if any.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.connected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connect_webview_id ⇒ String?
ID of the Connect Webview associated with the event.
2376 2377 2378 |
# File 'lib/seam/resources/event.rb', line 2376 def connect_webview_id @connect_webview_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2379 2380 2381 |
# File 'lib/seam/resources/event.rb', line 2379 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2382 2383 2384 |
# File 'lib/seam/resources/event.rb', line 2382 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with this connected account, if any.
2385 2386 2387 |
# File 'lib/seam/resources/event.rb', line 2385 def customer_key @customer_key end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2388 2389 2390 |
# File 'lib/seam/resources/event.rb', line 2388 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2391 2392 2393 |
# File 'lib/seam/resources/event.rb', line 2391 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.connected
2395 2396 2397 |
# File 'lib/seam/resources/event.rb', line 2395 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2398 2399 2400 |
# File 'lib/seam/resources/event.rb', line 2398 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2401 |
# File 'lib/seam/resources/event.rb', line 2401 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2404 |
# File 'lib/seam/resources/event.rb', line 2404 date_accessor :occurred_at |