Class: Seam::Resources::SeamEvent::ConnectedAccountCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account was created.
Instance Attribute Summary collapse
-
#connect_webview_id ⇒ String
ID of the Connect Webview associated with the event.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.created. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connect_webview_id ⇒ String
ID of the Connect Webview associated with the event.
2411 2412 2413 |
# File 'lib/seam/resources/event.rb', line 2411 def connect_webview_id @connect_webview_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2414 2415 2416 |
# File 'lib/seam/resources/event.rb', line 2414 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2417 2418 2419 |
# File 'lib/seam/resources/event.rb', line 2417 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2420 2421 2422 |
# File 'lib/seam/resources/event.rb', line 2420 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2423 2424 2425 |
# File 'lib/seam/resources/event.rb', line 2423 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.created
2427 2428 2429 |
# File 'lib/seam/resources/event.rb', line 2427 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2430 2431 2432 |
# File 'lib/seam/resources/event.rb', line 2430 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2433 |
# File 'lib/seam/resources/event.rb', line 2433 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2436 |
# File 'lib/seam/resources/event.rb', line 2436 date_accessor :occurred_at |