Class: Seam::Resources::SeamEvent::ConnectedAccountDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account was deleted.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#customer_key ⇒ String?
The customer key associated with this connected account, if any.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.deleted. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2563 2564 2565 |
# File 'lib/seam/resources/event.rb', line 2563 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2566 2567 2568 |
# File 'lib/seam/resources/event.rb', line 2566 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with this connected account, if any.
2569 2570 2571 |
# File 'lib/seam/resources/event.rb', line 2569 def customer_key @customer_key end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2572 2573 2574 |
# File 'lib/seam/resources/event.rb', line 2572 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2575 2576 2577 |
# File 'lib/seam/resources/event.rb', line 2575 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.deleted
2579 2580 2581 |
# File 'lib/seam/resources/event.rb', line 2579 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2582 2583 2584 |
# File 'lib/seam/resources/event.rb', line 2582 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
2585 |
# File 'lib/seam/resources/event.rb', line 2585 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2588 |
# File 'lib/seam/resources/event.rb', line 2588 date_accessor :occurred_at |