Class: Seam::Resources::SeamEvent::ConnectedAccountDisconnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountDisconnected
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account was disconnected.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.disconnected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2505 2506 2507 |
# File 'lib/seam/resources/event.rb', line 2505 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2508 2509 2510 |
# File 'lib/seam/resources/event.rb', line 2508 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2511 2512 2513 |
# File 'lib/seam/resources/event.rb', line 2511 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2514 2515 2516 |
# File 'lib/seam/resources/event.rb', line 2514 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.disconnected
2518 2519 2520 |
# File 'lib/seam/resources/event.rb', line 2518 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2521 2522 2523 |
# File 'lib/seam/resources/event.rb', line 2521 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
2499 |
# File 'lib/seam/resources/event.rb', line 2499 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
2502 |
# File 'lib/seam/resources/event.rb', line 2502 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
2524 |
# File 'lib/seam/resources/event.rb', line 2524 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2527 |
# File 'lib/seam/resources/event.rb', line 2527 date_accessor :occurred_at |