Class: Seam::Resources::SeamEvent::ConnectedAccountReauthorizationRequested
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ConnectedAccountReauthorizationRequested
- Defined in:
- lib/seam/resources/event.rb
Overview
A connected account requires reauthorization using a new Connect Webview. The account is still connected, but cannot access new features. Delaying reauthorization too long will eventually cause the Connected Account to become disconnected.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the affected connected account.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
connected_account.reauthorization_requested. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
2654 2655 2656 |
# File 'lib/seam/resources/event.rb', line 2654 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the affected connected account.
2657 2658 2659 |
# File 'lib/seam/resources/event.rb', line 2657 def connected_account_id @connected_account_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
2660 2661 2662 |
# File 'lib/seam/resources/event.rb', line 2660 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
2663 2664 2665 |
# File 'lib/seam/resources/event.rb', line 2663 def event_id @event_id end |
#event_type ⇒ String
Known values:
connected_account.reauthorization_requested
2667 2668 2669 |
# File 'lib/seam/resources/event.rb', line 2667 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
2670 2671 2672 |
# File 'lib/seam/resources/event.rb', line 2670 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
2648 |
# File 'lib/seam/resources/event.rb', line 2648 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
2651 |
# File 'lib/seam/resources/event.rb', line 2651 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
2673 |
# File 'lib/seam/resources/event.rb', line 2673 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
2676 |
# File 'lib/seam/resources/event.rb', line 2676 date_accessor :occurred_at |