Class: Seam::Resources::SeamEvent::DeviceAccessoryKeypadConnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceAccessoryKeypadConnected
- Defined in:
- lib/seam/resources/event.rb
Overview
An accessory keypad was connected to a device.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.accessory_keypad_connected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4086 4087 4088 |
# File 'lib/seam/resources/event.rb', line 4086 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4089 4090 4091 |
# File 'lib/seam/resources/event.rb', line 4089 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4092 4093 4094 |
# File 'lib/seam/resources/event.rb', line 4092 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4095 4096 4097 |
# File 'lib/seam/resources/event.rb', line 4095 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4098 4099 4100 |
# File 'lib/seam/resources/event.rb', line 4098 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4101 4102 4103 |
# File 'lib/seam/resources/event.rb', line 4101 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4104 4105 4106 |
# File 'lib/seam/resources/event.rb', line 4104 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.accessory_keypad_connected
4108 4109 4110 |
# File 'lib/seam/resources/event.rb', line 4108 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4111 4112 4113 |
# File 'lib/seam/resources/event.rb', line 4111 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4114 |
# File 'lib/seam/resources/event.rb', line 4114 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4117 |
# File 'lib/seam/resources/event.rb', line 4117 date_accessor :occurred_at |