Class: Seam::Resources::SeamEvent::DeviceAccessoryKeypadConnected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

An accessory keypad was connected to a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4079
4080
4081
# File 'lib/seam/resources/event.rb', line 4079

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4082
4083
4084
# File 'lib/seam/resources/event.rb', line 4082

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4085
4086
4087
# File 'lib/seam/resources/event.rb', line 4085

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4088
4089
4090
# File 'lib/seam/resources/event.rb', line 4088

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4091
4092
4093
# File 'lib/seam/resources/event.rb', line 4091

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4094
4095
4096
# File 'lib/seam/resources/event.rb', line 4094

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4097
4098
4099
# File 'lib/seam/resources/event.rb', line 4097

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.accessory_keypad_connected

Returns:

  • (String)


4101
4102
4103
# File 'lib/seam/resources/event.rb', line 4101

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4104
4105
4106
# File 'lib/seam/resources/event.rb', line 4104

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4107
# File 'lib/seam/resources/event.rb', line 4107

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4110
# File 'lib/seam/resources/event.rb', line 4110

date_accessor :occurred_at