Class: Seam::Resources::SeamEvent::DeviceAccessoryKeypadConnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceAccessoryKeypadConnected
- Defined in:
- lib/seam/resources/event.rb
Overview
An accessory keypad was connected to a device.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.accessory_keypad_connected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4079 4080 4081 |
# File 'lib/seam/resources/event.rb', line 4079 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4082 4083 4084 |
# File 'lib/seam/resources/event.rb', line 4082 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4085 4086 4087 |
# File 'lib/seam/resources/event.rb', line 4085 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4088 4089 4090 |
# File 'lib/seam/resources/event.rb', line 4088 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4091 4092 4093 |
# File 'lib/seam/resources/event.rb', line 4091 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4094 4095 4096 |
# File 'lib/seam/resources/event.rb', line 4094 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4097 4098 4099 |
# File 'lib/seam/resources/event.rb', line 4097 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.accessory_keypad_connected
4101 4102 4103 |
# File 'lib/seam/resources/event.rb', line 4101 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4104 4105 4106 |
# File 'lib/seam/resources/event.rb', line 4104 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4107 |
# File 'lib/seam/resources/event.rb', line 4107 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4110 |
# File 'lib/seam/resources/event.rb', line 4110 date_accessor :occurred_at |