Class: Seam::Resources::SeamEvent::DeviceAccessoryKeypadDisconnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceAccessoryKeypadDisconnected
- Defined in:
- lib/seam/resources/event.rb
Overview
An accessory keypad was disconnected from a device.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.accessory_keypad_disconnected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4184 4185 4186 |
# File 'lib/seam/resources/event.rb', line 4184 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4187 4188 4189 |
# File 'lib/seam/resources/event.rb', line 4187 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4190 4191 4192 |
# File 'lib/seam/resources/event.rb', line 4190 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4193 4194 4195 |
# File 'lib/seam/resources/event.rb', line 4193 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4196 4197 4198 |
# File 'lib/seam/resources/event.rb', line 4196 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4199 4200 4201 |
# File 'lib/seam/resources/event.rb', line 4199 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4202 4203 4204 |
# File 'lib/seam/resources/event.rb', line 4202 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.accessory_keypad_disconnected
4206 4207 4208 |
# File 'lib/seam/resources/event.rb', line 4206 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4209 4210 4211 |
# File 'lib/seam/resources/event.rb', line 4209 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
4172 |
# File 'lib/seam/resources/event.rb', line 4172 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
4175 |
# File 'lib/seam/resources/event.rb', line 4175 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
4212 |
# File 'lib/seam/resources/event.rb', line 4212 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
4178 |
# File 'lib/seam/resources/event.rb', line 4178 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
4181 |
# File 'lib/seam/resources/event.rb', line 4181 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4215 |
# File 'lib/seam/resources/event.rb', line 4215 date_accessor :occurred_at |