Class: Seam::Resources::SeamEvent::DeviceBatteryStatusChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceBatteryStatusChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
A device battery status changed since the last battery_status_changed event.
Instance Attribute Summary collapse
-
#battery_level ⇒ Float
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
-
#battery_status ⇒ String
Battery status of the affected device, calculated from the numeric
battery_levelvalue. -
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.battery_status_changed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#battery_level ⇒ Float
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
3534 3535 3536 |
# File 'lib/seam/resources/event.rb', line 3534 def battery_level @battery_level end |
#battery_status ⇒ String
Battery status of the affected device, calculated from the numeric battery_level value.
Known values:
criticallowgoodfull
3542 3543 3544 |
# File 'lib/seam/resources/event.rb', line 3542 def battery_status @battery_status end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3545 3546 3547 |
# File 'lib/seam/resources/event.rb', line 3545 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3548 3549 3550 |
# File 'lib/seam/resources/event.rb', line 3548 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3551 3552 3553 |
# File 'lib/seam/resources/event.rb', line 3551 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3554 3555 3556 |
# File 'lib/seam/resources/event.rb', line 3554 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3557 3558 3559 |
# File 'lib/seam/resources/event.rb', line 3557 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3560 3561 3562 |
# File 'lib/seam/resources/event.rb', line 3560 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3563 3564 3565 |
# File 'lib/seam/resources/event.rb', line 3563 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.battery_status_changed
3567 3568 3569 |
# File 'lib/seam/resources/event.rb', line 3567 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3570 3571 3572 |
# File 'lib/seam/resources/event.rb', line 3570 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3573 |
# File 'lib/seam/resources/event.rb', line 3573 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3576 |
# File 'lib/seam/resources/event.rb', line 3576 date_accessor :occurred_at |