Class: Seam::Resources::SeamEvent::DeviceConnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceConnected
- Defined in:
- lib/seam/resources/event.rb
Overview
The status of a device changed from offline to online. That is, the device.properties.online property changed from false to true. Note that some devices operate entirely in offline mode, so Seam never emits a device.connected event for these devices.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.connected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3048 3049 3050 |
# File 'lib/seam/resources/event.rb', line 3048 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3051 3052 3053 |
# File 'lib/seam/resources/event.rb', line 3051 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3054 3055 3056 |
# File 'lib/seam/resources/event.rb', line 3054 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3057 3058 3059 |
# File 'lib/seam/resources/event.rb', line 3057 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3060 3061 3062 |
# File 'lib/seam/resources/event.rb', line 3060 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3063 3064 3065 |
# File 'lib/seam/resources/event.rb', line 3063 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3066 3067 3068 |
# File 'lib/seam/resources/event.rb', line 3066 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.connected
3070 3071 3072 |
# File 'lib/seam/resources/event.rb', line 3070 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3073 3074 3075 |
# File 'lib/seam/resources/event.rb', line 3073 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3076 |
# File 'lib/seam/resources/event.rb', line 3076 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3079 |
# File 'lib/seam/resources/event.rb', line 3079 date_accessor :occurred_at |