Class: Seam::Resources::SeamEvent::DeviceConnectionBecameFlaky
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceConnectionBecameFlaky
- Defined in:
- lib/seam/resources/event.rb
Overview
Seam detected a flaky device connection.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.connection_became_flaky. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3867 3868 3869 |
# File 'lib/seam/resources/event.rb', line 3867 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3870 3871 3872 |
# File 'lib/seam/resources/event.rb', line 3870 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3873 3874 3875 |
# File 'lib/seam/resources/event.rb', line 3873 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3876 3877 3878 |
# File 'lib/seam/resources/event.rb', line 3876 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3879 3880 3881 |
# File 'lib/seam/resources/event.rb', line 3879 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3882 3883 3884 |
# File 'lib/seam/resources/event.rb', line 3882 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3885 3886 3887 |
# File 'lib/seam/resources/event.rb', line 3885 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.connection_became_flaky
3889 3890 3891 |
# File 'lib/seam/resources/event.rb', line 3889 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3892 3893 3894 |
# File 'lib/seam/resources/event.rb', line 3892 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
3855 |
# File 'lib/seam/resources/event.rb', line 3855 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
3858 |
# File 'lib/seam/resources/event.rb', line 3858 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
3895 |
# File 'lib/seam/resources/event.rb', line 3895 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
3861 |
# File 'lib/seam/resources/event.rb', line 3861 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
3864 |
# File 'lib/seam/resources/event.rb', line 3864 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3898 |
# File 'lib/seam/resources/event.rb', line 3898 date_accessor :occurred_at |