Class: Seam::Resources::SeamEvent::DeviceConnectionStabilized

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

Seam detected that a previously-flaky device connection stabilized.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3905
3906
3907
# File 'lib/seam/resources/event.rb', line 3905

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3908
3909
3910
# File 'lib/seam/resources/event.rb', line 3908

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3911
3912
3913
# File 'lib/seam/resources/event.rb', line 3911

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3914
3915
3916
# File 'lib/seam/resources/event.rb', line 3914

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3917
3918
3919
# File 'lib/seam/resources/event.rb', line 3917

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3920
3921
3922
# File 'lib/seam/resources/event.rb', line 3920

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3923
3924
3925
# File 'lib/seam/resources/event.rb', line 3923

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.connection_stabilized

Returns:

  • (String)


3927
3928
3929
# File 'lib/seam/resources/event.rb', line 3927

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3930
3931
3932
# File 'lib/seam/resources/event.rb', line 3930

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3933
# File 'lib/seam/resources/event.rb', line 3933

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3936
# File 'lib/seam/resources/event.rb', line 3936

date_accessor :occurred_at