Class: Seam::Resources::SeamEvent::DeviceConnectionStabilized
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceConnectionStabilized
- Defined in:
- lib/seam/resources/event.rb
Overview
Seam detected that a previously-flaky device connection stabilized.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.connection_stabilized. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3905 3906 3907 |
# File 'lib/seam/resources/event.rb', line 3905 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3908 3909 3910 |
# File 'lib/seam/resources/event.rb', line 3908 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3911 3912 3913 |
# File 'lib/seam/resources/event.rb', line 3911 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3914 3915 3916 |
# File 'lib/seam/resources/event.rb', line 3914 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3917 3918 3919 |
# File 'lib/seam/resources/event.rb', line 3917 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3920 3921 3922 |
# File 'lib/seam/resources/event.rb', line 3920 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3923 3924 3925 |
# File 'lib/seam/resources/event.rb', line 3923 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.connection_stabilized
3927 3928 3929 |
# File 'lib/seam/resources/event.rb', line 3927 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3930 3931 3932 |
# File 'lib/seam/resources/event.rb', line 3930 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3933 |
# File 'lib/seam/resources/event.rb', line 3933 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3936 |
# File 'lib/seam/resources/event.rb', line 3936 date_accessor :occurred_at |