Class: Seam::Resources::SeamEvent::DeviceConvertedToUnmanaged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceConvertedToUnmanaged
- Defined in:
- lib/seam/resources/event.rb
Overview
A managed device was successfully converted to an unmanaged device.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.converted_to_unmanaged. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3124 3125 3126 |
# File 'lib/seam/resources/event.rb', line 3124 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3127 3128 3129 |
# File 'lib/seam/resources/event.rb', line 3127 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3130 3131 3132 |
# File 'lib/seam/resources/event.rb', line 3130 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3133 3134 3135 |
# File 'lib/seam/resources/event.rb', line 3133 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3136 3137 3138 |
# File 'lib/seam/resources/event.rb', line 3136 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3139 3140 3141 |
# File 'lib/seam/resources/event.rb', line 3139 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3142 3143 3144 |
# File 'lib/seam/resources/event.rb', line 3142 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.converted_to_unmanaged
3146 3147 3148 |
# File 'lib/seam/resources/event.rb', line 3146 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3149 3150 3151 |
# File 'lib/seam/resources/event.rb', line 3149 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3152 |
# File 'lib/seam/resources/event.rb', line 3152 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3155 |
# File 'lib/seam/resources/event.rb', line 3155 date_accessor :occurred_at |