Class: Seam::Resources::SeamEvent::DeviceDoorbellRang
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceDoorbellRang
- Defined in:
- lib/seam/resources/event.rb
Overview
A doorbell button was pressed on a device.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.doorbell_rang. -
#image_url ⇒ String?
URL to a thumbnail image captured at the time the doorbell was pressed.
-
#video_url ⇒ String?
URL to a short video clip captured at the time the doorbell was pressed.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4893 4894 4895 |
# File 'lib/seam/resources/event.rb', line 4893 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4896 4897 4898 |
# File 'lib/seam/resources/event.rb', line 4896 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4899 4900 4901 |
# File 'lib/seam/resources/event.rb', line 4899 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4902 4903 4904 |
# File 'lib/seam/resources/event.rb', line 4902 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4905 4906 4907 |
# File 'lib/seam/resources/event.rb', line 4905 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4908 4909 4910 |
# File 'lib/seam/resources/event.rb', line 4908 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4911 4912 4913 |
# File 'lib/seam/resources/event.rb', line 4911 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.doorbell_rang
4915 4916 4917 |
# File 'lib/seam/resources/event.rb', line 4915 def event_type @event_type end |
#image_url ⇒ String?
URL to a thumbnail image captured at the time the doorbell was pressed.
4918 4919 4920 |
# File 'lib/seam/resources/event.rb', line 4918 def image_url @image_url end |
#video_url ⇒ String?
URL to a short video clip captured at the time the doorbell was pressed.
4921 4922 4923 |
# File 'lib/seam/resources/event.rb', line 4921 def video_url @video_url end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4924 4925 4926 |
# File 'lib/seam/resources/event.rb', line 4924 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4927 |
# File 'lib/seam/resources/event.rb', line 4927 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4930 |
# File 'lib/seam/resources/event.rb', line 4930 date_accessor :occurred_at |