Class: Seam::Resources::SeamEvent::DeviceDoorbellRang
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceDoorbellRang
- Defined in:
- lib/seam/resources/event.rb
Overview
A doorbell button was pressed on a device.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.doorbell_rang. -
#image_url ⇒ String?
URL to a thumbnail image captured at the time the doorbell was pressed.
-
#video_url ⇒ String?
URL to a short video clip captured at the time the doorbell was pressed.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4886 4887 4888 |
# File 'lib/seam/resources/event.rb', line 4886 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4889 4890 4891 |
# File 'lib/seam/resources/event.rb', line 4889 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4892 4893 4894 |
# File 'lib/seam/resources/event.rb', line 4892 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4895 4896 4897 |
# File 'lib/seam/resources/event.rb', line 4895 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4898 4899 4900 |
# File 'lib/seam/resources/event.rb', line 4898 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4901 4902 4903 |
# File 'lib/seam/resources/event.rb', line 4901 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4904 4905 4906 |
# File 'lib/seam/resources/event.rb', line 4904 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.doorbell_rang
4908 4909 4910 |
# File 'lib/seam/resources/event.rb', line 4908 def event_type @event_type end |
#image_url ⇒ String?
URL to a thumbnail image captured at the time the doorbell was pressed.
4911 4912 4913 |
# File 'lib/seam/resources/event.rb', line 4911 def image_url @image_url end |
#video_url ⇒ String?
URL to a short video clip captured at the time the doorbell was pressed.
4914 4915 4916 |
# File 'lib/seam/resources/event.rb', line 4914 def video_url @video_url end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4917 4918 4919 |
# File 'lib/seam/resources/event.rb', line 4917 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4920 |
# File 'lib/seam/resources/event.rb', line 4920 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4923 |
# File 'lib/seam/resources/event.rb', line 4923 date_accessor :occurred_at |