Class: Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequired
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequired
- Defined in:
- lib/seam/resources/event.rb
Overview
A third-party subscription is required to use all device features.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.error.subscription_required. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4010 4011 4012 |
# File 'lib/seam/resources/event.rb', line 4010 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4013 4014 4015 |
# File 'lib/seam/resources/event.rb', line 4013 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4016 4017 4018 |
# File 'lib/seam/resources/event.rb', line 4016 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4019 4020 4021 |
# File 'lib/seam/resources/event.rb', line 4019 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4022 4023 4024 |
# File 'lib/seam/resources/event.rb', line 4022 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4025 4026 4027 |
# File 'lib/seam/resources/event.rb', line 4025 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4028 4029 4030 |
# File 'lib/seam/resources/event.rb', line 4028 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.error.subscription_required
4032 4033 4034 |
# File 'lib/seam/resources/event.rb', line 4032 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4035 4036 4037 |
# File 'lib/seam/resources/event.rb', line 4035 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
3998 |
# File 'lib/seam/resources/event.rb', line 3998 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
4001 |
# File 'lib/seam/resources/event.rb', line 4001 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
4038 |
# File 'lib/seam/resources/event.rb', line 4038 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
4004 |
# File 'lib/seam/resources/event.rb', line 4004 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
4007 |
# File 'lib/seam/resources/event.rb', line 4007 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4041 |
# File 'lib/seam/resources/event.rb', line 4041 date_accessor :occurred_at |