Class: Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequired
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequired
- Defined in:
- lib/seam/resources/event.rb
Overview
A third-party subscription is required to use all device features.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.error.subscription_required. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4003 4004 4005 |
# File 'lib/seam/resources/event.rb', line 4003 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4006 4007 4008 |
# File 'lib/seam/resources/event.rb', line 4006 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4009 4010 4011 |
# File 'lib/seam/resources/event.rb', line 4009 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4012 4013 4014 |
# File 'lib/seam/resources/event.rb', line 4012 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4015 4016 4017 |
# File 'lib/seam/resources/event.rb', line 4015 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4018 4019 4020 |
# File 'lib/seam/resources/event.rb', line 4018 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4021 4022 4023 |
# File 'lib/seam/resources/event.rb', line 4021 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.error.subscription_required
4025 4026 4027 |
# File 'lib/seam/resources/event.rb', line 4025 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4028 4029 4030 |
# File 'lib/seam/resources/event.rb', line 4028 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
3991 |
# File 'lib/seam/resources/event.rb', line 3991 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
3994 |
# File 'lib/seam/resources/event.rb', line 3994 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
4031 |
# File 'lib/seam/resources/event.rb', line 4031 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
3997 |
# File 'lib/seam/resources/event.rb', line 3997 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
4000 |
# File 'lib/seam/resources/event.rb', line 4000 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4034 |
# File 'lib/seam/resources/event.rb', line 4034 date_accessor :occurred_at |