Class: Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequiredResolved

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A third-party subscription is active or no longer required to use all device features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4041
4042
4043
# File 'lib/seam/resources/event.rb', line 4041

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4044
4045
4046
# File 'lib/seam/resources/event.rb', line 4044

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4047
4048
4049
# File 'lib/seam/resources/event.rb', line 4047

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4050
4051
4052
# File 'lib/seam/resources/event.rb', line 4050

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4053
4054
4055
# File 'lib/seam/resources/event.rb', line 4053

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4056
4057
4058
# File 'lib/seam/resources/event.rb', line 4056

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4059
4060
4061
# File 'lib/seam/resources/event.rb', line 4059

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.error.subscription_required.resolved

Returns:

  • (String)


4063
4064
4065
# File 'lib/seam/resources/event.rb', line 4063

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4066
4067
4068
# File 'lib/seam/resources/event.rb', line 4066

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4069
# File 'lib/seam/resources/event.rb', line 4069

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4072
# File 'lib/seam/resources/event.rb', line 4072

date_accessor :occurred_at