Class: Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequiredResolved
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceErrorSubscriptionRequiredResolved
- Defined in:
- lib/seam/resources/event.rb
Overview
A third-party subscription is active or no longer required to use all device features.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.error.subscription_required.resolved. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4041 4042 4043 |
# File 'lib/seam/resources/event.rb', line 4041 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4044 4045 4046 |
# File 'lib/seam/resources/event.rb', line 4044 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4047 4048 4049 |
# File 'lib/seam/resources/event.rb', line 4047 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4050 4051 4052 |
# File 'lib/seam/resources/event.rb', line 4050 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4053 4054 4055 |
# File 'lib/seam/resources/event.rb', line 4053 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4056 4057 4058 |
# File 'lib/seam/resources/event.rb', line 4056 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4059 4060 4061 |
# File 'lib/seam/resources/event.rb', line 4059 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.error.subscription_required.resolved
4063 4064 4065 |
# File 'lib/seam/resources/event.rb', line 4063 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4066 4067 4068 |
# File 'lib/seam/resources/event.rb', line 4066 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4069 |
# File 'lib/seam/resources/event.rb', line 4069 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4072 |
# File 'lib/seam/resources/event.rb', line 4072 date_accessor :occurred_at |