Class: Seam::Resources::SeamEvent::DeviceLowBattery
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceLowBattery
- Defined in:
- lib/seam/resources/event.rb
Overview
A device battery level dropped below the low threshold.
Instance Attribute Summary collapse
-
#battery_level ⇒ Float
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.low_battery. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#battery_level ⇒ Float
Number in the range 0 to 1.0 indicating the amount of battery in the affected device, as reported by the device.
3486 3487 3488 |
# File 'lib/seam/resources/event.rb', line 3486 def battery_level @battery_level end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3489 3490 3491 |
# File 'lib/seam/resources/event.rb', line 3489 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3492 3493 3494 |
# File 'lib/seam/resources/event.rb', line 3492 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3495 3496 3497 |
# File 'lib/seam/resources/event.rb', line 3495 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3498 3499 3500 |
# File 'lib/seam/resources/event.rb', line 3498 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3501 3502 3503 |
# File 'lib/seam/resources/event.rb', line 3501 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3504 3505 3506 |
# File 'lib/seam/resources/event.rb', line 3504 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3507 3508 3509 |
# File 'lib/seam/resources/event.rb', line 3507 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.low_battery
3511 3512 3513 |
# File 'lib/seam/resources/event.rb', line 3511 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3514 3515 3516 |
# File 'lib/seam/resources/event.rb', line 3514 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3517 |
# File 'lib/seam/resources/event.rb', line 3517 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3520 |
# File 'lib/seam/resources/event.rb', line 3520 date_accessor :occurred_at |