Class: Seam::Resources::SeamEvent::DeviceNameChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceNameChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
The name of a device was changed.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#device_name ⇒ String
The new name of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.name_changed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4795 4796 4797 |
# File 'lib/seam/resources/event.rb', line 4795 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4798 4799 4800 |
# File 'lib/seam/resources/event.rb', line 4798 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4801 4802 4803 |
# File 'lib/seam/resources/event.rb', line 4801 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4804 4805 4806 |
# File 'lib/seam/resources/event.rb', line 4804 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4807 4808 4809 |
# File 'lib/seam/resources/event.rb', line 4807 def device_id @device_id end |
#device_name ⇒ String
The new name of the affected device.
4810 4811 4812 |
# File 'lib/seam/resources/event.rb', line 4810 def device_name @device_name end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4813 4814 4815 |
# File 'lib/seam/resources/event.rb', line 4813 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4816 4817 4818 |
# File 'lib/seam/resources/event.rb', line 4816 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.name_changed
4820 4821 4822 |
# File 'lib/seam/resources/event.rb', line 4820 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4823 4824 4825 |
# File 'lib/seam/resources/event.rb', line 4823 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4826 |
# File 'lib/seam/resources/event.rb', line 4826 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4829 |
# File 'lib/seam/resources/event.rb', line 4829 date_accessor :occurred_at |