Class: Seam::Resources::SeamEvent::DeviceSaltoPrivacyModeActivated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A Salto device activated privacy mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3731
3732
3733
# File 'lib/seam/resources/event.rb', line 3731

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3734
3735
3736
# File 'lib/seam/resources/event.rb', line 3734

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3737
3738
3739
# File 'lib/seam/resources/event.rb', line 3737

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3740
3741
3742
# File 'lib/seam/resources/event.rb', line 3740

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3743
3744
3745
# File 'lib/seam/resources/event.rb', line 3743

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3746
3747
3748
# File 'lib/seam/resources/event.rb', line 3746

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3749
3750
3751
# File 'lib/seam/resources/event.rb', line 3749

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.salto.privacy_mode_activated

Returns:

  • (String)


3753
3754
3755
# File 'lib/seam/resources/event.rb', line 3753

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3756
3757
3758
# File 'lib/seam/resources/event.rb', line 3756

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3759
# File 'lib/seam/resources/event.rb', line 3759

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3762
# File 'lib/seam/resources/event.rb', line 3762

date_accessor :occurred_at