Class: Seam::Resources::SeamEvent::DeviceSaltoPrivacyModeDeactivated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceSaltoPrivacyModeDeactivated
- Defined in:
- lib/seam/resources/event.rb
Overview
A Salto device deactivated privacy mode.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.salto.privacy_mode_deactivated. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3769 3770 3771 |
# File 'lib/seam/resources/event.rb', line 3769 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3772 3773 3774 |
# File 'lib/seam/resources/event.rb', line 3772 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3775 3776 3777 |
# File 'lib/seam/resources/event.rb', line 3775 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3778 3779 3780 |
# File 'lib/seam/resources/event.rb', line 3778 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3781 3782 3783 |
# File 'lib/seam/resources/event.rb', line 3781 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3784 3785 3786 |
# File 'lib/seam/resources/event.rb', line 3784 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3787 3788 3789 |
# File 'lib/seam/resources/event.rb', line 3787 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.salto.privacy_mode_deactivated
3791 3792 3793 |
# File 'lib/seam/resources/event.rb', line 3791 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3794 3795 3796 |
# File 'lib/seam/resources/event.rb', line 3794 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3797 |
# File 'lib/seam/resources/event.rb', line 3797 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3800 |
# File 'lib/seam/resources/event.rb', line 3800 date_accessor :occurred_at |