Class: Seam::Resources::SeamEvent::DeviceTampered
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceTampered
- Defined in:
- lib/seam/resources/event.rb
Overview
A device detected that it was tampered with, for example, opened or moved.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.tampered. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3448 3449 3450 |
# File 'lib/seam/resources/event.rb', line 3448 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3451 3452 3453 |
# File 'lib/seam/resources/event.rb', line 3451 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3454 3455 3456 |
# File 'lib/seam/resources/event.rb', line 3454 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3457 3458 3459 |
# File 'lib/seam/resources/event.rb', line 3457 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3460 3461 3462 |
# File 'lib/seam/resources/event.rb', line 3460 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3463 3464 3465 |
# File 'lib/seam/resources/event.rb', line 3463 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3466 3467 3468 |
# File 'lib/seam/resources/event.rb', line 3466 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.tampered
3470 3471 3472 |
# File 'lib/seam/resources/event.rb', line 3470 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3473 3474 3475 |
# File 'lib/seam/resources/event.rb', line 3473 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3476 |
# File 'lib/seam/resources/event.rb', line 3476 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3479 |
# File 'lib/seam/resources/event.rb', line 3479 date_accessor :occurred_at |