Class: Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationNoLongerDetected

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

Seam detected that a device is no longer using a third-party integration that was interfering with Seam device management.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3693
3694
3695
# File 'lib/seam/resources/event.rb', line 3693

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


3696
3697
3698
# File 'lib/seam/resources/event.rb', line 3696

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


3699
3700
3701
# File 'lib/seam/resources/event.rb', line 3699

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


3702
3703
3704
# File 'lib/seam/resources/event.rb', line 3702

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


3705
3706
3707
# File 'lib/seam/resources/event.rb', line 3705

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


3708
3709
3710
# File 'lib/seam/resources/event.rb', line 3708

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


3711
3712
3713
# File 'lib/seam/resources/event.rb', line 3711

def event_id
  @event_id
end

#event_typeString

Known values:

  • device.third_party_integration_no_longer_detected

Returns:

  • (String)


3715
3716
3717
# File 'lib/seam/resources/event.rb', line 3715

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


3718
3719
3720
# File 'lib/seam/resources/event.rb', line 3718

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


3721
# File 'lib/seam/resources/event.rb', line 3721

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


3724
# File 'lib/seam/resources/event.rb', line 3724

date_accessor :occurred_at