Class: Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationNoLongerDetected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceThirdPartyIntegrationNoLongerDetected
- Defined in:
- lib/seam/resources/event.rb
Overview
Seam detected that a device is no longer using a third-party integration that was interfering with Seam device management.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.third_party_integration_no_longer_detected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3693 3694 3695 |
# File 'lib/seam/resources/event.rb', line 3693 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3696 3697 3698 |
# File 'lib/seam/resources/event.rb', line 3696 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3699 3700 3701 |
# File 'lib/seam/resources/event.rb', line 3699 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3702 3703 3704 |
# File 'lib/seam/resources/event.rb', line 3702 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3705 3706 3707 |
# File 'lib/seam/resources/event.rb', line 3705 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3708 3709 3710 |
# File 'lib/seam/resources/event.rb', line 3708 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3711 3712 3713 |
# File 'lib/seam/resources/event.rb', line 3711 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.third_party_integration_no_longer_detected
3715 3716 3717 |
# File 'lib/seam/resources/event.rb', line 3715 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3718 3719 3720 |
# File 'lib/seam/resources/event.rb', line 3718 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3721 |
# File 'lib/seam/resources/event.rb', line 3721 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3724 |
# File 'lib/seam/resources/event.rb', line 3724 date_accessor :occurred_at |