Class: Seam::Resources::SeamEvent::DeviceUnmanagedConnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceUnmanagedConnected
- Defined in:
- lib/seam/resources/event.rb
Overview
The status of an unmanaged device changed from offline to online. That is, the device.properties.online property changed from false to true.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.unmanaged.connected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3200 3201 3202 |
# File 'lib/seam/resources/event.rb', line 3200 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3203 3204 3205 |
# File 'lib/seam/resources/event.rb', line 3203 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3206 3207 3208 |
# File 'lib/seam/resources/event.rb', line 3206 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3209 3210 3211 |
# File 'lib/seam/resources/event.rb', line 3209 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3212 3213 3214 |
# File 'lib/seam/resources/event.rb', line 3212 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3215 3216 3217 |
# File 'lib/seam/resources/event.rb', line 3215 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3218 3219 3220 |
# File 'lib/seam/resources/event.rb', line 3218 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.unmanaged.connected
3222 3223 3224 |
# File 'lib/seam/resources/event.rb', line 3222 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3225 3226 3227 |
# File 'lib/seam/resources/event.rb', line 3225 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3228 |
# File 'lib/seam/resources/event.rb', line 3228 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3231 |
# File 'lib/seam/resources/event.rb', line 3231 date_accessor :occurred_at |