Class: Seam::Resources::SeamEvent::DeviceUnmanagedConvertedToManaged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceUnmanagedConvertedToManaged
- Defined in:
- lib/seam/resources/event.rb
Overview
An unmanaged device was successfully converted to a managed device.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.unmanaged.converted_to_managed. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3162 3163 3164 |
# File 'lib/seam/resources/event.rb', line 3162 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3165 3166 3167 |
# File 'lib/seam/resources/event.rb', line 3165 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3168 3169 3170 |
# File 'lib/seam/resources/event.rb', line 3168 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3171 3172 3173 |
# File 'lib/seam/resources/event.rb', line 3171 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3174 3175 3176 |
# File 'lib/seam/resources/event.rb', line 3174 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3177 3178 3179 |
# File 'lib/seam/resources/event.rb', line 3177 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3180 3181 3182 |
# File 'lib/seam/resources/event.rb', line 3180 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.unmanaged.converted_to_managed
3184 3185 3186 |
# File 'lib/seam/resources/event.rb', line 3184 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3187 3188 3189 |
# File 'lib/seam/resources/event.rb', line 3187 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
3190 |
# File 'lib/seam/resources/event.rb', line 3190 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3193 |
# File 'lib/seam/resources/event.rb', line 3193 date_accessor :occurred_at |