Class: Seam::Resources::SeamEvent::DeviceUnmanagedDisconnected
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::DeviceUnmanagedDisconnected
- Defined in:
- lib/seam/resources/event.rb
Overview
The status of an unmanaged device changed from online to offline. That is, the device.properties.online property changed from true to false.
Defined Under Namespace
Classes: ConnectedAccountErrors, ConnectedAccountWarnings, DeviceErrors, DeviceWarnings
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#error_code ⇒ String
Error code associated with the disconnection event, if any.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
device.unmanaged.disconnected. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
-
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
-
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
3403 3404 3405 |
# File 'lib/seam/resources/event.rb', line 3403 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
3406 3407 3408 |
# File 'lib/seam/resources/event.rb', line 3406 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
3409 3410 3411 |
# File 'lib/seam/resources/event.rb', line 3409 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
3412 3413 3414 |
# File 'lib/seam/resources/event.rb', line 3412 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
3415 3416 3417 |
# File 'lib/seam/resources/event.rb', line 3415 def device_id @device_id end |
#error_code ⇒ String
Error code associated with the disconnection event, if any. Known values:
account_disconnectedhub_disconnecteddevice_disconnected
3422 3423 3424 |
# File 'lib/seam/resources/event.rb', line 3422 def error_code @error_code end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
3425 3426 3427 |
# File 'lib/seam/resources/event.rb', line 3425 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
3428 3429 3430 |
# File 'lib/seam/resources/event.rb', line 3428 def event_id @event_id end |
#event_type ⇒ String
Known values:
device.unmanaged.disconnected
3432 3433 3434 |
# File 'lib/seam/resources/event.rb', line 3432 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
3435 3436 3437 |
# File 'lib/seam/resources/event.rb', line 3435 def workspace_id @workspace_id end |
Instance Method Details
#connected_account_errors ⇒ Array<ConnectedAccountErrors>
Errors associated with the connected account.
3391 |
# File 'lib/seam/resources/event.rb', line 3391 resource_list_accessor :connected_account_errors, ConnectedAccountErrors |
#connected_account_warnings ⇒ Array<ConnectedAccountWarnings>
Warnings associated with the connected account.
3394 |
# File 'lib/seam/resources/event.rb', line 3394 resource_list_accessor :connected_account_warnings, ConnectedAccountWarnings |
#created_at ⇒ Time
Date and time at which the event was created.
3438 |
# File 'lib/seam/resources/event.rb', line 3438 date_accessor :created_at |
#device_errors ⇒ Array<DeviceErrors>
Errors associated with the device.
3397 |
# File 'lib/seam/resources/event.rb', line 3397 resource_list_accessor :device_errors, DeviceErrors |
#device_warnings ⇒ Array<DeviceWarnings>
Warnings associated with the device.
3400 |
# File 'lib/seam/resources/event.rb', line 3400 resource_list_accessor :device_warnings, DeviceWarnings |
#occurred_at ⇒ Time
Date and time at which the event occurred.
3441 |
# File 'lib/seam/resources/event.rb', line 3441 date_accessor :occurred_at |