Class: Seam::Resources::SeamEvent::LockAccessDenied

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

The lock denied access to a user after one or more consecutive invalid attempts to unlock the device.

Defined Under Namespace

Classes: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#access_code_idString?

ID of the access code that was used in the unlock attempts.

Returns:

  • (String, nil)


4422
4423
4424
# File 'lib/seam/resources/event.rb', line 4422

def access_code_id
  @access_code_id
end

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4425
4426
4427
# File 'lib/seam/resources/event.rb', line 4425

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4428
4429
4430
# File 'lib/seam/resources/event.rb', line 4428

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4431
4432
4433
# File 'lib/seam/resources/event.rb', line 4431

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4434
4435
4436
# File 'lib/seam/resources/event.rb', line 4434

def 
  @device_custom_metadata
end

#device_idString?

ID of the affected device.

Returns:

  • (String, nil)


4437
4438
4439
# File 'lib/seam/resources/event.rb', line 4437

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4440
4441
4442
# File 'lib/seam/resources/event.rb', line 4440

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4443
4444
4445
# File 'lib/seam/resources/event.rb', line 4443

def event_id
  @event_id
end

#event_typeString

Known values:

  • lock.access_denied

Returns:

  • (String)


4447
4448
4449
# File 'lib/seam/resources/event.rb', line 4447

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4450
4451
4452
# File 'lib/seam/resources/event.rb', line 4450

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4453
# File 'lib/seam/resources/event.rb', line 4453

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4456
# File 'lib/seam/resources/event.rb', line 4456

date_accessor :occurred_at

#reasonReason?

Why access was denied, when the provider reports a determinable cause. Omitted when unknown.

Returns:



4419
# File 'lib/seam/resources/event.rb', line 4419

resource_accessor :reason, Reason