Class: Seam::Resources::SeamEvent::LockAccessDenied
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::LockAccessDenied
- Defined in:
- lib/seam/resources/event.rb
Overview
The lock denied access to a user after one or more consecutive invalid attempts to unlock the device.
Defined Under Namespace
Classes: Reason
Instance Attribute Summary collapse
-
#access_code_id ⇒ String?
ID of the access code that was used in the unlock attempts.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String?
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
lock.access_denied. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
-
#reason ⇒ Reason?
Why access was denied, when the provider reports a determinable cause.
Instance Attribute Details
#access_code_id ⇒ String?
ID of the access code that was used in the unlock attempts.
4422 4423 4424 |
# File 'lib/seam/resources/event.rb', line 4422 def access_code_id @access_code_id end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4425 4426 4427 |
# File 'lib/seam/resources/event.rb', line 4425 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4428 4429 4430 |
# File 'lib/seam/resources/event.rb', line 4428 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4431 4432 4433 |
# File 'lib/seam/resources/event.rb', line 4431 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4434 4435 4436 |
# File 'lib/seam/resources/event.rb', line 4434 def @device_custom_metadata end |
#device_id ⇒ String?
ID of the affected device.
4437 4438 4439 |
# File 'lib/seam/resources/event.rb', line 4437 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4440 4441 4442 |
# File 'lib/seam/resources/event.rb', line 4440 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4443 4444 4445 |
# File 'lib/seam/resources/event.rb', line 4443 def event_id @event_id end |
#event_type ⇒ String
Known values:
lock.access_denied
4447 4448 4449 |
# File 'lib/seam/resources/event.rb', line 4447 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4450 4451 4452 |
# File 'lib/seam/resources/event.rb', line 4450 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4453 |
# File 'lib/seam/resources/event.rb', line 4453 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4456 |
# File 'lib/seam/resources/event.rb', line 4456 date_accessor :occurred_at |