Class: Seam::Resources::SeamEvent::NoiseSensorNoiseThresholdTriggered
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::NoiseSensorNoiseThresholdTriggered
- Defined in:
- lib/seam/resources/event.rb
Overview
Extended periods of noise or noise exceeding a threshold were detected.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
noise_sensor.noise_threshold_triggered. -
#minut_metadata ⇒ Hash?
Metadata from Minut.
-
#noise_level_decibels ⇒ Float?
Detected noise level in decibels.
-
#noise_level_nrs ⇒ Float?
Detected noise level in Noiseaware Noise Risk Score (NRS).
-
#noise_threshold_id ⇒ String?
ID of the noise threshold that was triggered.
-
#noise_threshold_name ⇒ String?
Name of the noise threshold that was triggered.
-
#noiseaware_metadata ⇒ Hash?
Metadata from Noiseaware.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4215 4216 4217 |
# File 'lib/seam/resources/event.rb', line 4215 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4218 4219 4220 |
# File 'lib/seam/resources/event.rb', line 4218 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4221 4222 4223 |
# File 'lib/seam/resources/event.rb', line 4221 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4224 4225 4226 |
# File 'lib/seam/resources/event.rb', line 4224 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4227 4228 4229 |
# File 'lib/seam/resources/event.rb', line 4227 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4230 4231 4232 |
# File 'lib/seam/resources/event.rb', line 4230 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4233 4234 4235 |
# File 'lib/seam/resources/event.rb', line 4233 def event_id @event_id end |
#event_type ⇒ String
Known values:
noise_sensor.noise_threshold_triggered
4237 4238 4239 |
# File 'lib/seam/resources/event.rb', line 4237 def event_type @event_type end |
#minut_metadata ⇒ Hash?
Metadata from Minut.
4240 4241 4242 |
# File 'lib/seam/resources/event.rb', line 4240 def @minut_metadata end |
#noise_level_decibels ⇒ Float?
Detected noise level in decibels.
4243 4244 4245 |
# File 'lib/seam/resources/event.rb', line 4243 def noise_level_decibels @noise_level_decibels end |
#noise_level_nrs ⇒ Float?
Detected noise level in Noiseaware Noise Risk Score (NRS).
4246 4247 4248 |
# File 'lib/seam/resources/event.rb', line 4246 def noise_level_nrs @noise_level_nrs end |
#noise_threshold_id ⇒ String?
ID of the noise threshold that was triggered.
4249 4250 4251 |
# File 'lib/seam/resources/event.rb', line 4249 def noise_threshold_id @noise_threshold_id end |
#noise_threshold_name ⇒ String?
Name of the noise threshold that was triggered.
4252 4253 4254 |
# File 'lib/seam/resources/event.rb', line 4252 def noise_threshold_name @noise_threshold_name end |
#noiseaware_metadata ⇒ Hash?
Metadata from Noiseaware.
4255 4256 4257 |
# File 'lib/seam/resources/event.rb', line 4255 def @noiseaware_metadata end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4258 4259 4260 |
# File 'lib/seam/resources/event.rb', line 4258 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4261 |
# File 'lib/seam/resources/event.rb', line 4261 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4264 |
# File 'lib/seam/resources/event.rb', line 4264 date_accessor :occurred_at |