Class: Seam::Resources::SeamEvent::PhoneDeactivated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::PhoneDeactivated
- Defined in:
- lib/seam/resources/event.rb
Overview
A phone device was deactivated.
Instance Attribute Summary collapse
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device; present when device_id is provided.
-
#device_id ⇒ String
ID of the affected phone device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
phone.deactivated. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device; present when device_id is provided.
4937 4938 4939 |
# File 'lib/seam/resources/event.rb', line 4937 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected phone device.
4940 4941 4942 |
# File 'lib/seam/resources/event.rb', line 4940 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4943 4944 4945 |
# File 'lib/seam/resources/event.rb', line 4943 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4946 4947 4948 |
# File 'lib/seam/resources/event.rb', line 4946 def event_id @event_id end |
#event_type ⇒ String
Known values:
phone.deactivated
4950 4951 4952 |
# File 'lib/seam/resources/event.rb', line 4950 def event_type @event_type end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4953 4954 4955 |
# File 'lib/seam/resources/event.rb', line 4953 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4956 |
# File 'lib/seam/resources/event.rb', line 4956 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4959 |
# File 'lib/seam/resources/event.rb', line 4959 date_accessor :occurred_at |