Class: Seam::Resources::SeamEvent::PhoneDeactivated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A phone device was deactivated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device; present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4930
4931
4932
# File 'lib/seam/resources/event.rb', line 4930

def 
  @device_custom_metadata
end

#device_idString

ID of the affected phone device.

Returns:

  • (String)


4933
4934
4935
# File 'lib/seam/resources/event.rb', line 4933

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4936
4937
4938
# File 'lib/seam/resources/event.rb', line 4936

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4939
4940
4941
# File 'lib/seam/resources/event.rb', line 4939

def event_id
  @event_id
end

#event_typeString

Known values:

  • phone.deactivated

Returns:

  • (String)


4943
4944
4945
# File 'lib/seam/resources/event.rb', line 4943

def event_type
  @event_type
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4946
4947
4948
# File 'lib/seam/resources/event.rb', line 4946

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4949
# File 'lib/seam/resources/event.rb', line 4949

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4952
# File 'lib/seam/resources/event.rb', line 4952

date_accessor :occurred_at