Class: Seam::Resources::SeamEvent::SpaceCreated

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A space was created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_entrance_idsArray<String>

IDs of all ACS entrances attached to the space when it was created.

Returns:

  • (Array<String>)


4995
4996
4997
# File 'lib/seam/resources/event.rb', line 4995

def acs_entrance_ids
  @acs_entrance_ids
end

#device_idsArray<String>

IDs of all devices attached to the space when it was created.

Returns:

  • (Array<String>)


4998
4999
5000
# File 'lib/seam/resources/event.rb', line 4998

def device_ids
  @device_ids
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


5001
5002
5003
# File 'lib/seam/resources/event.rb', line 5001

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


5004
5005
5006
# File 'lib/seam/resources/event.rb', line 5004

def event_id
  @event_id
end

#event_typeString

Type of the event. Known values:

  • space.created

Returns:

  • (String)


5009
5010
5011
# File 'lib/seam/resources/event.rb', line 5009

def event_type
  @event_type
end

#space_idString

ID of the affected space.

Returns:

  • (String)


5012
5013
5014
# File 'lib/seam/resources/event.rb', line 5012

def space_id
  @space_id
end

#space_keyString?

Unique key for the space within the workspace.

Returns:

  • (String, nil)


5015
5016
5017
# File 'lib/seam/resources/event.rb', line 5015

def space_key
  @space_key
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


5018
5019
5020
# File 'lib/seam/resources/event.rb', line 5018

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


5021
# File 'lib/seam/resources/event.rb', line 5021

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


5024
# File 'lib/seam/resources/event.rb', line 5024

date_accessor :occurred_at