Class: Seam::Resources::SeamEvent::SpaceCreated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::SpaceCreated
- Defined in:
- lib/seam/resources/event.rb
Overview
A space was created.
Instance Attribute Summary collapse
-
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances attached to the space when it was created.
-
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was created.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Type of the event.
-
#space_id ⇒ String
ID of the affected space.
-
#space_key ⇒ String?
Unique key for the space within the workspace.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances attached to the space when it was created.
4995 4996 4997 |
# File 'lib/seam/resources/event.rb', line 4995 def acs_entrance_ids @acs_entrance_ids end |
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was created.
4998 4999 5000 |
# File 'lib/seam/resources/event.rb', line 4998 def device_ids @device_ids end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
5001 5002 5003 |
# File 'lib/seam/resources/event.rb', line 5001 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
5004 5005 5006 |
# File 'lib/seam/resources/event.rb', line 5004 def event_id @event_id end |
#event_type ⇒ String
Type of the event. Known values:
space.created
5009 5010 5011 |
# File 'lib/seam/resources/event.rb', line 5009 def event_type @event_type end |
#space_id ⇒ String
ID of the affected space.
5012 5013 5014 |
# File 'lib/seam/resources/event.rb', line 5012 def space_id @space_id end |
#space_key ⇒ String?
Unique key for the space within the workspace.
5015 5016 5017 |
# File 'lib/seam/resources/event.rb', line 5015 def space_key @space_key end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
5018 5019 5020 |
# File 'lib/seam/resources/event.rb', line 5018 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
5021 |
# File 'lib/seam/resources/event.rb', line 5021 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
5024 |
# File 'lib/seam/resources/event.rb', line 5024 date_accessor :occurred_at |