Class: Seam::Resources::SeamEvent::SpaceDeleted

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A space was deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_entrance_idsArray<String>

IDs of all ACS entrances currently attached to the space when it was deleted.

Returns:

  • (Array<String>)


5031
5032
5033
# File 'lib/seam/resources/event.rb', line 5031

def acs_entrance_ids
  @acs_entrance_ids
end

#device_idsArray<String>

IDs of all devices attached to the space when it was deleted.

Returns:

  • (Array<String>)


5034
5035
5036
# File 'lib/seam/resources/event.rb', line 5034

def device_ids
  @device_ids
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


5037
5038
5039
# File 'lib/seam/resources/event.rb', line 5037

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


5040
5041
5042
# File 'lib/seam/resources/event.rb', line 5040

def event_id
  @event_id
end

#event_typeString

Type of the event. Known values:

  • space.deleted

Returns:

  • (String)


5045
5046
5047
# File 'lib/seam/resources/event.rb', line 5045

def event_type
  @event_type
end

#space_idString

ID of the affected space.

Returns:

  • (String)


5048
5049
5050
# File 'lib/seam/resources/event.rb', line 5048

def space_id
  @space_id
end

#space_keyString?

Unique key for the space within the workspace.

Returns:

  • (String, nil)


5051
5052
5053
# File 'lib/seam/resources/event.rb', line 5051

def space_key
  @space_key
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


5054
5055
5056
# File 'lib/seam/resources/event.rb', line 5054

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


5057
# File 'lib/seam/resources/event.rb', line 5057

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


5060
# File 'lib/seam/resources/event.rb', line 5060

date_accessor :occurred_at