Class: Seam::Resources::SeamEvent::SpaceDeleted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::SpaceDeleted
- Defined in:
- lib/seam/resources/event.rb
Overview
A space was deleted.
Instance Attribute Summary collapse
-
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances currently attached to the space when it was deleted.
-
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was deleted.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Type of the event.
-
#space_id ⇒ String
ID of the affected space.
-
#space_key ⇒ String?
Unique key for the space within the workspace.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#acs_entrance_ids ⇒ Array<String>
IDs of all ACS entrances currently attached to the space when it was deleted.
5031 5032 5033 |
# File 'lib/seam/resources/event.rb', line 5031 def acs_entrance_ids @acs_entrance_ids end |
#device_ids ⇒ Array<String>
IDs of all devices attached to the space when it was deleted.
5034 5035 5036 |
# File 'lib/seam/resources/event.rb', line 5034 def device_ids @device_ids end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
5037 5038 5039 |
# File 'lib/seam/resources/event.rb', line 5037 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
5040 5041 5042 |
# File 'lib/seam/resources/event.rb', line 5040 def event_id @event_id end |
#event_type ⇒ String
Type of the event. Known values:
space.deleted
5045 5046 5047 |
# File 'lib/seam/resources/event.rb', line 5045 def event_type @event_type end |
#space_id ⇒ String
ID of the affected space.
5048 5049 5050 |
# File 'lib/seam/resources/event.rb', line 5048 def space_id @space_id end |
#space_key ⇒ String?
Unique key for the space within the workspace.
5051 5052 5053 |
# File 'lib/seam/resources/event.rb', line 5051 def space_key @space_key end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
5054 5055 5056 |
# File 'lib/seam/resources/event.rb', line 5054 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
5057 |
# File 'lib/seam/resources/event.rb', line 5057 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
5060 |
# File 'lib/seam/resources/event.rb', line 5060 date_accessor :occurred_at |