Class: Seam::Resources::SeamEvent::SpaceDeviceMembershipChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A device was added or removed from a space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acs_entrance_idsArray<String>

IDs of all ACS entrances currently attached to the space.

Returns:

  • (Array<String>)


4959
4960
4961
# File 'lib/seam/resources/event.rb', line 4959

def acs_entrance_ids
  @acs_entrance_ids
end

#device_idsArray<String>

IDs of all devices currently attached to the space.

Returns:

  • (Array<String>)


4962
4963
4964
# File 'lib/seam/resources/event.rb', line 4962

def device_ids
  @device_ids
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4965
4966
4967
# File 'lib/seam/resources/event.rb', line 4965

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4968
4969
4970
# File 'lib/seam/resources/event.rb', line 4968

def event_id
  @event_id
end

#event_typeString

Type of the event. Known values:

  • space.device_membership_changed

Returns:

  • (String)


4973
4974
4975
# File 'lib/seam/resources/event.rb', line 4973

def event_type
  @event_type
end

#space_idString

ID of the affected space.

Returns:

  • (String)


4976
4977
4978
# File 'lib/seam/resources/event.rb', line 4976

def space_id
  @space_id
end

#space_keyString?

Unique key for the space within the workspace.

Returns:

  • (String, nil)


4979
4980
4981
# File 'lib/seam/resources/event.rb', line 4979

def space_key
  @space_key
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4982
4983
4984
# File 'lib/seam/resources/event.rb', line 4982

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4985
# File 'lib/seam/resources/event.rb', line 4985

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4988
# File 'lib/seam/resources/event.rb', line 4988

date_accessor :occurred_at