Class: Seam::Resources::SeamEvent::ThermostatClimatePresetActivated
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatClimatePresetActivated
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat climate preset was activated.
Instance Attribute Summary collapse
-
#climate_preset_key ⇒ String
Key of the climate preset that was activated.
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.climate_preset_activated. -
#is_fallback_climate_preset ⇒ Boolean
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
-
#thermostat_schedule_id ⇒ String?
ID of the thermostat schedule that prompted the affected climate preset to be activated.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#climate_preset_key ⇒ String
Key of the climate preset that was activated.
4470 4471 4472 |
# File 'lib/seam/resources/event.rb', line 4470 def climate_preset_key @climate_preset_key end |
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4473 4474 4475 |
# File 'lib/seam/resources/event.rb', line 4473 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4476 4477 4478 |
# File 'lib/seam/resources/event.rb', line 4476 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4479 4480 4481 |
# File 'lib/seam/resources/event.rb', line 4479 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4482 4483 4484 |
# File 'lib/seam/resources/event.rb', line 4482 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4485 4486 4487 |
# File 'lib/seam/resources/event.rb', line 4485 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4488 4489 4490 |
# File 'lib/seam/resources/event.rb', line 4488 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4491 4492 4493 |
# File 'lib/seam/resources/event.rb', line 4491 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.climate_preset_activated
4495 4496 4497 |
# File 'lib/seam/resources/event.rb', line 4495 def event_type @event_type end |
#is_fallback_climate_preset ⇒ Boolean
Indicates whether the climate preset that was activated is the fallback climate preset for the thermostat.
4498 4499 4500 |
# File 'lib/seam/resources/event.rb', line 4498 def is_fallback_climate_preset @is_fallback_climate_preset end |
#thermostat_schedule_id ⇒ String?
ID of the thermostat schedule that prompted the affected climate preset to be activated.
4501 4502 4503 |
# File 'lib/seam/resources/event.rb', line 4501 def thermostat_schedule_id @thermostat_schedule_id end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4504 4505 4506 |
# File 'lib/seam/resources/event.rb', line 4504 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4507 |
# File 'lib/seam/resources/event.rb', line 4507 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4510 |
# File 'lib/seam/resources/event.rb', line 4510 date_accessor :occurred_at |