Class: Seam::Resources::SeamEvent::ThermostatManuallyAdjusted
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatManuallyAdjusted
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat was adjusted manually.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C).
-
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F).
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.manually_adjusted. -
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as
on,auto, orcirculate. -
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C).
-
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F).
-
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as
heat,cool,heat_cool, oroff. -
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#event_method ⇒ String
Method used to adjust the affected thermostat manually.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4510 4511 4512 |
# File 'lib/seam/resources/event.rb', line 4510 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4513 4514 4515 |
# File 'lib/seam/resources/event.rb', line 4513 def connected_account_id @connected_account_id end |
#cooling_set_point_celsius ⇒ Float?
Temperature to which the thermostat should cool (in °C). See also Set Points.
4516 4517 4518 |
# File 'lib/seam/resources/event.rb', line 4516 def cooling_set_point_celsius @cooling_set_point_celsius end |
#cooling_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should cool (in °F). See also Set Points.
4519 4520 4521 |
# File 'lib/seam/resources/event.rb', line 4519 def cooling_set_point_fahrenheit @cooling_set_point_fahrenheit end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4522 4523 4524 |
# File 'lib/seam/resources/event.rb', line 4522 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4525 4526 4527 |
# File 'lib/seam/resources/event.rb', line 4525 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4528 4529 4530 |
# File 'lib/seam/resources/event.rb', line 4528 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4531 4532 4533 |
# File 'lib/seam/resources/event.rb', line 4531 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4534 4535 4536 |
# File 'lib/seam/resources/event.rb', line 4534 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.manually_adjusted
4538 4539 4540 |
# File 'lib/seam/resources/event.rb', line 4538 def event_type @event_type end |
#fan_mode_setting ⇒ String?
Desired fan mode setting, such as on, auto, or circulate.
Known values:
autooncirculate
4545 4546 4547 |
# File 'lib/seam/resources/event.rb', line 4545 def fan_mode_setting @fan_mode_setting end |
#heating_set_point_celsius ⇒ Float?
Temperature to which the thermostat should heat (in °C). See also Set Points.
4548 4549 4550 |
# File 'lib/seam/resources/event.rb', line 4548 def heating_set_point_celsius @heating_set_point_celsius end |
#heating_set_point_fahrenheit ⇒ Float?
Temperature to which the thermostat should heat (in °F). See also Set Points.
4551 4552 4553 |
# File 'lib/seam/resources/event.rb', line 4551 def heating_set_point_fahrenheit @heating_set_point_fahrenheit end |
#hvac_mode_setting ⇒ String?
Desired HVAC mode setting, such as heat, cool, heat_cool, or off.
Known values:
offheatcoolheat_cooleco
4560 4561 4562 |
# File 'lib/seam/resources/event.rb', line 4560 def hvac_mode_setting @hvac_mode_setting end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4569 4570 4571 |
# File 'lib/seam/resources/event.rb', line 4569 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4572 |
# File 'lib/seam/resources/event.rb', line 4572 date_accessor :created_at |
#event_method ⇒ String
Method used to adjust the affected thermostat manually. seam indicates that the Seam API, Seam CLI, or Seam Console was used to adjust the thermostat.
Known values:
seamexternal
4566 |
# File 'lib/seam/resources/event.rb', line 4566 aliased_accessor :event_method, from: :method |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4575 |
# File 'lib/seam/resources/event.rb', line 4575 date_accessor :occurred_at |