Class: Seam::Resources::SeamEvent::ThermostatTemperatureChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatTemperatureChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat's reported temperature changed by at least 1 °C.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.temperature_changed. -
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4751 4752 4753 |
# File 'lib/seam/resources/event.rb', line 4751 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4754 4755 4756 |
# File 'lib/seam/resources/event.rb', line 4754 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4757 4758 4759 |
# File 'lib/seam/resources/event.rb', line 4757 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4760 4761 4762 |
# File 'lib/seam/resources/event.rb', line 4760 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4763 4764 4765 |
# File 'lib/seam/resources/event.rb', line 4763 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4766 4767 4768 |
# File 'lib/seam/resources/event.rb', line 4766 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4769 4770 4771 |
# File 'lib/seam/resources/event.rb', line 4769 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.temperature_changed
4773 4774 4775 |
# File 'lib/seam/resources/event.rb', line 4773 def event_type @event_type end |
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
4776 4777 4778 |
# File 'lib/seam/resources/event.rb', line 4776 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
4779 4780 4781 |
# File 'lib/seam/resources/event.rb', line 4779 def temperature_fahrenheit @temperature_fahrenheit end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4782 4783 4784 |
# File 'lib/seam/resources/event.rb', line 4782 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4785 |
# File 'lib/seam/resources/event.rb', line 4785 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4788 |
# File 'lib/seam/resources/event.rb', line 4788 date_accessor :occurred_at |