Class: Seam::Resources::SeamEvent::ThermostatTemperatureChanged

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat's reported temperature changed by at least 1 °C.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4744
4745
4746
# File 'lib/seam/resources/event.rb', line 4744

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4747
4748
4749
# File 'lib/seam/resources/event.rb', line 4747

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4750
4751
4752
# File 'lib/seam/resources/event.rb', line 4750

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4753
4754
4755
# File 'lib/seam/resources/event.rb', line 4753

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4756
4757
4758
# File 'lib/seam/resources/event.rb', line 4756

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4759
4760
4761
# File 'lib/seam/resources/event.rb', line 4759

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4762
4763
4764
# File 'lib/seam/resources/event.rb', line 4762

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.temperature_changed

Returns:

  • (String)


4766
4767
4768
# File 'lib/seam/resources/event.rb', line 4766

def event_type
  @event_type
end

#temperature_celsiusFloat

Temperature, in °C, reported by the affected thermostat.

Returns:

  • (Float)


4769
4770
4771
# File 'lib/seam/resources/event.rb', line 4769

def temperature_celsius
  @temperature_celsius
end

#temperature_fahrenheitFloat

Temperature, in °F, reported by the affected thermostat.

Returns:

  • (Float)


4772
4773
4774
# File 'lib/seam/resources/event.rb', line 4772

def temperature_fahrenheit
  @temperature_fahrenheit
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4775
4776
4777
# File 'lib/seam/resources/event.rb', line 4775

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4778
# File 'lib/seam/resources/event.rb', line 4778

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4781
# File 'lib/seam/resources/event.rb', line 4781

date_accessor :occurred_at