Class: Seam::Resources::SeamEvent::ThermostatTemperatureChanged
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatTemperatureChanged
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat's reported temperature changed by at least 1 °C.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.temperature_changed. -
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4744 4745 4746 |
# File 'lib/seam/resources/event.rb', line 4744 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4747 4748 4749 |
# File 'lib/seam/resources/event.rb', line 4747 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4750 4751 4752 |
# File 'lib/seam/resources/event.rb', line 4750 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4753 4754 4755 |
# File 'lib/seam/resources/event.rb', line 4753 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4756 4757 4758 |
# File 'lib/seam/resources/event.rb', line 4756 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4759 4760 4761 |
# File 'lib/seam/resources/event.rb', line 4759 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4762 4763 4764 |
# File 'lib/seam/resources/event.rb', line 4762 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.temperature_changed
4766 4767 4768 |
# File 'lib/seam/resources/event.rb', line 4766 def event_type @event_type end |
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
4769 4770 4771 |
# File 'lib/seam/resources/event.rb', line 4769 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
4772 4773 4774 |
# File 'lib/seam/resources/event.rb', line 4772 def temperature_fahrenheit @temperature_fahrenheit end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4775 4776 4777 |
# File 'lib/seam/resources/event.rb', line 4775 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4778 |
# File 'lib/seam/resources/event.rb', line 4778 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4781 |
# File 'lib/seam/resources/event.rb', line 4781 date_accessor :occurred_at |