Class: Seam::Resources::SeamEvent::ThermostatTemperatureReachedSetPoint
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatTemperatureReachedSetPoint
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat's temperature reading is within 1 °C of the configured cooling or heating set point.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#desired_temperature_celsius ⇒ Float?
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
-
#desired_temperature_fahrenheit ⇒ Float?
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.temperature_reached_set_point. -
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4694 4695 4696 |
# File 'lib/seam/resources/event.rb', line 4694 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4697 4698 4699 |
# File 'lib/seam/resources/event.rb', line 4697 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4700 4701 4702 |
# File 'lib/seam/resources/event.rb', line 4700 def customer_key @customer_key end |
#desired_temperature_celsius ⇒ Float?
Desired temperature, in °C, defined by the affected thermostat's cooling or heating set point.
4703 4704 4705 |
# File 'lib/seam/resources/event.rb', line 4703 def desired_temperature_celsius @desired_temperature_celsius end |
#desired_temperature_fahrenheit ⇒ Float?
Desired temperature, in °F, defined by the affected thermostat's cooling or heating set point.
4706 4707 4708 |
# File 'lib/seam/resources/event.rb', line 4706 def desired_temperature_fahrenheit @desired_temperature_fahrenheit end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4709 4710 4711 |
# File 'lib/seam/resources/event.rb', line 4709 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4712 4713 4714 |
# File 'lib/seam/resources/event.rb', line 4712 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4715 4716 4717 |
# File 'lib/seam/resources/event.rb', line 4715 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4718 4719 4720 |
# File 'lib/seam/resources/event.rb', line 4718 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.temperature_reached_set_point
4722 4723 4724 |
# File 'lib/seam/resources/event.rb', line 4722 def event_type @event_type end |
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
4725 4726 4727 |
# File 'lib/seam/resources/event.rb', line 4725 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
4728 4729 4730 |
# File 'lib/seam/resources/event.rb', line 4728 def temperature_fahrenheit @temperature_fahrenheit end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4731 4732 4733 |
# File 'lib/seam/resources/event.rb', line 4731 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4734 |
# File 'lib/seam/resources/event.rb', line 4734 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4737 |
# File 'lib/seam/resources/event.rb', line 4737 date_accessor :occurred_at |