Class: Seam::Resources::SeamEvent::ThermostatTemperatureThresholdExceeded
- Inherits:
-
SeamEvent
- Object
- SeamEvent
- Seam::Resources::SeamEvent::ThermostatTemperatureThresholdExceeded
- Defined in:
- lib/seam/resources/event.rb
Overview
A thermostat's temperature reading exceeded the set threshold.
Instance Attribute Summary collapse
-
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
-
#connected_account_id ⇒ String
ID of the connected account associated with the event.
-
#customer_key ⇒ String?
The customer key associated with the device, if any.
-
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
-
#device_id ⇒ String
ID of the affected device.
-
#event_description ⇒ String?
Human-readable description of the event.
-
#event_id ⇒ String
ID of the event.
-
#event_type ⇒ String
Known values: -
thermostat.temperature_threshold_exceeded. -
#lower_limit_celsius ⇒ Float?
Lower temperature limit, in °C, defined by the set threshold.
-
#lower_limit_fahrenheit ⇒ Float?
Lower temperature limit, in °F, defined by the set threshold.
-
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
-
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
-
#upper_limit_celsius ⇒ Float?
Upper temperature limit, in °C, defined by the set threshold.
-
#upper_limit_fahrenheit ⇒ Float?
Upper temperature limit, in °F, defined by the set threshold.
-
#workspace_id ⇒ String
ID of the workspace associated with the event.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the event was created.
-
#occurred_at ⇒ Time
Date and time at which the event occurred.
Instance Attribute Details
#connected_account_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the connected account, present when connected_account_id is provided.
4589 4590 4591 |
# File 'lib/seam/resources/event.rb', line 4589 def @connected_account_custom_metadata end |
#connected_account_id ⇒ String
ID of the connected account associated with the event.
4592 4593 4594 |
# File 'lib/seam/resources/event.rb', line 4592 def connected_account_id @connected_account_id end |
#customer_key ⇒ String?
The customer key associated with the device, if any.
4595 4596 4597 |
# File 'lib/seam/resources/event.rb', line 4595 def customer_key @customer_key end |
#device_custom_metadata ⇒ Hash{String => String, Boolean}?
Custom metadata of the device, present when device_id is provided.
4598 4599 4600 |
# File 'lib/seam/resources/event.rb', line 4598 def @device_custom_metadata end |
#device_id ⇒ String
ID of the affected device.
4601 4602 4603 |
# File 'lib/seam/resources/event.rb', line 4601 def device_id @device_id end |
#event_description ⇒ String?
Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.
4604 4605 4606 |
# File 'lib/seam/resources/event.rb', line 4604 def event_description @event_description end |
#event_id ⇒ String
ID of the event.
4607 4608 4609 |
# File 'lib/seam/resources/event.rb', line 4607 def event_id @event_id end |
#event_type ⇒ String
Known values:
thermostat.temperature_threshold_exceeded
4611 4612 4613 |
# File 'lib/seam/resources/event.rb', line 4611 def event_type @event_type end |
#lower_limit_celsius ⇒ Float?
Lower temperature limit, in °C, defined by the set threshold.
4614 4615 4616 |
# File 'lib/seam/resources/event.rb', line 4614 def lower_limit_celsius @lower_limit_celsius end |
#lower_limit_fahrenheit ⇒ Float?
Lower temperature limit, in °F, defined by the set threshold.
4617 4618 4619 |
# File 'lib/seam/resources/event.rb', line 4617 def lower_limit_fahrenheit @lower_limit_fahrenheit end |
#temperature_celsius ⇒ Float
Temperature, in °C, reported by the affected thermostat.
4620 4621 4622 |
# File 'lib/seam/resources/event.rb', line 4620 def temperature_celsius @temperature_celsius end |
#temperature_fahrenheit ⇒ Float
Temperature, in °F, reported by the affected thermostat.
4623 4624 4625 |
# File 'lib/seam/resources/event.rb', line 4623 def temperature_fahrenheit @temperature_fahrenheit end |
#upper_limit_celsius ⇒ Float?
Upper temperature limit, in °C, defined by the set threshold.
4626 4627 4628 |
# File 'lib/seam/resources/event.rb', line 4626 def upper_limit_celsius @upper_limit_celsius end |
#upper_limit_fahrenheit ⇒ Float?
Upper temperature limit, in °F, defined by the set threshold.
4629 4630 4631 |
# File 'lib/seam/resources/event.rb', line 4629 def upper_limit_fahrenheit @upper_limit_fahrenheit end |
#workspace_id ⇒ String
ID of the workspace associated with the event.
4632 4633 4634 |
# File 'lib/seam/resources/event.rb', line 4632 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the event was created.
4635 |
# File 'lib/seam/resources/event.rb', line 4635 date_accessor :created_at |
#occurred_at ⇒ Time
Date and time at which the event occurred.
4638 |
# File 'lib/seam/resources/event.rb', line 4638 date_accessor :occurred_at |