Class: Seam::Resources::SeamEvent::ThermostatTemperatureThresholdExceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat's temperature reading exceeded the set threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4582
4583
4584
# File 'lib/seam/resources/event.rb', line 4582

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4585
4586
4587
# File 'lib/seam/resources/event.rb', line 4585

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4588
4589
4590
# File 'lib/seam/resources/event.rb', line 4588

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4591
4592
4593
# File 'lib/seam/resources/event.rb', line 4591

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4594
4595
4596
# File 'lib/seam/resources/event.rb', line 4594

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4597
4598
4599
# File 'lib/seam/resources/event.rb', line 4597

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4600
4601
4602
# File 'lib/seam/resources/event.rb', line 4600

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.temperature_threshold_exceeded

Returns:

  • (String)


4604
4605
4606
# File 'lib/seam/resources/event.rb', line 4604

def event_type
  @event_type
end

#lower_limit_celsiusFloat?

Lower temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


4607
4608
4609
# File 'lib/seam/resources/event.rb', line 4607

def lower_limit_celsius
  @lower_limit_celsius
end

#lower_limit_fahrenheitFloat?

Lower temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


4610
4611
4612
# File 'lib/seam/resources/event.rb', line 4610

def lower_limit_fahrenheit
  @lower_limit_fahrenheit
end

#temperature_celsiusFloat

Temperature, in °C, reported by the affected thermostat.

Returns:

  • (Float)


4613
4614
4615
# File 'lib/seam/resources/event.rb', line 4613

def temperature_celsius
  @temperature_celsius
end

#temperature_fahrenheitFloat

Temperature, in °F, reported by the affected thermostat.

Returns:

  • (Float)


4616
4617
4618
# File 'lib/seam/resources/event.rb', line 4616

def temperature_fahrenheit
  @temperature_fahrenheit
end

#upper_limit_celsiusFloat?

Upper temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


4619
4620
4621
# File 'lib/seam/resources/event.rb', line 4619

def upper_limit_celsius
  @upper_limit_celsius
end

#upper_limit_fahrenheitFloat?

Upper temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


4622
4623
4624
# File 'lib/seam/resources/event.rb', line 4622

def upper_limit_fahrenheit
  @upper_limit_fahrenheit
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4625
4626
4627
# File 'lib/seam/resources/event.rb', line 4625

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4628
# File 'lib/seam/resources/event.rb', line 4628

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4631
# File 'lib/seam/resources/event.rb', line 4631

date_accessor :occurred_at