Class: Seam::Resources::SeamEvent::ThermostatTemperatureThresholdNoLongerExceeded

Inherits:
SeamEvent
  • Object
show all
Defined in:
lib/seam/resources/event.rb

Overview

A thermostat's temperature reading no longer exceeds the set threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#connected_account_custom_metadataHash{String => String, Boolean}?

Custom metadata of the connected account, present when connected_account_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4638
4639
4640
# File 'lib/seam/resources/event.rb', line 4638

def 
  @connected_account_custom_metadata
end

#connected_account_idString

ID of the connected account associated with the event.

Returns:

  • (String)


4641
4642
4643
# File 'lib/seam/resources/event.rb', line 4641

def 
  @connected_account_id
end

#customer_keyString?

The customer key associated with the device, if any.

Returns:

  • (String, nil)


4644
4645
4646
# File 'lib/seam/resources/event.rb', line 4644

def customer_key
  @customer_key
end

#device_custom_metadataHash{String => String, Boolean}?

Custom metadata of the device, present when device_id is provided.

Returns:

  • (Hash{String => String, Boolean}, nil)


4647
4648
4649
# File 'lib/seam/resources/event.rb', line 4647

def 
  @device_custom_metadata
end

#device_idString

ID of the affected device.

Returns:

  • (String)


4650
4651
4652
# File 'lib/seam/resources/event.rb', line 4650

def device_id
  @device_id
end

#event_descriptionString?

Human-readable description of the event. Persisted when the event is created (so the creating code, including a provider, can supply a tailored description) and otherwise derived from the event.

Returns:

  • (String, nil)


4653
4654
4655
# File 'lib/seam/resources/event.rb', line 4653

def event_description
  @event_description
end

#event_idString

ID of the event.

Returns:

  • (String)


4656
4657
4658
# File 'lib/seam/resources/event.rb', line 4656

def event_id
  @event_id
end

#event_typeString

Known values:

  • thermostat.temperature_threshold_no_longer_exceeded

Returns:

  • (String)


4660
4661
4662
# File 'lib/seam/resources/event.rb', line 4660

def event_type
  @event_type
end

#lower_limit_celsiusFloat?

Lower temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


4663
4664
4665
# File 'lib/seam/resources/event.rb', line 4663

def lower_limit_celsius
  @lower_limit_celsius
end

#lower_limit_fahrenheitFloat?

Lower temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


4666
4667
4668
# File 'lib/seam/resources/event.rb', line 4666

def lower_limit_fahrenheit
  @lower_limit_fahrenheit
end

#temperature_celsiusFloat

Temperature, in °C, reported by the affected thermostat.

Returns:

  • (Float)


4669
4670
4671
# File 'lib/seam/resources/event.rb', line 4669

def temperature_celsius
  @temperature_celsius
end

#temperature_fahrenheitFloat

Temperature, in °F, reported by the affected thermostat.

Returns:

  • (Float)


4672
4673
4674
# File 'lib/seam/resources/event.rb', line 4672

def temperature_fahrenheit
  @temperature_fahrenheit
end

#upper_limit_celsiusFloat?

Upper temperature limit, in °C, defined by the set threshold.

Returns:

  • (Float, nil)


4675
4676
4677
# File 'lib/seam/resources/event.rb', line 4675

def upper_limit_celsius
  @upper_limit_celsius
end

#upper_limit_fahrenheitFloat?

Upper temperature limit, in °F, defined by the set threshold.

Returns:

  • (Float, nil)


4678
4679
4680
# File 'lib/seam/resources/event.rb', line 4678

def upper_limit_fahrenheit
  @upper_limit_fahrenheit
end

#workspace_idString

ID of the workspace associated with the event.

Returns:

  • (String)


4681
4682
4683
# File 'lib/seam/resources/event.rb', line 4681

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the event was created.

Returns:

  • (Time)


4684
# File 'lib/seam/resources/event.rb', line 4684

date_accessor :created_at

#occurred_atTime

Date and time at which the event occurred.

Returns:

  • (Time)


4687
# File 'lib/seam/resources/event.rb', line 4687

date_accessor :occurred_at