Class: Seam::Resources::Space

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/space.rb

Overview

Represents a space that is a logical grouping of devices and entrances. You can assign access to an entire space, thereby making granting access more efficient.

Defined Under Namespace

Classes: CustomerData, Geolocation

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_entrance_countObject

Number of entrances in the space.



28
29
30
# File 'lib/seam/resources/space.rb', line 28

def acs_entrance_count
  @acs_entrance_count
end

#customer_keyObject

Customer key associated with the space.



30
31
32
# File 'lib/seam/resources/space.rb', line 30

def customer_key
  @customer_key
end

#device_countObject

Number of devices in the space.



32
33
34
# File 'lib/seam/resources/space.rb', line 32

def device_count
  @device_count
end

#display_nameObject

Display name for the space.



34
35
36
# File 'lib/seam/resources/space.rb', line 34

def display_name
  @display_name
end

#nameObject

Name of the space.



36
37
38
# File 'lib/seam/resources/space.rb', line 36

def name
  @name
end

#space_idObject

ID of the space.



38
39
40
# File 'lib/seam/resources/space.rb', line 38

def space_id
  @space_id
end

#space_keyObject

Unique key for the space within the workspace.



40
41
42
# File 'lib/seam/resources/space.rb', line 40

def space_key
  @space_key
end

#workspace_idObject

ID of the workspace associated with the space.



42
43
44
# File 'lib/seam/resources/space.rb', line 42

def workspace_id
  @workspace_id
end