Class: Seam::Resources::Space

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/space.rb

Overview

Represents a space that is a logical grouping of devices and entrances. You can assign access to an entire space, thereby making granting access more efficient.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_entrance_countObject

Number of entrances in the space.



8
9
10
# File 'lib/seam/resources/space.rb', line 8

def acs_entrance_count
  @acs_entrance_count
end

#customer_dataObject

Reservation/stay-related defaults for the space. Also carries the provider/PMS-supplied name under a <connector_type>_name key (e.g. guesty_name), which Seam preserves when you rename the space (read-only — managed by Seam).



10
11
12
# File 'lib/seam/resources/space.rb', line 10

def customer_data
  @customer_data
end

#customer_keyObject

Customer key associated with the space.



12
13
14
# File 'lib/seam/resources/space.rb', line 12

def customer_key
  @customer_key
end

#device_countObject

Number of devices in the space.



14
15
16
# File 'lib/seam/resources/space.rb', line 14

def device_count
  @device_count
end

#display_nameObject

Display name for the space.



16
17
18
# File 'lib/seam/resources/space.rb', line 16

def display_name
  @display_name
end

#geolocationObject

Geographic coordinates (latitude and longitude) of the space.



18
19
20
# File 'lib/seam/resources/space.rb', line 18

def geolocation
  @geolocation
end

#nameObject

Name of the space.



20
21
22
# File 'lib/seam/resources/space.rb', line 20

def name
  @name
end

#space_idObject

ID of the space.



22
23
24
# File 'lib/seam/resources/space.rb', line 22

def space_id
  @space_id
end

#space_keyObject

Unique key for the space within the workspace.



24
25
26
# File 'lib/seam/resources/space.rb', line 24

def space_key
  @space_key
end

#workspace_idObject

ID of the workspace associated with the space.



26
27
28
# File 'lib/seam/resources/space.rb', line 26

def workspace_id
  @workspace_id
end