Class: Seam::Resources::Space
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Space
- Defined in:
- lib/seam/resources/space.rb
Overview
Represents a space that is a logical grouping of devices and entrances. You can assign access to an entire space, thereby making granting access more efficient.
Instance Attribute Summary collapse
-
#acs_entrance_count ⇒ Object
Number of entrances in the space.
-
#customer_data ⇒ Object
Reservation/stay-related defaults for the space.
-
#customer_key ⇒ Object
Customer key associated with the space.
-
#device_count ⇒ Object
Number of devices in the space.
-
#display_name ⇒ Object
Display name for the space.
-
#geolocation ⇒ Object
Geographic coordinates (latitude and longitude) of the space.
-
#name ⇒ Object
Name of the space.
-
#space_id ⇒ Object
ID of the space.
-
#space_key ⇒ Object
Unique key for the space within the workspace.
-
#workspace_id ⇒ Object
ID of the workspace associated with the space.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_entrance_count ⇒ Object
Number of entrances in the space.
8 9 10 |
# File 'lib/seam/resources/space.rb', line 8 def acs_entrance_count @acs_entrance_count end |
#customer_data ⇒ Object
Reservation/stay-related defaults for the space. Also carries the provider/PMS-supplied name under a <connector_type>_name key (e.g. guesty_name), which Seam preserves when you rename the space (read-only — managed by Seam).
10 11 12 |
# File 'lib/seam/resources/space.rb', line 10 def customer_data @customer_data end |
#customer_key ⇒ Object
Customer key associated with the space.
12 13 14 |
# File 'lib/seam/resources/space.rb', line 12 def customer_key @customer_key end |
#device_count ⇒ Object
Number of devices in the space.
14 15 16 |
# File 'lib/seam/resources/space.rb', line 14 def device_count @device_count end |
#display_name ⇒ Object
Display name for the space.
16 17 18 |
# File 'lib/seam/resources/space.rb', line 16 def display_name @display_name end |
#geolocation ⇒ Object
Geographic coordinates (latitude and longitude) of the space.
18 19 20 |
# File 'lib/seam/resources/space.rb', line 18 def geolocation @geolocation end |
#name ⇒ Object
Name of the space.
20 21 22 |
# File 'lib/seam/resources/space.rb', line 20 def name @name end |
#space_id ⇒ Object
ID of the space.
22 23 24 |
# File 'lib/seam/resources/space.rb', line 22 def space_id @space_id end |
#space_key ⇒ Object
Unique key for the space within the workspace.
24 25 26 |
# File 'lib/seam/resources/space.rb', line 24 def space_key @space_key end |
#workspace_id ⇒ Object
ID of the workspace associated with the space.
26 27 28 |
# File 'lib/seam/resources/space.rb', line 26 def workspace_id @workspace_id end |