Class: Seam::Resources::Space::CustomerData
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Space::CustomerData
- Defined in:
- lib/seam/resources/space.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Postal address for the space.
-
#default_checkin_time ⇒ String?
Default check-in time for reservations at the space, as HH:mm or HH:mm:ss.
-
#default_checkout_time ⇒ String?
Default check-out time for reservations at the space, as HH:mm or HH:mm:ss.
-
#time_zone ⇒ String?
IANA time zone for the space, e.g.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#address ⇒ String?
Postal address for the space.
10 11 12 |
# File 'lib/seam/resources/space.rb', line 10 def address @address end |
#default_checkin_time ⇒ String?
Default check-in time for reservations at the space, as HH:mm or HH:mm:ss.
13 14 15 |
# File 'lib/seam/resources/space.rb', line 13 def default_checkin_time @default_checkin_time end |
#default_checkout_time ⇒ String?
Default check-out time for reservations at the space, as HH:mm or HH:mm:ss.
16 17 18 |
# File 'lib/seam/resources/space.rb', line 16 def default_checkout_time @default_checkout_time end |
#time_zone ⇒ String?
IANA time zone for the space, e.g. America/Los_Angeles.
19 20 21 |
# File 'lib/seam/resources/space.rb', line 19 def time_zone @time_zone end |