Class: Seam::Resources::Space::CustomerData
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Space::CustomerData
- Defined in:
- lib/seam/resources/space.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Postal address for the space.
-
#default_checkin_time ⇒ Object
Default check-in time for reservations at the space, as HH:mm or HH:mm:ss.
-
#default_checkout_time ⇒ Object
Default check-out time for reservations at the space, as HH:mm or HH:mm:ss.
-
#time_zone ⇒ Object
IANA time zone for the space, e.g.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#address ⇒ Object
Postal address for the space.
9 10 11 |
# File 'lib/seam/resources/space.rb', line 9 def address @address end |
#default_checkin_time ⇒ Object
Default check-in time for reservations at the space, as HH:mm or HH:mm:ss.
11 12 13 |
# File 'lib/seam/resources/space.rb', line 11 def default_checkin_time @default_checkin_time end |
#default_checkout_time ⇒ Object
Default check-out time for reservations at the space, as HH:mm or HH:mm:ss.
13 14 15 |
# File 'lib/seam/resources/space.rb', line 13 def default_checkout_time @default_checkout_time end |
#time_zone ⇒ Object
IANA time zone for the space, e.g. America/Los_Angeles.
15 16 17 |
# File 'lib/seam/resources/space.rb', line 15 def time_zone @time_zone end |