Class: Seam::Resources::ThermostatDailyProgram
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ThermostatDailyProgram
- Defined in:
- lib/seam/resources/thermostat_daily_program.rb
Overview
Represents a thermostat daily program, consisting of a set of periods, each of which has a starting time and the key that identifies the climate preset to apply at the starting time.
Defined Under Namespace
Classes: Periods
Instance Attribute Summary collapse
-
#device_id ⇒ String
ID of the thermostat device on which the thermostat daily program is configured.
-
#name ⇒ String?
User-friendly name to identify the thermostat daily program.
-
#thermostat_daily_program_id ⇒ String
ID of the thermostat daily program.
-
#workspace_id ⇒ String
ID of the workspace that contains the thermostat daily program.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the thermostat daily program was created.
-
#periods ⇒ Array<Periods>
Array of thermostat daily program periods.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ String
ID of the thermostat device on which the thermostat daily program is configured.
21 22 23 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 21 def device_id @device_id end |
#name ⇒ String?
User-friendly name to identify the thermostat daily program.
24 25 26 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 24 def name @name end |
#thermostat_daily_program_id ⇒ String
ID of the thermostat daily program.
27 28 29 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 27 def thermostat_daily_program_id @thermostat_daily_program_id end |
#workspace_id ⇒ String
ID of the workspace that contains the thermostat daily program.
30 31 32 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 30 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the thermostat daily program was created.
34 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 34 date_accessor :created_at |