Class: Seam::Resources::ThermostatDailyProgram

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/thermostat_daily_program.rb

Overview

Represents a thermostat daily program, consisting of a set of periods, each of which has a starting time and the key that identifies the climate preset to apply at the starting time.

Defined Under Namespace

Classes: Periods

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idObject

ID of the thermostat device on which the thermostat daily program is configured.



16
17
18
# File 'lib/seam/resources/thermostat_daily_program.rb', line 16

def device_id
  @device_id
end

#nameObject

User-friendly name to identify the thermostat daily program.



18
19
20
# File 'lib/seam/resources/thermostat_daily_program.rb', line 18

def name
  @name
end

#thermostat_daily_program_idObject

ID of the thermostat daily program.



20
21
22
# File 'lib/seam/resources/thermostat_daily_program.rb', line 20

def thermostat_daily_program_id
  @thermostat_daily_program_id
end

#workspace_idObject

ID of the workspace that contains the thermostat daily program.



22
23
24
# File 'lib/seam/resources/thermostat_daily_program.rb', line 22

def workspace_id
  @workspace_id
end