Class: Seam::Resources::ThermostatDailyProgram

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/thermostat_daily_program.rb

Overview

Represents a thermostat daily program, consisting of a set of periods, each of which has a starting time and the key that identifies the climate preset to apply at the starting time.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#device_idObject

ID of the thermostat device on which the thermostat daily program is configured.



8
9
10
# File 'lib/seam/resources/thermostat_daily_program.rb', line 8

def device_id
  @device_id
end

#nameObject

User-friendly name to identify the thermostat daily program.



10
11
12
# File 'lib/seam/resources/thermostat_daily_program.rb', line 10

def name
  @name
end

#periodsObject

Array of thermostat daily program periods.



12
13
14
# File 'lib/seam/resources/thermostat_daily_program.rb', line 12

def periods
  @periods
end

#thermostat_daily_program_idObject

ID of the thermostat daily program.



14
15
16
# File 'lib/seam/resources/thermostat_daily_program.rb', line 14

def thermostat_daily_program_id
  @thermostat_daily_program_id
end

#workspace_idObject

ID of the workspace that contains the thermostat daily program.



16
17
18
# File 'lib/seam/resources/thermostat_daily_program.rb', line 16

def workspace_id
  @workspace_id
end