Class: Seam::Resources::ThermostatDailyProgram
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ThermostatDailyProgram
- Defined in:
- lib/seam/resources/thermostat_daily_program.rb
Overview
Represents a thermostat daily program, consisting of a set of periods, each of which has a starting time and the key that identifies the climate preset to apply at the starting time.
Instance Attribute Summary collapse
-
#device_id ⇒ Object
ID of the thermostat device on which the thermostat daily program is configured.
-
#name ⇒ Object
User-friendly name to identify the thermostat daily program.
-
#periods ⇒ Object
Array of thermostat daily program periods.
-
#thermostat_daily_program_id ⇒ Object
ID of the thermostat daily program.
-
#workspace_id ⇒ Object
ID of the workspace that contains the thermostat daily program.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#device_id ⇒ Object
ID of the thermostat device on which the thermostat daily program is configured.
8 9 10 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 8 def device_id @device_id end |
#name ⇒ Object
User-friendly name to identify the thermostat daily program.
10 11 12 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 10 def name @name end |
#periods ⇒ Object
Array of thermostat daily program periods.
12 13 14 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 12 def periods @periods end |
#thermostat_daily_program_id ⇒ Object
ID of the thermostat daily program.
14 15 16 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 14 def thermostat_daily_program_id @thermostat_daily_program_id end |
#workspace_id ⇒ Object
ID of the workspace that contains the thermostat daily program.
16 17 18 |
# File 'lib/seam/resources/thermostat_daily_program.rb', line 16 def workspace_id @workspace_id end |