Class: Seam::Resources::ThermostatSchedule

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/thermostat_schedule.rb

Overview

Represents a thermostat schedule that activates a configured climate preset on a thermostat at a specified starting time and deactivates the climate preset at a specified ending time.

Defined Under Namespace

Classes: Errors

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#climate_preset_keyObject

Key of the climate preset to use for the thermostat schedule.



18
19
20
# File 'lib/seam/resources/thermostat_schedule.rb', line 18

def climate_preset_key
  @climate_preset_key
end

#device_idObject

ID of the desired thermostat device.



20
21
22
# File 'lib/seam/resources/thermostat_schedule.rb', line 20

def device_id
  @device_id
end

#is_override_allowedObject

Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.



22
23
24
# File 'lib/seam/resources/thermostat_schedule.rb', line 22

def is_override_allowed
  @is_override_allowed
end

#max_override_period_minutesObject

Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.



24
25
26
# File 'lib/seam/resources/thermostat_schedule.rb', line 24

def max_override_period_minutes
  @max_override_period_minutes
end

#nameObject

User-friendly name to identify the thermostat schedule.



26
27
28
# File 'lib/seam/resources/thermostat_schedule.rb', line 26

def name
  @name
end

#thermostat_schedule_idObject

ID of the thermostat schedule.



28
29
30
# File 'lib/seam/resources/thermostat_schedule.rb', line 28

def thermostat_schedule_id
  @thermostat_schedule_id
end

#workspace_idObject

ID of the workspace that contains the thermostat schedule.



30
31
32
# File 'lib/seam/resources/thermostat_schedule.rb', line 30

def workspace_id
  @workspace_id
end