Class: Seam::Resources::ThermostatSchedule
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::ThermostatSchedule
- Includes:
- ResourceErrorsSupport
- Defined in:
- lib/seam/resources/thermostat_schedule.rb
Overview
Represents a thermostat schedule that activates a configured climate preset on a thermostat at a specified starting time and deactivates the climate preset at a specified ending time.
Instance Attribute Summary collapse
-
#climate_preset_key ⇒ Object
Key of the climate preset to use for the thermostat schedule.
-
#device_id ⇒ Object
ID of the desired thermostat device.
-
#is_override_allowed ⇒ Object
Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.
-
#max_override_period_minutes ⇒ Object
Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset.
-
#name ⇒ Object
User-friendly name to identify the thermostat schedule.
-
#thermostat_schedule_id ⇒ Object
ID of the thermostat schedule.
-
#workspace_id ⇒ Object
ID of the workspace that contains the thermostat schedule.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#climate_preset_key ⇒ Object
Key of the climate preset to use for the thermostat schedule.
8 9 10 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 8 def climate_preset_key @climate_preset_key end |
#device_id ⇒ Object
ID of the desired thermostat device.
10 11 12 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 10 def device_id @device_id end |
#is_override_allowed ⇒ Object
Indicates whether a person at the thermostat can change the thermostat's settings after the thermostat schedule starts.
12 13 14 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 12 def is_override_allowed @is_override_allowed end |
#max_override_period_minutes ⇒ Object
Number of minutes for which a person at the thermostat can change the thermostat's settings after the activation of the scheduled climate preset. See also Specifying Manual Override Permissions.
14 15 16 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 14 def max_override_period_minutes @max_override_period_minutes end |
#name ⇒ Object
User-friendly name to identify the thermostat schedule.
16 17 18 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 16 def name @name end |
#thermostat_schedule_id ⇒ Object
ID of the thermostat schedule.
18 19 20 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 18 def thermostat_schedule_id @thermostat_schedule_id end |
#workspace_id ⇒ Object
ID of the workspace that contains the thermostat schedule.
20 21 22 |
# File 'lib/seam/resources/thermostat_schedule.rb', line 20 def workspace_id @workspace_id end |