Class: Seam::Resources::UnmanagedAccessCode
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessCode
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Represents an unmanaged smart lock access code.
An access code is a code used for a keypad or pinpad device. Unlike physical keys, which can easily be lost or duplicated, PIN codes can be customized, tracked, and altered on the fly.
When you create an access code on a device in Seam, it is created as a managed access code. Access codes that exist on a device that were not created through Seam are considered unmanaged codes. We strictly limit the operations that can be performed on unmanaged codes.
Prior to using Seam to manage your devices, you may have used another lock management system to manage the access codes on your devices. Where possible, we help you keep any existing access codes on devices and transition those codes to ones managed by your Seam workspace.
Not all providers support unmanaged access codes. The following providers do not support unmanaged access codes:
Instance Attribute Summary collapse
-
#access_code_id ⇒ Object
Unique identifier for the access code.
-
#cannot_be_managed ⇒ Object
Indicates that Seam cannot convert this unmanaged access code to a managed access code.
-
#cannot_delete_unmanaged_access_code ⇒ Object
Indicates that Seam cannot delete this unmanaged access code through the provider.
-
#code ⇒ Object
Code used for access.
-
#device_id ⇒ Object
Unique identifier for the device associated with the access code.
-
#dormakaba_oracode_metadata ⇒ Object
Metadata for a dormakaba Oracode unmanaged access code.
-
#is_managed ⇒ Object
Indicates that Seam does not manage the access code.
-
#name ⇒ Object
Name of the access code.
-
#status ⇒ Object
Current status of the access code within the operational lifecycle.
-
#type ⇒ Object
Type of the access code.
-
#workspace_id ⇒ Object
Unique identifier for the Seam workspace associated with the access code.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_code_id ⇒ Object
Unique identifier for the access code.
18 19 20 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 18 def access_code_id @access_code_id end |
#cannot_be_managed ⇒ Object
Indicates that Seam cannot convert this unmanaged access code to a managed access code. Some providers do not support management of unmanaged access codes through API integrations.
20 21 22 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 20 def cannot_be_managed @cannot_be_managed end |
#cannot_delete_unmanaged_access_code ⇒ Object
Indicates that Seam cannot delete this unmanaged access code through the provider. If this access code needs to be deleted, it will only be possible from the manufacturer app.
22 23 24 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 22 def cannot_delete_unmanaged_access_code @cannot_delete_unmanaged_access_code end |
#code ⇒ Object
Code used for access. Typically, a numeric or alphanumeric string.
24 25 26 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 24 def code @code end |
#device_id ⇒ Object
Unique identifier for the device associated with the access code.
26 27 28 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 26 def device_id @device_id end |
#dormakaba_oracode_metadata ⇒ Object
Metadata for a dormakaba Oracode unmanaged access code. Only present for unmanaged access codes from dormakaba Oracode devices.
28 29 30 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 28 def @dormakaba_oracode_metadata end |
#is_managed ⇒ Object
Indicates that Seam does not manage the access code.
30 31 32 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 30 def is_managed @is_managed end |
#name ⇒ Object
Name of the access code. Enables administrators and users to identify the access code easily, especially when there are numerous access codes. Note that the name provided on Seam is used to identify the code on Seam and is not necessarily the name that will appear in the lock provider's app or on the device. This is because lock providers may have constraints on names, such as length, uniqueness, or characters that can be used. In addition, some lock providers may break down names into components such as first_name and last_name. To provide a consistent experience, Seam identifies the code on Seam by its name but may modify the name that appears on the lock provider's app or on the device. For example, Seam may add additional characters or truncate the name to meet provider constraints. To help your users identify codes set by Seam, Seam provides the name exactly as it appears on the lock provider's app or on the device as a separate property called appearance. This is an object with a name property and, optionally, first_name and last_name properties (for providers that break down a name into components).
32 33 34 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 32 def name @name end |
#status ⇒ Object
Current status of the access code within the operational lifecycle. set indicates that the code is active and operational. unset indicates that the code exists on the provider but is not usable on the device.
34 35 36 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 34 def status @status end |
#type ⇒ Object
Type of the access code. ongoing access codes are active continuously until deactivated manually. time_bound access codes have a specific duration.
36 37 38 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 36 def type @type end |
#workspace_id ⇒ Object
Unique identifier for the Seam workspace associated with the access code.
38 39 40 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 38 def workspace_id @workspace_id end |