Class: Seam::Resources::UnmanagedAccessCode::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessCode::Errors
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Defined Under Namespace
Classes: ModifiedFields
Instance Attribute Summary collapse
-
#change_type ⇒ String?
Indicates the type of external modification.
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ Boolean
Indicates that this is an access code error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
- #is_connected_account_error ⇒ Boolean?
- #is_device_error ⇒ Boolean
-
#managed_access_code_id ⇒ String?
ID of the managed access code that conflicts with this managed access code, when Seam can identify it.
-
#message ⇒ String
Detailed description of the error.
-
#unmanaged_access_code_id ⇒ String?
ID of the unmanaged access code that conflicts with this managed access code, when Seam can identify it.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
-
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#change_type ⇒ String?
Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.
62 63 64 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 62 def change_type @change_type end |
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
65 66 67 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 65 def error_code @error_code end |
#is_access_code_error ⇒ Boolean
Indicates that this is an access code error.
68 69 70 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 68 def is_access_code_error @is_access_code_error end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
71 72 73 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 71 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
73 74 75 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 73 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ Boolean
75 76 77 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 75 def is_device_error @is_device_error end |
#managed_access_code_id ⇒ String?
ID of the managed access code that conflicts with this managed access code, when Seam can identify it.
78 79 80 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 78 def managed_access_code_id @managed_access_code_id end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
81 82 83 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 81 def @message end |
#unmanaged_access_code_id ⇒ String?
ID of the unmanaged access code that conflicts with this managed access code, when Seam can identify it.
84 85 86 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 84 def unmanaged_access_code_id @unmanaged_access_code_id end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
87 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 87 date_accessor :created_at |
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
59 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 59 resource_list_accessor :modified_fields, ModifiedFields |