Class: Seam::Resources::UnmanagedAccessCode::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#change_typeObject

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.



48
49
50
# File 'lib/seam/resources/unmanaged_access_code.rb', line 48

def change_type
  @change_type
end

#error_codeObject

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.



50
51
52
# File 'lib/seam/resources/unmanaged_access_code.rb', line 50

def error_code
  @error_code
end

#is_access_code_errorObject

Indicates that this is an access code error.



52
53
54
# File 'lib/seam/resources/unmanaged_access_code.rb', line 52

def is_access_code_error
  @is_access_code_error
end

#is_bridge_errorObject

Indicates whether the error is related to Seam Bridge.



54
55
56
# File 'lib/seam/resources/unmanaged_access_code.rb', line 54

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorObject

Returns the value of attribute is_connected_account_error.



55
56
57
# File 'lib/seam/resources/unmanaged_access_code.rb', line 55

def 
  @is_connected_account_error
end

#is_device_errorObject

Returns the value of attribute is_device_error.



56
57
58
# File 'lib/seam/resources/unmanaged_access_code.rb', line 56

def is_device_error
  @is_device_error
end

#managed_access_code_idObject

ID of the managed access code that conflicts with this managed access code, when Seam can identify it.



58
59
60
# File 'lib/seam/resources/unmanaged_access_code.rb', line 58

def managed_access_code_id
  @managed_access_code_id
end

#messageObject

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.



60
61
62
# File 'lib/seam/resources/unmanaged_access_code.rb', line 60

def message
  @message
end

#unmanaged_access_code_idObject

ID of the unmanaged access code that conflicts with this managed access code, when Seam can identify it.



62
63
64
# File 'lib/seam/resources/unmanaged_access_code.rb', line 62

def unmanaged_access_code_id
  @unmanaged_access_code_id
end