Class: Seam::Resources::UnmanagedAccessCode::Errors::AccountDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::AccountDisconnected
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the account is disconnected.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
-
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
account_disconnected
223 224 225 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 223 def error_code @error_code end |
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
226 227 228 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 226 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
229 230 231 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 229 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
232 233 234 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 232 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
235 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 235 date_accessor :created_at |