Class: Seam::Resources::UnmanagedAccessCode::Errors::AugustLockNotAuthorized
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::AugustLockNotAuthorized
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the user is not authorized to use the August lock.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
august_lock_not_authorized
379 380 381 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 379 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
382 383 384 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 382 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
385 386 387 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 385 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
388 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 388 date_accessor :created_at |