Class: Seam::Resources::UnmanagedAccessCode::Errors::AuxiliaryHeatRunning
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::AuxiliaryHeatRunning
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that the auxiliary heat is running.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
auxiliary_heat_running
415 416 417 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 415 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
418 419 420 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 418 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
421 422 423 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 421 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
424 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 424 date_accessor :created_at |