Class: Seam::Resources::UnmanagedAccessCode::Errors::BridgeDisconnected

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Indicates that the Seam API cannot communicate with Seam Bridge, for example, if the Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • bridge_disconnected

Returns:

  • (String)


451
452
453
# File 'lib/seam/resources/unmanaged_access_code.rb', line 451

def error_code
  @error_code
end

#is_bridge_errorBoolean?

Indicates whether the error is related to Seam Bridge.

Returns:

  • (Boolean, nil)


454
455
456
# File 'lib/seam/resources/unmanaged_access_code.rb', line 454

def is_bridge_error
  @is_bridge_error
end

#is_connected_account_errorBoolean?

Indicates whether the error is related specifically to the connected account.

Returns:

  • (Boolean, nil)


457
458
459
# File 'lib/seam/resources/unmanaged_access_code.rb', line 457

def 
  @is_connected_account_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


460
461
462
# File 'lib/seam/resources/unmanaged_access_code.rb', line 460

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


463
# File 'lib/seam/resources/unmanaged_access_code.rb', line 463

date_accessor :created_at