Class: Seam::Resources::UnmanagedAccessCode::Errors::ConflictingExternalModification
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::ConflictingExternalModification
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Code was modified or removed externally after Seam successfully set it on the device. The external change conflicts with the state that Seam is trying to apply, so Seam will attempt to set the code on the device again.
Defined Under Namespace
Classes: ModifiedFields
Instance Attribute Summary collapse
-
#change_type ⇒ String?
Indicates the type of external modification.
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
-
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
Instance Attribute Details
#change_type ⇒ String?
Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.
Known values:
modifiedremoved
164 165 166 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 164 def change_type @change_type end |
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
conflicting_external_modification
169 170 171 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 169 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
172 173 174 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 172 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
175 176 177 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 175 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
178 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 178 date_accessor :created_at |
#modified_fields ⇒ Array<ModifiedFields>
List of fields that were changed externally, with their previous and new values.
158 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 158 resource_list_accessor :modified_fields, ModifiedFields |