Class: Seam::Resources::UnmanagedAccessCode::Errors::FailedToUpdate
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::FailedToUpdate
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Seam was unable to apply this access code's requested update to the device, so the code on the device does not match its requested state. Seam keeps retrying, and this error clears automatically once the update is applied.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
failed_to_update
241 242 243 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 241 def error_code @error_code end |
#is_access_code_error ⇒ TrueClass
Indicates that this is an access code error.
244 245 246 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 244 def is_access_code_error @is_access_code_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
247 248 249 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 247 def @message end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the error.
250 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 250 date_accessor :created_at |