Class: Seam::Resources::UnmanagedAccessCode::Errors::InsufficientPermissions

Inherits:
Errors
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Indicates that Seam's integration user does not have sufficient permissions on the provider's system to which this device belongs, so Seam cannot manage access codes or unlock the device. See the error message for specifics, then either reauthorize the connected account in Seam or grant the integration user the required permissions in the provider's system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:

  • insufficient_permissions

Returns:

  • (String)


247
248
249
# File 'lib/seam/resources/unmanaged_access_code.rb', line 247

def error_code
  @error_code
end

#is_connected_account_errorTrueClass

Indicates that the error is a connected account error.

Returns:

  • (TrueClass)


250
251
252
# File 'lib/seam/resources/unmanaged_access_code.rb', line 250

def 
  @is_connected_account_error
end

#is_device_errorFalseClass

Indicates that the error is not a device error.

Returns:

  • (FalseClass)


253
254
255
# File 'lib/seam/resources/unmanaged_access_code.rb', line 253

def is_device_error
  @is_device_error
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


256
257
258
# File 'lib/seam/resources/unmanaged_access_code.rb', line 256

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


259
# File 'lib/seam/resources/unmanaged_access_code.rb', line 259

date_accessor :created_at