Class: Seam::Resources::UnmanagedAccessCode::Errors::InsufficientPermissions
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedAccessCode::Errors::InsufficientPermissions
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Indicates that Seam's integration user does not have sufficient permissions on the provider's system to which this device belongs, so Seam cannot manage access codes or unlock the device. See the error message for specifics, then either reauthorize the connected account in Seam or grant the integration user the required permissions in the provider's system.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
-
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
insufficient_permissions
247 248 249 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 247 def error_code @error_code end |
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
250 251 252 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 250 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
253 254 255 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 253 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
256 257 258 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 256 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
259 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 259 date_accessor :created_at |