Class: Seam::Resources::UnmanagedAccessCode::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessCode::Warnings
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.
Defined Under Namespace
Classes: BeingDeleted, CodeRotatesPeriodically, DelayInRemovingFromDevice, DelayInSettingOnDevice, ExternalModificationInEffect, IglooAlgopinMustBeUsedWithinN24Hours, ManagementTransferred, ThirdPartyIntegrationDetected, TimeFrameAdjustedForUnknownTimeZone, UnknownIssueWithAccessCode, UsingBackupAccessCode
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
713 714 715 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 713 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
code_rotates_periodicallytime_frame_adjusted_for_unknown_time_zoneexternal_modification_in_effectdelay_in_setting_on_devicedelay_in_removing_from_devicethird_party_integration_detectedigloo_algopin_must_be_used_within_24_hoursmanagement_transferredusing_backup_access_codebeing_deletedunknown_issue_with_access_code
728 729 730 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 728 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
731 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 731 date_accessor :created_at |