Class: Seam::Resources::UnmanagedAccessCode::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#change_typeObject

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device.



79
80
81
# File 'lib/seam/resources/unmanaged_access_code.rb', line 79

def change_type
  @change_type
end

#messageObject

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.



81
82
83
# File 'lib/seam/resources/unmanaged_access_code.rb', line 81

def message
  @message
end

#warning_codeObject

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.



83
84
85
# File 'lib/seam/resources/unmanaged_access_code.rb', line 83

def warning_code
  @warning_code
end