Class: Seam::Resources::UnmanagedAccessCode::Warnings::ExternalModificationInEffect

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Code was modified or removed externally after Seam successfully set it on the device. External modification is allowed for this code, so the externally modified state is being honored.

Defined Under Namespace

Classes: ModifiedFields

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#change_typeString?

Indicates the type of external modification. modified means the code's PIN or schedule was changed. removed means the code was deleted from the device. Known values:

  • modified
  • removed

Returns:

  • (String, nil)


577
578
579
# File 'lib/seam/resources/unmanaged_access_code.rb', line 577

def change_type
  @change_type
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


580
581
582
# File 'lib/seam/resources/unmanaged_access_code.rb', line 580

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • external_modification_in_effect

Returns:

  • (String)


585
586
587
# File 'lib/seam/resources/unmanaged_access_code.rb', line 585

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


588
# File 'lib/seam/resources/unmanaged_access_code.rb', line 588

date_accessor :created_at

#modified_fieldsArray<ModifiedFields>

List of fields that were changed externally, with their previous and new values.

Returns:



571
# File 'lib/seam/resources/unmanaged_access_code.rb', line 571

resource_list_accessor :modified_fields, ModifiedFields