Class: Seam::Resources::UnmanagedAccessCode::Warnings::IglooAlgopinMustBeUsedWithinN24Hours
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessCode::Warnings::IglooAlgopinMustBeUsedWithinN24Hours
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Algopins must be used within 24 hours.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
640 641 642 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 640 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
igloo_algopin_must_be_used_within_24_hours
645 646 647 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 645 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
648 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 648 date_accessor :created_at |