Class: Seam::Resources::UnmanagedAccessCode::Warnings::ManagementTransferred

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

Management was transferred to another workspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


655
656
657
# File 'lib/seam/resources/unmanaged_access_code.rb', line 655

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • management_transferred

Returns:

  • (String)


660
661
662
# File 'lib/seam/resources/unmanaged_access_code.rb', line 660

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


663
# File 'lib/seam/resources/unmanaged_access_code.rb', line 663

date_accessor :created_at