Class: Seam::Resources::UnmanagedAccessCode::Warnings::ManagementTransferred
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessCode::Warnings::ManagementTransferred
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
Management was transferred to another workspace.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
655 656 657 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 655 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
management_transferred
660 661 662 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 660 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
663 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 663 date_accessor :created_at |