Class: Seam::Resources::UnmanagedAccessCode::Warnings::UnknownIssueWithAccessCode

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_code.rb

Overview

An unknown issue occurred with the access code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


720
721
722
# File 'lib/seam/resources/unmanaged_access_code.rb', line 720

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • unknown_issue_with_access_code

Returns:

  • (String)


725
726
727
# File 'lib/seam/resources/unmanaged_access_code.rb', line 725

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime?

Date and time at which Seam created the warning.

Returns:

  • (Time, nil)


728
# File 'lib/seam/resources/unmanaged_access_code.rb', line 728

date_accessor :created_at