Class: Seam::Resources::UnmanagedAccessCode::Warnings::UsingBackupAccessCode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessCode::Warnings::UsingBackupAccessCode
- Defined in:
- lib/seam/resources/unmanaged_access_code.rb
Overview
A backup access code has been pulled and is being used in place of this access code.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time?
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
670 671 672 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 670 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
using_backup_access_code
675 676 677 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 675 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time?
Date and time at which Seam created the warning.
678 |
# File 'lib/seam/resources/unmanaged_access_code.rb', line 678 date_accessor :created_at |