Class: Seam::Resources::UnmanagedAccessGrant
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessGrant
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Overview
Represents an unmanaged Access Grant. Unmanaged Access Grants do not have client sessions, instant keys, customization profiles, or keys.
Defined Under Namespace
Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the Access Grant.
-
#access_method_ids ⇒ Array<String>
IDs of the access methods created for the Access Grant.
-
#display_name ⇒ String
Display name of the Access Grant.
-
#location_ids ⇒ Array<String>
deprecated
Deprecated.
Use
space_ids. -
#name ⇒ String?
Name of the Access Grant.
-
#reservation_key ⇒ String?
Reservation key for the access grant.
-
#space_ids ⇒ Array<String>
IDs of the spaces to which the Access Grant gives access.
-
#user_identity_id ⇒ String?
ID of user identity to which the Access Grant gives access.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the Access Grant.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the Access Grant was created.
-
#ends_at ⇒ Time?
Date and time at which the Access Grant ends.
-
#errors ⇒ Array<Errors>
Errors associated with the access grant.
-
#pending_mutations ⇒ Array<PendingMutations>
List of pending mutations for the access grant.
-
#requested_access_methods ⇒ Array<RequestedAccessMethods>
Access methods that the user requested for the Access Grant.
-
#starts_at ⇒ Time
Date and time at which the Access Grant starts.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access grant.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_grant_id ⇒ String
ID of the Access Grant.
307 308 309 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 307 def access_grant_id @access_grant_id end |
#access_method_ids ⇒ Array<String>
IDs of the access methods created for the Access Grant.
310 311 312 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 310 def access_method_ids @access_method_ids end |
#display_name ⇒ String
Display name of the Access Grant.
313 314 315 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 313 def display_name @display_name end |
#location_ids ⇒ Array<String>
Use space_ids.
316 317 318 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 316 def location_ids @location_ids end |
#name ⇒ String?
Name of the Access Grant. If not provided, the display name will be computed.
319 320 321 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 319 def name @name end |
#reservation_key ⇒ String?
Reservation key for the access grant.
322 323 324 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 322 def reservation_key @reservation_key end |
#space_ids ⇒ Array<String>
IDs of the spaces to which the Access Grant gives access.
325 326 327 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 325 def space_ids @space_ids end |
#user_identity_id ⇒ String?
ID of user identity to which the Access Grant gives access.
328 329 330 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 328 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the Access Grant.
331 332 333 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 331 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the Access Grant was created.
335 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 335 date_accessor :created_at |
#ends_at ⇒ Time?
Date and time at which the Access Grant ends.
339 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 339 date_accessor :ends_at |
#errors ⇒ Array<Errors>
Errors associated with the access grant.
295 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 295 resource_list_accessor :errors, Errors |
#pending_mutations ⇒ Array<PendingMutations>
List of pending mutations for the access grant. This shows updates that are in progress.
298 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 298 resource_list_accessor :pending_mutations, PendingMutations |
#requested_access_methods ⇒ Array<RequestedAccessMethods>
Access methods that the user requested for the Access Grant.
301 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 301 resource_list_accessor :requested_access_methods, RequestedAccessMethods |
#starts_at ⇒ Time
Date and time at which the Access Grant starts.
343 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 343 date_accessor :starts_at |
#warnings ⇒ Array<Warnings>
Warnings associated with the access grant.
304 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 304 resource_list_accessor :warnings, Warnings |