Class: Seam::Resources::UnmanagedAccessGrant

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Represents an unmanaged Access Grant. Unmanaged Access Grants do not have client sessions, instant keys, customization profiles, or keys.

Defined Under Namespace

Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_grant_idString

ID of the Access Grant.

Returns:

  • (String)


143
144
145
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 143

def access_grant_id
  @access_grant_id
end

#access_method_idsArray<String>

IDs of the access methods created for the Access Grant.

Returns:

  • (Array<String>)


146
147
148
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 146

def access_method_ids
  @access_method_ids
end

#display_nameString

Display name of the Access Grant.

Returns:

  • (String)


149
150
151
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 149

def display_name
  @display_name
end

#location_idsArray<String>

Deprecated.

Use space_ids.

Returns:

  • (Array<String>)


152
153
154
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 152

def location_ids
  @location_ids
end

#nameString?

Name of the Access Grant. If not provided, the display name will be computed.

Returns:

  • (String, nil)


155
156
157
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 155

def name
  @name
end

#reservation_keyString?

Reservation key for the access grant.

Returns:

  • (String, nil)


158
159
160
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 158

def reservation_key
  @reservation_key
end

#space_idsArray<String>

IDs of the spaces to which the Access Grant gives access.

Returns:

  • (Array<String>)


161
162
163
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 161

def space_ids
  @space_ids
end

#user_identity_idString?

ID of user identity to which the Access Grant gives access.

Returns:

  • (String, nil)


164
165
166
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 164

def user_identity_id
  @user_identity_id
end

#workspace_idString

ID of the Seam workspace associated with the Access Grant.

Returns:

  • (String)


167
168
169
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 167

def workspace_id
  @workspace_id
end

Instance Method Details

#created_atTime

Date and time at which the Access Grant was created.

Returns:

  • (Time)


171
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 171

date_accessor :created_at

#ends_atTime?

Date and time at which the Access Grant ends.

Returns:

  • (Time, nil)


175
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 175

date_accessor :ends_at

#errorsArray<Errors>

Errors associated with the access grant.

Returns:



131
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 131

resource_list_accessor :errors, Errors

#pending_mutationsArray<PendingMutations>

List of pending mutations for the access grant. This shows updates that are in progress.

Returns:



134
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 134

resource_list_accessor :pending_mutations, PendingMutations

#requested_access_methodsArray<RequestedAccessMethods>

Access methods that the user requested for the Access Grant.

Returns:



137
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 137

resource_list_accessor :requested_access_methods, RequestedAccessMethods

#starts_atTime

Date and time at which the Access Grant starts.

Returns:

  • (Time)


179
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 179

date_accessor :starts_at

#warningsArray<Warnings>

Warnings associated with the access grant.

Returns:



140
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 140

resource_list_accessor :warnings, Warnings