Class: Seam::Resources::UnmanagedAccessGrant
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessGrant
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Overview
Represents an unmanaged Access Grant. Unmanaged Access Grants do not have client sessions, instant keys, customization profiles, or keys.
Defined Under Namespace
Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings
Instance Attribute Summary collapse
-
#access_grant_id ⇒ String
ID of the Access Grant.
-
#access_method_ids ⇒ Array<String>
IDs of the access methods created for the Access Grant.
-
#display_name ⇒ String
Display name of the Access Grant.
-
#location_ids ⇒ Array<String>
deprecated
Deprecated.
Use
space_ids. -
#name ⇒ String?
Name of the Access Grant.
-
#reservation_key ⇒ String?
Reservation key for the access grant.
-
#space_ids ⇒ Array<String>
IDs of the spaces to which the Access Grant gives access.
-
#user_identity_id ⇒ String?
ID of user identity to which the Access Grant gives access.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the Access Grant.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the Access Grant was created.
-
#ends_at ⇒ Time?
Date and time at which the Access Grant ends.
-
#errors ⇒ Array<Errors>
Errors associated with the access grant.
-
#pending_mutations ⇒ Array<PendingMutations>
List of pending mutations for the access grant.
-
#requested_access_methods ⇒ Array<RequestedAccessMethods>
Access methods that the user requested for the Access Grant.
-
#starts_at ⇒ Time
Date and time at which the Access Grant starts.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access grant.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_grant_id ⇒ String
ID of the Access Grant.
143 144 145 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 143 def access_grant_id @access_grant_id end |
#access_method_ids ⇒ Array<String>
IDs of the access methods created for the Access Grant.
146 147 148 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 146 def access_method_ids @access_method_ids end |
#display_name ⇒ String
Display name of the Access Grant.
149 150 151 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 149 def display_name @display_name end |
#location_ids ⇒ Array<String>
Use space_ids.
152 153 154 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 152 def location_ids @location_ids end |
#name ⇒ String?
Name of the Access Grant. If not provided, the display name will be computed.
155 156 157 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 155 def name @name end |
#reservation_key ⇒ String?
Reservation key for the access grant.
158 159 160 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 158 def reservation_key @reservation_key end |
#space_ids ⇒ Array<String>
IDs of the spaces to which the Access Grant gives access.
161 162 163 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 161 def space_ids @space_ids end |
#user_identity_id ⇒ String?
ID of user identity to which the Access Grant gives access.
164 165 166 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 164 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the Access Grant.
167 168 169 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 167 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the Access Grant was created.
171 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 171 date_accessor :created_at |
#ends_at ⇒ Time?
Date and time at which the Access Grant ends.
175 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 175 date_accessor :ends_at |
#errors ⇒ Array<Errors>
Errors associated with the access grant.
131 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 131 resource_list_accessor :errors, Errors |
#pending_mutations ⇒ Array<PendingMutations>
List of pending mutations for the access grant. This shows updates that are in progress.
134 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 134 resource_list_accessor :pending_mutations, PendingMutations |
#requested_access_methods ⇒ Array<RequestedAccessMethods>
Access methods that the user requested for the Access Grant.
137 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 137 resource_list_accessor :requested_access_methods, RequestedAccessMethods |
#starts_at ⇒ Time
Date and time at which the Access Grant starts.
179 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 179 date_accessor :starts_at |
#warnings ⇒ Array<Warnings>
Warnings associated with the access grant.
140 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 140 resource_list_accessor :warnings, Warnings |