Class: Seam::Resources::UnmanagedAccessGrant

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Represents an unmanaged Access Grant. Unmanaged Access Grants do not have client sessions, instant keys, customization profiles, or keys.

Defined Under Namespace

Classes: Errors, PendingMutations, RequestedAccessMethods, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_grant_idObject

ID of the Access Grant.



98
99
100
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 98

def access_grant_id
  @access_grant_id
end

#access_method_idsObject

IDs of the access methods created for the Access Grant.



100
101
102
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 100

def access_method_ids
  @access_method_ids
end

#display_nameObject

Display name of the Access Grant.



102
103
104
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 102

def display_name
  @display_name
end

#location_idsObject

Deprecated.

Use space_ids.



104
105
106
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 104

def location_ids
  @location_ids
end

#nameObject

Name of the Access Grant. If not provided, the display name will be computed.



106
107
108
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 106

def name
  @name
end

#reservation_keyObject

Reservation key for the access grant.



108
109
110
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 108

def reservation_key
  @reservation_key
end

#space_idsObject

IDs of the spaces to which the Access Grant gives access.



110
111
112
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 110

def space_ids
  @space_ids
end

#user_identity_idObject

ID of user identity to which the Access Grant gives access.



112
113
114
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 112

def user_identity_id
  @user_identity_id
end

#workspace_idObject

ID of the Seam workspace associated with the Access Grant.



114
115
116
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 114

def workspace_id
  @workspace_id
end