Class: Seam::Resources::UnmanagedAccessGrant

Inherits:
BaseResource show all
Includes:
ResourceErrorsSupport, ResourceWarningsSupport
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Overview

Represents an unmanaged Access Grant. Unmanaged Access Grants do not have client sessions, instant keys, customization profiles, or keys.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods included from ResourceWarningsSupport

#warnings

Methods included from ResourceErrorsSupport

#errors

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#access_grant_idObject

ID of the Access Grant.



8
9
10
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 8

def access_grant_id
  @access_grant_id
end

#access_method_idsObject

IDs of the access methods created for the Access Grant.



10
11
12
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 10

def access_method_ids
  @access_method_ids
end

#display_nameObject

Display name of the Access Grant.



12
13
14
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 12

def display_name
  @display_name
end

#location_idsObject

Deprecated.

Use space_ids.



14
15
16
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 14

def location_ids
  @location_ids
end

#nameObject

Name of the Access Grant. If not provided, the display name will be computed.



16
17
18
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 16

def name
  @name
end

#pending_mutationsObject

List of pending mutations for the access grant. This shows updates that are in progress.



18
19
20
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 18

def pending_mutations
  @pending_mutations
end

#requested_access_methodsObject

Access methods that the user requested for the Access Grant.



20
21
22
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 20

def requested_access_methods
  @requested_access_methods
end

#reservation_keyObject

Reservation key for the access grant.



22
23
24
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 22

def reservation_key
  @reservation_key
end

#space_idsObject

IDs of the spaces to which the Access Grant gives access.



24
25
26
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 24

def space_ids
  @space_ids
end

#user_identity_idObject

ID of user identity to which the Access Grant gives access.



26
27
28
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 26

def user_identity_id
  @user_identity_id
end

#workspace_idObject

ID of the Seam workspace associated with the Access Grant.



28
29
30
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 28

def workspace_id
  @workspace_id
end