Class: Seam::Resources::UnmanagedAccessGrant
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessGrant
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Overview
Represents an unmanaged Access Grant. Unmanaged Access Grants do not have client sessions, instant keys, customization profiles, or keys.
Instance Attribute Summary collapse
-
#access_grant_id ⇒ Object
ID of the Access Grant.
-
#access_method_ids ⇒ Object
IDs of the access methods created for the Access Grant.
-
#display_name ⇒ Object
Display name of the Access Grant.
-
#location_ids ⇒ Object
deprecated
Deprecated.
Use
space_ids. -
#name ⇒ Object
Name of the Access Grant.
-
#pending_mutations ⇒ Object
List of pending mutations for the access grant.
-
#requested_access_methods ⇒ Object
Access methods that the user requested for the Access Grant.
-
#reservation_key ⇒ Object
Reservation key for the access grant.
-
#space_ids ⇒ Object
IDs of the spaces to which the Access Grant gives access.
-
#user_identity_id ⇒ Object
ID of user identity to which the Access Grant gives access.
-
#workspace_id ⇒ Object
ID of the Seam workspace associated with the Access Grant.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_grant_id ⇒ Object
ID of the Access Grant.
8 9 10 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 8 def access_grant_id @access_grant_id end |
#access_method_ids ⇒ Object
IDs of the access methods created for the Access Grant.
10 11 12 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 10 def access_method_ids @access_method_ids end |
#display_name ⇒ Object
Display name of the Access Grant.
12 13 14 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 12 def display_name @display_name end |
#location_ids ⇒ Object
Use space_ids.
14 15 16 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 14 def location_ids @location_ids end |
#name ⇒ Object
Name of the Access Grant. If not provided, the display name will be computed.
16 17 18 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 16 def name @name end |
#pending_mutations ⇒ Object
List of pending mutations for the access grant. This shows updates that are in progress.
18 19 20 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 18 def pending_mutations @pending_mutations end |
#requested_access_methods ⇒ Object
Access methods that the user requested for the Access Grant.
20 21 22 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 20 def requested_access_methods @requested_access_methods end |
#reservation_key ⇒ Object
Reservation key for the access grant.
22 23 24 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 22 def reservation_key @reservation_key end |
#space_ids ⇒ Object
IDs of the spaces to which the Access Grant gives access.
24 25 26 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 24 def space_ids @space_ids end |
#user_identity_id ⇒ Object
ID of user identity to which the Access Grant gives access.
26 27 28 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 26 def user_identity_id @user_identity_id end |
#workspace_id ⇒ Object
ID of the Seam workspace associated with the Access Grant.
28 29 30 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 28 def workspace_id @workspace_id end |