Class: Seam::Resources::UnmanagedAccessGrant::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_grant.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


10
11
12
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 10

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


13
14
15
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 13

def message
  @message
end

#missing_device_idsArray<String>

IDs of the devices that did not receive an access code at grant creation. Use these to identify which specific devices failed when the message reports a partial failure.

Returns:

  • (Array<String>)


16
17
18
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 16

def missing_device_ids
  @missing_device_ids
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


19
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 19

date_accessor :created_at