Class: Seam::Resources::UnmanagedAccessGrant::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessGrant::Errors
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Instance Attribute Summary collapse
-
#error_code ⇒ Object
Unique identifier of the type of error.
-
#message ⇒ Object
Detailed description of the error.
-
#missing_device_ids ⇒ Object
IDs of the devices that did not receive an access code at grant creation.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#error_code ⇒ Object
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
9 10 11 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 9 def error_code @error_code end |
#message ⇒ Object
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
11 12 13 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 11 def @message end |
#missing_device_ids ⇒ Object
IDs of the devices that did not receive an access code at grant creation. Use these to identify which specific devices failed when the message reports a partial failure.
13 14 15 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 13 def missing_device_ids @missing_device_ids end |