Class: Seam::Resources::UnmanagedAccessGrant::Warnings::DeviceTimeConstraintsViolated
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessGrant::Warnings::DeviceTimeConstraintsViolated
- Defined in:
- lib/seam/resources/unmanaged_access_grant.rb
Overview
Indicates that a device in the access grant cannot program an access code for the grant's time range because of device-specific time constraints.
Instance Attribute Summary collapse
-
#device_id ⇒ String
ID of the device whose time constraints the access grant violates.
-
#message ⇒ String
Detailed description of the warning.
-
#reason ⇒ String
Specific reason why the grant's times are not programmable on the device.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#device_id ⇒ String
ID of the device whose time constraints the access grant violates.
243 244 245 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 243 def device_id @device_id end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
246 247 248 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 246 def @message end |
#reason ⇒ String
Specific reason why the grant's times are not programmable on the device. Known values:
duration_exceeds_maxtimes_do_not_match_slotsongoing_not_supported
253 254 255 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 253 def reason @reason end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
device_time_constraints_violated
258 259 260 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 258 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
261 |
# File 'lib/seam/resources/unmanaged_access_grant.rb', line 261 date_accessor :created_at |