Class: Seam::Resources::UnmanagedAccessMethod
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessMethod
- Defined in:
- lib/seam/resources/unmanaged_access_method.rb
Overview
Represents an unmanaged access method. Unmanaged access methods do not have client sessions, instant keys, customization profiles, or keys.
Defined Under Namespace
Classes: Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_method_id ⇒ String
ID of the access method.
-
#code ⇒ String?
The actual PIN code for code access methods.
-
#display_name ⇒ String
Display name of the access method.
-
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ String
Access method mode.
-
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the access method was created.
-
#errors ⇒ Array<Errors>
Errors associated with the access method.
-
#issued_at ⇒ Time?
Date and time at which the access method was issued.
-
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method.
-
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ String
ID of the access method.
179 180 181 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 179 def access_method_id @access_method_id end |
#code ⇒ String?
The actual PIN code for code access methods.
182 183 184 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 182 def code @code end |
#display_name ⇒ String
Display name of the access method.
185 186 187 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 185 def display_name @display_name end |
#is_assignment_required ⇒ Boolean?
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
188 189 190 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 188 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Boolean?
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
191 192 193 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 191 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Boolean
Indicates whether the access method has been issued.
194 195 196 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 194 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Boolean?
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
197 198 199 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 197 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Boolean?
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
200 201 202 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 200 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ String
Access method mode. Supported values: code, card, mobile_key, cloud_key.
Known values:
codecardmobile_keycloud_key
208 209 210 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 208 def mode @mode end |
#workspace_id ⇒ String
ID of the Seam workspace associated with the access method.
211 212 213 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 211 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the access method was created.
215 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 215 date_accessor :created_at |
#errors ⇒ Array<Errors>
Errors associated with the access method.
170 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 170 resource_list_accessor :errors, Errors |
#issued_at ⇒ Time?
Date and time at which the access method was issued.
219 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 219 date_accessor :issued_at |
#pending_mutations ⇒ Array<PendingMutations>
Pending mutations for the access method. Indicates operations that are in progress.
173 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 173 resource_list_accessor :pending_mutations, PendingMutations |
#warnings ⇒ Array<Warnings>
Warnings associated with the access method.
176 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 176 resource_list_accessor :warnings, Warnings |