Class: Seam::Resources::UnmanagedAccessMethod
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessMethod
- Defined in:
- lib/seam/resources/unmanaged_access_method.rb
Overview
Represents an unmanaged access method. Unmanaged access methods do not have client sessions, instant keys, customization profiles, or keys.
Defined Under Namespace
Classes: Errors, PendingMutations, Warnings
Instance Attribute Summary collapse
-
#access_method_id ⇒ Object
ID of the access method.
-
#code ⇒ Object
The actual PIN code for code access methods.
-
#display_name ⇒ Object
Display name of the access method.
-
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued.
-
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
-
#is_issued ⇒ Object
Indicates whether the access method has been issued.
-
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment.
-
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded.
-
#mode ⇒ Object
Access method mode.
-
#workspace_id ⇒ Object
ID of the Seam workspace associated with the access method.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#access_method_id ⇒ Object
ID of the access method.
57 58 59 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 57 def access_method_id @access_method_id end |
#code ⇒ Object
The actual PIN code for code access methods.
59 60 61 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 59 def code @code end |
#display_name ⇒ Object
Display name of the access method.
61 62 63 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 61 def display_name @display_name end |
#is_assignment_required ⇒ Object
Indicates whether an existing card credential must be assigned to this access method before it can be issued. Only applies to card-mode access methods on systems that support credential assignment.
63 64 65 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 63 def is_assignment_required @is_assignment_required end |
#is_encoding_required ⇒ Object
Indicates whether encoding with an card encoder is required to issue or reissue the plastic card associated with the access method.
65 66 67 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 65 def is_encoding_required @is_encoding_required end |
#is_issued ⇒ Object
Indicates whether the access method has been issued.
67 68 69 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 67 def is_issued @is_issued end |
#is_ready_for_assignment ⇒ Object
Indicates whether the access method is ready for card assignment. This is true when the access method is in card mode, has not yet been issued, and the system supports credential assignment.
69 70 71 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 69 def is_ready_for_assignment @is_ready_for_assignment end |
#is_ready_for_encoding ⇒ Object
Indicates whether the access method is ready to be encoded. This is true when the credential has been created and the card has not yet been issued.
71 72 73 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 71 def is_ready_for_encoding @is_ready_for_encoding end |
#mode ⇒ Object
Access method mode. Supported values: code, card, mobile_key, cloud_key.
73 74 75 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 73 def mode @mode end |
#workspace_id ⇒ Object
ID of the Seam workspace associated with the access method.
75 76 77 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 75 def workspace_id @workspace_id end |