Class: Seam::Resources::UnmanagedAccessMethod::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedAccessMethod::Warnings
- Defined in:
- lib/seam/resources/unmanaged_access_method.rb
Overview
Known warning_code values load as subclasses; unknown values remain Warnings instances for forward compatibility.
Defined Under Namespace
Classes: BeingDeleted, DelayInIssuing, PulledBackupAccessCode, UpdatingAccessTimes
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Methods inherited from BaseResource
#[], aliased_accessor, attribute_aliases, date_accessor, discriminated_by, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
147 148 149 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 147 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
being_deletedupdating_access_timespulled_backup_access_codedelay_in_issuing
155 156 157 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 155 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
158 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 158 date_accessor :created_at |