Class: Seam::Resources::UnmanagedAccessMethod::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_method.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


59
60
61
# File 'lib/seam/resources/unmanaged_access_method.rb', line 59

def message
  @message
end

#original_access_method_idString?

ID of the original access method from which this backup access method was split, if applicable.

Returns:

  • (String, nil)


62
63
64
# File 'lib/seam/resources/unmanaged_access_method.rb', line 62

def original_access_method_id
  @original_access_method_id
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


65
66
67
# File 'lib/seam/resources/unmanaged_access_method.rb', line 65

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


68
# File 'lib/seam/resources/unmanaged_access_method.rb', line 68

date_accessor :created_at