Class: Seam::Resources::UnmanagedAccessMethod::Warnings

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_access_method.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#messageObject

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.



44
45
46
# File 'lib/seam/resources/unmanaged_access_method.rb', line 44

def message
  @message
end

#original_access_method_idObject

ID of the original access method from which this backup access method was split, if applicable.



46
47
48
# File 'lib/seam/resources/unmanaged_access_method.rb', line 46

def original_access_method_id
  @original_access_method_id
end

#warning_codeObject

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.



48
49
50
# File 'lib/seam/resources/unmanaged_access_method.rb', line 48

def warning_code
  @warning_code
end