Class: Seam::Resources::UnmanagedAccessMethod::Warnings::DelayInIssuing
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedAccessMethod::Warnings::DelayInIssuing
- Defined in:
- lib/seam/resources/unmanaged_access_method.rb
Overview
Indicates that Seam has not yet issued this access method, even though its access grant is about to begin, so access may not be ready when the recipient arrives. Seam is still attempting to issue it, and this warning clears automatically once issuance succeeds.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
134 135 136 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 134 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
delay_in_issuing
139 140 141 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 139 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
142 |
# File 'lib/seam/resources/unmanaged_access_method.rb', line 142 date_accessor :created_at |