Class: Seam::Resources::UnmanagedDevice
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Represents an unmanaged device. An unmanaged device has a limited set of visible properties and a subset of supported events. You cannot control an unmanaged device. Any access codes on an unmanaged device are unmanaged. To control an unmanaged device with Seam, convert it to a managed device.
Defined Under Namespace
Classes: Errors, Location, Properties, Warnings
Instance Attribute Summary collapse
-
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
-
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
-
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
-
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
-
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
-
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
-
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
-
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
-
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
-
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
-
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
-
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
-
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
-
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
-
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
-
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
-
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
-
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
-
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
-
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
-
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam.
-
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
-
#custom_metadata ⇒ Hash
Set of key:value pairs.
-
#device_id ⇒ String
ID of the device.
-
#device_type ⇒ String
Type of the device.
-
#is_managed ⇒ Boolean
Indicates that Seam does not manage the device.
-
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the device object was created.
-
#errors ⇒ Array<Errors>
Array of errors associated with the device.
-
#location ⇒ Location?
Location information for the device.
-
#properties ⇒ Properties
properties of the device.
-
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#can_configure_auto_lock ⇒ Boolean?
Indicates whether the lock supports configuring automatic locking.
160 161 162 |
# File 'lib/seam/resources/unmanaged_device.rb', line 160 def can_configure_auto_lock @can_configure_auto_lock end |
#can_hvac_cool ⇒ Boolean?
Indicates whether the thermostat supports cooling.
163 164 165 |
# File 'lib/seam/resources/unmanaged_device.rb', line 163 def can_hvac_cool @can_hvac_cool end |
#can_hvac_heat ⇒ Boolean?
Indicates whether the thermostat supports heating.
166 167 168 |
# File 'lib/seam/resources/unmanaged_device.rb', line 166 def can_hvac_heat @can_hvac_heat end |
#can_hvac_heat_cool ⇒ Boolean?
Indicates whether the thermostat supports simultaneous heating and cooling.
169 170 171 |
# File 'lib/seam/resources/unmanaged_device.rb', line 169 def can_hvac_heat_cool @can_hvac_heat_cool end |
#can_program_offline_access_codes ⇒ Boolean?
Indicates whether the device supports programming offline access codes.
172 173 174 |
# File 'lib/seam/resources/unmanaged_device.rb', line 172 def can_program_offline_access_codes @can_program_offline_access_codes end |
#can_program_online_access_codes ⇒ Boolean?
Indicates whether the device supports programming online access codes.
175 176 177 |
# File 'lib/seam/resources/unmanaged_device.rb', line 175 def can_program_online_access_codes @can_program_online_access_codes end |
#can_program_thermostat_programs_as_different_each_day ⇒ Boolean?
Indicates whether the thermostat supports different climate programs for each day of the week.
178 179 180 |
# File 'lib/seam/resources/unmanaged_device.rb', line 178 def can_program_thermostat_programs_as_different_each_day @can_program_thermostat_programs_as_different_each_day end |
#can_program_thermostat_programs_as_same_each_day ⇒ Boolean?
Indicates whether the thermostat supports a single climate program applied to every day.
181 182 183 |
# File 'lib/seam/resources/unmanaged_device.rb', line 181 def can_program_thermostat_programs_as_same_each_day @can_program_thermostat_programs_as_same_each_day end |
#can_program_thermostat_programs_as_weekday_weekend ⇒ Boolean?
Indicates whether the thermostat supports weekday/weekend climate programs.
184 185 186 |
# File 'lib/seam/resources/unmanaged_device.rb', line 184 def can_program_thermostat_programs_as_weekday_weekend @can_program_thermostat_programs_as_weekday_weekend end |
#can_remotely_lock ⇒ Boolean?
Indicates whether the device supports remote locking.
187 188 189 |
# File 'lib/seam/resources/unmanaged_device.rb', line 187 def can_remotely_lock @can_remotely_lock end |
#can_remotely_unlock ⇒ Boolean?
Indicates whether the device supports remote unlocking.
190 191 192 |
# File 'lib/seam/resources/unmanaged_device.rb', line 190 def can_remotely_unlock @can_remotely_unlock end |
#can_run_thermostat_programs ⇒ Boolean?
Indicates whether the thermostat supports running climate programs.
193 194 195 |
# File 'lib/seam/resources/unmanaged_device.rb', line 193 def can_run_thermostat_programs @can_run_thermostat_programs end |
#can_simulate_connection ⇒ Boolean?
Indicates whether the device supports simulating connection in a sandbox.
196 197 198 |
# File 'lib/seam/resources/unmanaged_device.rb', line 196 def can_simulate_connection @can_simulate_connection end |
#can_simulate_disconnection ⇒ Boolean?
Indicates whether the device supports simulating disconnection in a sandbox.
199 200 201 |
# File 'lib/seam/resources/unmanaged_device.rb', line 199 def can_simulate_disconnection @can_simulate_disconnection end |
#can_simulate_hub_connection ⇒ Boolean?
Indicates whether the hub supports simulating connection in a sandbox.
202 203 204 |
# File 'lib/seam/resources/unmanaged_device.rb', line 202 def can_simulate_hub_connection @can_simulate_hub_connection end |
#can_simulate_hub_disconnection ⇒ Boolean?
Indicates whether the hub supports simulating disconnection in a sandbox.
205 206 207 |
# File 'lib/seam/resources/unmanaged_device.rb', line 205 def can_simulate_hub_disconnection @can_simulate_hub_disconnection end |
#can_simulate_paid_subscription ⇒ Boolean?
Indicates whether the device supports simulating a paid subscription in a sandbox.
208 209 210 |
# File 'lib/seam/resources/unmanaged_device.rb', line 208 def can_simulate_paid_subscription @can_simulate_paid_subscription end |
#can_simulate_removal ⇒ Boolean?
Indicates whether the device supports simulating removal in a sandbox.
211 212 213 |
# File 'lib/seam/resources/unmanaged_device.rb', line 211 def can_simulate_removal @can_simulate_removal end |
#can_turn_off_hvac ⇒ Boolean?
Indicates whether the thermostat can be turned off.
214 215 216 |
# File 'lib/seam/resources/unmanaged_device.rb', line 214 def can_turn_off_hvac @can_turn_off_hvac end |
#can_unlock_with_code ⇒ Boolean?
Indicates whether the lock supports unlocking with an access code.
217 218 219 |
# File 'lib/seam/resources/unmanaged_device.rb', line 217 def can_unlock_with_code @can_unlock_with_code end |
#capabilities_supported ⇒ Array<String>
Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.
220 221 222 |
# File 'lib/seam/resources/unmanaged_device.rb', line 220 def capabilities_supported @capabilities_supported end |
#connected_account_id ⇒ String
Unique identifier for the account associated with the device.
223 224 225 |
# File 'lib/seam/resources/unmanaged_device.rb', line 223 def connected_account_id @connected_account_id end |
#custom_metadata ⇒ Hash
Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.
226 227 228 |
# File 'lib/seam/resources/unmanaged_device.rb', line 226 def @custom_metadata end |
#device_id ⇒ String
ID of the device.
229 230 231 |
# File 'lib/seam/resources/unmanaged_device.rb', line 229 def device_id @device_id end |
#device_type ⇒ String
Type of the device.
232 233 234 |
# File 'lib/seam/resources/unmanaged_device.rb', line 232 def device_type @device_type end |
#is_managed ⇒ Boolean
Indicates that Seam does not manage the device.
235 236 237 |
# File 'lib/seam/resources/unmanaged_device.rb', line 235 def is_managed @is_managed end |
#workspace_id ⇒ String
Unique identifier for the Seam workspace associated with the device.
238 239 240 |
# File 'lib/seam/resources/unmanaged_device.rb', line 238 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the device object was created.
242 |
# File 'lib/seam/resources/unmanaged_device.rb', line 242 date_accessor :created_at |
#errors ⇒ Array<Errors>
Array of errors associated with the device. Each error object within the array contains two fields: error_code and message. error_code is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. message provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.
154 |
# File 'lib/seam/resources/unmanaged_device.rb', line 154 resource_list_accessor :errors, Errors |
#location ⇒ Location?
Location information for the device.
148 |
# File 'lib/seam/resources/unmanaged_device.rb', line 148 resource_accessor :location, Location |
#properties ⇒ Properties
properties of the device.
151 |
# File 'lib/seam/resources/unmanaged_device.rb', line 151 resource_accessor :properties, Properties |
#warnings ⇒ Array<Warnings>
Array of warnings associated with the device. Each warning object within the array contains two fields: warning_code and message. warning_code is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. message provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.
157 |
# File 'lib/seam/resources/unmanaged_device.rb', line 157 resource_list_accessor :warnings, Warnings |