Class: Seam::Resources::UnmanagedDevice

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Represents an unmanaged device. An unmanaged device has a limited set of visible properties and a subset of supported events. You cannot control an unmanaged device. Any access codes on an unmanaged device are unmanaged. To control an unmanaged device with Seam, convert it to a managed device.

Defined Under Namespace

Classes: Errors, Location, Properties, Warnings

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#can_configure_auto_lockObject

Indicates whether the lock supports configuring automatic locking.



107
108
109
# File 'lib/seam/resources/unmanaged_device.rb', line 107

def can_configure_auto_lock
  @can_configure_auto_lock
end

#can_hvac_coolObject

Indicates whether the thermostat supports cooling.



109
110
111
# File 'lib/seam/resources/unmanaged_device.rb', line 109

def can_hvac_cool
  @can_hvac_cool
end

#can_hvac_heatObject

Indicates whether the thermostat supports heating.



111
112
113
# File 'lib/seam/resources/unmanaged_device.rb', line 111

def can_hvac_heat
  @can_hvac_heat
end

#can_hvac_heat_coolObject

Indicates whether the thermostat supports simultaneous heating and cooling.



113
114
115
# File 'lib/seam/resources/unmanaged_device.rb', line 113

def can_hvac_heat_cool
  @can_hvac_heat_cool
end

#can_program_offline_access_codesObject

Indicates whether the device supports programming offline access codes.



115
116
117
# File 'lib/seam/resources/unmanaged_device.rb', line 115

def can_program_offline_access_codes
  @can_program_offline_access_codes
end

#can_program_online_access_codesObject

Indicates whether the device supports programming online access codes.



117
118
119
# File 'lib/seam/resources/unmanaged_device.rb', line 117

def can_program_online_access_codes
  @can_program_online_access_codes
end

#can_program_thermostat_programs_as_different_each_dayObject

Indicates whether the thermostat supports different climate programs for each day of the week.



119
120
121
# File 'lib/seam/resources/unmanaged_device.rb', line 119

def can_program_thermostat_programs_as_different_each_day
  @can_program_thermostat_programs_as_different_each_day
end

#can_program_thermostat_programs_as_same_each_dayObject

Indicates whether the thermostat supports a single climate program applied to every day.



121
122
123
# File 'lib/seam/resources/unmanaged_device.rb', line 121

def can_program_thermostat_programs_as_same_each_day
  @can_program_thermostat_programs_as_same_each_day
end

#can_program_thermostat_programs_as_weekday_weekendObject

Indicates whether the thermostat supports weekday/weekend climate programs.



123
124
125
# File 'lib/seam/resources/unmanaged_device.rb', line 123

def can_program_thermostat_programs_as_weekday_weekend
  @can_program_thermostat_programs_as_weekday_weekend
end

#can_remotely_lockObject

Indicates whether the device supports remote locking.



125
126
127
# File 'lib/seam/resources/unmanaged_device.rb', line 125

def can_remotely_lock
  @can_remotely_lock
end

#can_remotely_unlockObject

Indicates whether the device supports remote unlocking.



127
128
129
# File 'lib/seam/resources/unmanaged_device.rb', line 127

def can_remotely_unlock
  @can_remotely_unlock
end

#can_run_thermostat_programsObject

Indicates whether the thermostat supports running climate programs.



129
130
131
# File 'lib/seam/resources/unmanaged_device.rb', line 129

def can_run_thermostat_programs
  @can_run_thermostat_programs
end

#can_simulate_connectionObject

Indicates whether the device supports simulating connection in a sandbox.



131
132
133
# File 'lib/seam/resources/unmanaged_device.rb', line 131

def can_simulate_connection
  @can_simulate_connection
end

#can_simulate_disconnectionObject

Indicates whether the device supports simulating disconnection in a sandbox.



133
134
135
# File 'lib/seam/resources/unmanaged_device.rb', line 133

def can_simulate_disconnection
  @can_simulate_disconnection
end

#can_simulate_hub_connectionObject

Indicates whether the hub supports simulating connection in a sandbox.



135
136
137
# File 'lib/seam/resources/unmanaged_device.rb', line 135

def can_simulate_hub_connection
  @can_simulate_hub_connection
end

#can_simulate_hub_disconnectionObject

Indicates whether the hub supports simulating disconnection in a sandbox.



137
138
139
# File 'lib/seam/resources/unmanaged_device.rb', line 137

def can_simulate_hub_disconnection
  @can_simulate_hub_disconnection
end

#can_simulate_paid_subscriptionObject

Indicates whether the device supports simulating a paid subscription in a sandbox.



139
140
141
# File 'lib/seam/resources/unmanaged_device.rb', line 139

def can_simulate_paid_subscription
  @can_simulate_paid_subscription
end

#can_simulate_removalObject

Indicates whether the device supports simulating removal in a sandbox.



141
142
143
# File 'lib/seam/resources/unmanaged_device.rb', line 141

def can_simulate_removal
  @can_simulate_removal
end

#can_turn_off_hvacObject

Indicates whether the thermostat can be turned off.



143
144
145
# File 'lib/seam/resources/unmanaged_device.rb', line 143

def can_turn_off_hvac
  @can_turn_off_hvac
end

#can_unlock_with_codeObject

Indicates whether the lock supports unlocking with an access code.



145
146
147
# File 'lib/seam/resources/unmanaged_device.rb', line 145

def can_unlock_with_code
  @can_unlock_with_code
end

#capabilities_supportedObject

Collection of capabilities that the device supports when connected to Seam. Values are access_code, which indicates that the device can manage and utilize digital PIN codes for secure access; lock, which indicates that the device controls a door locking mechanism, enabling the remote opening and closing of doors and other entry points; noise_detection, which indicates that the device supports monitoring and responding to ambient noise levels; thermostat, which indicates that the device can regulate and adjust indoor temperatures; battery, which indicates that the device can manage battery life and health; and phone, which indicates that the device is a mobile device, such as a smartphone. Important: Superseded by capability flags.



147
148
149
# File 'lib/seam/resources/unmanaged_device.rb', line 147

def capabilities_supported
  @capabilities_supported
end

#connected_account_idObject

Unique identifier for the account associated with the device.



149
150
151
# File 'lib/seam/resources/unmanaged_device.rb', line 149

def 
  @connected_account_id
end

#custom_metadataObject

Set of key:value pairs. Adding custom metadata to a resource, such as a Connect Webview, connected account, or device, enables you to store custom information, like customer details or internal IDs from your application.



151
152
153
# File 'lib/seam/resources/unmanaged_device.rb', line 151

def 
  @custom_metadata
end

#device_idObject

ID of the device.



153
154
155
# File 'lib/seam/resources/unmanaged_device.rb', line 153

def device_id
  @device_id
end

#device_typeObject

Type of the device.



155
156
157
# File 'lib/seam/resources/unmanaged_device.rb', line 155

def device_type
  @device_type
end

#is_managedObject

Indicates that Seam does not manage the device.



157
158
159
# File 'lib/seam/resources/unmanaged_device.rb', line 157

def is_managed
  @is_managed
end

#workspace_idObject

Unique identifier for the Seam workspace associated with the device.



159
160
161
# File 'lib/seam/resources/unmanaged_device.rb', line 159

def workspace_id
  @workspace_id
end