Class: Seam::Resources::UnmanagedDevice::Errors::BridgeDisconnected
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedDevice::Errors::BridgeDisconnected
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the Seam API cannot communicate with Seam Bridge, for example, if the Seam Bridge executable has stopped or if the computer running the Seam Bridge executable is offline. See also Troubleshooting Your Access Control System.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
-
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
bridge_disconnected
261 262 263 |
# File 'lib/seam/resources/unmanaged_device.rb', line 261 def error_code @error_code end |
#is_bridge_error ⇒ Boolean?
Indicates whether the error is related to Seam Bridge.
264 265 266 |
# File 'lib/seam/resources/unmanaged_device.rb', line 264 def is_bridge_error @is_bridge_error end |
#is_connected_account_error ⇒ Boolean?
Indicates whether the error is related specifically to the connected account.
267 268 269 |
# File 'lib/seam/resources/unmanaged_device.rb', line 267 def is_connected_account_error @is_connected_account_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
270 271 272 |
# File 'lib/seam/resources/unmanaged_device.rb', line 270 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
273 |
# File 'lib/seam/resources/unmanaged_device.rb', line 273 date_accessor :created_at |