Class: Seam::Resources::UnmanagedDevice::Errors::DeviceOffline
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedDevice::Errors::DeviceOffline
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the device is offline.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
device_offline
99 100 101 |
# File 'lib/seam/resources/unmanaged_device.rb', line 99 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
102 103 104 |
# File 'lib/seam/resources/unmanaged_device.rb', line 102 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
105 106 107 |
# File 'lib/seam/resources/unmanaged_device.rb', line 105 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
108 |
# File 'lib/seam/resources/unmanaged_device.rb', line 108 date_accessor :created_at |