Class: Seam::Resources::UnmanagedDevice::Errors::SaltoKsSubscriptionLimitExceeded
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedDevice::Errors::SaltoKsSubscriptionLimitExceeded
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the Salto site user limit has been reached.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
-
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
salto_ks_subscription_limit_exceeded
36 37 38 |
# File 'lib/seam/resources/unmanaged_device.rb', line 36 def error_code @error_code end |
#is_connected_account_error ⇒ TrueClass
Indicates that the error is a connected account error.
39 40 41 |
# File 'lib/seam/resources/unmanaged_device.rb', line 39 def is_connected_account_error @is_connected_account_error end |
#is_device_error ⇒ FalseClass
Indicates that the error is not a device error.
42 43 44 |
# File 'lib/seam/resources/unmanaged_device.rb', line 42 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
45 46 47 |
# File 'lib/seam/resources/unmanaged_device.rb', line 45 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
48 |
# File 'lib/seam/resources/unmanaged_device.rb', line 48 date_accessor :created_at |