Class: Seam::Resources::UnmanagedDevice::Errors::SubscriptionRequired
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedDevice::Errors::SubscriptionRequired
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that a subscription is required to connect.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
subscription_required
243 244 245 |
# File 'lib/seam/resources/unmanaged_device.rb', line 243 def error_code @error_code end |
#is_device_error ⇒ TrueClass
Indicates that the error is a device error.
246 247 248 |
# File 'lib/seam/resources/unmanaged_device.rb', line 246 def is_device_error @is_device_error end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
249 250 251 |
# File 'lib/seam/resources/unmanaged_device.rb', line 249 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
252 |
# File 'lib/seam/resources/unmanaged_device.rb', line 252 date_accessor :created_at |