Class: Seam::Resources::UnmanagedDevice::Properties

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Defined Under Namespace

Classes: AccessoryKeypad, Battery, Model

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#battery_levelFloat?

Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.

Returns:

  • (Float, nil)


101
102
103
# File 'lib/seam/resources/unmanaged_device.rb', line 101

def battery_level
  @battery_level
end

#image_alt_textString?

Alt text for the device image.

Returns:

  • (String, nil)


104
105
106
# File 'lib/seam/resources/unmanaged_device.rb', line 104

def image_alt_text
  @image_alt_text
end

#image_urlString?

Image URL for the device.

Returns:

  • (String, nil)


107
108
109
# File 'lib/seam/resources/unmanaged_device.rb', line 107

def image_url
  @image_url
end

#manufacturerString?

Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.

Returns:

  • (String, nil)


110
111
112
# File 'lib/seam/resources/unmanaged_device.rb', line 110

def manufacturer
  @manufacturer
end

#nameString

Deprecated.

use device.display_name instead

Name of the device.

Returns:

  • (String)


114
115
116
# File 'lib/seam/resources/unmanaged_device.rb', line 114

def name
  @name
end

#offline_access_codes_enabledBoolean?

Deprecated.

use device.can_program_offline_access_codes

Indicates whether it is currently possible to use offline access codes for the device.

Returns:

  • (Boolean, nil)


118
119
120
# File 'lib/seam/resources/unmanaged_device.rb', line 118

def offline_access_codes_enabled
  @offline_access_codes_enabled
end

#onlineBoolean

Indicates whether the device is online.

Returns:

  • (Boolean)


121
122
123
# File 'lib/seam/resources/unmanaged_device.rb', line 121

def online
  @online
end

#online_access_codes_enabledBoolean?

Deprecated.

use device.can_program_online_access_codes

Indicates whether it is currently possible to use online access codes for the device.

Returns:

  • (Boolean, nil)


125
126
127
# File 'lib/seam/resources/unmanaged_device.rb', line 125

def online_access_codes_enabled
  @online_access_codes_enabled
end

Instance Method Details

#accessory_keypadAccessoryKeypad?

Accessory keypad properties and state.

Returns:



92
# File 'lib/seam/resources/unmanaged_device.rb', line 92

resource_accessor :accessory_keypad, AccessoryKeypad

#batteryBattery?

Represents the current status of the battery charge level.

Returns:



95
# File 'lib/seam/resources/unmanaged_device.rb', line 95

resource_accessor :battery, Battery

#modelModel

Device model-related properties.

Returns:



98
# File 'lib/seam/resources/unmanaged_device.rb', line 98

resource_accessor :model, Model