Class: Seam::Resources::UnmanagedDevice::Properties
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice::Properties
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Defined Under Namespace
Classes: AccessoryKeypad, Battery, Model
Instance Attribute Summary collapse
-
#battery_level ⇒ Float?
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
-
#image_alt_text ⇒ String?
Alt text for the device image.
-
#image_url ⇒ String?
Image URL for the device.
-
#manufacturer ⇒ String?
Manufacturer of the device.
-
#name ⇒ String
deprecated
Deprecated.
use device.display_name instead
-
#offline_access_codes_enabled ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_offline_access_codes
-
#online ⇒ Boolean
Indicates whether the device is online.
-
#online_access_codes_enabled ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_online_access_codes
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#accessory_keypad ⇒ AccessoryKeypad?
Accessory keypad properties and state.
-
#battery ⇒ Battery?
Represents the current status of the battery charge level.
-
#model ⇒ Model
Device model-related properties.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#battery_level ⇒ Float?
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
101 102 103 |
# File 'lib/seam/resources/unmanaged_device.rb', line 101 def battery_level @battery_level end |
#image_alt_text ⇒ String?
Alt text for the device image.
104 105 106 |
# File 'lib/seam/resources/unmanaged_device.rb', line 104 def image_alt_text @image_alt_text end |
#image_url ⇒ String?
Image URL for the device.
107 108 109 |
# File 'lib/seam/resources/unmanaged_device.rb', line 107 def image_url @image_url end |
#manufacturer ⇒ String?
Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.
110 111 112 |
# File 'lib/seam/resources/unmanaged_device.rb', line 110 def manufacturer @manufacturer end |
#name ⇒ String
use device.display_name instead
Name of the device.
114 115 116 |
# File 'lib/seam/resources/unmanaged_device.rb', line 114 def name @name end |
#offline_access_codes_enabled ⇒ Boolean?
use device.can_program_offline_access_codes
Indicates whether it is currently possible to use offline access codes for the device.
118 119 120 |
# File 'lib/seam/resources/unmanaged_device.rb', line 118 def offline_access_codes_enabled @offline_access_codes_enabled end |
#online ⇒ Boolean
Indicates whether the device is online.
121 122 123 |
# File 'lib/seam/resources/unmanaged_device.rb', line 121 def online @online end |
#online_access_codes_enabled ⇒ Boolean?
use device.can_program_online_access_codes
Indicates whether it is currently possible to use online access codes for the device.
125 126 127 |
# File 'lib/seam/resources/unmanaged_device.rb', line 125 def online_access_codes_enabled @online_access_codes_enabled end |
Instance Method Details
#accessory_keypad ⇒ AccessoryKeypad?
Accessory keypad properties and state.
92 |
# File 'lib/seam/resources/unmanaged_device.rb', line 92 resource_accessor :accessory_keypad, AccessoryKeypad |