Class: Seam::Resources::UnmanagedDevice::Properties
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice::Properties
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Defined Under Namespace
Classes: AccessoryKeypad, Battery, Model
Instance Attribute Summary collapse
-
#battery_level ⇒ Object
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
-
#image_alt_text ⇒ Object
Alt text for the device image.
-
#image_url ⇒ Object
Image URL for the device.
-
#manufacturer ⇒ Object
Manufacturer of the device.
-
#name ⇒ Object
deprecated
Deprecated.
use device.display_name instead
-
#offline_access_codes_enabled ⇒ Object
deprecated
Deprecated.
use device.can_program_offline_access_codes
-
#online ⇒ Object
Indicates whether the device is online.
-
#online_access_codes_enabled ⇒ Object
deprecated
Deprecated.
use device.can_program_online_access_codes
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#battery_level ⇒ Object
Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.
69 70 71 |
# File 'lib/seam/resources/unmanaged_device.rb', line 69 def battery_level @battery_level end |
#image_alt_text ⇒ Object
Alt text for the device image.
71 72 73 |
# File 'lib/seam/resources/unmanaged_device.rb', line 71 def image_alt_text @image_alt_text end |
#image_url ⇒ Object
Image URL for the device.
73 74 75 |
# File 'lib/seam/resources/unmanaged_device.rb', line 73 def image_url @image_url end |
#manufacturer ⇒ Object
Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.
75 76 77 |
# File 'lib/seam/resources/unmanaged_device.rb', line 75 def manufacturer @manufacturer end |
#name ⇒ Object
use device.display_name instead
Name of the device.
78 79 80 |
# File 'lib/seam/resources/unmanaged_device.rb', line 78 def name @name end |
#offline_access_codes_enabled ⇒ Object
use device.can_program_offline_access_codes
Indicates whether it is currently possible to use offline access codes for the device.
81 82 83 |
# File 'lib/seam/resources/unmanaged_device.rb', line 81 def offline_access_codes_enabled @offline_access_codes_enabled end |
#online ⇒ Object
Indicates whether the device is online.
83 84 85 |
# File 'lib/seam/resources/unmanaged_device.rb', line 83 def online @online end |
#online_access_codes_enabled ⇒ Object
use device.can_program_online_access_codes
Indicates whether it is currently possible to use online access codes for the device.
86 87 88 |
# File 'lib/seam/resources/unmanaged_device.rb', line 86 def online_access_codes_enabled @online_access_codes_enabled end |