Class: Seam::Resources::UnmanagedDevice::Properties

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Defined Under Namespace

Classes: AccessoryKeypad, Battery, Model

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#battery_levelObject

Indicates the battery level of the device as a decimal value between 0 and 1, inclusive.



69
70
71
# File 'lib/seam/resources/unmanaged_device.rb', line 69

def battery_level
  @battery_level
end

#image_alt_textObject

Alt text for the device image.



71
72
73
# File 'lib/seam/resources/unmanaged_device.rb', line 71

def image_alt_text
  @image_alt_text
end

#image_urlObject

Image URL for the device.



73
74
75
# File 'lib/seam/resources/unmanaged_device.rb', line 73

def image_url
  @image_url
end

#manufacturerObject

Manufacturer of the device. When a device, such as a smart lock, is connected through a smart hub, the manufacturer of the device might be different from that of the smart hub.



75
76
77
# File 'lib/seam/resources/unmanaged_device.rb', line 75

def manufacturer
  @manufacturer
end

#nameObject

Deprecated.

use device.display_name instead

Name of the device.



78
79
80
# File 'lib/seam/resources/unmanaged_device.rb', line 78

def name
  @name
end

#offline_access_codes_enabledObject

Deprecated.

use device.can_program_offline_access_codes

Indicates whether it is currently possible to use offline access codes for the device.



81
82
83
# File 'lib/seam/resources/unmanaged_device.rb', line 81

def offline_access_codes_enabled
  @offline_access_codes_enabled
end

#onlineObject

Indicates whether the device is online.



83
84
85
# File 'lib/seam/resources/unmanaged_device.rb', line 83

def online
  @online
end

#online_access_codes_enabledObject

Deprecated.

use device.can_program_online_access_codes

Indicates whether it is currently possible to use online access codes for the device.



86
87
88
# File 'lib/seam/resources/unmanaged_device.rb', line 86

def online_access_codes_enabled
  @online_access_codes_enabled
end