Class: Seam::Resources::UnmanagedDevice::Properties::Model
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice::Properties::Model
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Instance Attribute Summary collapse
-
#accessory_keypad_supported ⇒ Boolean?
deprecated
Deprecated.
use device.properties.model.can_connect_accessory_keypad
-
#can_connect_accessory_keypad ⇒ Boolean?
Indicates whether the device can connect a accessory keypad.
-
#display_name ⇒ String
Display name of the device model.
-
#has_built_in_keypad ⇒ Boolean?
Indicates whether the device has a built in accessory keypad.
-
#manufacturer_display_name ⇒ String
Display name that corresponds to the manufacturer-specific terminology for the device.
-
#offline_access_codes_supported ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_offline_access_codes.
-
#online_access_codes_supported ⇒ Boolean?
deprecated
Deprecated.
use device.can_program_online_access_codes.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#accessory_keypad_supported ⇒ Boolean?
use device.properties.model.can_connect_accessory_keypad
69 70 71 |
# File 'lib/seam/resources/unmanaged_device.rb', line 69 def accessory_keypad_supported @accessory_keypad_supported end |
#can_connect_accessory_keypad ⇒ Boolean?
Indicates whether the device can connect a accessory keypad.
72 73 74 |
# File 'lib/seam/resources/unmanaged_device.rb', line 72 def can_connect_accessory_keypad @can_connect_accessory_keypad end |
#display_name ⇒ String
Display name of the device model.
75 76 77 |
# File 'lib/seam/resources/unmanaged_device.rb', line 75 def display_name @display_name end |
#has_built_in_keypad ⇒ Boolean?
Indicates whether the device has a built in accessory keypad.
78 79 80 |
# File 'lib/seam/resources/unmanaged_device.rb', line 78 def has_built_in_keypad @has_built_in_keypad end |
#manufacturer_display_name ⇒ String
Display name that corresponds to the manufacturer-specific terminology for the device.
81 82 83 |
# File 'lib/seam/resources/unmanaged_device.rb', line 81 def manufacturer_display_name @manufacturer_display_name end |
#offline_access_codes_supported ⇒ Boolean?
use device.can_program_offline_access_codes.
84 85 86 |
# File 'lib/seam/resources/unmanaged_device.rb', line 84 def offline_access_codes_supported @offline_access_codes_supported end |
#online_access_codes_supported ⇒ Boolean?
use device.can_program_online_access_codes.
87 88 89 |
# File 'lib/seam/resources/unmanaged_device.rb', line 87 def online_access_codes_supported @online_access_codes_supported end |