Class: Seam::Resources::UnmanagedDevice::Properties::Model

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#accessory_keypad_supportedObject

Deprecated.

use device.properties.model.can_connect_accessory_keypad



50
51
52
# File 'lib/seam/resources/unmanaged_device.rb', line 50

def accessory_keypad_supported
  @accessory_keypad_supported
end

#can_connect_accessory_keypadObject

Indicates whether the device can connect a accessory keypad.



52
53
54
# File 'lib/seam/resources/unmanaged_device.rb', line 52

def can_connect_accessory_keypad
  @can_connect_accessory_keypad
end

#display_nameObject

Display name of the device model.



54
55
56
# File 'lib/seam/resources/unmanaged_device.rb', line 54

def display_name
  @display_name
end

#has_built_in_keypadObject

Indicates whether the device has a built in accessory keypad.



56
57
58
# File 'lib/seam/resources/unmanaged_device.rb', line 56

def has_built_in_keypad
  @has_built_in_keypad
end

#manufacturer_display_nameObject

Display name that corresponds to the manufacturer-specific terminology for the device.



58
59
60
# File 'lib/seam/resources/unmanaged_device.rb', line 58

def manufacturer_display_name
  @manufacturer_display_name
end

#offline_access_codes_supportedObject

Deprecated.

use device.can_program_offline_access_codes.



60
61
62
# File 'lib/seam/resources/unmanaged_device.rb', line 60

def offline_access_codes_supported
  @offline_access_codes_supported
end

#online_access_codes_supportedObject

Deprecated.

use device.can_program_online_access_codes.



62
63
64
# File 'lib/seam/resources/unmanaged_device.rb', line 62

def online_access_codes_supported
  @online_access_codes_supported
end