Class: Seam::Resources::UnmanagedDevice::Warnings
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedDevice::Warnings
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Instance Attribute Summary collapse
-
#active_access_code_count ⇒ Object
Number of active access codes on the device when the warning was set.
-
#max_active_access_code_count ⇒ Object
Maximum number of active access codes supported by the device.
-
#message ⇒ Object
Detailed description of the warning.
-
#warning_code ⇒ Object
Unique identifier of the type of warning.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#active_access_code_count ⇒ Object
Number of active access codes on the device when the warning was set.
91 92 93 |
# File 'lib/seam/resources/unmanaged_device.rb', line 91 def active_access_code_count @active_access_code_count end |
#max_active_access_code_count ⇒ Object
Maximum number of active access codes supported by the device.
93 94 95 |
# File 'lib/seam/resources/unmanaged_device.rb', line 93 def max_active_access_code_count @max_active_access_code_count end |
#message ⇒ Object
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
95 96 97 |
# File 'lib/seam/resources/unmanaged_device.rb', line 95 def @message end |
#warning_code ⇒ Object
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue.
97 98 99 |
# File 'lib/seam/resources/unmanaged_device.rb', line 97 def warning_code @warning_code end |