Class: Seam::Resources::UnmanagedDevice::Warnings::LocklyTimeZoneNotConfigured
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::LocklyTimeZoneNotConfigured
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that Seam detected that the Lockly device does not have a time zone configured. Time-bound codes may not work as expected.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
672 673 674 |
# File 'lib/seam/resources/unmanaged_device.rb', line 672 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
lockly_time_zone_not_configured
677 678 679 |
# File 'lib/seam/resources/unmanaged_device.rb', line 677 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
680 |
# File 'lib/seam/resources/unmanaged_device.rb', line 680 date_accessor :created_at |