Class: Seam::Resources::UnmanagedDevice::Warnings::MaxAccessCodesReached

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device has reached its maximum number of active access codes. Delete existing codes before creating new ones.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#active_access_code_countInteger

Number of active access codes on the device when the warning was set.

Returns:

  • (Integer)


822
823
824
# File 'lib/seam/resources/unmanaged_device.rb', line 822

def active_access_code_count
  @active_access_code_count
end

#max_active_access_code_countInteger

Maximum number of active access codes supported by the device.

Returns:

  • (Integer)


825
826
827
# File 'lib/seam/resources/unmanaged_device.rb', line 825

def max_active_access_code_count
  @max_active_access_code_count
end

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


828
829
830
# File 'lib/seam/resources/unmanaged_device.rb', line 828

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • max_access_codes_reached

Returns:

  • (String)


833
834
835
# File 'lib/seam/resources/unmanaged_device.rb', line 833

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


836
# File 'lib/seam/resources/unmanaged_device.rb', line 836

date_accessor :created_at