Class: Seam::Resources::UnmanagedDevice::Warnings::MaxAccessCodesReached
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::MaxAccessCodesReached
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the device has reached its maximum number of active access codes. Delete existing codes before creating new ones.
Instance Attribute Summary collapse
-
#active_access_code_count ⇒ Integer
Number of active access codes on the device when the warning was set.
-
#max_active_access_code_count ⇒ Integer
Maximum number of active access codes supported by the device.
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#active_access_code_count ⇒ Integer
Number of active access codes on the device when the warning was set.
822 823 824 |
# File 'lib/seam/resources/unmanaged_device.rb', line 822 def active_access_code_count @active_access_code_count end |
#max_active_access_code_count ⇒ Integer
Maximum number of active access codes supported by the device.
825 826 827 |
# File 'lib/seam/resources/unmanaged_device.rb', line 825 def max_active_access_code_count @max_active_access_code_count end |
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
828 829 830 |
# File 'lib/seam/resources/unmanaged_device.rb', line 828 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
max_access_codes_reached
833 834 835 |
# File 'lib/seam/resources/unmanaged_device.rb', line 833 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
836 |
# File 'lib/seam/resources/unmanaged_device.rb', line 836 date_accessor :created_at |