Class: Seam::Resources::UnmanagedDevice::Warnings::ProviderIssue
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::ProviderIssue
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates a provider-specific issue that may affect device functionality.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
762 763 764 |
# File 'lib/seam/resources/unmanaged_device.rb', line 762 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
provider_issue
767 768 769 |
# File 'lib/seam/resources/unmanaged_device.rb', line 767 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
770 |
# File 'lib/seam/resources/unmanaged_device.rb', line 770 date_accessor :created_at |