Class: Seam::Resources::UnmanagedDevice::Warnings::SaltoKsPrivacyMode
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::SaltoKsPrivacyMode
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the Salto KS lock is in Privacy Mode. Access Codes will not unlock doors.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
597 598 599 |
# File 'lib/seam/resources/unmanaged_device.rb', line 597 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
salto_ks_privacy_mode
602 603 604 |
# File 'lib/seam/resources/unmanaged_device.rb', line 602 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
605 |
# File 'lib/seam/resources/unmanaged_device.rb', line 605 date_accessor :created_at |