Class: Seam::Resources::UnmanagedDevice::Warnings::ThirdPartyIntegrationDetected
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::ThirdPartyIntegrationDetected
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that a third-party integration has been detected.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
462 463 464 |
# File 'lib/seam/resources/unmanaged_device.rb', line 462 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
third_party_integration_detected
467 468 469 |
# File 'lib/seam/resources/unmanaged_device.rb', line 467 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
470 |
# File 'lib/seam/resources/unmanaged_device.rb', line 470 date_accessor :created_at |