Class: Seam::Resources::UnmanagedDevice::Warnings::TtlockLockGatewayUnlockingNotEnabled
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::TtlockLockGatewayUnlockingNotEnabled
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that the Remote Unlock feature is not enabled in the settings."
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
477 478 479 |
# File 'lib/seam/resources/unmanaged_device.rb', line 477 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
ttlock_lock_gateway_unlocking_not_enabled
482 483 484 |
# File 'lib/seam/resources/unmanaged_device.rb', line 482 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
485 |
# File 'lib/seam/resources/unmanaged_device.rb', line 485 date_accessor :created_at |