Class: Seam::Resources::UnmanagedDevice::Warnings::UnknownIssueWithPhone
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedDevice::Warnings::UnknownIssueWithPhone
- Defined in:
- lib/seam/resources/unmanaged_device.rb
Overview
Indicates that an unknown issue occurred while syncing the state of the phone with the provider. This issue may affect the proper functioning of the phone.
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
657 658 659 |
# File 'lib/seam/resources/unmanaged_device.rb', line 657 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
unknown_issue_with_phone
662 663 664 |
# File 'lib/seam/resources/unmanaged_device.rb', line 662 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
665 |
# File 'lib/seam/resources/unmanaged_device.rb', line 665 date_accessor :created_at |