Class: Seam::Resources::UnmanagedDevice::Warnings::UnreliableOnlineStatus

Inherits:
Warnings
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_device.rb

Overview

Indicates that the device may optimistically be reported as online because the provider does not reliably report its online status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#messageString

Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


807
808
809
# File 'lib/seam/resources/unmanaged_device.rb', line 807

def message
  @message
end

#warning_codeString

Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:

  • unreliable_online_status

Returns:

  • (String)


812
813
814
# File 'lib/seam/resources/unmanaged_device.rb', line 812

def warning_code
  @warning_code
end

Instance Method Details

#created_atTime

Date and time at which Seam created the warning.

Returns:

  • (Time)


815
# File 'lib/seam/resources/unmanaged_device.rb', line 815

date_accessor :created_at