Class: Seam::Resources::UnmanagedUserIdentity
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedUserIdentity
- Defined in:
- lib/seam/resources/unmanaged_user_identity.rb
Overview
Represents an unmanaged user identity. Unmanaged user identities do not have keys.
Defined Under Namespace
Instance Attribute Summary collapse
-
#acs_user_ids ⇒ Array<String>
Array of access system user IDs associated with the user identity.
-
#display_name ⇒ String
Display name for the user identity.
-
#email_address ⇒ String?
Unique email address for the user identity.
-
#full_name ⇒ String?
Full name of the user associated with the user identity.
-
#phone_number ⇒ String?
Unique phone number for the user identity in E.164 format (for example, +15555550100).
-
#user_identity_id ⇒ String
ID of the user identity.
-
#workspace_id ⇒ String
ID of the workspace that contains the user identity.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which the user identity was created.
-
#errors ⇒ Array<Errors>
Array of errors associated with the user identity.
-
#warnings ⇒ Array<Warnings>
Array of warnings associated with the user identity.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_user_ids ⇒ Array<String>
Array of access system user IDs associated with the user identity.
45 46 47 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 45 def acs_user_ids @acs_user_ids end |
#display_name ⇒ String
Display name for the user identity.
48 49 50 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 48 def display_name @display_name end |
#email_address ⇒ String?
Unique email address for the user identity.
51 52 53 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 51 def email_address @email_address end |
#full_name ⇒ String?
Full name of the user associated with the user identity.
54 55 56 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 54 def full_name @full_name end |
#phone_number ⇒ String?
Unique phone number for the user identity in E.164 format (for example, +15555550100).
57 58 59 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 57 def phone_number @phone_number end |
#user_identity_id ⇒ String
ID of the user identity.
60 61 62 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 60 def user_identity_id @user_identity_id end |
#workspace_id ⇒ String
ID of the workspace that contains the user identity.
63 64 65 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 63 def workspace_id @workspace_id end |
Instance Method Details
#created_at ⇒ Time
Date and time at which the user identity was created.
67 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 67 date_accessor :created_at |
#errors ⇒ Array<Errors>
Array of errors associated with the user identity. Each error object within the array contains fields like "error_code" and "message." "error_code" is a string that uniquely identifies the type of error, enabling quick recognition and categorization of the issue. "message" provides a more detailed description of the error, offering insights into the issue and potentially how to rectify it.
39 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 39 resource_list_accessor :errors, Errors |
#warnings ⇒ Array<Warnings>
Array of warnings associated with the user identity. Each warning object within the array contains two fields: "warning_code" and "message." "warning_code" is a string that uniquely identifies the type of warning, enabling quick recognition and categorization of the issue. "message" provides a more detailed description of the warning, offering insights into the issue and potentially how to rectify it.
42 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 42 resource_list_accessor :warnings, Warnings |