Class: Seam::Resources::UnmanagedUserIdentity
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedUserIdentity
- Defined in:
- lib/seam/resources/unmanaged_user_identity.rb
Overview
Represents an unmanaged user identity. Unmanaged user identities do not have keys.
Defined Under Namespace
Instance Attribute Summary collapse
-
#acs_user_ids ⇒ Object
Array of access system user IDs associated with the user identity.
-
#display_name ⇒ Object
Display name for the user identity.
-
#email_address ⇒ Object
Unique email address for the user identity.
-
#full_name ⇒ Object
Full name of the user associated with the user identity.
-
#phone_number ⇒ Object
Unique phone number for the user identity in E.164 format (for example, +15555550100).
-
#user_identity_id ⇒ Object
ID of the user identity.
-
#workspace_id ⇒ Object
ID of the workspace that contains the user identity.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_user_ids ⇒ Object
Array of access system user IDs associated with the user identity.
32 33 34 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 32 def acs_user_ids @acs_user_ids end |
#display_name ⇒ Object
Display name for the user identity.
34 35 36 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 34 def display_name @display_name end |
#email_address ⇒ Object
Unique email address for the user identity.
36 37 38 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 36 def email_address @email_address end |
#full_name ⇒ Object
Full name of the user associated with the user identity.
38 39 40 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 38 def full_name @full_name end |
#phone_number ⇒ Object
Unique phone number for the user identity in E.164 format (for example, +15555550100).
40 41 42 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 40 def phone_number @phone_number end |
#user_identity_id ⇒ Object
ID of the user identity.
42 43 44 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 42 def user_identity_id @user_identity_id end |
#workspace_id ⇒ Object
ID of the workspace that contains the user identity.
44 45 46 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 44 def workspace_id @workspace_id end |