Class: Seam::Resources::UnmanagedUserIdentity::Errors
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UnmanagedUserIdentity::Errors
- Defined in:
- lib/seam/resources/unmanaged_user_identity.rb
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system that the user identity is associated with.
-
#acs_user_id ⇒ String
ID of the access system user that has an issue.
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Attributes inherited from BaseResource
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system that the user identity is associated with.
10 11 12 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 10 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the access system user that has an issue.
13 14 15 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 13 def acs_user_id @acs_user_id end |
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue.
16 17 18 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 16 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
19 20 21 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 19 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
22 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 22 date_accessor :created_at |