Class: Seam::Resources::UnmanagedUserIdentity::Errors

Inherits:
BaseResource
  • Object
show all
Defined in:
lib/seam/resources/unmanaged_user_identity.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_system_idObject

ID of the access system that the user identity is associated with.



9
10
11
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 9

def acs_system_id
  @acs_system_id
end

#acs_user_idObject

ID of the access system user that has an issue.



11
12
13
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 11

def acs_user_id
  @acs_user_id
end

#error_codeObject

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.



13
14
15
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 13

def error_code
  @error_code
end

#messageObject

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.



15
16
17
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 15

def message
  @message
end