Class: Seam::Resources::UnmanagedUserIdentity::Errors::IssueWithAcsUser
- Inherits:
-
Errors
- Object
- Errors
- Seam::Resources::UnmanagedUserIdentity::Errors::IssueWithAcsUser
- Defined in:
- lib/seam/resources/unmanaged_user_identity.rb
Overview
Indicates that there is an issue with an access system user associated with this user identity.
Instance Attribute Summary collapse
-
#acs_system_id ⇒ String
ID of the access system that the user identity is associated with.
-
#acs_user_id ⇒ String
ID of the access system user that has an issue.
-
#error_code ⇒ String
Unique identifier of the type of error.
-
#message ⇒ String
Detailed description of the error.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the error.
Instance Attribute Details
#acs_system_id ⇒ String
ID of the access system that the user identity is associated with.
13 14 15 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 13 def acs_system_id @acs_system_id end |
#acs_user_id ⇒ String
ID of the access system user that has an issue.
16 17 18 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 16 def acs_user_id @acs_user_id end |
#error_code ⇒ String
Unique identifier of the type of error. Enables quick recognition and categorization of the issue. Known values:
issue_with_acs_user
21 22 23 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 21 def error_code @error_code end |
#message ⇒ String
Detailed description of the error. Provides insights into the issue and potentially how to rectify it.
24 25 26 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 24 def @message end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the error.
27 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 27 date_accessor :created_at |