Class: Seam::Resources::UnmanagedUserIdentity::Warnings::AcsUserProfileDoesNotMatchUserIdentity
- Inherits:
-
Warnings
- Object
- Warnings
- Seam::Resources::UnmanagedUserIdentity::Warnings::AcsUserProfileDoesNotMatchUserIdentity
- Defined in:
- lib/seam/resources/unmanaged_user_identity.rb
Overview
Indicates that the ACS user's profile does not match the user identity's profile
Instance Attribute Summary collapse
-
#message ⇒ String
Detailed description of the warning.
-
#warning_code ⇒ String
Unique identifier of the type of warning.
Instance Method Summary collapse
-
#created_at ⇒ Time
Date and time at which Seam created the warning.
Instance Attribute Details
#message ⇒ String
Detailed description of the warning. Provides insights into the issue and potentially how to rectify it.
74 75 76 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 74 def @message end |
#warning_code ⇒ String
Unique identifier of the type of warning. Enables quick recognition and categorization of the issue. Known values:
acs_user_profile_does_not_match_user_identity
79 80 81 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 79 def warning_code @warning_code end |
Instance Method Details
#created_at ⇒ Time
Date and time at which Seam created the warning.
82 |
# File 'lib/seam/resources/unmanaged_user_identity.rb', line 82 date_accessor :created_at |