Class: Seam::Resources::UserIdentity
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::UserIdentity
- Includes:
- ResourceErrorsSupport, ResourceWarningsSupport
- Defined in:
- lib/seam/resources/user_identity.rb
Overview
Represents a user identity associated with an application user account.
Instance Attribute Summary collapse
-
#acs_user_ids ⇒ Object
Array of access system user IDs associated with the user identity.
-
#display_name ⇒ Object
Display name for the user identity.
-
#email_address ⇒ Object
Unique email address for the user identity.
-
#full_name ⇒ Object
Full name of the user associated with the user identity.
-
#phone_number ⇒ Object
Unique phone number for the user identity in E.164 format (for example, +15555550100).
-
#user_identity_id ⇒ Object
ID of the user identity.
-
#user_identity_key ⇒ Object
Unique key for the user identity.
-
#workspace_id ⇒ Object
ID of the workspace that contains the user identity.
Attributes inherited from BaseResource
Method Summary
Methods included from ResourceWarningsSupport
Methods included from ResourceErrorsSupport
Methods inherited from BaseResource
date_accessor, #initialize, #inspect, load_from_response, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#acs_user_ids ⇒ Object
Array of access system user IDs associated with the user identity.
8 9 10 |
# File 'lib/seam/resources/user_identity.rb', line 8 def acs_user_ids @acs_user_ids end |
#display_name ⇒ Object
Display name for the user identity.
10 11 12 |
# File 'lib/seam/resources/user_identity.rb', line 10 def display_name @display_name end |
#email_address ⇒ Object
Unique email address for the user identity.
12 13 14 |
# File 'lib/seam/resources/user_identity.rb', line 12 def email_address @email_address end |
#full_name ⇒ Object
Full name of the user associated with the user identity.
14 15 16 |
# File 'lib/seam/resources/user_identity.rb', line 14 def full_name @full_name end |
#phone_number ⇒ Object
Unique phone number for the user identity in E.164 format (for example, +15555550100).
16 17 18 |
# File 'lib/seam/resources/user_identity.rb', line 16 def phone_number @phone_number end |
#user_identity_id ⇒ Object
ID of the user identity.
18 19 20 |
# File 'lib/seam/resources/user_identity.rb', line 18 def user_identity_id @user_identity_id end |
#user_identity_key ⇒ Object
Unique key for the user identity.
20 21 22 |
# File 'lib/seam/resources/user_identity.rb', line 20 def user_identity_key @user_identity_key end |
#workspace_id ⇒ Object
ID of the workspace that contains the user identity.
22 23 24 |
# File 'lib/seam/resources/user_identity.rb', line 22 def workspace_id @workspace_id end |