Class: Seam::Resources::UserIdentity::Errors

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/user_identity.rb

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Instance Method Summary collapse

Methods inherited from BaseResource

#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#acs_system_idString

ID of the access system that the user identity is associated with.

Returns:

  • (String)


10
11
12
# File 'lib/seam/resources/user_identity.rb', line 10

def acs_system_id
  @acs_system_id
end

#acs_user_idString

ID of the access system user that has an issue.

Returns:

  • (String)


13
14
15
# File 'lib/seam/resources/user_identity.rb', line 13

def acs_user_id
  @acs_user_id
end

#error_codeString

Unique identifier of the type of error. Enables quick recognition and categorization of the issue.

Returns:

  • (String)


16
17
18
# File 'lib/seam/resources/user_identity.rb', line 16

def error_code
  @error_code
end

#messageString

Detailed description of the error. Provides insights into the issue and potentially how to rectify it.

Returns:

  • (String)


19
20
21
# File 'lib/seam/resources/user_identity.rb', line 19

def message
  @message
end

Instance Method Details

#created_atTime

Date and time at which Seam created the error.

Returns:

  • (Time)


22
# File 'lib/seam/resources/user_identity.rb', line 22

date_accessor :created_at