Class: Seam::Resources::Webhook

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/webhook.rb

Overview

Represents a webhook that enables you to receive notifications of events. When you create a webhook, specify the endpoint URL at which you want to receive events and the set of event types that you want to receive.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#event_typesObject

Types of events that the webhook should receive.



8
9
10
# File 'lib/seam/resources/webhook.rb', line 8

def event_types
  @event_types
end

#secretObject

Secret associated with the webhook.



10
11
12
# File 'lib/seam/resources/webhook.rb', line 10

def secret
  @secret
end

#urlObject

URL for the webhook.



12
13
14
# File 'lib/seam/resources/webhook.rb', line 12

def url
  @url
end

#webhook_idObject

ID of the webhook.



14
15
16
# File 'lib/seam/resources/webhook.rb', line 14

def webhook_id
  @webhook_id
end