Class: Seam::Resources::Workspace
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Workspace
- Defined in:
- lib/seam/resources/workspace.rb
Overview
Represents a Seam workspace. A workspace is a top-level entity that encompasses all other resources below it, such as devices, connected accounts, and Connect Webviews. Seam provides two types of workspaces. A sandbox workspace is a special type of workspace designed for testing code. Sandbox workspaces offer test device accounts and virtual devices that you can connect and control. This ability to work with virtual devices is quite handy because it removes the need to own physical devices from multiple brands. To connect real devices and systems to Seam, use a production workspace.
Defined Under Namespace
Classes: ConnectWebviewCustomization
Instance Attribute Summary collapse
-
#company_name ⇒ Object
Company name associated with the workspace.
-
#connect_partner_name ⇒ Object
deprecated
Deprecated.
Use
company_nameinstead. -
#is_publishable_key_auth_enabled ⇒ Object
Indicates whether publishable key authentication is enabled for this workspace.
-
#is_sandbox ⇒ Object
Indicates whether the workspace is a sandbox workspace.
-
#is_suspended ⇒ Object
Indicates whether the sandbox workspace is suspended.
-
#name ⇒ Object
Name of the workspace.
-
#organization_id ⇒ Object
ID of the organization to which the workspace belongs, or
nullif the workspace is not assigned to an organization. -
#publishable_key ⇒ Object
Publishable key for the workspace.
-
#workspace_id ⇒ Object
ID of the workspace.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#company_name ⇒ Object
Company name associated with the workspace.
22 23 24 |
# File 'lib/seam/resources/workspace.rb', line 22 def company_name @company_name end |
#connect_partner_name ⇒ Object
Use company_name instead.
24 25 26 |
# File 'lib/seam/resources/workspace.rb', line 24 def connect_partner_name @connect_partner_name end |
#is_publishable_key_auth_enabled ⇒ Object
Indicates whether publishable key authentication is enabled for this workspace.
26 27 28 |
# File 'lib/seam/resources/workspace.rb', line 26 def is_publishable_key_auth_enabled @is_publishable_key_auth_enabled end |
#is_sandbox ⇒ Object
Indicates whether the workspace is a sandbox workspace.
28 29 30 |
# File 'lib/seam/resources/workspace.rb', line 28 def is_sandbox @is_sandbox end |
#is_suspended ⇒ Object
Indicates whether the sandbox workspace is suspended. Seam suspends sandbox workspaces that have not been accessed in 14 days.
30 31 32 |
# File 'lib/seam/resources/workspace.rb', line 30 def is_suspended @is_suspended end |
#name ⇒ Object
Name of the workspace.
32 33 34 |
# File 'lib/seam/resources/workspace.rb', line 32 def name @name end |
#organization_id ⇒ Object
ID of the organization to which the workspace belongs, or null if the workspace is not assigned to an organization.
34 35 36 |
# File 'lib/seam/resources/workspace.rb', line 34 def organization_id @organization_id end |
#publishable_key ⇒ Object
Publishable key for the workspace. This key is used to identify the workspace in client-side applications.
36 37 38 |
# File 'lib/seam/resources/workspace.rb', line 36 def publishable_key @publishable_key end |
#workspace_id ⇒ Object
ID of the workspace.
38 39 40 |
# File 'lib/seam/resources/workspace.rb', line 38 def workspace_id @workspace_id end |