Class: Seam::Resources::Workspace

Inherits:
BaseResource show all
Defined in:
lib/seam/resources/workspace.rb

Overview

Represents a Seam workspace. A workspace is a top-level entity that encompasses all other resources below it, such as devices, connected accounts, and Connect Webviews. Seam provides two types of workspaces. A sandbox workspace is a special type of workspace designed for testing code. Sandbox workspaces offer test device accounts and virtual devices that you can connect and control. This ability to work with virtual devices is quite handy because it removes the need to own physical devices from multiple brands. To connect real devices and systems to Seam, use a production workspace.

Instance Attribute Summary collapse

Attributes inherited from BaseResource

#client, #data

Method Summary

Methods inherited from BaseResource

date_accessor, #initialize, #inspect, load_from_response, #update_from_response

Constructor Details

This class inherits a constructor from Seam::Resources::BaseResource

Instance Attribute Details

#company_nameObject

Company name associated with the workspace.



8
9
10
# File 'lib/seam/resources/workspace.rb', line 8

def company_name
  @company_name
end

#connect_partner_nameObject

Deprecated.

Use company_name instead.



10
11
12
# File 'lib/seam/resources/workspace.rb', line 10

def connect_partner_name
  @connect_partner_name
end

#connect_webview_customizationObject

Returns the value of attribute connect_webview_customization.



11
12
13
# File 'lib/seam/resources/workspace.rb', line 11

def connect_webview_customization
  @connect_webview_customization
end

#is_publishable_key_auth_enabledObject

Indicates whether publishable key authentication is enabled for this workspace.



13
14
15
# File 'lib/seam/resources/workspace.rb', line 13

def is_publishable_key_auth_enabled
  @is_publishable_key_auth_enabled
end

#is_sandboxObject

Indicates whether the workspace is a sandbox workspace.



15
16
17
# File 'lib/seam/resources/workspace.rb', line 15

def is_sandbox
  @is_sandbox
end

#is_suspendedObject

Indicates whether the sandbox workspace is suspended. Seam suspends sandbox workspaces that have not been accessed in 14 days.



17
18
19
# File 'lib/seam/resources/workspace.rb', line 17

def is_suspended
  @is_suspended
end

#nameObject

Name of the workspace.



19
20
21
# File 'lib/seam/resources/workspace.rb', line 19

def name
  @name
end

#organization_idObject

ID of the organization to which the workspace belongs, or null if the workspace is not assigned to an organization.



21
22
23
# File 'lib/seam/resources/workspace.rb', line 21

def organization_id
  @organization_id
end

#publishable_keyObject

Publishable key for the workspace. This key is used to identify the workspace in client-side applications.



23
24
25
# File 'lib/seam/resources/workspace.rb', line 23

def publishable_key
  @publishable_key
end

#workspace_idObject

ID of the workspace.



25
26
27
# File 'lib/seam/resources/workspace.rb', line 25

def workspace_id
  @workspace_id
end