Class: Seam::Resources::Workspace::ConnectWebviewCustomization
- Inherits:
-
BaseResource
- Object
- BaseResource
- Seam::Resources::Workspace::ConnectWebviewCustomization
- Defined in:
- lib/seam/resources/workspace.rb
Instance Attribute Summary collapse
-
#inviter_logo_url ⇒ Object
URL of the inviter logo for Connect Webviews in the workspace.
-
#logo_shape ⇒ Object
Logo shape for Connect Webviews in the workspace.
-
#primary_button_color ⇒ Object
Primary button color for Connect Webviews in the workspace.
-
#primary_button_text_color ⇒ Object
Primary button text color for Connect Webviews in the workspace.
-
#success_message ⇒ Object
Success message for Connect Webviews in the workspace.
Attributes inherited from BaseResource
Method Summary
Methods inherited from BaseResource
#[], date_accessor, #initialize, #inspect, load_from_response, resource_accessor, resource_accessors, resource_list_accessor, resource_list_accessors, #update_from_response
Constructor Details
This class inherits a constructor from Seam::Resources::BaseResource
Instance Attribute Details
#inviter_logo_url ⇒ Object
URL of the inviter logo for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.
9 10 11 |
# File 'lib/seam/resources/workspace.rb', line 9 def inviter_logo_url @inviter_logo_url end |
#logo_shape ⇒ Object
Logo shape for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.
11 12 13 |
# File 'lib/seam/resources/workspace.rb', line 11 def logo_shape @logo_shape end |
#primary_button_color ⇒ Object
Primary button color for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.
13 14 15 |
# File 'lib/seam/resources/workspace.rb', line 13 def @primary_button_color end |
#primary_button_text_color ⇒ Object
Primary button text color for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.
15 16 17 |
# File 'lib/seam/resources/workspace.rb', line 15 def @primary_button_text_color end |
#success_message ⇒ Object
Success message for Connect Webviews in the workspace. See also Customize the Look and Feel of Your Connect Webviews.
17 18 19 |
# File 'lib/seam/resources/workspace.rb', line 17 def @success_message end |